@@ -7,6 +7,10 @@
 #include <stdlib.h>
 #include "utils.h"
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 /*
  * ** PeekToken: returns next token from string, leaving string intact
  * **            (you should free returned string later)
