@@ -30,39 +30,42 @@
 #include "xfce-common.h"
 #include "constant.h"
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 static GtkWidget *fileselect;
 static char *result = NULL;
 
-static void 
-ok_cb (GtkWidget *twidget, gpointer data)
+static void
+ok_cb (GtkWidget * twidget, gpointer data)
 {
   char *filename = (char *) data;
-  strcpy(filename, gtk_file_selection_get_filename (GTK_FILE_SELECTION (fileselect)));
+  strcpy (filename,
+	  gtk_file_selection_get_filename (GTK_FILE_SELECTION (fileselect)));
   result = filename;
   gtk_widget_destroy (fileselect);
-  gtk_main_quit();
+  gtk_main_quit ();
 }
 
-static void 
-cancel_cb (GtkWidget *twidget)
+static void
+cancel_cb (GtkWidget * twidget)
 {
   result = NULL;
   gtk_widget_destroy (fileselect);
-  gtk_main_quit();
+  gtk_main_quit ();
 }
 
 static gboolean
-delete_event( GtkWidget *widget,
-	      GdkEvent  *event,
-	      gpointer   data )
+delete_event (GtkWidget * widget, GdkEvent * event, gpointer data)
 {
   gtk_widget_destroy (fileselect);
-  gtk_main_quit();
+  gtk_main_quit ();
   return (TRUE);
 }
 
 char *
-open_fileselect (char * pat)
+open_fileselect (char *pat)
 {
   GtkWidget *fileselect_ok_button;
   GtkWidget *fileselect_cancel_button;
@@ -71,7 +74,7 @@ open_fileselect (char * pat)
   static char filename[MAXSTRLEN];
   char pattern[MAXSTRLEN];
   char *slash;
-  
+
 
 
   fileselect = gtk_file_selection_new (_("Select File"));
@@ -86,53 +89,53 @@ open_fileselect (char * pat)
 
   fileselect_ok_button = GTK_FILE_SELECTION (fileselect)->ok_button;
   gtk_widget_set_name (fileselect_ok_button, "fileselect_ok_button");
-  gtk_object_set_data (GTK_OBJECT (fileselect), "fileselect_ok_button", fileselect_ok_button);
+  gtk_object_set_data (GTK_OBJECT (fileselect), "fileselect_ok_button",
+		       fileselect_ok_button);
   gtk_widget_show (fileselect_ok_button);
   GTK_WIDGET_SET_FLAGS (fileselect_ok_button, GTK_CAN_DEFAULT);
 
   fileselect_cancel_button = GTK_FILE_SELECTION (fileselect)->cancel_button;
   gtk_widget_set_name (fileselect_cancel_button, "fileselect_cancel_button");
-  gtk_object_set_data (GTK_OBJECT (fileselect), "fileselect_cancel_button", fileselect_cancel_button);
+  gtk_object_set_data (GTK_OBJECT (fileselect), "fileselect_cancel_button",
+		       fileselect_cancel_button);
   gtk_widget_show (fileselect_cancel_button);
   GTK_WIDGET_SET_FLAGS (fileselect_cancel_button, GTK_CAN_DEFAULT);
 
   gtk_signal_connect (GTK_OBJECT (fileselect_ok_button), "clicked",
-		          GTK_SIGNAL_FUNC (ok_cb),
-		          (gpointer) filename);
+		      GTK_SIGNAL_FUNC (ok_cb), (gpointer) filename);
   gtk_signal_connect (GTK_OBJECT (fileselect_cancel_button), "clicked",
-		          GTK_SIGNAL_FUNC (cancel_cb),
-		          NULL);
+		      GTK_SIGNAL_FUNC (cancel_cb), NULL);
 
   gtk_signal_connect (GTK_OBJECT (fileselect), "delete_event",
-                          GTK_SIGNAL_FUNC (delete_event), NULL);
+		      GTK_SIGNAL_FUNC (delete_event), NULL);
 
   gtk_signal_connect (GTK_OBJECT (fileselect), "destroy",
-                      GTK_SIGNAL_FUNC (delete_event), NULL);
+		      GTK_SIGNAL_FUNC (delete_event), NULL);
 
   gtk_widget_add_accelerator (fileselect_ok_button, "clicked", accel_group,
-                              GDK_Return, 0, GTK_ACCEL_VISIBLE);
+			      GDK_Return, 0, GTK_ACCEL_VISIBLE);
   gtk_widget_add_accelerator (fileselect_ok_button, "clicked", accel_group,
-                              GDK_o, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
-  gtk_widget_add_accelerator (fileselect_cancel_button, "clicked", accel_group,
-                              GDK_Escape, 0, GTK_ACCEL_VISIBLE);
-  gtk_widget_add_accelerator (fileselect_cancel_button, "clicked", accel_group,
-                              GDK_c, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
+			      GDK_o, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
+  gtk_widget_add_accelerator (fileselect_cancel_button, "clicked",
+			      accel_group, GDK_Escape, 0, GTK_ACCEL_VISIBLE);
+  gtk_widget_add_accelerator (fileselect_cancel_button, "clicked",
+			      accel_group, GDK_c, GDK_CONTROL_MASK,
+			      GTK_ACCEL_VISIBLE);
 
 
   /* gtk_file_selection_hide_fileop_buttons(GTK_FILE_SELECTION (fileselect)); */
-  if ((pat) && strlen(pat))
+  if ((pat) && strlen (pat))
     {
       strcpy (pattern, pat);
       slash = strrchr (pattern, '/');
       if (slash)
-        *(++slash) = '\0';
-      gtk_file_selection_complete(GTK_FILE_SELECTION (fileselect), pattern);
+	*(++slash) = '\0';
+      gtk_file_selection_complete (GTK_FILE_SELECTION (fileselect), pattern);
     }
-  gtk_window_set_modal (GTK_WINDOW(fileselect),TRUE);
+  gtk_window_set_modal (GTK_WINDOW (fileselect), TRUE);
   result = NULL;
-  gtk_widget_show(fileselect);
-  gtk_main();
+  gtk_widget_show (fileselect);
+  gtk_main ();
 
   return result;
 }
-
