@@ -42,101 +42,104 @@
 #include "snprintf.h"
 #endif
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 static char *question[] = {
-"    32    32        2            1",
-". s mask  c none",
-"# c #000000",
-"................................",
-"................................",
-"................................",
-"................................",
-"................................",
-".........##########.............",
-"........##.#.#.#.#.#............",
-".......##.#.#.#.#.#.#...........",
-"......##.#.#######.#.#..........",
-"......#.#.###########.#.........",
-"......##.###########.#..........",
-"......#.#.###.#.#####.#.........",
-"......##.#####.#####.#.#........",
-"......#.#.###.#.#####.#.#.......",
-"......##.#.#.#.#####.#.#.#......",
-"......#.#.#.#.#####.#.#.........",
-"......##.#.#.#####.#.#..........",
-".......##.#.#####.#.#.#.........",
-"........##.#.###.#.#.#..........",
-".........##.#####.#.#...........",
-"..........##.#.#.#.#.#..........",
-"..........#.#.#.#.#.#...........",
-"..........##.###.#..............",
-"..........#.#####.#.............",
-"..........##.###.#..............",
-".........##.#.#.#.#.............",
-".........#.#.#.#.#.#............",
-"................................",
-"................................",
-"................................",
-"................................",
-"................................"
+  "    32    32        2            1",
+  ". s mask  c none",
+  "# c #000000",
+  "................................",
+  "................................",
+  "................................",
+  "................................",
+  "................................",
+  ".........##########.............",
+  "........##.#.#.#.#.#............",
+  ".......##.#.#.#.#.#.#...........",
+  "......##.#.#######.#.#..........",
+  "......#.#.###########.#.........",
+  "......##.###########.#..........",
+  "......#.#.###.#.#####.#.........",
+  "......##.#####.#####.#.#........",
+  "......#.#.###.#.#####.#.#.......",
+  "......##.#.#.#.#####.#.#.#......",
+  "......#.#.#.#.#####.#.#.........",
+  "......##.#.#.#####.#.#..........",
+  ".......##.#.#####.#.#.#.........",
+  "........##.#.###.#.#.#..........",
+  ".........##.#####.#.#...........",
+  "..........##.#.#.#.#.#..........",
+  "..........#.#.#.#.#.#...........",
+  "..........##.###.#..............",
+  "..........#.#####.#.............",
+  "..........##.###.#..............",
+  ".........##.#.#.#.#.............",
+  ".........#.#.#.#.#.#............",
+  "................................",
+  "................................",
+  "................................",
+  "................................",
+  "................................"
 };
 
 static char *warning[] = {
-"    32    32        2            1",
-". s mask  c none",
-"# c #000000",
-"................................",
-"................................",
-"................................",
-"................................",
-"................................",
-".........##########.............",
-"........##.#.#.#.#.#............",
-".......##.#.#.#.#.#.#...........",
-"......##.#.#.###.#.#.#..........",
-"......#.#.#.#####.#.#.#.........",
-"......##.#.#######.#.#..........",
-"......#.#.#.#####.#.#.#.........",
-"......##.#.#######.###.#........",
-"......#.#.#.#####.#.#.#.#.......",
-"......##.#.#.###.#.#.#.#.#......",
-"......#.#.#.#####.#.#.#.........",
-"......##.#.#.###.#.#.#..........",
-".......##.#.#####.#.#.#.........",
-"........##.#.###.#.#.#..........",
-".........##.#####.#.#...........",
-"..........##.#.#.#.#.#..........",
-"..........#.#.#.#.#.#...........",
-"..........##.###.#..............",
-"..........#.#####.#.............",
-"..........##.###.#..............",
-".........##.#.#.#.#.............",
-".........#.#.#.#.#.#............",
-"................................",
-"................................",
-"................................",
-"................................",
-"................................"
+  "    32    32        2            1",
+  ". s mask  c none",
+  "# c #000000",
+  "................................",
+  "................................",
+  "................................",
+  "................................",
+  "................................",
+  ".........##########.............",
+  "........##.#.#.#.#.#............",
+  ".......##.#.#.#.#.#.#...........",
+  "......##.#.#.###.#.#.#..........",
+  "......#.#.#.#####.#.#.#.........",
+  "......##.#.#######.#.#..........",
+  "......#.#.#.#####.#.#.#.........",
+  "......##.#.#######.###.#........",
+  "......#.#.#.#####.#.#.#.#.......",
+  "......##.#.#.###.#.#.#.#.#......",
+  "......#.#.#.#####.#.#.#.........",
+  "......##.#.#.###.#.#.#..........",
+  ".......##.#.#####.#.#.#.........",
+  "........##.#.###.#.#.#..........",
+  ".........##.#####.#.#...........",
+  "..........##.#.#.#.#.#..........",
+  "..........#.#.#.#.#.#...........",
+  "..........##.###.#..............",
+  "..........#.#####.#.............",
+  "..........##.###.#..............",
+  ".........##.#.#.#.#.............",
+  ".........#.#.#.#.#.#............",
+  "................................",
+  "................................",
+  "................................",
+  "................................",
+  "................................"
 };
 
-GtkWidget*
-get_widget                             (GtkWidget       *widget,
-                                        gchar           *widget_name)
+GtkWidget *
+get_widget (GtkWidget * widget, gchar * widget_name)
 {
   GtkWidget *parent, *found_widget;
 
   for (;;)
     {
       if (GTK_IS_MENU (widget))
-        parent = gtk_menu_get_attach_widget (GTK_MENU (widget));
+	parent = gtk_menu_get_attach_widget (GTK_MENU (widget));
       else
-        parent = widget->parent;
+	parent = widget->parent;
       if (parent == NULL)
-        break;
+	break;
       widget = parent;
     }
 
-  found_widget = (GtkWidget*) gtk_object_get_data (GTK_OBJECT (widget),
-                                                   widget_name);
+  found_widget = (GtkWidget *) gtk_object_get_data (GTK_OBJECT (widget),
+						    widget_name);
   if (!found_widget)
     g_warning ("Widget not found: %s", widget_name);
   return found_widget;
@@ -144,40 +147,41 @@ get_widget                             (GtkWidget       *widget,
 
 /* This is an internally used function to set notebook tab widgets. */
 void
-set_notebook_tab                       (GtkWidget       *notebook,
-                                        gint             page_num,
-                                        GtkWidget       *widget)
+set_notebook_tab (GtkWidget * notebook, gint page_num, GtkWidget * widget)
 {
   GtkNotebookPage *page;
   GtkWidget *notebook_page;
 
-  page = (GtkNotebookPage*) g_list_nth (GTK_NOTEBOOK (notebook)->children, page_num)->data;
+  page =
+    (GtkNotebookPage *) g_list_nth (GTK_NOTEBOOK (notebook)->children,
+				    page_num)->data;
   notebook_page = page->child;
   gtk_widget_ref (notebook_page);
   gtk_notebook_remove_page (GTK_NOTEBOOK (notebook), page_num);
   gtk_notebook_insert_page (GTK_NOTEBOOK (notebook), notebook_page,
-                            widget, page_num);
+			    widget, page_num);
   gtk_widget_unref (notebook_page);
 }
 
 void
-lock_size (GtkWidget *toplevel)
+lock_size (GtkWidget * toplevel)
 {
   GdkGeometry geometry;
   GdkWindowHints geometry_mask;
   gint uwidth = 0;
   gint uheight = 0;
 
-  gdk_window_get_size(((GtkWidget *) toplevel)->window, &uwidth, &uheight);
+  gdk_window_get_size (((GtkWidget *) toplevel)->window, &uwidth, &uheight);
 
   geometry_mask = GDK_HINT_MAX_SIZE | GDK_HINT_MIN_SIZE | GDK_HINT_BASE_SIZE;
   geometry.min_width = geometry.max_width = geometry.base_width = uwidth;
   geometry.min_height = geometry.max_height = geometry.base_height = uheight;
-  gtk_window_set_geometry_hints (GTK_WINDOW (toplevel), toplevel, &geometry, geometry_mask);
+  gtk_window_set_geometry_hints (GTK_WINDOW (toplevel), toplevel, &geometry,
+				 geometry_mask);
 }
 
 void
-set_icon(GtkWidget *toplevel, gchar *name,  gchar **data)
+set_icon (GtkWidget * toplevel, gchar * name, gchar ** data)
 {
   GdkPixmap *icon;
   GdkBitmap *mask;
@@ -185,11 +189,14 @@ set_icon(GtkWidget *toplevel, gchar *name,  gchar **data)
 
   if (!GTK_WIDGET_REALIZED (toplevel))
     gtk_widget_realize (toplevel);
-  style = gtk_widget_get_style( toplevel );
-  icon = gdk_pixmap_create_from_xpm_d (toplevel->window, &mask, &style->bg[GTK_STATE_NORMAL],(gchar **)data);
+  style = gtk_widget_get_style (toplevel);
+  icon =
+    gdk_pixmap_create_from_xpm_d (toplevel->window, &mask,
+				  &style->bg[GTK_STATE_NORMAL],
+				  (gchar **) data);
 
   gdk_window_set_icon (toplevel->window, NULL, icon, mask);
-      
+
   gdk_window_set_icon_name (toplevel->window, name);
 }
 
@@ -200,20 +207,19 @@ set_icon(GtkWidget *toplevel, gchar *name,  gchar **data)
 
 static GtkWidget *dialog_show_message;
 
-static void 
-on_ok_show_message (GtkWidget *twidget)
+static void
+on_ok_show_message (GtkWidget * twidget)
 {
   gtk_widget_destroy (dialog_show_message);
-  gtk_main_quit();
+  gtk_main_quit ();
 }
 
 static gboolean
-delete_event_show_message( GtkWidget *widget,
-	      GdkEvent  *event,
-	      gpointer   data )
+delete_event_show_message (GtkWidget * widget,
+			   GdkEvent * event, gpointer data)
 {
   gtk_widget_destroy (dialog_show_message);
-  gtk_main_quit();
+  gtk_main_quit ();
   return (TRUE);
 }
 
@@ -235,49 +241,49 @@ my_show_message (gchar * message)
 
   hbox = gtk_hbox_new (FALSE, 0);
   gtk_container_border_width (GTK_CONTAINER (hbox), 5);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog_show_message)->vbox), hbox, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog_show_message)->vbox), hbox,
+		      TRUE, TRUE, 0);
   gtk_widget_show (hbox);
 
-  style = gtk_widget_get_style( dialog_show_message );
-  pixmap = gdk_pixmap_create_from_xpm_d( dialog_show_message->window,  &mask,
-                                           &style->bg[GTK_STATE_NORMAL],
-                                           (gchar **)warning );
+  style = gtk_widget_get_style (dialog_show_message);
+  pixmap = gdk_pixmap_create_from_xpm_d (dialog_show_message->window, &mask,
+					 &style->bg[GTK_STATE_NORMAL],
+					 (gchar **) warning);
 
   /* a pixmap widget to contain the pixmap */
-  pixmapwid = gtk_pixmap_new( pixmap, mask );
-  gdk_pixmap_unref( pixmap );
-  gtk_widget_show( pixmapwid );
+  pixmapwid = gtk_pixmap_new (pixmap, mask);
+  gdk_pixmap_unref (pixmap);
+  gtk_widget_show (pixmapwid);
   gtk_box_pack_start (GTK_BOX (hbox), pixmapwid, FALSE, FALSE, 0);
-  
+
   label = gtk_label_new (message);
   gtk_misc_set_padding (GTK_MISC (label), 20, 20);
-  gtk_box_pack_start (GTK_BOX (hbox), label,
-		      TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
   gtk_widget_show (label);
 
   button = gtk_button_new_with_label (_("OK"));
   gtk_widget_set_usize (button, 80, -1);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog_show_message)->action_area), button,
-		      FALSE, FALSE, 14);
+  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog_show_message)->action_area),
+		      button, FALSE, FALSE, 14);
   GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
   gtk_widget_grab_default (button);
   gtk_widget_show (button);
 
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
-			     GTK_SIGNAL_FUNC (on_ok_show_message),
-			     GTK_OBJECT (dialog_show_message));
+		      GTK_SIGNAL_FUNC (on_ok_show_message),
+		      GTK_OBJECT (dialog_show_message));
 
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
-        		     GTK_SIGNAL_FUNC (gtk_widget_destroy),
-			     GTK_OBJECT (dialog_show_message));
+		      GTK_SIGNAL_FUNC (gtk_widget_destroy),
+		      GTK_OBJECT (dialog_show_message));
   gtk_signal_connect (GTK_OBJECT (dialog_show_message), "delete_event",
-                      GTK_SIGNAL_FUNC (delete_event_show_message), NULL);
+		      GTK_SIGNAL_FUNC (delete_event_show_message), NULL);
   gtk_signal_connect (GTK_OBJECT (dialog_show_message), "destroy",
-                      GTK_SIGNAL_FUNC (on_ok_show_message), NULL);
-  gtk_window_set_modal (GTK_WINDOW(dialog_show_message),TRUE);
-  gtk_window_set_title (GTK_WINDOW(dialog_show_message),_("Message"));
+		      GTK_SIGNAL_FUNC (on_ok_show_message), NULL);
+  gtk_window_set_modal (GTK_WINDOW (dialog_show_message), TRUE);
+  gtk_window_set_title (GTK_WINDOW (dialog_show_message), _("Message"));
   gtk_widget_show (dialog_show_message);
-  gtk_main();
+  gtk_main ();
 }
 
 
@@ -295,13 +301,12 @@ my_show_message (gchar * message)
      dialog = my_util_show_dialog ("Do you want to save the current project?", 3, buttons, 3, signal_handlers, NULL);
      gtk_widget_show (dialog);
  */
-GtkWidget*
-my_show_dialog (  gchar * message,
-		       gint nbuttons,
-		       gchar * buttons[],
-		       gint default_button,
-		       GtkSignalFunc signal_handlers[],
-		       gpointer data)
+GtkWidget *
+my_show_dialog (gchar * message,
+		gint nbuttons,
+		gchar * buttons[],
+		gint default_button,
+		GtkSignalFunc signal_handlers[], gpointer data)
 {
   GtkWidget *dialog, *hbox, *label, *button, *bbox, *pixmapwid;
   GdkPixmap *pixmap;
@@ -311,7 +316,7 @@ my_show_dialog (  gchar * message,
 
   dialog = gtk_dialog_new ();
   gtk_window_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
-  gtk_window_set_policy(GTK_WINDOW(dialog), TRUE, TRUE, FALSE);
+  gtk_window_set_policy (GTK_WINDOW (dialog), TRUE, TRUE, FALSE);
   gtk_container_border_width (GTK_CONTAINER (dialog), 5);
 
   gtk_widget_realize (dialog);
@@ -323,17 +328,17 @@ my_show_dialog (  gchar * message,
 		      TRUE, TRUE, 0);
   gtk_widget_show (hbox);
 
-  style = gtk_widget_get_style( dialog );
-  pixmap = gdk_pixmap_create_from_xpm_d( dialog->window,  &mask,
-                                           &style->bg[GTK_STATE_NORMAL],
-                                           (gchar **)question );
+  style = gtk_widget_get_style (dialog);
+  pixmap = gdk_pixmap_create_from_xpm_d (dialog->window, &mask,
+					 &style->bg[GTK_STATE_NORMAL],
+					 (gchar **) question);
 
   /* a pixmap widget to contain the pixmap */
-  pixmapwid = gtk_pixmap_new( pixmap, mask );
-  gdk_pixmap_unref( pixmap );
-  gtk_widget_show( pixmapwid );
+  pixmapwid = gtk_pixmap_new (pixmap, mask);
+  gdk_pixmap_unref (pixmap);
+  gtk_widget_show (pixmapwid);
   gtk_box_pack_start (GTK_BOX (hbox), pixmapwid, FALSE, FALSE, 0);
-  
+
 
   label = gtk_label_new (message);
   gtk_misc_set_padding (GTK_MISC (label), 20, 20);
@@ -357,12 +362,12 @@ my_show_dialog (  gchar * message,
       gtk_widget_show (button);
 
       if (signal_handlers[i])
-	gtk_signal_connect (GTK_OBJECT (button), "clicked", signal_handlers[i],
-			    data);
+	gtk_signal_connect (GTK_OBJECT (button), "clicked",
+			    signal_handlers[i], data);
 
       gtk_signal_connect (GTK_OBJECT (button), "clicked",
-				 GTK_SIGNAL_FUNC (gtk_widget_destroy),
-				 GTK_OBJECT (dialog));
+			  GTK_SIGNAL_FUNC (gtk_widget_destroy),
+			  GTK_OBJECT (dialog));
     }
   return dialog;
 }
@@ -370,48 +375,48 @@ my_show_dialog (  gchar * message,
 static GtkWidget *dialog_yesno_dialog;
 static int rep_yesno_dialog = 0;
 
-static void 
-on_yes_yesno_dialog (GtkWidget *twidget)
+static void
+on_yes_yesno_dialog (GtkWidget * twidget)
 {
   rep_yesno_dialog = 1;
   gtk_widget_destroy (dialog_yesno_dialog);
-  gtk_main_quit();
+  gtk_main_quit ();
 }
 
-static void 
-on_no_yesno_dialog (GtkWidget *twidget)
+static void
+on_no_yesno_dialog (GtkWidget * twidget)
 {
   rep_yesno_dialog = 0;
   gtk_widget_destroy (dialog_yesno_dialog);
-  gtk_main_quit();
+  gtk_main_quit ();
 }
 
 static gboolean
-delete_event_yesno_dialog( GtkWidget *widget,
-	      GdkEvent  *event,
-	      gpointer   data )
+delete_event_yesno_dialog (GtkWidget * widget,
+			   GdkEvent * event, gpointer data)
 {
   gtk_widget_destroy (dialog_yesno_dialog);
-  gtk_main_quit();
+  gtk_main_quit ();
   return (TRUE);
 }
 
-gint
-my_yesno_dialog (gchar * message)
+gint my_yesno_dialog (gchar * message)
 {
   /* FIXME : how make this short and ANSI ? */
   gchar *buttons[] = { _("Yes"), _("No") };
-  
-  GtkSignalFunc signal_handlers[] = { on_yes_yesno_dialog, on_no_yesno_dialog };
-  dialog_yesno_dialog = my_show_dialog (message, 2, buttons, 2, signal_handlers, NULL);
+
+  GtkSignalFunc signal_handlers[] =
+    { on_yes_yesno_dialog, on_no_yesno_dialog };
+  dialog_yesno_dialog =
+    my_show_dialog (message, 2, buttons, 2, signal_handlers, NULL);
   gtk_signal_connect (GTK_OBJECT (dialog_yesno_dialog), "delete_event",
 		      GTK_SIGNAL_FUNC (delete_event_yesno_dialog), NULL);
   gtk_signal_connect (GTK_OBJECT (dialog_yesno_dialog), "destroy",
-                      GTK_SIGNAL_FUNC (delete_event_yesno_dialog), NULL);
-  gtk_window_set_modal (GTK_WINDOW(dialog_yesno_dialog),TRUE);
-  gtk_window_set_title (GTK_WINDOW(dialog_yesno_dialog),_("Question"));
+		      GTK_SIGNAL_FUNC (delete_event_yesno_dialog), NULL);
+  gtk_window_set_modal (GTK_WINDOW (dialog_yesno_dialog), TRUE);
+  gtk_window_set_title (GTK_WINDOW (dialog_yesno_dialog), _("Question"));
   gtk_widget_show (dialog_yesno_dialog);
-  gtk_main();
+  gtk_main ();
   return rep_yesno_dialog;
 }
 
@@ -421,46 +426,47 @@ refresh_screen (void)
   XSetWindowAttributes attributes;
   unsigned long valuemask;
   Window w;
-  
-  valuemask = CWOverrideRedirect | CWBackingStore | CWSaveUnder | CWBackPixmap;
+
+  valuemask =
+    CWOverrideRedirect | CWBackingStore | CWSaveUnder | CWBackPixmap;
   attributes.override_redirect = True;
   attributes.save_under = False;
   attributes.background_pixmap = None;
   attributes.backing_store = NotUseful;
-  w = XCreateWindow (GDK_DISPLAY(), GDK_WINDOW_XWINDOW(GDK_ROOT_PARENT()), 0, 0,
-                     (unsigned int)  gdk_screen_width (),
-                     (unsigned int) gdk_screen_height (),
-                     (unsigned int) 0,
-                     CopyFromParent, (unsigned int) CopyFromParent,
-                     (Visual *) CopyFromParent, valuemask,
-                     &attributes);
-  XMapWindow (GDK_DISPLAY(), w);
-  XDestroyWindow (GDK_DISPLAY(), w);
-  XFlush (GDK_DISPLAY());
+  w =
+    XCreateWindow (GDK_DISPLAY (), GDK_WINDOW_XWINDOW (GDK_ROOT_PARENT ()), 0,
+		   0, (unsigned int) gdk_screen_width (),
+		   (unsigned int) gdk_screen_height (), (unsigned int) 0,
+		   CopyFromParent, (unsigned int) CopyFromParent,
+		   (Visual *) CopyFromParent, valuemask, &attributes);
+  XMapWindow (GDK_DISPLAY (), w);
+  XDestroyWindow (GDK_DISPLAY (), w);
+  XFlush (GDK_DISPLAY ());
 }
 
 char *
-build_path(char *value)
+build_path (char *value)
 {
   static char filename[MAXSTRLEN];
   char *path;
-  
+
   path = (char *) getenv ("XFCE_DATA");
-  if (path) 
+  if (path)
     strcpy (filename, path);
   else
     strcpy (filename, XFCE_DIR);
-    
-  if ((value) && strlen(value))
+
+  if ((value) && strlen (value))
     strcat (filename, value);
-    
+
   return filename;
 }
 
 void
-update_events(void)
+update_events (void)
 {
-   while (gtk_events_pending()) gtk_main_iteration_do(TRUE);
+  while (gtk_events_pending ())
+    gtk_main_iteration_do (TRUE);
 }
 
 /*** the next three routines are taken straight from gnome-libs so that the
@@ -471,11 +477,11 @@ update_events(void)
  *
  * Releases all of the resources allocated by @list.
  */
-void          
-gnome_uri_list_free_strings      (GList *list)
+void
+gnome_uri_list_free_strings (GList * list)
 {
-	g_list_foreach (list, (GFunc)g_free, NULL);
-	g_list_free (list);
+  g_list_foreach (list, (GFunc) g_free, NULL);
+  g_list_free (list);
 }
 
 
@@ -486,49 +492,52 @@ gnome_uri_list_free_strings      (GList *list)
  * Returns a GList containing strings allocated with g_malloc
  * that have been splitted from @uri-list.
  */
-GList*        
-gnome_uri_list_extract_uris (const gchar* uri_list)
+GList *
+gnome_uri_list_extract_uris (const gchar * uri_list)
 {
-	const gchar *p, *q;
-	gchar *retval;
-	GList *result = NULL;
-	
-	g_return_val_if_fail (uri_list != NULL, NULL);
+  const gchar *p, *q;
+  gchar *retval;
+  GList *result = NULL;
 
-	p = uri_list;
-	
-	/* We don't actually try to validate the URI according to RFC
-	 * 2396, or even check for allowed characters - we just ignore
-	 * comments and trim whitespace off the ends.  We also
-	 * allow LF delimination as well as the specified CRLF.
-	 */
-	while (p) {
-		if (*p != '#') {
-			while (isspace((int)(*p)))
-				p++;
-			
-			q = p;
-			while (*q && (*q != '\n') && (*q != '\r'))
-				q++;
-		  
-			if (q > p) {
-			        q--;
-				while (q > p && isspace((int)(*q)))
-					q--;
-				
-				retval = (char *)g_malloc (q - p + 2);
-				strncpy (retval, p, q - p + 1);
-				retval[q - p + 1] = '\0';
-				
-				result = g_list_prepend (result, retval);
-			}
-		}
-		p = strchr (p, '\n');
-		if (p)
-			p++;
+  g_return_val_if_fail (uri_list != NULL, NULL);
+
+  p = uri_list;
+
+  /* We don't actually try to validate the URI according to RFC
+   * 2396, or even check for allowed characters - we just ignore
+   * comments and trim whitespace off the ends.  We also
+   * allow LF delimination as well as the specified CRLF.
+   */
+  while (p)
+    {
+      if (*p != '#')
+	{
+	  while (isspace ((int) (*p)))
+	    p++;
+
+	  q = p;
+	  while (*q && (*q != '\n') && (*q != '\r'))
+	    q++;
+
+	  if (q > p)
+	    {
+	      q--;
+	      while (q > p && isspace ((int) (*q)))
+		q--;
+
+	      retval = (char *) g_malloc (q - p + 2);
+	      strncpy (retval, p, q - p + 1);
+	      retval[q - p + 1] = '\0';
+
+	      result = g_list_prepend (result, retval);
+	    }
 	}
-	
-	return g_list_reverse (result);
+      p = strchr (p, '\n');
+      if (p)
+	p++;
+    }
+
+  return g_list_reverse (result);
 }
 
 
@@ -542,53 +551,58 @@ gnome_uri_list_extract_uris (const gchar* uri_list)
  * Note that unlike gnome_uri_list_extract_uris() function, this
  * will discard any non-file uri from the result value.
  */
-GList*        
-gnome_uri_list_extract_filenames (const gchar* uri_list)
+GList *
+gnome_uri_list_extract_filenames (const gchar * uri_list)
 {
-	GList *tmp_list, *node, *result;
-	
-	g_return_val_if_fail (uri_list != NULL, NULL);
-	
-	result = gnome_uri_list_extract_uris (uri_list);
+  GList *tmp_list, *node, *result;
 
-	tmp_list = result;
-	while (tmp_list) {
-		gchar *s = (char *)tmp_list->data;
-		
-		node = tmp_list;
-		tmp_list = tmp_list->next;
+  g_return_val_if_fail (uri_list != NULL, NULL);
 
-		if (!strncmp (s, "file:", 5)) {
-			node->data = cleanup(g_strdup (s+5));
-		} else {
-			node->data = cleanup(g_strdup (s));
-		}
-		g_free (s);
+  result = gnome_uri_list_extract_uris (uri_list);
+
+  tmp_list = result;
+  while (tmp_list)
+    {
+      gchar *s = (char *) tmp_list->data;
+
+      node = tmp_list;
+      tmp_list = tmp_list->next;
+
+      if (!strncmp (s, "file:", 5))
+	{
+	  node->data = cleanup (g_strdup (s + 5));
 	}
-	return result;
+      else
+	{
+	  node->data = cleanup (g_strdup (s));
+	}
+      g_free (s);
+    }
+  return result;
 }
 
 void
 my_flush_events (void)
 {
-   while (gtk_events_pending()) gtk_main_iteration_do(TRUE);
-   gdk_flush ();
+  while (gtk_events_pending ())
+    gtk_main_iteration_do (TRUE);
+  gdk_flush ();
 }
 
 void
-cursor_wait (GtkWidget *widget)
+cursor_wait (GtkWidget * widget)
 {
-	GdkCursor *cursor;
-	cursor = gdk_cursor_new (GDK_WATCH);
-	gdk_window_set_cursor (widget->window, cursor);
-	gdk_flush ();
-	gdk_cursor_destroy (cursor);
+  GdkCursor *cursor;
+  cursor = gdk_cursor_new (GDK_WATCH);
+  gdk_window_set_cursor (widget->window, cursor);
+  gdk_flush ();
+  gdk_cursor_destroy (cursor);
 }
 
 void
-cursor_reset (GtkWidget *widget)
+cursor_reset (GtkWidget * widget)
 {
-	gdk_window_set_cursor (widget->window, NULL);
+  gdk_window_set_cursor (widget->window, NULL);
 }
 
 void
@@ -644,16 +658,16 @@ on_signal (int sig_num)
 }
 
 void
-signal_setup(void)
+signal_setup (void)
 {
   /* Handle some signals */
-  signal (SIGHUP,  on_signal);
-  signal (SIGINT,  on_signal);
+  signal (SIGHUP, on_signal);
+  signal (SIGINT, on_signal);
   signal (SIGQUIT, on_signal);
   signal (SIGABRT, on_signal);
-  signal (SIGBUS,  on_signal);
+  signal (SIGBUS, on_signal);
   signal (SIGSEGV, on_signal);
   signal (SIGPIPE, on_signal);
   signal (SIGTERM, on_signal);
-  signal (SIGFPE,  on_signal);
+  signal (SIGFPE, on_signal);
 }
