@@ -32,9 +32,7 @@
  * or alternatively any widget in the component, and the name of the widget
  * you want returned.
  */
-GtkWidget*
-get_widget                             (GtkWidget       *widget,
-                                        gchar           *widget_name);
+GtkWidget *get_widget (GtkWidget * widget, gchar * widget_name);
 
 
  /*
@@ -42,21 +40,17 @@ get_widget                             (GtkWidget       *widget,
   * included in this header file so you don't get compilation warnings
   */
 void
-set_notebook_tab                       (GtkWidget       *notebook,
-                                        gint             page_num,
-                                        GtkWidget       *widget);
+set_notebook_tab (GtkWidget * notebook, gint page_num, GtkWidget * widget);
 
-void
-lock_size (GtkWidget *toplevel);
+void lock_size (GtkWidget * toplevel);
 
-void
-set_icon(GtkWidget *, gchar *,  gchar **);
+void set_icon (GtkWidget *, gchar *, gchar **);
 
 /* This shows a simple dialog box with a label and an 'OK' button.
    Example usage:
     my_show_message_box ("Error saving file");
  */
-void	    my_show_message	(gchar		    *message);
+void my_show_message (gchar * message);
 
 
 /* This creates a dialog box with a message and a number of buttons.
@@ -71,47 +65,37 @@ void	    my_show_message	(gchar		    *message);
      my_show_dialog ("Do you want to save the current project?",
 			     3, buttons, 3, signal_handlers, NULL);
  */
-GtkWidget*  my_show_dialog (  gchar	*message,
-				   gint		 nbuttons,
-				   gchar	*buttons[],
-				   gint		 default_button,
-				   GtkSignalFunc signal_handlers[],
-				   gpointer	 data);
+GtkWidget *my_show_dialog (gchar * message,
+			   gint nbuttons,
+			   gchar * buttons[],
+			   gint default_button,
+			   GtkSignalFunc signal_handlers[], gpointer data);
 
 
-gint my_yesno_dialog (gchar *message);
+gint my_yesno_dialog (gchar * message);
 
 void refresh_screen (void);
 
-char * build_path(char *);
+char *build_path (char *);
 
-void update_events(void);
+void update_events (void);
 
-void          
-gnome_uri_list_free_strings      (GList *list);
+void gnome_uri_list_free_strings (GList * list);
 
-GList*        
-gnome_uri_list_extract_uris (const gchar* uri_list);
+GList *gnome_uri_list_extract_uris (const gchar * uri_list);
 
-GList*        
-gnome_uri_list_extract_filenames (const gchar* uri_list);
+GList *gnome_uri_list_extract_filenames (const gchar * uri_list);
 
-void
-my_flush_events (void);
+void my_flush_events (void);
 
-void
-cursor_wait (GtkWidget *widget);
+void cursor_wait (GtkWidget * widget);
 
-void
-cursor_reset (GtkWidget *widget);
+void cursor_reset (GtkWidget * widget);
 
-void
-terminate (char *fmt, ...);
+void terminate (char *fmt, ...);
 
-void
-on_signal (int sig_num);
+void on_signal (int sig_num);
 
-void
-signal_setup(void);
+void signal_setup (void);
 
 #endif
