@@ -36,11 +36,11 @@
 #include <X11/Xutil.h>
 
 #ifdef HAVE_GDK_IMLIB
-  #include <fcntl.h>
-  #include <gdk_imlib.h>
+#include <fcntl.h>
+#include <gdk_imlib.h>
 #else
 #ifdef HAVE_GDK_PIXBUF
-  #include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
 #endif
 #endif
 
@@ -55,10 +55,14 @@
 #include "xfce-common.h"
 #include "empty.h"
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 #include "xfbd_icon.xpm"
 
 void
-display_error(char *s)
+display_error (char *s)
 {
   fprintf (stderr, "%s\n", s);
   my_alert (s);
@@ -68,116 +72,122 @@ int
 setroot (char *str)
 {
 #ifdef HAVE_GDK_IMLIB
-  GdkImlibImage         *im;
-  GdkPixmapPrivate      *pixmap_private;
-  GdkPixmap             *rootXpm       = 0;
-  Pixmap                 xpixmap;
+  GdkImlibImage *im;
+  GdkPixmapPrivate *pixmap_private;
+  GdkPixmap *rootXpm = 0;
+  Pixmap xpixmap;
 #else
 #ifdef HAVE_GDK_PIXBUF
-  GdkPixmapPrivate      *pixmap_private;
-  GdkPixbuf             *Pixbuf;
-  GdkWindow             *root;
-  GdkPixmap             *rootXpm       = 0;
-  GdkBitmap             *shapeMask     = 0;
-  Pixmap                 xpixmap;
+  GdkPixmapPrivate *pixmap_private;
+  GdkPixbuf *Pixbuf;
+  GdkWindow *root;
+  GdkPixmap *rootXpm = 0;
+  GdkBitmap *shapeMask = 0;
+  Pixmap xpixmap;
 #else
   Display *tmpDpy;
   XWindowAttributes root_attr;
   int val;
-  Pixmap                 rootXpm       = 0;
-  Pixmap                 shapeMask     = 0;
-  XpmAttributes          xpm_attributes;
+  Pixmap rootXpm = 0;
+  Pixmap shapeMask = 0;
+  XpmAttributes xpm_attributes;
 #endif /* HAVE_GDK_PIXBUF */
 #endif /* HAVE_GDK_IMLIB */
 
-  int pix_width                 = 0;
-  int pix_height                = 0;
+  int pix_width = 0;
+  int pix_height = 0;
 
   if (my_strncasecmp (str, NOBACK, strlen (NOBACK)) && existfile (str))
     {
 #ifdef HAVE_GDK_IMLIB
-      im=gdk_imlib_load_image(str);
-      if (im) 
-        {
-          if ((im->rgb_width > (gdk_screen_width() / 2)) && (im->rgb_height > (gdk_screen_height() / 2)))
-          {
-            pix_width  = gdk_screen_width();
-            pix_height = gdk_screen_height();
-          }
-          else
-          {
-            pix_width  = im->rgb_width;
-            pix_height = im->rgb_height;
-          }
-          gdk_imlib_render(im,pix_width,pix_height);
-	  rootXpm=gdk_imlib_copy_image(im);
-	  gdk_window_set_back_pixmap(GDK_ROOT_PARENT(), rootXpm, 0);
-	  pixmap_private = (GdkPixmapPrivate*) rootXpm;
-          xpixmap = duppix(pixmap_private->xwindow, pix_width, pix_height);
-          setPixmapProperty(xpixmap);
-          gdk_window_clear(GDK_ROOT_PARENT());
-          gdk_flush();
-          gdk_imlib_destroy_image(im);
+      im = gdk_imlib_load_image (str);
+      if (im)
+	{
+	  if ((im->rgb_width > (gdk_screen_width () / 2))
+	      && (im->rgb_height > (gdk_screen_height () / 2)))
+	    {
+	      pix_width = gdk_screen_width ();
+	      pix_height = gdk_screen_height ();
+	    }
+	  else
+	    {
+	      pix_width = im->rgb_width;
+	      pix_height = im->rgb_height;
+	    }
+	  gdk_imlib_render (im, pix_width, pix_height);
+	  rootXpm = gdk_imlib_copy_image (im);
+	  gdk_window_set_back_pixmap (GDK_ROOT_PARENT (), rootXpm, 0);
+	  pixmap_private = (GdkPixmapPrivate *) rootXpm;
+	  xpixmap = duppix (pixmap_private->xwindow, pix_width, pix_height);
+	  setPixmapProperty (xpixmap);
+	  gdk_window_clear (GDK_ROOT_PARENT ());
+	  gdk_flush ();
+	  gdk_imlib_destroy_image (im);
 	}
-#else     
+#else
 #ifdef HAVE_GDK_PIXBUF
       Pixbuf = gdk_pixbuf_new_from_file (str);
       if (Pixbuf)
-        {
-          if ((gdk_pixbuf_get_width (Pixbuf) > (gdk_screen_width() / 2)) && 
-	      (gdk_pixbuf_get_height (Pixbuf) > (gdk_screen_height() / 2)))
-          {
-            pix_width  = gdk_screen_width();
-            pix_height = gdk_screen_height();
-          }
-          else
-          {
-            pix_width  = gdk_pixbuf_get_width (Pixbuf);
-            pix_height = gdk_pixbuf_get_height (Pixbuf);
-          }
-          gdk_pixbuf_scale_simple (Pixbuf, pix_width, 
-                                           pix_height,
-                                           GDK_INTERP_NEAREST);
-          gdk_pixbuf_render_pixmap_and_mask (Pixbuf, &rootXpm, &shapeMask, 0);
-	  gdk_window_set_back_pixmap(GDK_ROOT_PARENT(), rootXpm, 0);
-	  pixmap_private = (GdkPixmapPrivate*) rootXpm;
-          xpixmap = duppix(pixmap_private->xwindow, pix_width, pix_height);
-          setPixmapProperty(xpixmap);
-          gdk_window_clear(GDK_ROOT_PARENT());
-          gdk_flush();
-          gdk_pixbuf_unref (Pixbuf);
+	{
+	  if ((gdk_pixbuf_get_width (Pixbuf) > (gdk_screen_width () / 2)) &&
+	      (gdk_pixbuf_get_height (Pixbuf) > (gdk_screen_height () / 2)))
+	    {
+	      pix_width = gdk_screen_width ();
+	      pix_height = gdk_screen_height ();
+	    }
+	  else
+	    {
+	      pix_width = gdk_pixbuf_get_width (Pixbuf);
+	      pix_height = gdk_pixbuf_get_height (Pixbuf);
+	    }
+	  gdk_pixbuf_scale_simple (Pixbuf, pix_width,
+				   pix_height, GDK_INTERP_NEAREST);
+	  gdk_pixbuf_render_pixmap_and_mask (Pixbuf, &rootXpm, &shapeMask, 0);
+	  gdk_window_set_back_pixmap (GDK_ROOT_PARENT (), rootXpm, 0);
+	  pixmap_private = (GdkPixmapPrivate *) rootXpm;
+	  xpixmap = duppix (pixmap_private->xwindow, pix_width, pix_height);
+	  setPixmapProperty (xpixmap);
+	  gdk_window_clear (GDK_ROOT_PARENT ());
+	  gdk_flush ();
+	  gdk_pixbuf_unref (Pixbuf);
 	}
 #else
-      if (!(tmpDpy = XOpenDisplay(""))) 
-        return 0;
+      if (!(tmpDpy = XOpenDisplay ("")))
+	return 0;
 
-      XGetWindowAttributes (tmpDpy, GDK_WINDOW_XWINDOW(GDK_ROOT_PARENT()), &root_attr);
+      XGetWindowAttributes (tmpDpy, GDK_WINDOW_XWINDOW (GDK_ROOT_PARENT ()),
+			    &root_attr);
       xpm_attributes.colormap = root_attr.colormap;
       xpm_attributes.valuemask = XpmSize | XpmReturnPixels | XpmColormap;
-      if ((val = XpmReadFileToPixmap (tmpDpy, GDK_WINDOW_XWINDOW(GDK_ROOT_PARENT()), str,
-				      &rootXpm, &shapeMask,
-				      &xpm_attributes)) != XpmSuccess)
+      if (
+	  (val =
+	   XpmReadFileToPixmap (tmpDpy,
+				GDK_WINDOW_XWINDOW (GDK_ROOT_PARENT ()), str,
+				&rootXpm, &shapeMask,
+				&xpm_attributes)) != XpmSuccess)
 	{
 	  if (val == XpmOpenFailed)
-	    display_error(_("Error\nCannot open file"));
+	    display_error (_("Error\nCannot open file"));
 	  else if (val == XpmColorFailed)
-	    display_error(_("Error\nCannot allocate colors"));
+	    display_error (_("Error\nCannot allocate colors"));
 	  else if (val == XpmFileInvalid)
-	    display_error(_("Error\nFile format invalid"));
+	    display_error (_("Error\nFile format invalid"));
 	  else if (val == XpmColorError)
-	    display_error(_("Error\nColor definition invalid"));
+	    display_error (_("Error\nColor definition invalid"));
 	  else if (val == XpmNoMemory)
-	    display_error(_("Error\nNot enough Memory"));
+	    display_error (_("Error\nNot enough Memory"));
 	  return (0);
 	}
-      pix_width  = xpm_attributes.width;
+      pix_width = xpm_attributes.width;
       pix_height = xpm_attributes.height;
-      XSetWindowBackgroundPixmap (tmpDpy, GDK_WINDOW_XWINDOW(GDK_ROOT_PARENT()), rootXpm);
-      setPixmapProperty(rootXpm);
-      XClearWindow (tmpDpy, GDK_WINDOW_XWINDOW(GDK_ROOT_PARENT()));
-      XpmFreeAttributes(&xpm_attributes);
-      XSetCloseDownMode(tmpDpy, RetainPermanent);
-      XCloseDisplay(tmpDpy);
+      XSetWindowBackgroundPixmap (tmpDpy,
+				  GDK_WINDOW_XWINDOW (GDK_ROOT_PARENT ()),
+				  rootXpm);
+      setPixmapProperty (rootXpm);
+      XClearWindow (tmpDpy, GDK_WINDOW_XWINDOW (GDK_ROOT_PARENT ()));
+      XpmFreeAttributes (&xpm_attributes);
+      XSetCloseDownMode (tmpDpy, RetainPermanent);
+      XCloseDisplay (tmpDpy);
 #endif /* HAVE_GDK_PIXBUF */
 #endif /* HAVE_GDK_IMLIB */
     }
@@ -192,7 +202,7 @@ readstr (char *str)
 
   homedir = (char *) malloc ((MAXSTRLEN + 1) * sizeof (char));
   strcpy (homedir, (char *) getenv ("HOME"));
-  strcat (homedir, "/."RCFILE);
+  strcat (homedir, "/." RCFILE);
   if (existfile (homedir))
     {
       f = fopen (homedir, "r");
@@ -201,17 +211,17 @@ readstr (char *str)
     {
       fprintf (stderr, "%s File not found.\n", homedir);
       strcpy (homedir, XFCE_CONFDIR);
-      strcat (homedir, "/"RCFILE);
+      strcat (homedir, "/" RCFILE);
       if (existfile (homedir))
 	{
 	  f = fopen (homedir, "r");
 	}
     }
-  if (f) 
+  if (f)
     {
       fgets (str, FILENAME_MAX - 1, f);
       if (strlen (str))
-        str[strlen (str) - 1] = 0;
+	str[strlen (str) - 1] = 0;
     }
   else
     strcpy (str, NOBACK);
@@ -226,7 +236,7 @@ writestr (char *str)
 
   homedir = (char *) malloc ((MAXSTRLEN + 1) * sizeof (char));
   strcpy (homedir, (char *) getenv ("HOME"));
-  strcat (homedir, "/."RCFILE);
+  strcat (homedir, "/." RCFILE);
 
   if ((f = fopen (homedir, "w")))
     {
@@ -240,13 +250,14 @@ writestr (char *str)
 void
 display_back (char *str)
 {
-  if ((str) && (my_strncasecmp (str, NOBACK, strlen (NOBACK)) && existfile (str)))
+  if ((str)
+      && (my_strncasecmp (str, NOBACK, strlen (NOBACK)) && existfile (str)))
     MySetPixmapFile (preview_pixmap, preview_pixmap_frame, str);
   else
     MySetPixmapData (preview_pixmap, preview_pixmap_frame, empty);
 }
 
-GtkWidget*
+GtkWidget *
 create_xfbd (XFCE_palette * pal)
 {
   GtkWidget *frame1;
@@ -283,7 +294,8 @@ create_xfbd (XFCE_palette * pal)
 
   preview_pixmap_frame = gtk_frame_new (NULL);
   gtk_widget_set_name (preview_pixmap_frame, "preview_pixmap_frame");
-  gtk_object_set_data (GTK_OBJECT (xfbd), "preview_pixmap_frame", preview_pixmap_frame);
+  gtk_object_set_data (GTK_OBJECT (xfbd), "preview_pixmap_frame",
+		       preview_pixmap_frame);
   gtk_widget_set_usize (preview_pixmap_frame, 500, 300);
   gtk_widget_show (preview_pixmap_frame);
   gtk_box_pack_start (GTK_BOX (vbox1), preview_pixmap_frame, TRUE, TRUE, 0);
@@ -330,7 +342,8 @@ create_xfbd (XFCE_palette * pal)
   gtk_object_set_data (GTK_OBJECT (xfbd), "hbuttonbox1", hbuttonbox1);
   gtk_widget_show (hbuttonbox1);
   gtk_container_add (GTK_CONTAINER (frame3), hbuttonbox1);
-  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox1), GTK_BUTTONBOX_SPREAD);
+  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox1),
+			     GTK_BUTTONBOX_SPREAD);
   gtk_button_box_set_spacing (GTK_BUTTON_BOX (hbuttonbox1), 0);
   gtk_button_box_set_child_size (GTK_BUTTON_BOX (hbuttonbox1), 0, 0);
   gtk_button_box_set_child_ipadding (GTK_BUTTON_BOX (hbuttonbox1), 0, 0);
@@ -345,9 +358,9 @@ create_xfbd (XFCE_palette * pal)
   accel_group = gtk_accel_group_new ();
   gtk_window_add_accel_group (GTK_WINDOW (xfbd), accel_group);
   gtk_widget_add_accelerator (ok_button, "clicked", accel_group,
-                              GDK_Return, 0, GTK_ACCEL_VISIBLE);
+			      GDK_Return, 0, GTK_ACCEL_VISIBLE);
   gtk_widget_add_accelerator (ok_button, "clicked", accel_group,
-                              GDK_o, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
+			      GDK_o, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
 
   browse_button = gtk_button_new_with_label (_("Browse ..."));
   gtk_widget_set_name (browse_button, "browse_button");
@@ -357,7 +370,7 @@ create_xfbd (XFCE_palette * pal)
   gtk_container_border_width (GTK_CONTAINER (browse_button), 5);
   GTK_WIDGET_SET_FLAGS (browse_button, GTK_CAN_DEFAULT);
   gtk_widget_add_accelerator (browse_button, "clicked", accel_group,
-                              GDK_b, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
+			      GDK_b, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
 
   apply_button = gtk_button_new_with_label (_("Apply"));
   gtk_widget_set_name (apply_button, "apply_button");
@@ -367,7 +380,7 @@ create_xfbd (XFCE_palette * pal)
   gtk_container_border_width (GTK_CONTAINER (apply_button), 5);
   GTK_WIDGET_SET_FLAGS (apply_button, GTK_CAN_DEFAULT);
   gtk_widget_add_accelerator (apply_button, "clicked", accel_group,
-                              GDK_a, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
+			      GDK_a, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
 
   clear_button = gtk_button_new_with_label (_("Clear"));
   gtk_widget_set_name (clear_button, "clear_button");
@@ -377,7 +390,8 @@ create_xfbd (XFCE_palette * pal)
   gtk_container_border_width (GTK_CONTAINER (clear_button), 5);
   GTK_WIDGET_SET_FLAGS (clear_button, GTK_CAN_DEFAULT);
   gtk_widget_add_accelerator (clear_button, "clicked", accel_group,
-                              GDK_Delete, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
+			      GDK_Delete, GDK_CONTROL_MASK,
+			      GTK_ACCEL_VISIBLE);
 
   cancel_button = gtk_button_new_with_label (_("Cancel"));
   gtk_widget_set_name (cancel_button, "cancel_button");
@@ -387,29 +401,24 @@ create_xfbd (XFCE_palette * pal)
   gtk_container_border_width (GTK_CONTAINER (cancel_button), 5);
   GTK_WIDGET_SET_FLAGS (cancel_button, GTK_CAN_DEFAULT);
   gtk_widget_add_accelerator (cancel_button, "clicked", accel_group,
-                              GDK_Escape, 0, GTK_ACCEL_VISIBLE);
+			      GDK_Escape, 0, GTK_ACCEL_VISIBLE);
   gtk_widget_add_accelerator (cancel_button, "clicked", accel_group,
-                              GDK_c, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
+			      GDK_c, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
 
   gtk_signal_connect (GTK_OBJECT (apply_button), "clicked",
-				 GTK_SIGNAL_FUNC (apply_cb),
-				 NULL);
+		      GTK_SIGNAL_FUNC (apply_cb), NULL);
   gtk_signal_connect (GTK_OBJECT (ok_button), "clicked",
-				 GTK_SIGNAL_FUNC (ok_cb),
-				 NULL);
+		      GTK_SIGNAL_FUNC (ok_cb), NULL);
   gtk_signal_connect (GTK_OBJECT (browse_button), "clicked",
-				 GTK_SIGNAL_FUNC (browse_cb),
-				 NULL);
+		      GTK_SIGNAL_FUNC (browse_cb), NULL);
   gtk_signal_connect (GTK_OBJECT (clear_button), "clicked",
-				 GTK_SIGNAL_FUNC (clear_cb),
-				 NULL);
+		      GTK_SIGNAL_FUNC (clear_cb), NULL);
   gtk_signal_connect (GTK_OBJECT (cancel_button), "clicked",
-				 GTK_SIGNAL_FUNC (cancel_cb),
-				 NULL);
+		      GTK_SIGNAL_FUNC (cancel_cb), NULL);
   gtk_signal_connect (GTK_OBJECT (xfbd), "delete_event",
-                          GTK_SIGNAL_FUNC (delete_event), NULL);
+		      GTK_SIGNAL_FUNC (delete_event), NULL);
   gtk_signal_connect (GTK_OBJECT (xfbd), "destroy",
-                      GTK_SIGNAL_FUNC (cancel_cb), NULL);
+		      GTK_SIGNAL_FUNC (cancel_cb), NULL);
   return xfbd;
 }
 
@@ -418,17 +427,17 @@ main (int argc, char *argv[])
 {
   XFCE_palette *pal;
 
-  signal_setup();
-  
+  signal_setup ();
+
   gtk_set_locale ();
-  bindtextdomain(PACKAGE, XFCE_LOCALE_DIR);
+  bindtextdomain (PACKAGE, XFCE_LOCALE_DIR);
   textdomain (PACKAGE);
   gtk_init (&argc, &argv);
 #ifdef HAVE_GDK_IMLIB
-  gdk_imlib_init();
+  gdk_imlib_init ();
 /* Get gdk to use imlib's visual and colormap */
-  gtk_widget_push_visual(gdk_imlib_get_visual());
-  gtk_widget_push_colormap(gdk_imlib_get_colormap());  
+  gtk_widget_push_visual (gdk_imlib_get_visual ());
+  gtk_widget_push_colormap (gdk_imlib_get_colormap ());
 #endif
 
 
@@ -442,12 +451,12 @@ main (int argc, char *argv[])
       loadpal (pal);
       applypal (pal, NULL);
       xfbd = create_xfbd (pal);
-      gtk_entry_set_text(GTK_ENTRY(filename_entry), backdrp);
-      gtk_entry_set_position(GTK_ENTRY(filename_entry)  , 0);
+      gtk_entry_set_text (GTK_ENTRY (filename_entry), backdrp);
+      gtk_entry_set_position (GTK_ENTRY (filename_entry), 0);
       display_back (backdrp);
       gtk_widget_show (xfbd);
       set_icon (xfbd, "XFbd", xfbd_icon_xpm);
-      reg_xfce_app(xfbd, pal);
+      reg_xfce_app (xfbd, pal);
       gtk_main ();
     }
   if ((argc == 1) || (argc == 2 && strcmp (argv[1], "-d") == 0))
@@ -458,12 +467,16 @@ main (int argc, char *argv[])
 
   fprintf (stderr, _("Usage : %s [OPTIONS]\n"), argv[0]);
   fprintf (stderr, _("   Where OPTIONS are :\n"));
-  fprintf (stderr, _("   -i : interactive, prompts for backdrop to display\n"));
-  fprintf (stderr, _("   -d : display, reads configuration and exit (default)\n\n"));
-  fprintf (stderr, _("%s is part of the XFce distribution, written by Olivier Fourdan\n\n"), argv[0]);
+  fprintf (stderr,
+	   _("   -i : interactive, prompts for backdrop to display\n"));
+  fprintf (stderr,
+	   _("   -d : display, reads configuration and exit (default)\n\n"));
+  fprintf (stderr,
+	   _
+	   ("%s is part of the XFce distribution, written by Olivier Fourdan\n\n"),
+	   argv[0]);
 
   return (-1);
 
   return 0;
 }
-
