@@ -35,44 +35,56 @@
 #include "my_string.h"
 #include "xfce-common.h"
 
-void browse_cb( GtkWidget *widget, gpointer   data )
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
+void
+browse_cb (GtkWidget * widget, gpointer data)
 {
   char *fselect;
-  
-  fselect = gtk_entry_get_text(GTK_ENTRY(filename_entry));
-  if (strlen(fselect) && existfile (fselect))
+
+  fselect = gtk_entry_get_text (GTK_ENTRY (filename_entry));
+  if (strlen (fselect) && existfile (fselect))
     fselect = open_fileselect (fselect);
   else
-    fselect = open_fileselect (build_path(XFCE_BACKDROPS));
+    fselect = open_fileselect (build_path (XFCE_BACKDROPS));
   if (fselect)
     if (strlen (fselect))
       {
-        gtk_entry_set_text(GTK_ENTRY(filename_entry), fselect);
-        gtk_entry_set_position(GTK_ENTRY(filename_entry)  , 0);
+	gtk_entry_set_text (GTK_ENTRY (filename_entry), fselect);
+	gtk_entry_set_position (GTK_ENTRY (filename_entry), 0);
 	strcpy (backdrp, fselect);
 	display_back (backdrp);
       }
 }
 
-void apply_cb( GtkWidget *widget, gpointer   data )
+void
+apply_cb (GtkWidget * widget, gpointer data)
 {
-  strncpy(backdrp, cleanup ((char *)gtk_entry_get_text (GTK_ENTRY(filename_entry))), FILENAME_MAX - 1);
+  strncpy (backdrp,
+	   cleanup ((char *) gtk_entry_get_text (GTK_ENTRY (filename_entry))),
+	   FILENAME_MAX - 1);
   if (!strlen (backdrp))
     strcpy (backdrp, NOBACK);
   display_back (backdrp);
   setroot (backdrp);
 }
 
-void cancel_cb( GtkWidget *widget, gpointer   data )
+void
+cancel_cb (GtkWidget * widget, gpointer data)
 {
   free (backdrp);
   gtk_main_quit ();
   exit (0);
 }
 
-void ok_cb( GtkWidget *widget, gpointer   data )
+void
+ok_cb (GtkWidget * widget, gpointer data)
 {
-  strncpy(backdrp, cleanup ((char *)gtk_entry_get_text (GTK_ENTRY(filename_entry))), FILENAME_MAX - 1);
+  strncpy (backdrp,
+	   cleanup ((char *) gtk_entry_get_text (GTK_ENTRY (filename_entry))),
+	   FILENAME_MAX - 1);
   if (!strlen (backdrp))
     strcpy (backdrp, NOBACK);
   writestr (backdrp);
@@ -82,18 +94,18 @@ void ok_cb( GtkWidget *widget, gpointer   data )
   exit (0);
 }
 
-void clear_cb( GtkWidget *widget, gpointer   data )
+void
+clear_cb (GtkWidget * widget, gpointer data)
 {
-  gtk_entry_set_text(GTK_ENTRY(filename_entry), NOBACK);
-  gtk_entry_set_position(GTK_ENTRY(filename_entry)  , 0);
+  gtk_entry_set_text (GTK_ENTRY (filename_entry), NOBACK);
+  gtk_entry_set_position (GTK_ENTRY (filename_entry), 0);
   strcpy (backdrp, NOBACK);
   display_back (backdrp);
 }
 
-gboolean delete_event( GtkWidget *widget,
-                   GdkEvent  *event,
-                   gpointer   data )
+gboolean
+delete_event (GtkWidget * widget, GdkEvent * event, gpointer data)
 {
-  cancel_cb (widget,data);
+  cancel_cb (widget, data);
   return (TRUE);
 }
