@@ -39,77 +39,85 @@
 #include "selects.h"
 #include "configfile.h"
 
-void action_cancel_cb( GtkWidget *widget,
-                     gpointer   data )
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
+void
+action_cancel_cb (GtkWidget * widget, gpointer data)
 {
-  gtk_signal_disconnect(GTK_OBJECT(action_ok_button), action_signal_id1);
-  gtk_signal_disconnect(GTK_OBJECT(action_icon_browse_button), action_signal_id2);
+  gtk_signal_disconnect (GTK_OBJECT (action_ok_button), action_signal_id1);
+  gtk_signal_disconnect (GTK_OBJECT (action_icon_browse_button),
+			 action_signal_id2);
   gtk_main_quit ();
   gtk_widget_hide (action);
 }
 
-void action_ok_cb( GtkWidget *widget,
-                     gpointer   data )
+void
+action_ok_cb (GtkWidget * widget, gpointer data)
 {
   char *s;
   int x;
-  
-  s = cleanup ((char *) gtk_entry_get_text(GTK_ENTRY(action_command_entry)));
+
+  s =
+    cleanup ((char *) gtk_entry_get_text (GTK_ENTRY (action_command_entry)));
   x = strlen (s);
-  if (x) {
-    gtk_signal_disconnect(GTK_OBJECT(action_ok_button), action_signal_id1);
-    gtk_signal_disconnect(GTK_OBJECT(action_icon_browse_button), action_signal_id2);
-    set_command ((int) data, s);
-    if (((int) data) < NBSELECTS)
-      set_icon_nbr ((int) data, action_get_choice_selected());
-    gtk_main_quit ();
-    gtk_widget_hide (action);
-    writeconfig();
-  }
+  if (x)
+    {
+      gtk_signal_disconnect (GTK_OBJECT (action_ok_button),
+			     action_signal_id1);
+      gtk_signal_disconnect (GTK_OBJECT (action_icon_browse_button),
+			     action_signal_id2);
+      set_command ((int) data, s);
+      if (((int) data) < NBSELECTS)
+	set_icon_nbr ((int) data, action_get_choice_selected ());
+      gtk_main_quit ();
+      gtk_widget_hide (action);
+      writeconfig ();
+    }
   else
-    my_show_message(_("You must provide the command to execute !"));
+    my_show_message (_("You must provide the command to execute !"));
 }
 
 gboolean
-action_delete_event( GtkWidget *widget,
-                   GdkEvent  *event,
-                   gpointer   data )
+action_delete_event (GtkWidget * widget, GdkEvent * event, gpointer data)
 {
   action_cancel_cb (widget, data);
   return (TRUE);
 }
 
-void action_browse_command_cb( GtkWidget *widget,
-                               gpointer   data )
+void
+action_browse_command_cb (GtkWidget * widget, gpointer data)
 {
   char *command;
-  
+
   command = get_command ((int) data);
   if (strlen (command) && existfile (command))
     command = open_fileselect (command);
   else
     command = open_fileselect (XBINDIR);
-  if (command) {
-    gtk_entry_set_text(GTK_ENTRY(action_command_entry), command);
-  }
+  if (command)
+    {
+      gtk_entry_set_text (GTK_ENTRY (action_command_entry), command);
+    }
 }
 
-void action_browse_icon_cb( GtkWidget *widget,
-                            gpointer   data )
+void
+action_browse_icon_cb (GtkWidget * widget, gpointer data)
 {
   char *pixfile;
-  
-  pixfile = get_exticon_str((int) data);
+
+  pixfile = get_exticon_str ((int) data);
   if (strlen (pixfile) && existfile (pixfile))
     pixfile = open_fileselect (pixfile);
   else
-    pixfile = open_fileselect (build_path(XFCE_ICONS));
-  if (pixfile) {
-    action_set_choice_selected(NB_PANEL_ICONS);
-    if (existfile (pixfile))
-      set_exticon_str((int) data, pixfile);
-    else 
-      set_exticon_str((int) data, "None");
-  }
+    pixfile = open_fileselect (build_path (XFCE_ICONS));
+  if (pixfile)
+    {
+      action_set_choice_selected (NB_PANEL_ICONS);
+      if (existfile (pixfile))
+	set_exticon_str ((int) data, pixfile);
+      else
+	set_exticon_str ((int) data, "None");
+    }
 }
-
