@@ -1,6 +1,5 @@
 /* XPM */
-static char *addiconpix[] =
-{
+static char *addiconpix[] = {
   "20 20 3 1",
   ". c none",
   "X c #ffffff",
@@ -24,4 +23,5 @@ static char *addiconpix[] =
   "o...XXXXXXXXXXXX...X",
   "o..................X",
   "o..................X",
-  "oXXXXXXXXXXXXXXXXXXX"};
+  "oXXXXXXXXXXXXXXXXXXX"
+};
