@@ -1,6 +1,5 @@
 /* XPM */
-static char *closepix[] =
-{
+static char *closepix[] = {
   "8 4 3 1",
   ". c none",
   "X c #303030",
@@ -8,4 +7,5 @@ static char *closepix[] =
   "XXXXXXXo",
   "X......o",
   "X......o",
-  "Xooooooo"};
+  "Xooooooo"
+};
