@@ -1,5 +1,4 @@
-static char *handle[] =
-{
+static char *handle[] = {
   "94 10 3 1",
   ". c none",
   "X c #ffffff",
@@ -13,4 +12,5 @@ static char *handle[] =
   "oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX",
   "oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX",
   "oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX..oX",
-  "XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX"};
+  "XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX..XX"
+};
