@@ -1,6 +1,5 @@
 /* XPM */
-static char *iconify[] =
-{
+static char *iconify[] = {
   "4 4 3 1",
   ". c none",
   "X c #303030",
@@ -8,4 +7,5 @@ static char *iconify[] =
   "XXXo",
   "X..o",
   "X..o",
-  "Xooo"};
+  "Xooo"
+};
