@@ -1,6 +1,5 @@
 /* XPM */
-static char *minbutdn[] =
-{
+static char *minbutdn[] = {
   "14 7 4 1",
   ". c none",
   "X c #ffffff",
@@ -12,4 +11,5 @@ static char *minbutdn[] =
   "...oo++++XX...",
   "....oo++XX....",
   ".....ooXX.....",
-  "......oX......"};
+  "......oX......"
+};
