@@ -1,6 +1,5 @@
 /* XPM */
-static char *minbutup[] =
-{
+static char *minbutup[] = {
   "14 7 3 1",
   ". c none",
   "X c #ffffff",
@@ -11,4 +10,5 @@ static char *minbutup[] =
   "...oo....XX...",
   "..oo......XX..",
   ".oo........XX.",
-  "oXXXXXXXXXXXXX"};
+  "oXXXXXXXXXXXXX"
+};
