@@ -20,21 +20,20 @@
 #define __MODIFY_H__
 #include "xfcolor.h"
 
-  GtkWidget *modify_command_entry;
-  GtkWidget *modify_icon_entry;
-  GtkWidget *modify_displayed_entry;
-  GtkWidget *modify_preview_frame;
-  GtkWidget *modify_preview_pixmap;
-  GtkWidget *modify_ok_button;
-  GtkWidget *modify_cancel_button;
-  GtkWidget *modify_remove_button;
+GtkWidget *modify_command_entry;
+GtkWidget *modify_icon_entry;
+GtkWidget *modify_displayed_entry;
+GtkWidget *modify_preview_frame;
+GtkWidget *modify_preview_pixmap;
+GtkWidget *modify_ok_button;
+GtkWidget *modify_cancel_button;
+GtkWidget *modify_remove_button;
 
-  guint signal_id1;
-  guint signal_id2;
+guint signal_id1;
+guint signal_id2;
 
-GtkWidget* create_modify (XFCE_palette *);
+GtkWidget *create_modify (XFCE_palette *);
 
-void
-open_modify(GtkWidget *modify, int menu, int item);
+void open_modify (GtkWidget * modify, int menu, int item);
 
 #endif
