@@ -29,7 +29,11 @@
 #ifndef __MOVE_H__
 #define __MOVE_H__
 
-typedef struct _cursoroffset {gint x,y;} CursorOffset;
+typedef struct _cursoroffset
+{
+  gint x, y;
+}
+CursorOffset;
 
 void CreateDrawGC (GdkWindow *);
 void create_move_button (GtkWidget *, GtkWidget *);
