@@ -27,6 +27,10 @@
 #include "my_string.h"
 #include "action.h"
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 /*
    Load pixmap files 
  */
@@ -51,8 +55,7 @@
 #define MAIL_SPOOL_DIR "/var/spool/mail"
 #define MAX_FILENAME 255
 
-static char *icon_name[] =
-{
+static char *icon_name[] = {
   N_("Files related"),
   N_("Terminals/Connections"),
   N_("Mail tools/browsers"),
@@ -66,10 +69,10 @@ static char *icon_name[] =
   N_("Games"),
   N_("Network"),
   N_("Sound"),
-  N_("External...")};
+  N_("External...")
+};
 
-static char **icon_data[] =
-{
+static char **icon_data[] = {
   file1,
   term,
   nomail,
@@ -83,37 +86,40 @@ static char **icon_data[] =
   games,
   network,
   sound,
-  defaulticon};
+  defaulticon
+};
 
 char pathbuf[MAX_FILENAME] = "";
 
-void 
+void
 alloc_selects (void)
 {
   int i;
 
-  for (i = 0; i < NBSELECTS + 1; i++) {
-    selects[i].command  = (char *) malloc (5 * sizeof (char));
-    strcpy(selects[i].command, "None");
-    selects[i].ext_icon = (char *) malloc (5 * sizeof (char));
-    strcpy(selects[i].ext_icon, "None");
-    selects[i].icon_nbr = 99;
-  }
+  for (i = 0; i < NBSELECTS + 1; i++)
+    {
+      selects[i].command = (char *) malloc (5 * sizeof (char));
+      strcpy (selects[i].command, "None");
+      selects[i].ext_icon = (char *) malloc (5 * sizeof (char));
+      strcpy (selects[i].ext_icon, "None");
+      selects[i].icon_nbr = 99;
+    }
 }
 
-void 
+void
 free_selects (void)
 {
   int i;
 
-  for (i = 0; i < NBSELECTS + 1; i++) {
-    free (selects[i].command);
-    free (selects[i].ext_icon);
-  }
+  for (i = 0; i < NBSELECTS + 1; i++)
+    {
+      free (selects[i].command);
+      free (selects[i].ext_icon);
+    }
 
 }
 
-int 
+int
 load_icon_str (char *str)
 {
   char *a;
@@ -123,8 +129,8 @@ load_icon_str (char *str)
       selects[0].icon_nbr = atoi (a);
       for (i = 1; i < NBSELECTS; i++)
 	if ((a = strtok (NULL, ",")))
-	  selects[i].icon_nbr = (((atoi(a) < NB_PANEL_ICONS) 
-                                  || (atoi(a) == 99)) ? atoi(a) : i);
+	  selects[i].icon_nbr = (((atoi (a) < NB_PANEL_ICONS)
+				  || (atoi (a) == 99)) ? atoi (a) : i);
 	else
 	  {
 	    error = i + 1;
@@ -158,54 +164,53 @@ save_icon_str (void)
 }
 
 void
-set_exticon_str(int i, char *s)
+set_exticon_str (int i, char *s)
 {
-  if (i < NBSELECTS) {
-    free (selects[i].ext_icon);
-    if ((s) && (strlen(s)))
-      {
-        selects[i].ext_icon = (char *) malloc ((strlen (s) + 1) * sizeof (char));
-        strcpy(selects[i].ext_icon, s);
-      }
-    else
-      {
-        selects[i].ext_icon = (char *) malloc (5 * sizeof (char));
-        strcpy(selects[i].ext_icon, "None");
-      }
-  }
+  if (i < NBSELECTS)
+    {
+      free (selects[i].ext_icon);
+      if ((s) && (strlen (s)))
+	{
+	  selects[i].ext_icon =
+	    (char *) malloc ((strlen (s) + 1) * sizeof (char));
+	  strcpy (selects[i].ext_icon, s);
+	}
+      else
+	{
+	  selects[i].ext_icon = (char *) malloc (5 * sizeof (char));
+	  strcpy (selects[i].ext_icon, "None");
+	}
+    }
 }
 
 char *
-get_exticon_str(int i)
+get_exticon_str (int i)
 {
-   return selects[i].ext_icon;
+  return selects[i].ext_icon;
 }
 
-void 
+void
 setup_icon (void)
 {
   int i;
 
   for (i = 0; i < NBSELECTS; i++)
     if ((selects[i].icon_nbr >= 0) && (selects[i].icon_nbr < NB_PANEL_ICONS))
-      MySetPixmapData (select_buttons.select_pixmap[i], 
-                       select_buttons.select_button[i],
+      MySetPixmapData (select_buttons.select_pixmap[i],
+		       select_buttons.select_button[i],
 		       icon_data[selects[i].icon_nbr]);
     else
-      if ((selects[i].icon_nbr == 99) 
-           && (selects[i].ext_icon) 
-           && (existfile (selects[i].ext_icon))) 
-         MySetPixmapFile (select_buttons.select_pixmap[i],
-	 		  select_buttons.select_button[i], 
-			  selects[i].ext_icon);
-      else
-        MySetPixmapData (select_buttons.select_pixmap[i],
-	                 select_buttons.select_button[i],
-			 defaulticon);
-			 
+      if ((selects[i].icon_nbr == 99)
+	  && (selects[i].ext_icon) && (existfile (selects[i].ext_icon)))
+      MySetPixmapFile (select_buttons.select_pixmap[i],
+		       select_buttons.select_button[i], selects[i].ext_icon);
+    else
+      MySetPixmapData (select_buttons.select_pixmap[i],
+		       select_buttons.select_button[i], defaulticon);
+
 }
 
-void 
+void
 default_icon_str (void)
 {
   char *s;
@@ -217,7 +222,7 @@ default_icon_str (void)
   free (s);
 }
 
-int 
+int
 get_icon_nbr (int no_cmd)
 {
   int i;
@@ -226,29 +231,31 @@ get_icon_nbr (int no_cmd)
   return ((i < NB_PANEL_ICONS) ? i : 99);
 }
 
-void 
+void
 set_icon_nbr (int no_cmd, int icon_nbr)
 {
-  if (icon_nbr < NB_PANEL_ICONS) {
-    selects[no_cmd].icon_nbr = icon_nbr;
-    MySetPixmapData (select_buttons.select_pixmap[no_cmd],
-                     select_buttons.select_button[no_cmd],
-		     icon_data[icon_nbr]);
-  }
-  else {
-    selects[no_cmd].icon_nbr = 99;
-    if ((selects[no_cmd].ext_icon) && (existfile (selects[no_cmd].ext_icon)))
-         MySetPixmapFile (select_buttons.select_pixmap[no_cmd],
-	                  select_buttons.select_button[no_cmd], 
-			  selects[no_cmd].ext_icon);
+  if (icon_nbr < NB_PANEL_ICONS)
+    {
+      selects[no_cmd].icon_nbr = icon_nbr;
+      MySetPixmapData (select_buttons.select_pixmap[no_cmd],
+		       select_buttons.select_button[no_cmd],
+		       icon_data[icon_nbr]);
+    }
+  else
+    {
+      selects[no_cmd].icon_nbr = 99;
+      if ((selects[no_cmd].ext_icon)
+	  && (existfile (selects[no_cmd].ext_icon)))
+	MySetPixmapFile (select_buttons.select_pixmap[no_cmd],
+			 select_buttons.select_button[no_cmd],
+			 selects[no_cmd].ext_icon);
       else
-         MySetPixmapData (select_buttons.select_pixmap[no_cmd],
-	                  select_buttons.select_button[no_cmd],
-			  defaulticon);
-  }
+	MySetPixmapData (select_buttons.select_pixmap[no_cmd],
+			 select_buttons.select_button[no_cmd], defaulticon);
+    }
 }
 
-void 
+void
 init_choice_str (void)
 {
   int i;
@@ -257,7 +264,7 @@ init_choice_str (void)
     action_addto_choice (_(icon_name[i]));
 }
 
-void 
+void
 set_choice_value (int no_cmd)
 {
   if (selects[no_cmd].icon_nbr < NB_PANEL_ICONS)
@@ -266,7 +273,7 @@ set_choice_value (int no_cmd)
     action_set_choice_selected (NB_PANEL_ICONS);
 }
 
-void 
+void
 set_command (int no_sel, char *s)
 {
   free (selects[no_sel].command);
@@ -277,81 +284,89 @@ set_command (int no_sel, char *s)
     }
   else
     {
-      selects[no_sel].command = (char *) malloc ((strlen (s) + 1) * sizeof (char));
+      selects[no_sel].command =
+	(char *) malloc ((strlen (s) + 1) * sizeof (char));
       strcpy (selects[no_sel].command, s);
     }
   gtk_tooltips_set_tip (select_buttons.select_tooltips[no_sel],
-                        select_buttons.select_button[no_sel], 
-			selects[no_sel].command, 
-			"ContextHelp/buttons/?");
+			select_buttons.select_button[no_sel],
+			selects[no_sel].command, "ContextHelp/buttons/?");
 }
 
 char *
 get_command (int no_sel)
 {
-   return selects[no_sel].command;
+  return selects[no_sel].command;
 }
 
 int
-got_mail()
+got_mail ()
 {
   struct stat s;
   char *p;
 
-  if (!pathbuf[0]) {
-    p = getenv("MAIL");
-    if (p) {
-      strcpy(pathbuf, p);
-    } else {
-      p = getenv("LOGNAME");
-      if (p) {
-	sprintf(pathbuf, MAIL_SPOOL_DIR "/%s", p);
-      } /* perhaps it would make sense to do something else here? */
+  if (!pathbuf[0])
+    {
+      p = getenv ("MAIL");
+      if (p)
+	{
+	  strcpy (pathbuf, p);
+	}
+      else
+	{
+	  p = getenv ("LOGNAME");
+	  if (p)
+	    {
+	      sprintf (pathbuf, MAIL_SPOOL_DIR "/%s", p);
+	    }			/* perhaps it would make sense to do something else here? */
+	}
     }
-  }
 
-  if (stat(pathbuf, &s) < 0) return 0;
+  if (stat (pathbuf, &s) < 0)
+    return 0;
 
   if (s.st_size)
     {
-      if (s.st_mtime >= s.st_atime) 
-        return 2;
+      if (s.st_mtime >= s.st_atime)
+	return 2;
       else
-        return 1;
+	return 1;
     }
 
   return 0;
 }
 
-gint
-check_mail (gpointer data)
+gint check_mail (gpointer data)
 {
   static int had_mail = 0;
   int have_mail, i;
 
-  have_mail = got_mail();
+  have_mail = got_mail ();
 
-  if (have_mail != had_mail) {
-    switch (have_mail)
+  if (have_mail != had_mail)
     {
-      case 0 :
-        icon_data[MAIL_ICON_NUMBER] = nomail;
-	break;
-      case 1 :
-        icon_data[MAIL_ICON_NUMBER] = oldmail;
-	break;
-      case 2 :
-        icon_data[MAIL_ICON_NUMBER] = mail;
-	break;
-      default :
-        icon_data[MAIL_ICON_NUMBER] = nomail;
-    }      	
-    for(i = 0; i < NB_PANEL_ICONS; i++) {
-      if (get_icon_nbr(i) == MAIL_ICON_NUMBER) {
-	set_icon_nbr(i, MAIL_ICON_NUMBER);
-      }
+      switch (have_mail)
+	{
+	case 0:
+	  icon_data[MAIL_ICON_NUMBER] = nomail;
+	  break;
+	case 1:
+	  icon_data[MAIL_ICON_NUMBER] = oldmail;
+	  break;
+	case 2:
+	  icon_data[MAIL_ICON_NUMBER] = mail;
+	  break;
+	default:
+	  icon_data[MAIL_ICON_NUMBER] = nomail;
+	}
+      for (i = 0; i < NB_PANEL_ICONS; i++)
+	{
+	  if (get_icon_nbr (i) == MAIL_ICON_NUMBER)
+	    {
+	      set_icon_nbr (i, MAIL_ICON_NUMBER);
+	    }
+	}
     }
-  }
 
   had_mail = have_mail;
   return TRUE;
