@@ -30,22 +30,28 @@
 #include "fileutil.h"
 #include "my_intl.h"
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 char *rcfile = "xfclockrc";
 int nl = 0;
 int buffersize = 127;
 
-void 
+void
 syntax_error (char *s)
 {
-  fprintf (stderr, _("XFclock : Syntax error in configuration file\n(%s)\n"), s);
+  fprintf (stderr, _("XFclock : Syntax error in configuration file\n(%s)\n"),
+	   s);
   my_alert (_("Syntax error in configuration file\nAborting"));
   exit (0);
 }
 
-void 
+void
 data_error (char *s)
 {
-  fprintf (stderr, _("XFclock : Data mismatch error in config file\n(%s)\n"), s);
+  fprintf (stderr, _("XFclock : Data mismatch error in config file\n(%s)\n"),
+	   s);
   my_alert (_("Data mismatch error in configuration file\nAborting"));
   exit (0);
 }
@@ -64,40 +70,40 @@ nextline (FILE * f, char *lineread)
   while (!strlen (p) && !feof (f));
   if (strlen (p))
     skiptail (p);
-  return ((!feof(f)) ? p : NULL);
+  return ((!feof (f)) ? p : NULL);
 }
 
-config * 
-initconfig(config *conf)
+config *
+initconfig (config * conf)
 {
-   if (!conf)
-     conf=(config *) malloc (sizeof (config));
-   conf->x = -1;
-   conf->y = -1;
-   conf->w = -1;
-   conf->h = -1;
-   conf->calendar = TRUE;
-   conf->menubar  = TRUE;
-   conf->digital  = FALSE;
-   conf->seconds  = FALSE;
-   conf->ampm     = FALSE; /* Medium size */
-   conf->military = FALSE;
-   conf->back_red   = -1;
-   conf->back_green = -1;
-   conf->back_blue  = -1;
-   conf->fore_red   = -1;
-   conf->fore_green = -1;
-   conf->fore_blue  = -1;
-   conf->font = (char *) malloc (sizeof(char) * MAXSTRLEN);
-   strcpy(conf->font, "*");
-   
-   return conf;
+  if (!conf)
+    conf = (config *) malloc (sizeof (config));
+  conf->x = -1;
+  conf->y = -1;
+  conf->w = -1;
+  conf->h = -1;
+  conf->calendar = TRUE;
+  conf->menubar = TRUE;
+  conf->digital = FALSE;
+  conf->seconds = FALSE;
+  conf->ampm = FALSE;		/* Medium size */
+  conf->military = FALSE;
+  conf->back_red = -1;
+  conf->back_green = -1;
+  conf->back_blue = -1;
+  conf->fore_red = -1;
+  conf->fore_green = -1;
+  conf->fore_blue = -1;
+  conf->font = (char *) malloc (sizeof (char) * MAXSTRLEN);
+  strcpy (conf->font, "*");
+
+  return conf;
 }
 
-void 
-writeconfig (GtkWidget *widget, config *conf)
+void
+writeconfig (GtkWidget * widget, config * conf)
 {
-  char homedir  [MAXSTRLEN + 1];
+  char homedir[MAXSTRLEN + 1];
   FILE *configfile = NULL;
   int x, y;
   int w, h;
@@ -114,36 +120,40 @@ writeconfig (GtkWidget *widget, config *conf)
     {
       fprintf (configfile, "[Coords]\n");
       gdk_window_get_root_origin (((GtkWidget *) widget)->window, &x, &y);
-      gdk_window_get_size(((GtkWidget *) widget)->window, &w, &h);
+      gdk_window_get_size (((GtkWidget *) widget)->window, &w, &h);
       fprintf (configfile, "\t%i\n", x);
       fprintf (configfile, "\t%i\n", y);
       fprintf (configfile, "\t%i\n", w);
       fprintf (configfile, "\t%i\n", h);
       fprintf (configfile, "[Colors]\n");
-      fprintf (configfile, "\t%i %i %i\n", conf->fore_red, 
-                                           conf->fore_green, 
-					   conf->fore_blue);
-      fprintf (configfile, "\t%i %i %i\n", conf->back_red, 
-                                           conf->back_green, 
-					   conf->back_blue);
+      fprintf (configfile, "\t%i %i %i\n", conf->fore_red,
+	       conf->fore_green, conf->fore_blue);
+      fprintf (configfile, "\t%i %i %i\n", conf->back_red,
+	       conf->back_green, conf->back_blue);
       fprintf (configfile, "\t%s\n", conf->font);
       fprintf (configfile, "[Options]\n");
-      fprintf (configfile, conf->calendar ? "\tDisplayCalendar\n" : "\tHideCalendar\n");
-      fprintf (configfile, conf->menubar  ? "\tDisplayMenuBar\n"  : "\tHideMenuBar\n");
-      fprintf (configfile, conf->digital  ? "\tDigitalClock\n"    : "\tAnalogClock\n");
-      fprintf (configfile, conf->seconds  ? "\tDisplaySeconds\n"  : "\tHideSeconds\n");
-      fprintf (configfile, conf->ampm     ? "\tDisplayAMPM\n"     : "\tHideAMPM\n");
-      fprintf (configfile, conf->military ? "\tDisplayMilitary\n" : "\tHideMilitary\n");
+      fprintf (configfile,
+	       conf->calendar ? "\tDisplayCalendar\n" : "\tHideCalendar\n");
+      fprintf (configfile,
+	       conf->menubar ? "\tDisplayMenuBar\n" : "\tHideMenuBar\n");
+      fprintf (configfile,
+	       conf->digital ? "\tDigitalClock\n" : "\tAnalogClock\n");
+      fprintf (configfile,
+	       conf->seconds ? "\tDisplaySeconds\n" : "\tHideSeconds\n");
+      fprintf (configfile, conf->ampm ? "\tDisplayAMPM\n" : "\tHideAMPM\n");
+      fprintf (configfile,
+	       conf->military ? "\tDisplayMilitary\n" : "\tHideMilitary\n");
       fflush (configfile);
       fclose (configfile);
     }
 }
 
 
-void readconfig (config *conf)
+void
+readconfig (config * conf)
 {
-  char homedir  [MAXSTRLEN + 1];
-  char lineread [MAXSTRLEN + 1];
+  char homedir[MAXSTRLEN + 1];
+  char lineread[MAXSTRLEN + 1];
   char *p;
   FILE *configfile = NULL;
 
@@ -185,30 +195,38 @@ void readconfig (config *conf)
       if (my_strncasecmp (p, "[Colors]", strlen ("[Colors]")))
 	syntax_error (p);
       p = nextline (configfile, lineread);
-      sscanf (p, "%i %i %i", &(conf->fore_red), 
-                                &(conf->fore_green), 
-			        &(conf->fore_blue));
+      sscanf (p, "%i %i %i", &(conf->fore_red),
+	      &(conf->fore_green), &(conf->fore_blue));
       p = nextline (configfile, lineread);
-      sscanf (p, "%i %i %i", &(conf->back_red), 
-                                &(conf->back_green), 
-			        &(conf->back_blue));
+      sscanf (p, "%i %i %i", &(conf->back_red),
+	      &(conf->back_green), &(conf->back_blue));
       p = nextline (configfile, lineread);
       strcpy (conf->font, p);
       p = nextline (configfile, lineread);
       if (my_strncasecmp (p, "[Options]", strlen ("[Options]")))
 	syntax_error (p);
       p = nextline (configfile, lineread);
-      conf->calendar = (my_strncasecmp (p, "DisplayCalendar", strlen ("DisplayCalendar")) == 0);
+      conf->calendar =
+	(my_strncasecmp (p, "DisplayCalendar", strlen ("DisplayCalendar")) ==
+	 0);
       p = nextline (configfile, lineread);
-      conf->menubar  = (my_strncasecmp (p, "DisplayMenuBar", strlen ("DisplayMenuBar")) == 0);
+      conf->menubar =
+	(my_strncasecmp (p, "DisplayMenuBar", strlen ("DisplayMenuBar")) ==
+	 0);
       p = nextline (configfile, lineread);
-      conf->digital  = (my_strncasecmp (p, "DigitalClock", strlen ("DigitalClock")) == 0);
+      conf->digital =
+	(my_strncasecmp (p, "DigitalClock", strlen ("DigitalClock")) == 0);
       p = nextline (configfile, lineread);
-      conf->seconds  = (my_strncasecmp (p, "DisplaySeconds", strlen ("DisplaySeconds")) == 0);
+      conf->seconds =
+	(my_strncasecmp (p, "DisplaySeconds", strlen ("DisplaySeconds")) ==
+	 0);
       p = nextline (configfile, lineread);
-      conf->ampm  = (my_strncasecmp (p, "DisplayAMPM", strlen ("DisplayAMPM")) == 0);
+      conf->ampm =
+	(my_strncasecmp (p, "DisplayAMPM", strlen ("DisplayAMPM")) == 0);
       p = nextline (configfile, lineread);
-      conf->military  = (my_strncasecmp (p, "DisplayMilitary", strlen ("DisplayMilitary")) == 0);
+      conf->military =
+	(my_strncasecmp (p, "DisplayMilitary", strlen ("DisplayMilitary")) ==
+	 0);
       fclose (configfile);
     }
 }
