@@ -27,50 +27,53 @@
 #include "xfclock_cb.h"
 #include "xfclock_menus.h"
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 GtkWidget *
-clock_make_popup (MyGtkClock *clockw) 
+clock_make_popup (MyGtkClock * clockw)
 {
   GtkWidget *menuitem;
 
   if (!clock_popup_menu)
-  {
-    clock_popup_menu = gtk_menu_new ();
-    if (!clock_popup_menu) return (GtkWidget *) NULL;
-  }
-  
-  menuitem = gtk_menu_item_new_with_label(_("Hide/show menubar"));
+    {
+      clock_popup_menu = gtk_menu_new ();
+      if (!clock_popup_menu)
+	return (GtkWidget *) NULL;
+    }
 
-  gtk_menu_append (GTK_MENU(clock_popup_menu), menuitem);
-  gtk_signal_connect(GTK_OBJECT(menuitem), "activate",
-        		    GTK_SIGNAL_FUNC(toggle_menubar_cb),
-        		    (gpointer) clockw);
+  menuitem = gtk_menu_item_new_with_label (_("Hide/show menubar"));
+
+  gtk_menu_append (GTK_MENU (clock_popup_menu), menuitem);
+  gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
+		      GTK_SIGNAL_FUNC (toggle_menubar_cb), (gpointer) clockw);
   gtk_widget_show (menuitem);
 
-  menuitem = gtk_menu_item_new_with_label(_("Hide/show calendar"));
+  menuitem = gtk_menu_item_new_with_label (_("Hide/show calendar"));
 
-  gtk_menu_append (GTK_MENU(clock_popup_menu), menuitem);
-  gtk_signal_connect(GTK_OBJECT(menuitem), "activate",
-        		    GTK_SIGNAL_FUNC(toggle_calendar_cb),
-        		    (gpointer) clockw);
+  gtk_menu_append (GTK_MENU (clock_popup_menu), menuitem);
+  gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
+		      GTK_SIGNAL_FUNC (toggle_calendar_cb),
+		      (gpointer) clockw);
   gtk_widget_show (menuitem);
 
-  menuitem = gtk_menu_item_new();
+  menuitem = gtk_menu_item_new ();
 
-  gtk_menu_append (GTK_MENU(clock_popup_menu), menuitem);
+  gtk_menu_append (GTK_MENU (clock_popup_menu), menuitem);
   gtk_widget_show (menuitem);
 
   menuitem = gtk_menu_item_new_with_label (_("Quit"));
   gtk_menu_append (GTK_MENU (clock_popup_menu), menuitem);
   gtk_widget_show (menuitem);
-  gtk_signal_connect(GTK_OBJECT(menuitem), "activate",
-                            GTK_SIGNAL_FUNC(quit_cb),
-                            (gpointer) clockw);
+  gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
+		      GTK_SIGNAL_FUNC (quit_cb), (gpointer) clockw);
   return clock_popup_menu;
 }
 
 /* clock widget *has to* be created and properly configured when create_menu is called */
-GtkWidget*
-create_menu (MyGtkClock *clockw)
+GtkWidget *
+create_menu (MyGtkClock * clockw)
 {
   GtkWidget *menubar;
   GtkWidget *menu;
@@ -89,9 +92,8 @@ create_menu (MyGtkClock *clockw)
   menuitem = gtk_menu_item_new_with_label (_("Quit"));
   gtk_menu_append (GTK_MENU (menu), menuitem);
   gtk_widget_show (menuitem);
-  gtk_signal_connect(GTK_OBJECT(menuitem), "activate",
-                            GTK_SIGNAL_FUNC(quit_cb),
-                            (gpointer) clockw);
+  gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
+		      GTK_SIGNAL_FUNC (quit_cb), (gpointer) clockw);
   /* Create "Settings" menu */
   menuitem = gtk_menu_item_new_with_label (_("Settings"));
   gtk_menu_bar_append (GTK_MENU_BAR (menubar), menuitem);
@@ -101,86 +103,82 @@ create_menu (MyGtkClock *clockw)
   gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), menu);
 
   menuitem = gtk_menu_item_new_with_label (_("Hide/show calendar"));
-  gtk_signal_connect(GTK_OBJECT(menuitem), "activate",
-        		    GTK_SIGNAL_FUNC(toggle_calendar_cb),
-        		    (gpointer) clockw);
+  gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
+		      GTK_SIGNAL_FUNC (toggle_calendar_cb),
+		      (gpointer) clockw);
   gtk_menu_append (GTK_MENU (menu), menuitem);
   gtk_widget_show (menuitem);
 
-  menuitem = gtk_menu_item_new();
-  gtk_menu_append (GTK_MENU (menu), menuitem);
-  gtk_widget_show (menuitem);
-  
-  menuitem = gtk_check_menu_item_new_with_label(_("Digital mode"));
-  GTK_CHECK_MENU_ITEM(menuitem)->active = 
-                      (my_gtk_clock_get_mode(MY_GTK_CLOCK(clockw)) == MY_GTK_CLOCK_DIGITAL);
-  gtk_signal_connect(GTK_OBJECT(menuitem), "activate",
-        		    GTK_SIGNAL_FUNC(toggle_digital_cb),
-        		    (gpointer) clockw);
-  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM(menuitem), 1);
+  menuitem = gtk_menu_item_new ();
   gtk_menu_append (GTK_MENU (menu), menuitem);
   gtk_widget_show (menuitem);
 
-  menuitem = gtk_check_menu_item_new_with_label(_("24 hours mode"));
-  GTK_CHECK_MENU_ITEM(menuitem)->active = my_gtk_clock_military_shown(MY_GTK_CLOCK(clockw));
-  gtk_signal_connect(GTK_OBJECT(menuitem), "activate",
-        		    GTK_SIGNAL_FUNC(toggle_military_cb),
-        		    (gpointer) clockw);
-  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM(menuitem), 1);
+  menuitem = gtk_check_menu_item_new_with_label (_("Digital mode"));
+  GTK_CHECK_MENU_ITEM (menuitem)->active =
+    (my_gtk_clock_get_mode (MY_GTK_CLOCK (clockw)) == MY_GTK_CLOCK_DIGITAL);
+  gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
+		      GTK_SIGNAL_FUNC (toggle_digital_cb), (gpointer) clockw);
+  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (menuitem), 1);
   gtk_menu_append (GTK_MENU (menu), menuitem);
   gtk_widget_show (menuitem);
 
-  menuitem = gtk_check_menu_item_new_with_label(_("Display AM/PM"));
-  GTK_CHECK_MENU_ITEM(menuitem)->active = my_gtk_clock_ampm_shown(MY_GTK_CLOCK(clockw));
-  gtk_signal_connect(GTK_OBJECT(menuitem), "activate",
-        		    GTK_SIGNAL_FUNC(toggle_ampm_cb),
-        		    (gpointer) clockw);
-  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM(menuitem), 1);
+  menuitem = gtk_check_menu_item_new_with_label (_("24 hours mode"));
+  GTK_CHECK_MENU_ITEM (menuitem)->active =
+    my_gtk_clock_military_shown (MY_GTK_CLOCK (clockw));
+  gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
+		      GTK_SIGNAL_FUNC (toggle_military_cb),
+		      (gpointer) clockw);
+  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (menuitem), 1);
   gtk_menu_append (GTK_MENU (menu), menuitem);
   gtk_widget_show (menuitem);
 
-  menuitem = gtk_check_menu_item_new_with_label(_("Display seconds"));
-  GTK_CHECK_MENU_ITEM(menuitem)->active = my_gtk_clock_secs_shown(MY_GTK_CLOCK(clockw));
-  gtk_signal_connect(GTK_OBJECT(menuitem), "activate",
-        		    GTK_SIGNAL_FUNC(toggle_secs_cb),
-        		    (gpointer) clockw);
-  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM(menuitem), 1);
+  menuitem = gtk_check_menu_item_new_with_label (_("Display AM/PM"));
+  GTK_CHECK_MENU_ITEM (menuitem)->active =
+    my_gtk_clock_ampm_shown (MY_GTK_CLOCK (clockw));
+  gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
+		      GTK_SIGNAL_FUNC (toggle_ampm_cb), (gpointer) clockw);
+  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (menuitem), 1);
   gtk_menu_append (GTK_MENU (menu), menuitem);
   gtk_widget_show (menuitem);
 
-  menuitem = gtk_menu_item_new();
+  menuitem = gtk_check_menu_item_new_with_label (_("Display seconds"));
+  GTK_CHECK_MENU_ITEM (menuitem)->active =
+    my_gtk_clock_secs_shown (MY_GTK_CLOCK (clockw));
+  gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
+		      GTK_SIGNAL_FUNC (toggle_secs_cb), (gpointer) clockw);
+  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (menuitem), 1);
   gtk_menu_append (GTK_MENU (menu), menuitem);
   gtk_widget_show (menuitem);
-  
+
+  menuitem = gtk_menu_item_new ();
+  gtk_menu_append (GTK_MENU (menu), menuitem);
+  gtk_widget_show (menuitem);
+
   menuitem = gtk_menu_item_new_with_label (_("Background color..."));
-  gtk_signal_connect(GTK_OBJECT(menuitem), "activate",
-        		    GTK_SIGNAL_FUNC(background_cb),
-        		    (gpointer) clockw);
+  gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
+		      GTK_SIGNAL_FUNC (background_cb), (gpointer) clockw);
   gtk_menu_append (GTK_MENU (menu), menuitem);
   gtk_widget_show (menuitem);
 
   menuitem = gtk_menu_item_new_with_label (_("Foreground color..."));
-  gtk_signal_connect(GTK_OBJECT(menuitem), "activate",
-        		    GTK_SIGNAL_FUNC(foreground_cb),
-        		    (gpointer) clockw);
+  gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
+		      GTK_SIGNAL_FUNC (foreground_cb), (gpointer) clockw);
   gtk_menu_append (GTK_MENU (menu), menuitem);
   gtk_widget_show (menuitem);
 
   menuitem = gtk_menu_item_new_with_label (_("Font..."));
-  gtk_signal_connect(GTK_OBJECT(menuitem), "activate",
-        		    GTK_SIGNAL_FUNC(font_cb),
-        		    (gpointer) clockw);
+  gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
+		      GTK_SIGNAL_FUNC (font_cb), (gpointer) clockw);
   gtk_menu_append (GTK_MENU (menu), menuitem);
   gtk_widget_show (menuitem);
 
-  menuitem = gtk_menu_item_new();
+  menuitem = gtk_menu_item_new ();
   gtk_menu_append (GTK_MENU (menu), menuitem);
   gtk_widget_show (menuitem);
-  
+
   menuitem = gtk_menu_item_new_with_label (_("Hide menubar"));
-  gtk_signal_connect(GTK_OBJECT(menuitem), "activate",
-        		    GTK_SIGNAL_FUNC(toggle_menubar_cb),
-        		    (gpointer) clockw);
+  gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
+		      GTK_SIGNAL_FUNC (toggle_menubar_cb), (gpointer) clockw);
   gtk_menu_append (GTK_MENU (menu), menuitem);
   gtk_widget_show (menuitem);
 
@@ -193,12 +191,10 @@ create_menu (MyGtkClock *clockw)
   menu = gtk_menu_new ();
   gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), menu);
   menuitem = gtk_menu_item_new_with_label (_("About..."));
-  gtk_signal_connect(GTK_OBJECT(menuitem), "activate",
-        		    GTK_SIGNAL_FUNC(about_cb),
-        		    NULL);
-   gtk_menu_append (GTK_MENU (menu), menuitem);
+  gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
+		      GTK_SIGNAL_FUNC (about_cb), NULL);
+  gtk_menu_append (GTK_MENU (menu), menuitem);
   gtk_widget_show (menuitem);
-  
+
   return menubar;
 }
-
