@@ -29,8 +29,8 @@
 #include <gdk/gdkkeysyms.h>
 
 #ifdef HAVE_GDK_IMLIB
-  #include <fcntl.h>
-  #include <gdk_imlib.h>
+#include <fcntl.h>
+#include <gdk_imlib.h>
 #endif
 
 #include "my_intl.h"
@@ -41,67 +41,74 @@
 #include "my_string.h"
 #include "fileutil.h"
 #include "xfce-common.h"
-#include "xfmouse.xpm"
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
+#include "xfmouse.xpm"
 #include "xfmouse_icon.xpm"
 
-void 
-mouse_values(XFMouse *s)
+void
+mouse_values (XFMouse * s)
 {
-   unsigned char map[5] = "\0\0\0\0\0";
-   unsigned int buttons = 0;
-   Display *tmpDpy;
+  unsigned char map[5] = "\0\0\0\0\0";
+  unsigned int buttons = 0;
+  Display *tmpDpy;
 
-   if (!(tmpDpy = XOpenDisplay("")))
-     {
-       fprintf ( stderr, _("xfmouse: Error, cannot open display.\n"));
-       fprintf ( stderr, _("Is X running and $DISPLAY correctly set ?\n"));
-       return;
-     }
-   XSync(tmpDpy, False);
-   XChangePointerControl(tmpDpy, 1, 1, s->accel, DENOMINATOR, s->thresh);
-   buttons = XGetPointerMapping(tmpDpy, map, 5);
-   if (s->button) {
-     if (buttons > 2)
-       {
-         map[0]=1;
-         map[1]=2;
-         map[2]=3; 
-       }
-     else
-       {
-         map[0]=2;
-         map[1]=1;
-       }
-   }
-   else {
-     if (buttons > 2)
-       {
-         map[0]=3;
-         map[1]=2;
-         map[2]=1; 
-       }
-     else
-       {
-         map[0]=1;
-         map[1]=2;
-       }
-   }
-   XSetPointerMapping(tmpDpy, map, buttons);
-   XFlush(tmpDpy);
-   XCloseDisplay(tmpDpy);
+  if (!(tmpDpy = XOpenDisplay ("")))
+    {
+      fprintf (stderr, _("xfmouse: Error, cannot open display.\n"));
+      fprintf (stderr, _("Is X running and $DISPLAY correctly set ?\n"));
+      return;
+    }
+  XSync (tmpDpy, False);
+  XChangePointerControl (tmpDpy, 1, 1, s->accel, DENOMINATOR, s->thresh);
+  buttons = XGetPointerMapping (tmpDpy, map, 5);
+  if (s->button)
+    {
+      if (buttons > 2)
+	{
+	  map[0] = 1;
+	  map[1] = 2;
+	  map[2] = 3;
+	}
+      else
+	{
+	  map[0] = 2;
+	  map[1] = 1;
+	}
+    }
+  else
+    {
+      if (buttons > 2)
+	{
+	  map[0] = 3;
+	  map[1] = 2;
+	  map[2] = 1;
+	}
+      else
+	{
+	  map[0] = 1;
+	  map[1] = 2;
+	}
+    }
+  XSetPointerMapping (tmpDpy, map, buttons);
+  XFlush (tmpDpy);
+  XCloseDisplay (tmpDpy);
 }
 
-void 
-apply_mouse_values(XFMouse *s)
+void
+apply_mouse_values (XFMouse * s)
 {
-   s->button = (int) gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (rightbtn));
-   s->accel  = (int) GTK_ADJUSTMENT(accel)->value;
-   s->thresh = (int) GTK_ADJUSTMENT(thresh)->value;
-   mouse_values ( s );
+  s->button =
+    (int) gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (rightbtn));
+  s->accel = (int) GTK_ADJUSTMENT (accel)->value;
+  s->thresh = (int) GTK_ADJUSTMENT (thresh)->value;
+  mouse_values (s);
 }
 
-GtkWidget*
+GtkWidget *
 create_xfmouse ()
 {
   GtkWidget *xfmouse_mainframe;
@@ -130,12 +137,14 @@ create_xfmouse ()
   gtk_widget_set_name (xfmouse, "xfmouse");
   gtk_object_set_data (GTK_OBJECT (xfmouse), "xfmouse", xfmouse);
   gtk_widget_set_usize (xfmouse, 340, -2);
-  gtk_window_set_title (GTK_WINDOW (xfmouse), _("XFMouse - XFce Mouse Configuration"));
+  gtk_window_set_title (GTK_WINDOW (xfmouse),
+			_("XFMouse - XFce Mouse Configuration"));
   gtk_window_position (GTK_WINDOW (xfmouse), GTK_WIN_POS_CENTER);
 
   xfmouse_mainframe = gtk_frame_new (NULL);
   gtk_widget_set_name (xfmouse_mainframe, "xfmouse_mainframe");
-  gtk_object_set_data (GTK_OBJECT (xfmouse), "xfmouse_mainframe", xfmouse_mainframe);
+  gtk_object_set_data (GTK_OBJECT (xfmouse), "xfmouse_mainframe",
+		       xfmouse_mainframe);
   gtk_widget_show (xfmouse_mainframe);
   gtk_container_add (GTK_CONTAINER (xfmouse), xfmouse_mainframe);
   gtk_frame_set_shadow_type (GTK_FRAME (xfmouse_mainframe), GTK_SHADOW_OUT);
@@ -197,7 +206,7 @@ create_xfmouse ()
   accel_group = gtk_accel_group_new ();
   gtk_window_add_accel_group (GTK_WINDOW (xfmouse), accel_group);
   gtk_widget_add_accelerator (leftbtn, "toggled", accel_group,
-                              GDK_l, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
+			      GDK_l, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
 
   rightbtn = gtk_radio_button_new_with_label (hbox3_group, _("Right"));
   hbox3_group = gtk_radio_button_group (GTK_RADIO_BUTTON (rightbtn));
@@ -206,7 +215,7 @@ create_xfmouse ()
   gtk_widget_show (rightbtn);
   gtk_box_pack_start (GTK_BOX (hbox3), rightbtn, TRUE, TRUE, 0);
   gtk_widget_add_accelerator (rightbtn, "toggled", accel_group,
-                              GDK_r, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
+			      GDK_r, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
   gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (rightbtn), TRUE);
 
   frame5 = gtk_frame_new (_("Motion Settings"));
@@ -222,20 +231,26 @@ create_xfmouse ()
   gtk_widget_show (table1);
   gtk_container_add (GTK_CONTAINER (frame5), table1);
 
-  hscale3 = gtk_hscale_new (GTK_ADJUSTMENT (accel = gtk_adjustment_new (6, 1, 30, 1, 1, 1)));
+  hscale3 =
+    gtk_hscale_new (GTK_ADJUSTMENT
+		    (accel = gtk_adjustment_new (6, 1, 30, 1, 1, 1)));
   gtk_widget_set_name (hscale3, "hscale3");
   gtk_object_set_data (GTK_OBJECT (xfmouse), "hscale3", hscale3);
   gtk_widget_show (hscale3);
   gtk_table_attach (GTK_TABLE (table1), hscale3, 1, 2, 0, 1,
-                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
+		    (GtkAttachOptions) GTK_EXPAND | GTK_FILL,
+		    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
   gtk_scale_set_digits (GTK_SCALE (hscale3), 0);
 
-  hscale4 = gtk_hscale_new (GTK_ADJUSTMENT (thresh = gtk_adjustment_new (4, 1, 20, 1, 1, 1)));
+  hscale4 =
+    gtk_hscale_new (GTK_ADJUSTMENT
+		    (thresh = gtk_adjustment_new (4, 1, 20, 1, 1, 1)));
   gtk_widget_set_name (hscale4, "hscale4");
   gtk_object_set_data (GTK_OBJECT (xfmouse), "hscale4", hscale4);
   gtk_widget_show (hscale4);
   gtk_table_attach (GTK_TABLE (table1), hscale4, 1, 2, 1, 2,
-                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
+		    (GtkAttachOptions) GTK_EXPAND | GTK_FILL,
+		    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
   gtk_scale_set_digits (GTK_SCALE (hscale4), 0);
 
   label3 = gtk_label_new (_("Threshold : "));
@@ -243,7 +258,9 @@ create_xfmouse ()
   gtk_object_set_data (GTK_OBJECT (xfmouse), "label3", label3);
   gtk_widget_show (label3);
   gtk_table_attach (GTK_TABLE (table1), label3, 0, 1, 1, 2,
-                    (GtkAttachOptions) GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_SHRINK | GTK_FILL, 0, 0);
+		    (GtkAttachOptions) GTK_FILL,
+		    (GtkAttachOptions) GTK_EXPAND | GTK_SHRINK | GTK_FILL, 0,
+		    0);
   gtk_label_set_justify (GTK_LABEL (label3), GTK_JUSTIFY_RIGHT);
   gtk_misc_set_alignment (GTK_MISC (label3), 1, 0.5);
   gtk_misc_set_padding (GTK_MISC (label3), 5, 0);
@@ -253,7 +270,9 @@ create_xfmouse ()
   gtk_object_set_data (GTK_OBJECT (xfmouse), "label2", label2);
   gtk_widget_show (label2);
   gtk_table_attach (GTK_TABLE (table1), label2, 0, 1, 0, 1,
-                    (GtkAttachOptions) GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_SHRINK | GTK_FILL, 0, 0);
+		    (GtkAttachOptions) GTK_FILL,
+		    (GtkAttachOptions) GTK_EXPAND | GTK_SHRINK | GTK_FILL, 0,
+		    0);
   gtk_label_set_justify (GTK_LABEL (label2), GTK_JUSTIFY_RIGHT);
   gtk_misc_set_alignment (GTK_MISC (label2), 1, 0.5);
   gtk_misc_set_padding (GTK_MISC (label2), 5, 0);
@@ -270,7 +289,8 @@ create_xfmouse ()
   gtk_object_set_data (GTK_OBJECT (xfmouse), "hbuttonbox1", hbuttonbox1);
   gtk_widget_show (hbuttonbox1);
   gtk_container_add (GTK_CONTAINER (frame3), hbuttonbox1);
-  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox1), GTK_BUTTONBOX_SPREAD);
+  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox1),
+			     GTK_BUTTONBOX_SPREAD);
   gtk_button_box_set_spacing (GTK_BUTTON_BOX (hbuttonbox1), 0);
   gtk_button_box_set_child_size (GTK_BUTTON_BOX (hbuttonbox1), 0, 0);
   gtk_button_box_set_child_ipadding (GTK_BUTTON_BOX (hbuttonbox1), 0, 0);
@@ -283,9 +303,9 @@ create_xfmouse ()
   gtk_container_border_width (GTK_CONTAINER (ok_button), 5);
   GTK_WIDGET_SET_FLAGS (ok_button, GTK_CAN_DEFAULT);
   gtk_widget_add_accelerator (ok_button, "clicked", accel_group,
-                              GDK_Return, 0, GTK_ACCEL_VISIBLE);
+			      GDK_Return, 0, GTK_ACCEL_VISIBLE);
   gtk_widget_add_accelerator (ok_button, "clicked", accel_group,
-                              GDK_o, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
+			      GDK_o, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
 
   apply_button = gtk_button_new_with_label (_("Apply"));
   gtk_widget_set_name (apply_button, "apply_button");
@@ -295,7 +315,7 @@ create_xfmouse ()
   gtk_container_border_width (GTK_CONTAINER (apply_button), 5);
   GTK_WIDGET_SET_FLAGS (apply_button, GTK_CAN_DEFAULT);
   gtk_widget_add_accelerator (apply_button, "clicked", accel_group,
-                              GDK_a, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
+			      GDK_a, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
 
   cancel_button = gtk_button_new_with_label (_("Cancel"));
   gtk_widget_set_name (cancel_button, "cancel_button");
@@ -305,30 +325,27 @@ create_xfmouse ()
   gtk_container_border_width (GTK_CONTAINER (cancel_button), 5);
   GTK_WIDGET_SET_FLAGS (cancel_button, GTK_CAN_DEFAULT);
   gtk_widget_add_accelerator (cancel_button, "clicked", accel_group,
-                              GDK_Escape, 0, GTK_ACCEL_VISIBLE);
+			      GDK_Escape, 0, GTK_ACCEL_VISIBLE);
   gtk_widget_add_accelerator (cancel_button, "clicked", accel_group,
-                              GDK_c, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
+			      GDK_c, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
 
   gtk_signal_connect (GTK_OBJECT (ok_button), "clicked",
-				 GTK_SIGNAL_FUNC (ok_cb),
-				 NULL);
+		      GTK_SIGNAL_FUNC (ok_cb), NULL);
   gtk_signal_connect (GTK_OBJECT (cancel_button), "clicked",
-				 GTK_SIGNAL_FUNC (cancel_cb),
-				 NULL);
+		      GTK_SIGNAL_FUNC (cancel_cb), NULL);
   gtk_signal_connect (GTK_OBJECT (apply_button), "clicked",
-				 GTK_SIGNAL_FUNC (apply_cb),
-				 NULL);
+		      GTK_SIGNAL_FUNC (apply_cb), NULL);
   gtk_signal_connect (GTK_OBJECT (xfmouse), "delete_event",
-                          GTK_SIGNAL_FUNC (delete_event), NULL);
+		      GTK_SIGNAL_FUNC (delete_event), NULL);
   gtk_signal_connect (GTK_OBJECT (xfmouse), "destroy",
-                      GTK_SIGNAL_FUNC (cancel_cb), NULL);
+		      GTK_SIGNAL_FUNC (cancel_cb), NULL);
 
   set_icon (xfmouse, "XFMouse", xfmouse_xpm);
   return xfmouse;
 }
 
 void
-show_xfmouse(XFMouse *s)
+show_xfmouse (XFMouse * s)
 {
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (rightbtn), (s->button));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (leftbtn), !(s->button));
@@ -340,26 +357,28 @@ show_xfmouse(XFMouse *s)
 
 
 void
-readstr (int i, char *str, FILE *f)
+readstr (int i, char *str, FILE * f)
 {
-  if (str) {
-    if (f) {
-      fgets (str, i - 1, f);
-      if (strlen (str))
-        str[strlen (str) - 1] = 0;
+  if (str)
+    {
+      if (f)
+	{
+	  fgets (str, i - 1, f);
+	  if (strlen (str))
+	    str[strlen (str) - 1] = 0;
+	}
+      else
+	strcpy (str, "\0");
     }
-    else
-      strcpy(str, "\0");
-  }
 }
 
 void
-loadcfg (XFMouse *s)
+loadcfg (XFMouse * s)
 {
   FILE *f = NULL;
 
   strcpy (homedir, (char *) getenv ("HOME"));
-  strcat (homedir, "/."RCFILE);
+  strcat (homedir, "/." RCFILE);
   if (existfile (homedir))
     {
       f = fopen (homedir, "r");
@@ -367,14 +386,14 @@ loadcfg (XFMouse *s)
   else
     {
       strcpy (homedir, XFCE_CONFDIR);
-      strcat (homedir, "/"RCFILE);
+      strcat (homedir, "/" RCFILE);
       if (existfile (homedir))
 	{
 	  f = fopen (homedir, "r");
 	}
     }
 
-  if (f) 
+  if (f)
     {
       readstr (10, tempstr, f);
       s->button = (my_strncasecmp (tempstr, "Right", strlen ("Right")) == 0);
@@ -383,30 +402,30 @@ loadcfg (XFMouse *s)
       readstr (10, tempstr, f);
       s->thresh = atoi (tempstr);
       if (s->accel < ACCEL_MIN)
-        s->accel = ACCEL_MIN;
+	s->accel = ACCEL_MIN;
       else if (s->accel > ACCEL_MAX)
-        s->accel = ACCEL_MIN;
+	s->accel = ACCEL_MIN;
       if (s->thresh < THRESH_MIN)
-        s->thresh = THRESH_MIN;
+	s->thresh = THRESH_MIN;
       else if (s->thresh > THRESH_MAX)
-        s->thresh = THRESH_MIN;
+	s->thresh = THRESH_MIN;
       fclose (f);
     }
   else
     {
       s->button = 1;
-      s->accel  = 2 * DENOMINATOR;
+      s->accel = 2 * DENOMINATOR;
       s->thresh = 4;
     }
 }
 
 int
-savecfg (XFMouse *s)
+savecfg (XFMouse * s)
 {
   FILE *f;
 
   strcpy (homedir, (char *) getenv ("HOME"));
-  strcat (homedir, "/."RCFILE);
+  strcat (homedir, "/." RCFILE);
 
   if ((f = fopen (homedir, "w")))
     {
@@ -423,7 +442,7 @@ main (int argc, char *argv[])
 {
   XFCE_palette *pal;
 
-  signal_setup();
+  signal_setup ();
 
   homedir = (char *) malloc ((MAXSTRLEN + 1) * sizeof (char));
   tempstr = (char *) malloc (16 * sizeof (char));
@@ -432,14 +451,14 @@ main (int argc, char *argv[])
   if (argc == 2 && strcmp (argv[1], "-i") == 0)
     {
       gtk_set_locale ();
-      bindtextdomain(PACKAGE, XFCE_LOCALE_DIR);
+      bindtextdomain (PACKAGE, XFCE_LOCALE_DIR);
       textdomain (PACKAGE);
       gtk_init (&argc, &argv);
 #ifdef HAVE_GDK_IMLIB
-      gdk_imlib_init();
+      gdk_imlib_init ();
 /* Get gdk to use imlib's visual and colormap */
-      gtk_widget_push_visual(gdk_imlib_get_visual());
-      gtk_widget_push_colormap(gdk_imlib_get_colormap());  
+      gtk_widget_push_visual (gdk_imlib_get_visual ());
+      gtk_widget_push_colormap (gdk_imlib_get_colormap ());
 #endif
 
       pal = newpal ();
@@ -449,7 +468,7 @@ main (int argc, char *argv[])
 
       xfmouse = create_xfmouse ();
       set_icon (xfmouse, "XFMouse", xfmouse_icon_xpm);
-      reg_xfce_app(xfmouse, pal);
+      reg_xfce_app (xfmouse, pal);
       show_xfmouse (&mouseval);
     }
   if ((argc == 1) || (argc == 2 && strcmp (argv[1], "-d") == 0))
@@ -462,8 +481,10 @@ main (int argc, char *argv[])
   fprintf (stderr, _("   Where OPTIONS are :\n"));
   fprintf (stderr, _("   -i : interactive\n"));
   fprintf (stderr, _("   -d : apply configuration and exit (default)\n\n"));
-  fprintf (stderr, _("%s is part of the XFce distribution, written by Olivier Fourdan\n\n"), argv[0]);
+  fprintf (stderr,
+	   _
+	   ("%s is part of the XFce distribution, written by Olivier Fourdan\n\n"),
+	   argv[0]);
 
   return (-1);
 }
-
