@@ -22,21 +22,23 @@
 #ifndef __GTK_myDND_H__
 #define __GTK_myDND_H__
 
-enum {
-	DND_NONE,
-	DND_MOVE,
-	DND_COPY,
-	DND_LINK,
+enum
+{
+  DND_NONE,
+  DND_MOVE,
+  DND_COPY,
+  DND_LINK,
 };
 
-enum {
-	TARGET_URI_LIST,
-	TARGET_PLAIN,
-	TARGET_STRING,
-	TARGET_XTREE_WIDGET,
-	TARGET_XTREE_WINDOW,
-	TARGET_ROOTWIN,
-	TARGETS,
+enum
+{
+  TARGET_URI_LIST,
+  TARGET_PLAIN,
+  TARGET_STRING,
+  TARGET_XTREE_WIDGET,
+  TARGET_XTREE_WINDOW,
+  TARGET_ROOTWIN,
+  TARGETS,
 };
 
 #endif
