@@ -27,15 +27,17 @@
 #define IS_MULTI		1
 #define IS_STALE_LINK	2
 
-typedef struct {
-	mode_t mode;
-	uid_t uid;
-	gid_t gid;
-	time_t ctime;
-	time_t mtime;
-	time_t atime;
-	off_t size;
-} fprop;
+typedef struct
+{
+  mode_t mode;
+  uid_t uid;
+  gid_t gid;
+  time_t ctime;
+  time_t mtime;
+  time_t atime;
+  off_t size;
+}
+fprop;
 
-int dlg_prop (char *path, fprop *prop, int multi);
+int dlg_prop (char *path, fprop * prop, int multi);
 #endif
