@@ -22,21 +22,23 @@
 #ifndef __REG_H__
 #define __REG_H__
 
-typedef struct {
-	char *app;	/* program name */
-	char *arg;	/* arguments/options */
-	char *sfx;	/* suffix */
-	int len;	/* suffix length */
-} reg, reg_t;
+typedef struct
+{
+  char *app;			/* program name */
+  char *arg;			/* arguments/options */
+  char *sfx;			/* suffix */
+  int len;			/* suffix length */
+}
+reg, reg_t;
 
-GList *reg_build_list(char *file);
-void reg_destroy_list(GList *list);
-GList *reg_add_suffix (GList *list, char *sfx, char *prog, char *args);
-char *reg_app_by_file (GList *list, char *file);
-char *reg_app_by_suffix(GList *list, char *sfx);
-reg_t *reg_prog_by_file (GList *list, char *file);
-reg_t *reg_prog_by_suffix (GList *list, char *sfx);
-GList *reg_app_list(GList *list);
-int reg_save (GList *list);
+GList *reg_build_list (char *file);
+void reg_destroy_list (GList * list);
+GList *reg_add_suffix (GList * list, char *sfx, char *prog, char *args);
+char *reg_app_by_file (GList * list, char *file);
+char *reg_app_by_suffix (GList * list, char *sfx);
+reg_t *reg_prog_by_file (GList * list, char *file);
+reg_t *reg_prog_by_suffix (GList * list, char *sfx);
+GList *reg_app_list (GList * list);
+int reg_save (GList * list);
 
 #endif
