@@ -22,6 +22,10 @@
 #include <glib.h>
 #include "top.h"
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 static GList *list;
 
 /*
@@ -30,7 +34,7 @@ static GList *list;
 void
 top_register (void *data)
 {
-	list = g_list_append (list, data);
+  list = g_list_append (list, data);
 }
 
 /*
@@ -38,7 +42,7 @@ top_register (void *data)
 void
 top_delete (void *data)
 {
-	list = g_list_remove (list, data);
+  list = g_list_remove (list, data);
 }
 
 /*
@@ -46,12 +50,11 @@ top_delete (void *data)
 void *
 top_has_more (void)
 {
-	return list;
+  return list;
 }
 
 int
 top_length (void)
 {
-	return g_list_length (list);
+  return g_list_length (list);
 }
-
