@@ -26,25 +26,28 @@
 
 #define URI_MAX 1024
 
-enum {
-	URI_LOCAL,
-	URI_FILE,
-	URI_HTTP,
-	URI_FTP,
-} UriType;
+enum
+{
+  URI_LOCAL,
+  URI_FILE,
+  URI_HTTP,
+  URI_FTP,
+}
+UriType;
 
-typedef struct {
-	char *url;
-	int len;
-	int type;
-} uri, uri_t;
+typedef struct
+{
+  char *url;
+  int len;
+  int type;
+}
+uri, uri_t;
 
 char *uri_clear_path (const char *);
 char *uri_to_quoted_list (GList *);
 int uri_parse_list (const char *, GList **);
-int uri_remove_file_prefix(char *, int);
-int uri_remove_file_prefix_from_list(GList *);
+int uri_remove_file_prefix (char *, int);
+int uri_remove_file_prefix_from_list (GList *);
 void uri_free_list (GList *);
 char *uri_basename (const char *);
 #endif
-
