@@ -24,20 +24,21 @@
 
 #define IGNORE_HIDDEN 1
 
-typedef struct {
-	void *compare;
-	char *trash;
-	char *xap;		/* xap home-dir, default: $HOME/.xap */
-	GList *reg;		/* registered programs */
-	int dnd_row;
-	void *dnd_menu;
-	char *dnd_data;
-	int dnd_has_drag;
-	int timer;
-	/* geometry */
-	int width;
-	int height;
-} cfg, cfg_t;
+typedef struct
+{
+  void *compare;
+  char *trash;
+  char *xap;			/* xap home-dir, default: $HOME/.xap */
+  GList *reg;			/* registered programs */
+  int dnd_row;
+  void *dnd_menu;
+  char *dnd_data;
+  int dnd_has_drag;
+  int timer;
+  /* geometry */
+  int width;
+  int height;
+}
+cfg, cfg_t;
 
 #endif
-
