@@ -25,10 +25,11 @@
 #define ROW_TOP_YPIXEL(clist,row) (((clist)->row_height*(row))+\
 	(((row))+1)*1+(clist)->voffset)
 
-void on_drag_data (GtkWidget *ctree, GdkDragContext *context, gint x, gint y,
-			GtkSelectionData *data, guint info, guint itme, void *client);
+void on_drag_data (GtkWidget * ctree, GdkDragContext * context, gint x,
+		   gint y, GtkSelectionData * data, guint info, guint itme,
+		   void *client);
 
-void on_drag_data_get (GtkWidget *widget, GdkDragContext *context,
-			GtkSelectionData *selection_data, guint info,
-			guint time, gpointer data);
+void on_drag_data_get (GtkWidget * widget, GdkDragContext * context,
+		       GtkSelectionData * selection_data, guint info,
+		       guint time, gpointer data);
 #endif
