@@ -22,14 +22,15 @@
 #ifndef __XTREE_GUI_H__
 #define __XTREE_GUI_H__
 
-typedef struct {
-	int x;
-	int y;
-	int width;
-	int height;
-} wgeo_t;
+typedef struct
+{
+  int x;
+  int y;
+  int width;
+  int height;
+}
+wgeo_t;
 
 void gui_init (int *argc, char ***argv, char *rc);
-void gui_main (char *path, char *xap, char *trash, char *reg, wgeo_t *,int);
+void gui_main (char *path, char *xap, char *trash, char *reg, wgeo_t *, int);
 #endif
-
