@@ -52,11 +52,12 @@
 #include "module.h"
 #include "session.h"
 
-/* Used to parse command line of clients for specific desk requests. */
-/* Todo: check for multiple desks. */
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 static XrmDatabase db;
-static XrmOptionDescRec table[] =
-{
+static XrmOptionDescRec table[] = {
   /* Want to accept "-workspace N" or -xrm "xfwm*desk:N" as options
    * to specify the desktop. I have to include dummy options that
    * are meaningless since Xrm seems to allow -w to match -workspace
@@ -118,7 +119,8 @@ AddWindow (Window w)
   tmp_win->flags = 0;
   tmp_win->w = w;
   tmp_win->icon_arranged = False;
-  
+  tmp_win->triggered = False;
+
   tmp_win->cmap_windows = (Window *) NULL;
 
   if (!PPosOverride)
@@ -128,28 +130,43 @@ AddWindow (Window w)
 	free ((char *) tmp_win);
 	return (NULL);
       }
-  tmp_win->name = NoName;
+  tmp_win->name = NULL;
   if (XGetWMName (dpy, tmp_win->w, &text_prop) != 0)
     {
       if (text_prop.format == 8)
-        { /* Multi-byte string */
-          char **text_list = NULL;
-          int text_list_num;
-          if (XmbTextPropertyToTextList(dpy, &text_prop,
-                                &text_list, &text_list_num) == Success)
-            {
+	{			/* Multi-byte string */
+	  char **text_list = NULL;
+	  int text_list_num;
+	  if (XmbTextPropertyToTextList (dpy, &text_prop,
+					 &text_list,
+					 &text_list_num) == Success)
+	    {
 	      if (text_list)
-	        {
-                  tmp_win->name = (char *) malloc(strlen (text_list[0]) + 1);
-                  strcpy (tmp_win->name, text_list[0]);
-                  XFreeStringList(text_list);
-	        } 
-            }
-          else
-            tmp_win->name = (char *) text_prop.value;
-        }
+		{
+		  tmp_win->name = (char *) malloc (strlen (text_list[0]) + 1);
+		  strcpy (tmp_win->name, text_list[0]);
+		  XFreeStringList (text_list);
+		}
+	    }
+	  else
+	    {
+	      tmp_win->name =
+		(char *) malloc (strlen ((char *) text_prop.value) + 1);
+	      strcpy (tmp_win->name, (char *) text_prop.value);
+	    }
+	}
       else
-        tmp_win->name = (char *) text_prop.value;
+	{
+	  tmp_win->name =
+	    (char *) malloc (strlen ((char *) text_prop.value) + 1);
+	  strcpy (tmp_win->name, (char *) text_prop.value);
+	}
+      XFree (text_prop.value);
+    }
+  if (!(tmp_win->name))
+    {
+      tmp_win->name = (char *) malloc (strlen (NoName) + 1);
+      strcpy (tmp_win->name, NoName);
     }
 
   /* removing NoClass change for now... */
@@ -189,7 +206,8 @@ AddWindow (Window w)
     }
 
   tflag = LookInList (Scr.TheList, tmp_win->name, &tmp_win->class, &value,
-		      &Desk, &border_width, &forecolor, &backcolor, &tmp_win->buttons);
+		      &Desk, &border_width, &forecolor, &backcolor,
+		      &tmp_win->buttons);
 
 
   tmp_win->title_height = GetDecor (tmp_win, TitleHeight) + tmp_win->bw;
@@ -233,7 +251,8 @@ AddWindow (Window w)
   if (XGetCommand (dpy, tmp_win->w, &client_argv, &client_argc))
     {
       XrmParseCommand (&db, table, 4, "xfwm", &client_argc, client_argv);
-      status = XrmGetResource (db, "xfwm.desk", "Xfwm.Desk", &str_type, &rm_value);
+      status =
+	XrmGetResource (db, "xfwm.desk", "Xfwm.Desk", &str_type, &rm_value);
       if ((status == True) && (rm_value.size != 0))
 	{
 	  Desk = atoi (rm_value.addr);
@@ -245,44 +264,48 @@ AddWindow (Window w)
     }
 
   if (!PlaceWindow (tmp_win, tflag, Desk))
-    return NULL;
+    {
+      free ((char *) tmp_win);
+      return (NULL);
+    }
 
   /* Load Session Management saved values */
-  MatchWinToSM(tmp_win);
+  MatchWinToSM (tmp_win);
 
   /* If restarting, retrieve parameters saved as Atoms */
- if ((XGetWindowProperty (dpy, tmp_win->w, _XA_XFWM_FLAGS, 0L, 1L, True,
-                          _XA_XFWM_FLAGS, &atype, &aformat, &nitems,
-                          &bytes_remain, &prop)) == Success)
-   {
-     if (prop != NULL)
-       {
-         tmp_win->flags |= (*(unsigned long *) prop) & (STICKY | ICON_MOVED | SHADED);
-         XFree (prop);
-       }
-   }
-  
- if ((XGetWindowProperty (dpy, tmp_win->w, _XA_XFWM_ICONPOS_X, 0L, 1L, True,
-                          _XA_XFWM_ICONPOS_X, &atype, &aformat, &nitems,
-                          &bytes_remain, &prop)) == Success)
-   {
-     if (prop != NULL)
-       {
-         tmp_win->icon_x_loc = *(int *) prop;
-         XFree (prop);
-       }
-   }
+  if ((XGetWindowProperty (dpy, tmp_win->w, _XA_XFWM_FLAGS, 0L, 1L, True,
+			   _XA_XFWM_FLAGS, &atype, &aformat, &nitems,
+			   &bytes_remain, &prop)) == Success)
+    {
+      if (prop != NULL)
+	{
+	  tmp_win->flags |=
+	    (*(unsigned long *) prop) & (STICKY | ICON_MOVED | SHADED);
+	  XFree (prop);
+	}
+    }
 
- if ((XGetWindowProperty (dpy, tmp_win->w, _XA_XFWM_ICONPOS_Y, 0L, 1L, True,
-                          _XA_XFWM_ICONPOS_Y, &atype, &aformat, &nitems,
-                          &bytes_remain, &prop)) == Success)
-   {
-     if (prop != NULL)
-       {
-         tmp_win->icon_y_loc = *(int *) prop;
-         XFree (prop);
-       }
-   }
+  if ((XGetWindowProperty (dpy, tmp_win->w, _XA_XFWM_ICONPOS_X, 0L, 1L, True,
+			   _XA_XFWM_ICONPOS_X, &atype, &aformat, &nitems,
+			   &bytes_remain, &prop)) == Success)
+    {
+      if (prop != NULL)
+	{
+	  tmp_win->icon_x_loc = *(int *) prop;
+	  XFree (prop);
+	}
+    }
+
+  if ((XGetWindowProperty (dpy, tmp_win->w, _XA_XFWM_ICONPOS_Y, 0L, 1L, True,
+			   _XA_XFWM_ICONPOS_Y, &atype, &aformat, &nitems,
+			   &bytes_remain, &prop)) == Success)
+    {
+      if (prop != NULL)
+	{
+	  tmp_win->icon_y_loc = *(int *) prop;
+	  XFree (prop);
+	}
+    }
 
   /*
    * Make sure the client window still exists.  We don't want to leave an
@@ -291,45 +314,56 @@ AddWindow (Window w)
    * reparented, so we'll get a DestroyNotify for it.  We won't have
    * gotten one for anything up to here, however.
    */
-  XSync (dpy, 0);
+  MyXGrabServer (dpy);
   if (XGetGeometry (dpy, w, &JunkRoot, &JunkX, &JunkY,
-		    &JunkWidth, &JunkHeight,
-		    &JunkBW, &JunkDepth) == 0)
+		    &JunkWidth, &JunkHeight, &JunkBW, &JunkDepth) == 0)
     {
       free ((char *) tmp_win);
+      MyXUngrabServer (dpy);
       return (NULL);
     }
 
   XSetWindowBorderWidth (dpy, tmp_win->w, 0);
 
   tmp_win->icon_name = NULL;
-  if (XGetWMIconName (dpy, tmp_win->w, &text_prop) != 0) 
+  if (XGetWMIconName (dpy, tmp_win->w, &text_prop) != 0)
     {
       if (text_prop.format == 8)
-	{ /* Multi-byte string */
+	{			/* Multi-byte string */
 	  char **text_list = NULL;
 	  int text_list_num;
-	  if (XmbTextPropertyToTextList(dpy, &text_prop,
-                        	&text_list, &text_list_num) == Success)
-            {
-              if (text_list)
-	        {
-                  tmp_win->icon_name = (char *) malloc(strlen (text_list[0]) + 1);
-                  strcpy (tmp_win->icon_name, text_list[0]);
-                  XFreeStringList(text_list);
-	        }
-            }
+	  if (XmbTextPropertyToTextList (dpy, &text_prop,
+					 &text_list,
+					 &text_list_num) == Success)
+	    {
+	      if (text_list)
+		{
+		  tmp_win->icon_name =
+		    (char *) malloc (strlen (text_list[0]) + 1);
+		  strcpy (tmp_win->icon_name, text_list[0]);
+		  XFreeStringList (text_list);
+		}
+	    }
 	  else
-            tmp_win->icon_name = (char *) text_prop.value;
+	    {
+	      tmp_win->icon_name =
+		(char *) malloc (strlen ((char *) text_prop.value) + 1);
+	      strcpy (tmp_win->icon_name, (char *) text_prop.value);
+	    }
 	}
       else
-	tmp_win->icon_name = (char *) text_prop.value;
+	{
+	  tmp_win->icon_name =
+	    (char *) malloc (strlen ((char *) text_prop.value) + 1);
+	  strcpy (tmp_win->icon_name, (char *) text_prop.value);
+	}
+      XFree (text_prop.value);
+    }
+  if (!(tmp_win->icon_name))
+    {
+      tmp_win->icon_name = (char *) malloc (strlen (tmp_win->name) + 1);
+      strcpy (tmp_win->icon_name, tmp_win->name);
     }
-  else
-    tmp_win->icon_name = tmp_win->name;
-  
-  if (tmp_win->icon_name == (char *) NULL)
-    tmp_win->icon_name = tmp_win->name;
 
   tmp_win->flags &= ~ICONIFIED;
   tmp_win->flags &= ~ICON_UNMAPPED;
@@ -373,25 +407,38 @@ AddWindow (Window w)
 
   valuemask |= CWCursor | CWEventMask;
   attributes.cursor = Scr.XfwmCursors[DEFAULT];
-  attributes.event_mask = (SubstructureRedirectMask | 
-  		           ButtonPressMask | ButtonReleaseMask | 
-                           EnterWindowMask | LeaveWindowMask | 
+  attributes.event_mask = (SubstructureRedirectMask |
+			   ButtonPressMask | ButtonReleaseMask |
+			   EnterWindowMask | LeaveWindowMask | 
                            ExposureMask);
 
   tmp_win->frame =
     XCreateWindow (dpy, Scr.Root, tmp_win->frame_x, tmp_win->frame_y,
 		   tmp_win->frame_width, tmp_win->frame_height,
-		   tmp_win->bw, CopyFromParent, InputOutput,
-		   CopyFromParent,
-		   (valuemask & ~CWBackPixel),
-		   &attributes);
+		   0, CopyFromParent, InputOutput, CopyFromParent,
+		   (valuemask & ~CWBackPixel), &attributes);
 
-  attributes.save_under = FALSE;
-  attributes.backing_store = WhenMapped;
-  attributes.event_mask = (ButtonPressMask | ButtonReleaseMask | 
+  /* Reparenting is back :-( MWM is designed like this, and some 
+   * Java (tm) application seem to mis it. Argh !
+   */
+  attributes.cursor = Scr.XfwmCursors[DEFAULT];
+  tmp_win->Parent =
+    XCreateWindow (dpy, tmp_win->frame,
+		   tmp_win->boundary_width,
+		   tmp_win->boundary_width + tmp_win->title_height,
+		   (tmp_win->frame_width - 2 * tmp_win->boundary_width),
+		   (tmp_win->frame_height - 2 * tmp_win->boundary_width -
+		    tmp_win->title_height), tmp_win->bw, CopyFromParent,
+		   InputOutput, CopyFromParent, (valuemask & ~CWBackPixel),
+                   &attributes);
+
+  attributes.event_mask = (ButtonPressMask | ButtonReleaseMask |
+		        /* EnterWindowMask | LeaveWindowMask | */
                            ExposureMask);
 
   valuemask |= CWBackingStore;
+  attributes.backing_store = WhenMapped;
+
   tmp_win->title_x = tmp_win->title_y = 0;
   tmp_win->title_w = 0;
   tmp_win->title_width = tmp_win->frame_width - 2 * tmp_win->corner_width
@@ -409,33 +456,31 @@ AddWindow (Window w)
 	    XCreateWindow (dpy, tmp_win->frame, 0, 0,
 			   tmp_win->corner_width, tmp_win->corner_width,
 			   0, CopyFromParent, InputOutput,
-			   CopyFromParent,
-			   valuemask,
-			   &attributes);
+			   CopyFromParent, valuemask, &attributes);
 	}
     }
-    
+
   if (tmp_win->flags & TITLE)
     {
       tmp_win->title_x = tmp_win->boundary_width + tmp_win->title_height + 1;
       tmp_win->title_y = tmp_win->boundary_width;
       attributes.cursor = Scr.XfwmCursors[TITLE_CURSOR];
       tmp_win->title_w =
-	XCreateWindow (dpy, tmp_win->frame, tmp_win->title_x, tmp_win->title_y,
-		       tmp_win->title_width, tmp_win->title_height, 0,
-		       CopyFromParent, InputOutput, CopyFromParent,
-		       (valuemask & ~CWBackPixel), &attributes);
+	XCreateWindow (dpy, tmp_win->frame, tmp_win->title_x,
+		       tmp_win->title_y, tmp_win->title_width,
+		       tmp_win->title_height, 0, CopyFromParent, InputOutput,
+		       CopyFromParent, (valuemask & ~CWBackPixel),
+		       &attributes);
       attributes.cursor = Scr.XfwmCursors[SYS];
       for (i = 2; i >= 0; i--)
 	{
 	  if ((i < Scr.nr_left_buttons) && (tmp_win->left_w[i] > 0))
 	    {
 	      tmp_win->left_w[i] =
-		XCreateWindow (dpy, tmp_win->frame, tmp_win->title_height * i, 0,
-			    tmp_win->title_height, tmp_win->title_height, 0,
-			       CopyFromParent, InputOutput,
-			       CopyFromParent,
-			       valuemask,
+		XCreateWindow (dpy, tmp_win->frame, tmp_win->title_height * i,
+			       0, tmp_win->title_height,
+			       tmp_win->title_height, 0, CopyFromParent,
+			       InputOutput, CopyFromParent, valuemask,
 			       &attributes);
 	    }
 	  else
@@ -450,9 +495,7 @@ AddWindow (Window w)
 			       0, tmp_win->title_height,
 			       tmp_win->title_height,
 			       0, CopyFromParent, InputOutput,
-			       CopyFromParent,
-			       valuemask,
-			       &attributes);
+			       CopyFromParent, valuemask, &attributes);
 	    }
 	  else
 	    tmp_win->right_w[i] = None;
@@ -468,51 +511,27 @@ AddWindow (Window w)
 	    XCreateWindow (dpy, tmp_win->frame, 0, 0, tmp_win->boundary_width,
 			   tmp_win->boundary_width, 0, CopyFromParent,
 			   InputOutput, CopyFromParent,
-			   (valuemask & ~CWBackPixel),
-			   &attributes);
+			   (valuemask & ~CWBackPixel), &attributes);
 	}
     }
 
 
   XMapSubwindows (dpy, tmp_win->frame);
 
-  XReparentWindow (dpy, tmp_win->w, tmp_win->frame, 0, 0);
+  XRaiseWindow (dpy, tmp_win->Parent);
+  XReparentWindow (dpy, tmp_win->w, tmp_win->Parent, 0, 0);
 
-  valuemask = (CWEventMask | CWDontPropagate | CWBackingStore);
-  attributes.event_mask = (StructureNotifyMask | 
-  		           PropertyChangeMask |
-			   VisibilityChangeMask | 
-			   ColormapChangeMask | 
-                           EnterWindowMask | LeaveWindowMask | 
-                           FocusChangeMask);
+  valuemask = (CWEventMask | CWDontPropagate);
+  attributes.event_mask = (StructureNotifyMask |
+			   PropertyChangeMask |
+			   VisibilityChangeMask |
+			   ColormapChangeMask |
+			   EnterWindowMask | LeaveWindowMask |
+			   FocusChangeMask);
 
   attributes.do_not_propagate_mask = ButtonPressMask | ButtonReleaseMask;
 
   XChangeWindowAttributes (dpy, tmp_win->w, valuemask, &attributes);
-  tmp_win->name = NoName;
-  if (XGetWMName (dpy, tmp_win->w, &text_prop) != 0)
-    {
-      if (text_prop.format == 8)
-        { /* Multi-byte string */
-          char **text_list = NULL;
-          int text_list_num;
-          if (XmbTextPropertyToTextList(dpy, &text_prop,
-                                &text_list, &text_list_num) == Success)
-            {
-	      if (text_list)
-	        {
-                  tmp_win->name = (char *) malloc(strlen (text_list[0]) + 1);
-                  strcpy (tmp_win->name, text_list[0]);
-                  XFreeStringList(text_list);
-	        } 
-            }
-          else
-            tmp_win->name = (char *) text_prop.value;
-        }
-      else
-        tmp_win->name = (char *) text_prop.value;
-    }
-
   XAddToSaveSet (dpy, tmp_win->w);
 
   /*
@@ -540,11 +559,13 @@ AddWindow (Window w)
   GrabKeys (tmp_win);
   XSaveContext (dpy, tmp_win->w, XfwmContext, (caddr_t) tmp_win);
   XSaveContext (dpy, tmp_win->frame, XfwmContext, (caddr_t) tmp_win);
+  XSaveContext (dpy, tmp_win->Parent, XfwmContext, (caddr_t) tmp_win);
   if (tmp_win->flags & TITLE)
     {
       XSaveContext (dpy, tmp_win->title_w, XfwmContext, (caddr_t) tmp_win);
       for (i = 0; i < Scr.nr_left_buttons; i++)
-	XSaveContext (dpy, tmp_win->left_w[i], XfwmContext, (caddr_t) tmp_win);
+	XSaveContext (dpy, tmp_win->left_w[i], XfwmContext,
+		      (caddr_t) tmp_win);
       for (i = 0; i < Scr.nr_right_buttons; i++)
 	if (tmp_win->right_w[i] != None)
 	  XSaveContext (dpy, tmp_win->right_w[i], XfwmContext,
@@ -554,13 +575,16 @@ AddWindow (Window w)
     {
       for (i = 0; i < 4; i++)
 	{
-	  XSaveContext (dpy, tmp_win->sides[i], XfwmContext, (caddr_t) tmp_win);
-	  XSaveContext (dpy, tmp_win->corners[i], XfwmContext, (caddr_t) tmp_win);
+	  XSaveContext (dpy, tmp_win->sides[i], XfwmContext,
+			(caddr_t) tmp_win);
+	  XSaveContext (dpy, tmp_win->corners[i], XfwmContext,
+			(caddr_t) tmp_win);
 	}
     }
 
+  MyXUngrabServer (dpy);
   RaiseWindow (tmp_win);
-  KeepOnTop();
+  KeepOnTop ();
 
   XGetGeometry (dpy, tmp_win->w, &JunkRoot, &JunkX, &JunkY,
 		&JunkWidth, &JunkHeight, &JunkBW, &JunkDepth);
@@ -568,27 +592,25 @@ AddWindow (Window w)
 			 &a, &b, &JunkChild);
   tmp_win->xdiff -= a;
   tmp_win->ydiff -= b;
-  
-  XGrabButton (dpy, AnyButton, 0, tmp_win->frame, True,
-               ButtonPressMask, GrabModeSync, GrabModeAsync, None,
-               None);
-  XGrabButton (dpy, AnyButton, AnyModifier, tmp_win->frame, True,
-               ButtonPressMask, GrabModeSync, GrabModeAsync, None,
-               None);
-  
-  BroadcastConfig (M_ADD_WINDOW, tmp_win);
 
-  BroadcastName (M_WINDOW_NAME, tmp_win->w, tmp_win->frame,
+  MyXGrabButton (dpy, AnyButton, 0, tmp_win->frame, True,
+		 ButtonPressMask, GrabModeSync, GrabModeAsync, None, None);
+  MyXGrabButton (dpy, AnyButton, AnyModifier, tmp_win->frame, True,
+		 ButtonPressMask, GrabModeSync, GrabModeAsync, None, None);
+
+  BroadcastConfig (XFCE_M_ADD_WINDOW, tmp_win);
+
+  BroadcastName (XFCE_M_WINDOW_NAME, tmp_win->w, tmp_win->frame,
 		 (unsigned long) tmp_win, tmp_win->name);
-  BroadcastName (M_ICON_NAME, tmp_win->w, tmp_win->frame,
+  BroadcastName (XFCE_M_ICON_NAME, tmp_win->w, tmp_win->frame,
 		 (unsigned long) tmp_win, tmp_win->icon_name);
   if (tmp_win->icon_bitmap_file != NULL &&
       tmp_win->icon_bitmap_file != Scr.DefaultIcon)
-    BroadcastName (M_ICON_FILE, tmp_win->w, tmp_win->frame,
+    BroadcastName (XFCE_M_ICON_FILE, tmp_win->w, tmp_win->frame,
 		   (unsigned long) tmp_win, tmp_win->icon_bitmap_file);
-  BroadcastName (M_RES_CLASS, tmp_win->w, tmp_win->frame,
+  BroadcastName (XFCE_M_RES_CLASS, tmp_win->w, tmp_win->frame,
 		 (unsigned long) tmp_win, tmp_win->class.res_class);
-  BroadcastName (M_RES_NAME, tmp_win->w, tmp_win->frame,
+  BroadcastName (XFCE_M_RES_NAME, tmp_win->w, tmp_win->frame,
 		 (unsigned long) tmp_win, tmp_win->class.res_name);
 
   FetchWmProtocols (tmp_win);
@@ -597,7 +619,9 @@ AddWindow (Window w)
     tmp_win->attr.colormap = Scr.XfwmRoot.attr.colormap;
   InstallWindowColormaps (colormap_win);
 
-  XSync(dpy,0);
+  if (tmp_win->flags & SHADED)
+    XUnmapWindow (dpy, tmp_win->Parent);
+
   return (tmp_win);
 }
 
@@ -623,19 +647,17 @@ GrabButtons (XfwmWindow * tmp_win)
 	{
 	  if (MouseEntry->Button_Key > 0)
 	    {
-	      XGrabButton (dpy, MouseEntry->Button_Key, MouseEntry->Modifier,
-			   tmp_win->w,
-			   True, ButtonPressMask | ButtonReleaseMask,
-			   GrabModeAsync, GrabModeAsync, None,
-			   None);
+	      MyXGrabButton (dpy, MouseEntry->Button_Key,
+			     MouseEntry->Modifier, tmp_win->w, True,
+			     ButtonPressMask | ButtonReleaseMask,
+			     GrabModeAsync, GrabModeAsync, None, None);
 	    }
 	  else
 	    {
-	      XGrabButton (dpy, AnyButton, MouseEntry->Modifier,
-			   tmp_win->w,
-			   True, ButtonPressMask | ButtonReleaseMask,
-			   GrabModeAsync, GrabModeAsync, None,
-			   None);
+	      MyXGrabButton (dpy, AnyButton, MouseEntry->Modifier,
+			     tmp_win->w, True,
+			     ButtonPressMask | ButtonReleaseMask,
+			     GrabModeAsync, GrabModeAsync, None, None);
 	    }
 	}
       MouseEntry = MouseEntry->NextBinding;
@@ -658,44 +680,11 @@ GrabKeys (XfwmWindow * tmp_win)
   Binding *tmp;
   for (tmp = Scr.AllBindings; tmp != NULL; tmp = tmp->NextBinding)
     {
-      if ((tmp->Context & (C_WINDOW | C_TITLE | C_RALL | C_LALL | C_SIDEBAR)) &&
-	  (tmp->IsMouse == 0))
+      if ((tmp->Context & (C_WINDOW | C_TITLE | C_RALL | C_LALL | C_SIDEBAR))
+	  && (tmp->IsMouse == 0))
 	{
-	  XGrabKey (dpy, tmp->Button_Key, tmp->Modifier, tmp_win->frame, True,
-		    GrabModeAsync, GrabModeAsync);
-	  if (tmp->Modifier != AnyModifier)
-	    {
-	      XGrabKey (dpy, tmp->Button_Key, tmp->Modifier | LockMask,
-			tmp_win->frame, True,
-			GrabModeAsync, GrabModeAsync);
-              if (NumLockMask != 0)
-	        {
-	          XGrabKey (dpy, tmp->Button_Key, tmp->Modifier | NumLockMask,
-			tmp_win->frame, True,
-			GrabModeAsync, GrabModeAsync);
-	          XGrabKey (dpy, tmp->Button_Key, tmp->Modifier | NumLockMask | LockMask,
-			tmp_win->frame, True,
-			GrabModeAsync, GrabModeAsync);
-	        }
-              if (ScrollLockMask != 0)
-	        {
-	          XGrabKey (dpy, tmp->Button_Key, tmp->Modifier | ScrollLockMask,
-			tmp_win->frame, True,
-			GrabModeAsync, GrabModeAsync);
-	          XGrabKey (dpy, tmp->Button_Key, tmp->Modifier | ScrollLockMask | LockMask,
-			tmp_win->frame, True,
-			GrabModeAsync, GrabModeAsync);
-	        }
-              if ((NumLockMask != 0) && (ScrollLockMask != 0))
-	        {
-	          XGrabKey (dpy, tmp->Button_Key, tmp->Modifier | NumLockMask | ScrollLockMask,
-			tmp_win->frame, True,
-			GrabModeAsync, GrabModeAsync);
-	          XGrabKey (dpy, tmp->Button_Key, tmp->Modifier | NumLockMask | ScrollLockMask | LockMask,
-			tmp_win->frame, True,
-			GrabModeAsync, GrabModeAsync);
-	        }
-	    }
+	  MyXGrabKey (dpy, tmp->Button_Key, tmp->Modifier, tmp_win->frame,
+		      True, GrabModeAsync, GrabModeAsync);
 	}
     }
   return;
@@ -858,8 +847,7 @@ unsigned long
 LookInList (name_list * list, char *name, XClassHint * class,
 	    char **value,
 	    int *Desk, int *border_width,
-	    char **forecolor, char **backcolor,
-	    unsigned long *buttons)
+	    char **forecolor, char **backcolor, unsigned long *buttons)
 {
   name_list *nptr;
   unsigned long retval = 0;
