@@ -13,6 +13,10 @@
 #include "screen.h"
 #include "module.h"
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 #define Shift  1
 #define Ctrl   2
 #define Alt    4
@@ -21,14 +25,13 @@
 #define Hyper  32
 
 struct charstring
-  {
-    char key;
-    int value;
-  };
+{
+  char key;
+  int value;
+};
 
 /* The keys musat be in lower case! */
-struct charstring win_contexts[] =
-{
+struct charstring win_contexts[] = {
   {'w', C_WINDOW},
   {'t', C_TITLE},
   {'i', C_ICON},
@@ -51,8 +54,7 @@ struct charstring win_contexts[] =
 };
 
 /* The keys musat be in lower case! */
-struct charstring key_modifiers[] =
-{
+struct charstring key_modifiers[] = {
   {'s', ShiftMask},
   {'c', ControlMask},
   {'m', Mod1Mask},
@@ -66,27 +68,28 @@ struct charstring key_modifiers[] =
   {0, 0}
 };
 
-unsigned int vmod(int m) 
+unsigned int
+vmod (int m)
 {
-    int vm = 0;
+  int vm = 0;
 
-    if (m & ShiftMask)
-        vm |= Shift;
-    if (m & ControlMask)
-        vm |= Ctrl;
-    if (m & AltMask)
-        vm |= Alt;
-    if (m & MetaMask)
-        vm |= Meta;
-    if (m & SuperMask)
-        vm |= Super;
-    if (m & HyperMask)
-        vm |= Hyper;
+  if (m & ShiftMask)
+    vm |= Shift;
+  if (m & ControlMask)
+    vm |= Ctrl;
+  if (m & AltMask)
+    vm |= Alt;
+  if (m & MetaMask)
+    vm |= Meta;
+  if (m & SuperMask)
+    vm |= Super;
+  if (m & HyperMask)
+    vm |= Hyper;
 
-    if ((vm & (Ctrl | Alt | Meta)) == Meta)
-        vm = (vm & ~Meta) | Ctrl | Alt;
+  if ((vm & (Ctrl | Alt | Meta)) == Meta)
+    vm = (vm & ~Meta) | Ctrl | Alt;
 
-    return vm;
+  return vm;
 }
 
 void find_context (char *string, int *output, struct charstring *table,
@@ -102,6 +105,7 @@ remove_binding (int contexts, int mods, int button, KeySym keysym,
 {
   Binding *temp = Scr.AllBindings, *temp2, *prev = NULL;
   KeyCode keycode = 0;
+  XfwmWindow *t;
 
   if (!mouse_binding)
     keycode = XKeysymToKeycode (dpy, keysym);
@@ -111,11 +115,25 @@ remove_binding (int contexts, int mods, int button, KeySym keysym,
       temp2 = temp->NextBinding;
       if (temp->IsMouse == mouse_binding)
 	{
-	  if ((temp->Button_Key == ((mouse_binding) ? (button) : (keycode))) &&
-	      (temp->Context == contexts) &&
-	      (temp->Modifier == mods))
+	  if ((temp->Button_Key == ((mouse_binding) ? (button) : (keycode)))
+	      && (temp->Context == contexts) && (temp->Modifier == mods))
 	    {
 	      /* we found it, remove it from list */
+	      if ((temp->Action != NULL) && (temp->Context & C_WINDOW)
+		  && (temp->IsMouse == 1))
+		{
+		  MyXGrabServer (dpy);
+		  for (t = Scr.XfwmRoot.next; t != NULL; t = t->next)
+		    {
+		      if (temp->Button_Key > 0)
+			MyXUngrabButton (dpy, temp->Button_Key,
+					 temp->Modifier, t->w);
+		      else
+			MyXUngrabButton (dpy, AnyButton, temp->Modifier,
+					 t->w);
+		    }
+		  MyXUngrabServer (dpy);
+		}
 	      if (prev)		/* middle of list */
 		{
 		  prev->NextBinding = temp2;
@@ -176,8 +194,8 @@ ParseMouseEntry (XEvent * eventp, Window w, XfwmWindow * tmp_win,
     }
   if ((n1 != 1) || (n2 != 1) || (n3 != 1))
     {
-      xfwm_msg (ERR, "ParseMouseEntry", "Mouse binding: Syntax error in line %s",
-		tline);
+      xfwm_msg (ERR, "ParseMouseEntry",
+		"Mouse binding: Syntax error in line %s", tline);
       return;
     }
 
@@ -382,8 +400,7 @@ find_context (char *string, int *output, struct charstring *table,
 	}
       if (!matched)
 	{
-	  xfwm_msg (ERR, "find_context",
-		    "bad context in line %s", tline);
+	  xfwm_msg (ERR, "find_context", "bad context in line %s", tline);
 	}
       i++;
     }
