@@ -30,27 +30,25 @@
 
 #include <X11/extensions/shape.h>
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 void DrawButton (XfwmWindow * t,
 		 Window win,
 		 int W,
 		 int H,
 		 ButtonFace * bf,
-		 GC ReliefGC, GC ShadowGC,
-		 Boolean inverted,
-		 int stateflags);
+		 GC ReliefGC, GC ShadowGC, Boolean inverted, int stateflags);
 
 void DrawLinePattern (Window win,
 		      GC ReliefGC,
 		      GC ShadowGC,
-		      struct vector_coords *coords,
-		      int w, int h);
+		      struct vector_coords *coords, int w, int h);
 
 void
-RelieveRoundedRectangle (Window win, 
-                         int x, 
-                         int y, 
-                         int w, 
-                         int h, GC Hilite, GC Shadow);
+RelieveRoundedRectangle (Window win,
+			 int x, int y, int w, int h, GC Hilite, GC Shadow);
 
 #define GetButtonState(window) (onoroff ? Active : Inactive)
 
@@ -158,8 +156,8 @@ SetBorder (XfwmWindow * t, Bool onoroff, Bool force, Bool Mapped,
 	      enum ButtonState bs = GetButtonState (t->left_w[i]);
 	      ButtonFace *bf = &GetDecor (t, left_buttons[i].state[bs]);
 	      ChangeWindowColor (t->left_w[i], valuemask);
-	      if (flush_expose (t->left_w[i]) || (expose_win == t->left_w[i]) ||
-		  (expose_win == None) || NewColor)
+	      if (flush_expose (t->left_w[i]) || (expose_win == t->left_w[i])
+		  || (expose_win == None) || NewColor)
 		{
 		  int inverted = PressedW == t->left_w[i];
 		  if (bf->style & UseTitleStyle)
@@ -169,13 +167,16 @@ SetBorder (XfwmWindow * t, Bool onoroff, Bool force, Bool Mapped,
 			DrawButton (t, t->left_w[i],
 				    t->title_height, t->title_height,
 				    tsbf, ReliefGC, ShadowGC,
-			     inverted, GetDecor (t, left_buttons[i].flags));
+				    inverted, GetDecor (t,
+							left_buttons
+							[i].flags));
 		    }
 		  for (; bf; bf = bf->next)
 		    DrawButton (t, t->left_w[i],
 				t->title_height, t->title_height,
 				bf, ReliefGC, ShadowGC,
-			     inverted, GetDecor (t, left_buttons[i].flags));
+				inverted, GetDecor (t,
+						    left_buttons[i].flags));
 
 		}
 	    }
@@ -187,8 +188,9 @@ SetBorder (XfwmWindow * t, Bool onoroff, Bool force, Bool Mapped,
 	      enum ButtonState bs = GetButtonState (t->right_w[i]);
 	      ButtonFace *bf = &GetDecor (t, right_buttons[i].state[bs]);
 	      ChangeWindowColor (t->right_w[i], valuemask);
-	      if (flush_expose (t->right_w[i]) || (expose_win == t->right_w[i]) ||
-		  (expose_win == None) || NewColor)
+	      if (flush_expose (t->right_w[i])
+		  || (expose_win == t->right_w[i]) || (expose_win == None)
+		  || NewColor)
 		{
 		  int inverted = PressedW == t->right_w[i];
 		  if (bf->style & UseTitleStyle)
@@ -198,55 +200,59 @@ SetBorder (XfwmWindow * t, Bool onoroff, Bool force, Bool Mapped,
 			DrawButton (t, t->right_w[i],
 				    t->title_height, t->title_height,
 				    tsbf, ReliefGC, ShadowGC,
-			    inverted, GetDecor (t, right_buttons[i].flags));
+				    inverted, GetDecor (t,
+							right_buttons
+							[i].flags));
 		    }
 		  for (; bf; bf = bf->next)
 		    DrawButton (t, t->right_w[i],
 				t->title_height, t->title_height,
 				bf, ReliefGC, ShadowGC,
-			    inverted, GetDecor (t, right_buttons[i].flags));
+				inverted, GetDecor (t,
+						    right_buttons[i].flags));
 
 		}
 	    }
 	}
-     if (flush_expose (t->title_w) || (expose_win ==t->title_w) || (expose_win == None) || NewColor)
-       SetTitleBar (t, onoroff, False);
+      if (flush_expose (t->title_w) || (expose_win == t->title_w)
+	  || (expose_win == None) || NewColor)
+	SetTitleBar (t, onoroff, False);
     }
 
   if (t->flags & BORDER)
     {
-       /* draw relief lines */
-       y = fh - 2 * t->corner_width;
-       x = t->frame_width - 2 * t->corner_width + t->bw;
-       for (i = 0; i < 4; i++)
-         {
-           int vertical = i % 2;
-           if ((flush_expose (t->sides[i])) || (expose_win == t->sides[i]) ||
-     	       (expose_win == None) || NewColor)
-     	     {
-     	       GC sgc, rgc;
+      /* draw relief lines */
+      y = fh - 2 * t->corner_width;
+      x = t->frame_width - 2 * t->corner_width + t->bw;
+      for (i = 0; i < 4; i++)
+	{
+	  int vertical = i % 2;
+	  if ((flush_expose (t->sides[i])) || (expose_win == t->sides[i]) ||
+	      (expose_win == None) || NewColor)
+	    {
+	      GC sgc, rgc;
 
-     	       rgc = ReliefGC;
-     	       sgc = ShadowGC;
-     	       RelieveWindow (t, t->sides[i], 0, 0,
-     			      ((vertical) ? t->boundary_width : x),
-     			      ((vertical) ? y : t->boundary_width),
-     			      rgc, sgc, (0x0001 << i));
-     	     }
-           ChangeWindowColor (t->corners[i], valuemask);
-           if ((flush_expose (t->corners[i])) || (expose_win == t->corners[i]) ||
-     	       (expose_win == None) || NewColor)
-     	     {
-     	       GC rgc, sgc;
+	      rgc = ReliefGC;
+	      sgc = ShadowGC;
+	      RelieveWindow (t, t->sides[i], 0, 0,
+			     ((vertical) ? t->boundary_width : x),
+			     ((vertical) ? y : t->boundary_width),
+			     rgc, sgc, (0x0001 << i));
+	    }
+	  ChangeWindowColor (t->corners[i], valuemask);
+	  if ((flush_expose (t->corners[i])) || (expose_win == t->corners[i])
+	      || (expose_win == None) || NewColor)
+	    {
+	      GC rgc, sgc;
 
-     	       rgc = ReliefGC;
-     	       sgc = ShadowGC;
-     	       RelieveWindow (t, t->corners[i], 0, 0, t->corner_width,
-     		       ((i / 2) ? t->corner_width + t->bw : t->corner_width),
-     			      rgc, sgc, corners[i]);
+	      rgc = ReliefGC;
+	      sgc = ShadowGC;
+	      RelieveWindow (t, t->corners[i], 0, 0, t->corner_width,
+			     ((i / 2) ? t->corner_width +
+			      t->bw : t->corner_width), rgc, sgc, corners[i]);
 
-     	     }
-        }
+	    }
+	}
     }
 }
 
@@ -262,8 +268,9 @@ DrawButton (XfwmWindow * t, Window win, int w, int h,
 {
   int type = bf->style & ButtonFaceTypeMask;
   GC BackGC = NULL;
-  
-  if (w - t->boundary_width + t->bw  <= 0) return;
+
+  if (w - t->boundary_width + t->bw <= 0)
+    return;
 
   switch (type)
     {
@@ -277,68 +284,70 @@ DrawButton (XfwmWindow * t, Window win, int w, int h,
 	bounds.width = w;
 	bounds.height = h;
 	flush_expose (win);
-        BackGC = ((Scr.Hilite == t) ? GetDecor (t, HiBackGC) : GetDecor (t, LoBackGC));
-        
-        XSetForeground (dpy, Scr.TransMaskGC, bf->u.back);
-        if (w > h)
-          {
-            XFillRectangle (dpy, win, BackGC,0, 0, bounds.height / 2, bounds.height);
-	      
-            XFillArc (dpy, win, Scr.TransMaskGC, 0, 
-                                                 0, 
-                                                 bounds.height, 
-                                                 bounds.height - 1,
-                                                 90 * 64, 180 * 64);
-            XFillRectangle (dpy, win, Scr.TransMaskGC,
-			      bounds.height / 2 , 1,
-			      bounds.width  - bounds.height, bounds.height - 1);
+	BackGC =
+	  ((Scr.Hilite == t) ? GetDecor (t, HiBackGC) :
+	   GetDecor (t, LoBackGC));
 
-            XFillRectangle (dpy, win, BackGC, bounds.width  - (bounds.height / 2), 
-		                                  0, bounds.height / 2, bounds.height);
+	XSetForeground (dpy, Scr.TransMaskGC, bf->u.back);
+	if (w > h)
+	  {
+	    XFillRectangle (dpy, win, BackGC, 0, 0, bounds.height / 2,
+			    bounds.height);
 
-            XFillArc (dpy, win, Scr.TransMaskGC, bounds.width  - bounds.height - 1, 
-                                                 0, 
-                                                 bounds.height, 
-                                                 bounds.height - 1,
-                                                 90 * 64,  - 180 * 64);
-          }
-        else
-          XFillRectangle (dpy, win, Scr.TransMaskGC,0 , 0, w, h - 1);
+	    XFillArc (dpy, win, Scr.TransMaskGC, 0,
+		      0, bounds.height, bounds.height - 1, 90 * 64, 180 * 64);
+	    XFillRectangle (dpy, win, Scr.TransMaskGC,
+			    bounds.height / 2, 1,
+			    bounds.width - bounds.height, bounds.height - 1);
+
+	    XFillRectangle (dpy, win, BackGC,
+			    bounds.width - (bounds.height / 2), 0,
+			    bounds.height / 2, bounds.height);
+
+	    XFillArc (dpy, win, Scr.TransMaskGC,
+		      bounds.width - bounds.height - 1, 0, bounds.height,
+		      bounds.height - 1, 90 * 64, -180 * 64);
+	  }
+	else
+	  XFillRectangle (dpy, win, Scr.TransMaskGC, 0, 0, w, h - 1);
       }
       break;
 
     case VectorButton:
-      BackGC = ((Scr.Hilite == t) ? GetDecor (t, HiBackGC) : GetDecor (t, LoBackGC));
-      if (((stateflags & MWMDecorMaximize) && (t->flags & MAXIMIZED)) ||
-          ((stateflags & DecorSticky) && (t->flags & STICKY)) ||
-          ((stateflags & DecorShaded) && (t->flags & SHADED)))
-        {
-          if (Scr.Options & BitmapButtons)
-            {
-              XSetClipOrigin(dpy, BackGC, (w - 16) / 2, (h - 16) / 2);
-              XCopyPlane(dpy, bf->bitmap_pressed, win, BackGC, 0, 0, 15, 15, (w - 16) / 2, (h - 16) / 2, 1);
-            }
-          else
-            {
-  	      DrawLinePattern (win, ShadowGC, ReliefGC, &bf->vector, w, h);
-            }
-        }
+      BackGC =
+	((Scr.Hilite == t) ? GetDecor (t, HiBackGC) : GetDecor (t, LoBackGC));
+      if (((stateflags & MWMDecorMaximize) && (t->flags & MAXIMIZED))
+	  || ((stateflags & DecorSticky) && (t->flags & STICKY))
+	  || ((stateflags & DecorShaded) && (t->flags & SHADED)))
+	{
+	  if (Scr.Options & BitmapButtons)
+	    {
+	      XSetClipOrigin (dpy, BackGC, (w - 16) / 2, (h - 16) / 2);
+	      XCopyPlane (dpy, bf->bitmap_pressed, win, BackGC, 0, 0, 15, 15,
+			  (w - 16) / 2, (h - 16) / 2, 1);
+	    }
+	  else
+	    {
+	      DrawLinePattern (win, ShadowGC, ReliefGC, &bf->vector, w, h);
+	    }
+	}
       else
-        {
-          if (Scr.Options & BitmapButtons)
-            {
-              XSetClipOrigin(dpy, BackGC, (w - 16) / 2, (h - 16) / 2);
-              XCopyPlane(dpy, bf->bitmap, win, BackGC, 0, 0, 15, 15, (w - 16) / 2, (h - 16) / 2, 1);
-            }
-          else
-            {
+	{
+	  if (Scr.Options & BitmapButtons)
+	    {
+	      XSetClipOrigin (dpy, BackGC, (w - 16) / 2, (h - 16) / 2);
+	      XCopyPlane (dpy, bf->bitmap, win, BackGC, 0, 0, 15, 15,
+			  (w - 16) / 2, (h - 16) / 2, 1);
+	    }
+	  else
+	    {
 	      DrawLinePattern (win, ReliefGC, ShadowGC, &bf->vector, w, h);
-            }
-        }
+	    }
+	}
 
       if (inverted)
-         RelieveRectangle (win, 0, 0, w - 1, h - 1, ShadowGC, ReliefGC);
-      
+	RelieveRectangle (win, 0, 0, w - 1, h - 1, ShadowGC, ReliefGC);
+
       break;
 
     case GradButton:
@@ -348,41 +357,43 @@ DrawButton (XfwmWindow * t, Window win, int w, int h,
 	bounds.width = w;
 	bounds.height = h;
 	flush_expose (win);
-        BackGC = ((Scr.Hilite == t) ? GetDecor (t, HiBackGC) : GetDecor (t, LoBackGC));
+	BackGC =
+	  ((Scr.Hilite == t) ? GetDecor (t, HiBackGC) :
+	   GetDecor (t, LoBackGC));
 
 	{
-	  int i = 0, dw = ((w > h) ? bounds.width : 0) / bf->u.grad.npixels + 1;
+	  int i = 0, dw =
+	    ((w > h) ? bounds.width : 0) / bf->u.grad.npixels + 1;
 	  XSetForeground (dpy, Scr.TransMaskGC, bf->u.grad.pixels[i]);
-          if (w > h)
-            {
-              XFillRectangle (dpy, win, BackGC,0, 0, bounds.height / 2, bounds.height);
+	  if (w > h)
+	    {
+	      XFillRectangle (dpy, win, BackGC, 0, 0, bounds.height / 2,
+			      bounds.height);
 
-              XFillArc (dpy, win, Scr.TransMaskGC, 0, 
-                                                   0, 
-                                                   bounds.height, 
-                                                   bounds.height - 1,
-                                                   90 * 64, 180 * 64);
-            }
+	      XFillArc (dpy, win, Scr.TransMaskGC, 0,
+			0,
+			bounds.height, bounds.height - 1, 90 * 64, 180 * 64);
+	    }
 	  while (i < bf->u.grad.npixels)
 	    {
-	      unsigned short x = ((w > h) ? (bounds.height / 2) : 0) 
-                                          + i * (bounds.width - ((w > h) ? bounds.height : 0))/ bf->u.grad.npixels;
+	      unsigned short x = ((w > h) ? (bounds.height / 2) : 0)
+		+ i * (bounds.width -
+		       ((w > h) ? bounds.height : 0)) / bf->u.grad.npixels;
 	      XSetForeground (dpy, Scr.TransMaskGC, bf->u.grad.pixels[i++]);
 	      XFillRectangle (dpy, win, Scr.TransMaskGC,
 			      bounds.x + x, bounds.y + 1,
 			      dw, bounds.height - 2);
 	    }
-          if (w > h)
-            {
-              XFillRectangle (dpy, win, BackGC, bounds.width - (bounds.height / 2), 
-		                                  0, bounds.height / 2, bounds.height);
+	  if (w > h)
+	    {
+	      XFillRectangle (dpy, win, BackGC,
+			      bounds.width - (bounds.height / 2), 0,
+			      bounds.height / 2, bounds.height);
 
-              XFillArc (dpy, win, Scr.TransMaskGC, bounds.width  - bounds.height - 1, 
-                                                   0, 
-                                                   bounds.height, 
-                                                   bounds.height - 1,
-                                                   90 * 64,  - 180 * 64);
-            }
+	      XFillArc (dpy, win, Scr.TransMaskGC,
+			bounds.width - bounds.height - 1, 0, bounds.height,
+			bounds.height - 1, 90 * 64, -180 * 64);
+	    }
 	}
       }
       break;
@@ -434,13 +445,15 @@ SetTitleBar (XfwmWindow * t, Bool onoroff, Bool NewTitle)
     {
       XFontSet fontset = GetDecor (t, WindowFont.fontset);
       if (fontset)
-        {
-          XRectangle rect1, rect2;
-          XmbTextExtents (fontset, t->name, strlen (t->name), &rect1, &rect2);
-          w = rect2.width;
-        }
+	{
+	  XRectangle rect1, rect2;
+	  XmbTextExtents (fontset, t->name, strlen (t->name), &rect1, &rect2);
+	  w = rect2.width;
+	}
       else
-        w = XTextWidth (GetDecor (t, WindowFont.font), t->name, strlen (t->name));
+	w =
+	  XTextWidth (GetDecor (t, WindowFont.font), t->name,
+		      strlen (t->name));
       if (w > t->title_width - 12)
 	w = t->title_width - 4;
       if (w < 0)
@@ -456,7 +469,8 @@ SetTitleBar (XfwmWindow * t, Bool onoroff, Bool NewTitle)
 
   if (GetDecor (t, WindowFont.font))
     {
-      NewFontAndColor (GetDecor (t, WindowFont.font->fid), Forecolor, BackColor);
+      NewFontAndColor (GetDecor (t, WindowFont.font->fid), Forecolor,
+		       BackColor);
     }
   else
     {
@@ -467,40 +481,45 @@ SetTitleBar (XfwmWindow * t, Bool onoroff, Bool NewTitle)
   /* draw compound titlebar (veliaa@rpi.edu) */
   for (; bf; bf = bf->next)
     DrawButton (t, t->title_w, t->title_width, t->title_height,
-    		bf, ShadowGC, ReliefGC, True, 0);
+		bf, ShadowGC, ReliefGC, True, 0);
   if (t->name != (char *) NULL)
     {
       XFontSet fontset = GetDecor (t, WindowFont.fontset);
       if (fontset)
-  	XmbDrawString (dpy, t->title_w, fontset, Scr.ScratchGC3, hor_off,
-  		     GetDecor (t, WindowFont.y) + 1,
-  		     t->name, strlen (t->name));
+	XmbDrawString (dpy, t->title_w, fontset, Scr.ScratchGC3, hor_off,
+		       GetDecor (t, WindowFont.y) + 1,
+		       t->name, strlen (t->name));
       else
-    	XDrawString (dpy, t->title_w, Scr.ScratchGC3, hor_off,
-    		     GetDecor (t, WindowFont.y) + 1,
-    		     t->name, strlen (t->name));
+	XDrawString (dpy, t->title_w, Scr.ScratchGC3, hor_off,
+		     GetDecor (t, WindowFont.y) + 1,
+		     t->name, strlen (t->name));
     }
   RelieveRoundedRectangle (t->title_w, 0, 0, t->title_width, t->title_height,
-    		      ShadowGC, ReliefGC);
+			   ShadowGC, ReliefGC);
   if (!onoroff)
-    RelieveRoundedRectangle (t->title_w, 1, 1, t->title_width-2, t->title_height-2,
-    		      ReliefGC, ShadowGC);
+    RelieveRoundedRectangle (t->title_w, 1, 1, t->title_width - 2,
+			     t->title_height - 2, ReliefGC, ShadowGC);
 }
 
 void
-RelieveRoundedRectangle (Window win, int x, int y, int w, int h, GC Hilite, GC Shadow)
+RelieveRoundedRectangle (Window win, int x, int y, int w, int h, GC Hilite,
+			 GC Shadow)
 {
-  if (w <= 0) return;
+  if (w <= 0)
+    return;
   if (w > h)
-   {
+    {
       XDrawLine (dpy, win, Hilite, x + h / 2, y, w + x - h / 2, y);
-      XDrawArc  (dpy, win, Hilite, x, y, h, h - 1, 90 * 64, 135 * 64);
-      XDrawArc  (dpy, win, Shadow, x, y, h, h - 1, 270 * 64, -45 * 64);
+      XDrawArc (dpy, win, Hilite, x, y, h, h - 1, 90 * 64, 135 * 64);
+      XDrawArc (dpy, win, Shadow, x, y, h, h - 1, 270 * 64, -45 * 64);
 
-      XDrawLine (dpy, win, Shadow, x + h / 2, h + y - 1, w + x - h / 2, h + y - 1);
-      XDrawArc  (dpy, win, Shadow, w + x - h - 1, y, h, h - 1, 270 * 64, 135 * 64);
-      XDrawArc  (dpy, win, Hilite, w + x - h - 1, y, h, h - 1, 90 * 64,  - 45 * 64);
-   }
+      XDrawLine (dpy, win, Shadow, x + h / 2, h + y - 1, w + x - h / 2,
+		 h + y - 1);
+      XDrawArc (dpy, win, Shadow, w + x - h - 1, y, h, h - 1, 270 * 64,
+		135 * 64);
+      XDrawArc (dpy, win, Hilite, w + x - h - 1, y, h, h - 1, 90 * 64,
+		-45 * 64);
+    }
   else
     RelieveRectangle (win, x, y, w, h, Hilite, Shadow);
 }
@@ -513,9 +532,7 @@ RelieveRoundedRectangle (Window win, int x, int y, int w, int h, GC Hilite, GC S
 void
 DrawLinePattern (Window win,
 		 GC ReliefGC,
-		 GC ShadowGC,
-		 struct vector_coords *coords,
-		 int w, int h)
+		 GC ShadowGC, struct vector_coords *coords, int w, int h)
 {
   int i = 1;
 
@@ -523,10 +540,10 @@ DrawLinePattern (Window win,
     {
       XDrawLine (dpy, win,
 		 coords->line_style[i] ? ReliefGC : ShadowGC,
-                 (w * coords->x[i - 1] / 100.0 + .5) - 1,
-                 (h * coords->y[i - 1] / 100.0 + .5) - 1,
-                 (w * coords->x[i]     / 100.0 + .5) - 1,
-                 (h * coords->y[i]     / 100.0 + .5) - 1);
+		 (w * coords->x[i - 1] / 100.0 + .5) - 1,
+		 (h * coords->y[i - 1] / 100.0 + .5) - 1,
+		 (w * coords->x[i] / 100.0 + .5) - 1,
+		 (h * coords->y[i] / 100.0 + .5) - 1);
     }
 }
 
@@ -541,7 +558,7 @@ RelieveWindow (XfwmWindow * t, Window win,
 	       GC ReliefGC, GC ShadowGC, int hilite)
 {
   XSegment seg[4];
-  GC BackGC   = NULL;
+  GC BackGC = NULL;
   int i;
   int edge;
 
@@ -561,34 +578,44 @@ RelieveWindow (XfwmWindow * t, Window win,
   /* window sides */
   if (edge == -1)
     {
-      BackGC = ((Scr.Hilite == t) ? GetDecor (t, HiBackGC) : GetDecor (t, LoBackGC));
+      BackGC =
+	((Scr.Hilite == t) ? GetDecor (t, HiBackGC) : GetDecor (t, LoBackGC));
       switch (hilite)
 	{
 	case LEFT_HILITE:
-          XFillRectangle (dpy, win, BackGC,
-		      x + 1, y, w, h + y + 1);
+	  XFillRectangle (dpy, win, BackGC, x + 2, y, w - 1, h + y + 1);
 	  i = 0;
 	  seg[i].x1 = x;
 	  seg[i].y1 = y;
 	  seg[i].x2 = x;
 	  seg[i++].y2 = h + y;
+	  XDrawSegments (dpy, win, Scr.BlackGC, seg, i);
+	  i = 0;
+	  seg[i].x1 = x + 1;
+	  seg[i].y1 = y;
+	  seg[i].x2 = x + 1;
+	  seg[i++].y2 = h + y;
 	  XDrawSegments (dpy, win, ReliefGC, seg, i);
 	  break;
 
 	case TOP_HILITE:
-          XFillRectangle (dpy, win, BackGC,
-		      x, y + 1, w + x + 1, h);
+	  XFillRectangle (dpy, win, BackGC, x, y + 2, w + x + 1, h - 1);
 	  i = 0;
 	  seg[i].x1 = x;
 	  seg[i].y1 = y;
 	  seg[i].x2 = w + x;
 	  seg[i++].y2 = y;
+	  XDrawSegments (dpy, win, Scr.BlackGC, seg, i);
+	  i = 0;
+	  seg[i].x1 = x;
+	  seg[i].y1 = y + 1;
+	  seg[i].x2 = w + x;
+	  seg[i++].y2 = y + 1;
 	  XDrawSegments (dpy, win, ReliefGC, seg, i);
 	  break;
 
 	case RIGHT_HILITE:
-          XFillRectangle (dpy, win, BackGC,
-		      x, y, w + x - 2, h + y + 1);
+	  XFillRectangle (dpy, win, BackGC, x, y, w + x - 2, h + y + 1);
 	  i = 0;
 	  seg[i].x1 = w + x - 1;
 	  seg[i].y1 = y;
@@ -604,8 +631,7 @@ RelieveWindow (XfwmWindow * t, Window win,
 	  break;
 
 	case BOTTOM_HILITE:
-          XFillRectangle (dpy, win, BackGC,
-		      x, y, w + x + 1, h + y - 2);
+	  XFillRectangle (dpy, win, BackGC, x, y, w + x + 1, h + y - 2);
 	  i = 0;
 	  seg[i].x1 = x;
 	  seg[i].y1 = h + y - 1;
@@ -639,35 +665,50 @@ RelieveWindow (XfwmWindow * t, Window win,
 	  seg[i].y1 = y;
 	  seg[i].x2 = w + x - 1;
 	  seg[i++].y2 = y;
+	  XDrawSegments (dpy, win, Scr.BlackGC, seg, i);
+	  i = 0;
+	  seg[i].x1 = x + 1;
+	  seg[i].y1 = y + 1;
+	  seg[i].x2 = x + 1;
+	  seg[i++].y2 = h + y;
+	  seg[i].x1 = x + 1;
+	  seg[i].y1 = y + 1;
+	  seg[i].x2 = w + x;
+	  seg[i++].y2 = y + 1;
 	  XDrawSegments (dpy, win, ReliefGC, seg, i);
 	  break;
 
 	case 2:
 	  i = 0;
+	  i = 0;
+	  seg[i].x1 = x;
+	  seg[i].y1 = y + 1;
+	  seg[i].x2 = w + x - 1;
+	  seg[i++].y2 = y + 1;
+	  XDrawSegments (dpy, win, ReliefGC, seg, i);
+	  i = 0;
+	  seg[i].x1 = w + x - 2;
+	  seg[i].y1 = y + 3;
+	  seg[i].x2 = w + x - 2;
+	  seg[i++].y2 = h + y;
+	  XDrawSegments (dpy, win, ShadowGC, seg, i);
+	  i = 0;
+	  seg[i].x1 = w + x - 1;
+	  seg[i].y1 = y + 1;
+	  seg[i].x2 = w + x - 1;
+	  seg[i++].y2 = h + y;
 	  seg[i].x1 = x;
 	  seg[i].y1 = y;
 	  seg[i].x2 = w + x - 1;
 	  seg[i++].y2 = y;
-	  XDrawSegments (dpy, win, ReliefGC, seg, i);
-	  i = 0;
-	  seg[i].x1 = w + x - 1;
-	  seg[i].y1 = y;
-	  seg[i].x2 = w + x - 1;
-	  seg[i++].y2 = h + y - 1;
 	  XDrawSegments (dpy, win, Scr.BlackGC, seg, i);
-	  i = 0;
-	  seg[i].x1 = w + x - 2;
-	  seg[i].y1 = y + 2;
-	  seg[i].x2 = w + x - 2;
-	  seg[i++].y2 = h + y - 1;
-	  XDrawSegments (dpy, win, ShadowGC, seg, i);
 	  break;
 
 	case 3:
 	  i = 0;
-	  seg[i].x1 = x;
+	  seg[i].x1 = x + 1;
 	  seg[i].y1 = y;
-	  seg[i].x2 = x;
+	  seg[i].x2 = x + 1;
 	  seg[i++].y2 = h + y - 1;
 	  XDrawSegments (dpy, win, ReliefGC, seg, i);
 	  i = 0;
@@ -675,11 +716,15 @@ RelieveWindow (XfwmWindow * t, Window win,
 	  seg[i].y1 = h + y - 1;
 	  seg[i].x2 = w + x - 1;
 	  seg[i++].y2 = h + y - 1;
+	  seg[i].x1 = x;
+	  seg[i].y1 = y;
+	  seg[i].x2 = x;
+	  seg[i++].y2 = h + y - 1;
 	  XDrawSegments (dpy, win, Scr.BlackGC, seg, i);
 	  i = 0;
-	  seg[i].x1 = x + 2;
+	  seg[i].x1 = x + 3;
 	  seg[i].y1 = h + y - 2;
-	  seg[i].x2 = w + x - 1;
+	  seg[i].x2 = w + x;
 	  seg[i++].y2 = h + y - 2;
 	  XDrawSegments (dpy, win, ShadowGC, seg, i);
 	  break;
@@ -789,13 +834,14 @@ RelieveWindow (XfwmWindow * t, Window win,
  ************************************************************************/
 
 void
-SetupFrame (XfwmWindow * tmp_win, int x, int y, int w, int h, 
-            Bool sendEvent, Bool broadcast)
+SetupFrame (XfwmWindow * tmp_win, int x, int y, int w, int h,
+	    Bool sendEvent, Bool broadcast)
 {
-  XWindowChanges frame_wc, xwc;
+  XWindowChanges winwc;
   Bool Resized = False, Moved = False;
   int xwidth, ywidth, left, right, horig;
   int cx, cy, i;
+  unsigned long winmask;
 
   horig = h;
 
@@ -837,26 +883,6 @@ SetupFrame (XfwmWindow * tmp_win, int x, int y, int w, int h,
   if (tmp_win->title_width < 1)
     tmp_win->title_width = 1;
 
-  tmp_win->attr.width = w - 2 * tmp_win->boundary_width;
-  tmp_win->attr.height = horig - tmp_win->title_height
-    - 2 * tmp_win->boundary_width;
-  /* may need to omit the -1 for shaped windows, next two lines */
-  cx = tmp_win->boundary_width - tmp_win->bw;
-  cy = tmp_win->title_height + tmp_win->boundary_width - tmp_win->bw;
-
-  XMoveResizeWindow (dpy, tmp_win->w, cx, cy,
-		     tmp_win->attr.width, tmp_win->attr.height);
-  /* 
-   * fix up frame and assign size/location values in tmp_win
-   */
-  frame_wc.x = tmp_win->frame_x = tmp_win->shade_x = x;
-  frame_wc.y = tmp_win->frame_y = tmp_win->shade_y  = y;
-  frame_wc.width = tmp_win->frame_width = tmp_win->shade_width  = w;
-  tmp_win->shade_height = tmp_win->title_height + 2 * tmp_win->boundary_width;
-  tmp_win->frame_height = horig;
-  frame_wc.height = h;
-  XMoveResizeWindow (dpy, tmp_win->frame, frame_wc.x, frame_wc.y, frame_wc.width, frame_wc.height);
-
   /*
    * According to the July 27, 1988 ICCCM draft, we should send a
    * "synthetic" ConfigureNotify event to the client if the window
@@ -865,6 +891,7 @@ SetupFrame (XfwmWindow * tmp_win, int x, int y, int w, int h,
   if (Moved && !Resized)
     sendEvent = True;
 
+  winmask = (CWX | CWY | CWWidth | CWHeight);
   if (Resized)
     {
       if (tmp_win->flags & TITLE)
@@ -875,46 +902,67 @@ SetupFrame (XfwmWindow * tmp_win, int x, int y, int w, int h,
 	    tmp_win->title_x = -10;
 	  tmp_win->title_y = tmp_win->boundary_width;
 
-	  xwc.width = tmp_win->title_width;
+	  winwc.width = tmp_win->title_width;
 
-	  xwc.height = tmp_win->title_height;
-	  xwc.x = tmp_win->title_x;
-	  xwc.y = tmp_win->title_y;
-          XMoveResizeWindow (dpy, tmp_win->title_w, xwc.x, xwc.y, xwc.width, xwc.height);
+	  winwc.height = tmp_win->title_height;
+	  winwc.x = tmp_win->title_x;
+	  winwc.y = tmp_win->title_y;
+	  XMoveResizeWindow (dpy, tmp_win->title_w, winwc.x, winwc.y, winwc.width,
+			     winwc.height);
+          /*
+	  XConfigureWindow(dpy, tmp_win->title_w, winmask, &winwc);
+           */
 
 
-	  xwc.height = tmp_win->title_height;
-	  xwc.width = tmp_win->title_height;
+	  winwc.height = tmp_win->title_height;
+	  winwc.width = tmp_win->title_height;
 
-	  xwc.y = tmp_win->boundary_width;
-	  xwc.x = tmp_win->boundary_width;
+	  winwc.y = tmp_win->boundary_width;
+	  winwc.x = tmp_win->boundary_width;
 	  for (i = 0; i < Scr.nr_left_buttons; i++)
 	    {
 	      if (tmp_win->left_w[i] != None)
 		{
-		  if (xwc.x + tmp_win->title_height < w - tmp_win->boundary_width)
-                    XMoveResizeWindow (dpy, tmp_win->left_w[i], xwc.x, xwc.y, xwc.width, xwc.height);
+		  if (winwc.x + tmp_win->title_height <
+		      w - tmp_win->boundary_width)
+		    XMoveResizeWindow (dpy, tmp_win->left_w[i], winwc.x, winwc.y,
+				       winwc.width, winwc.height);
+                    /*
+		    XConfigureWindow(dpy, tmp_win->left_w[i], winmask, &winwc);
+                     */
 		  else
 		    {
-		      xwc.x = -tmp_win->title_height;
-                      XMoveResizeWindow (dpy, tmp_win->left_w[i], xwc.x, xwc.y, xwc.width, xwc.height);
+		      winwc.x = -tmp_win->title_height;
+		      XMoveResizeWindow (dpy, tmp_win->left_w[i], winwc.x,
+					 winwc.y, winwc.width, winwc.height);
+                      /*
+		      XConfigureWindow(dpy, tmp_win->left_w[i], winmask, &winwc);
+                       */
 		    }
-		  xwc.x += tmp_win->title_height;
+		  winwc.x += tmp_win->title_height;
 		}
 	    }
 
-	  xwc.x = w - tmp_win->boundary_width + tmp_win->bw;
+	  winwc.x = w - tmp_win->boundary_width + tmp_win->bw;
 	  for (i = 0; i < Scr.nr_right_buttons; i++)
 	    {
 	      if (tmp_win->right_w[i] != None)
 		{
-		  xwc.x -= tmp_win->title_height;
-		  if (xwc.x > tmp_win->boundary_width)
-                    XMoveResizeWindow (dpy, tmp_win->right_w[i], xwc.x, xwc.y, xwc.width, xwc.height);
+		  winwc.x -= tmp_win->title_height;
+		  if (winwc.x > tmp_win->boundary_width)
+		    XMoveResizeWindow (dpy, tmp_win->right_w[i], winwc.x, winwc.y,
+				       winwc.width, winwc.height);
+                    /*
+		    XConfigureWindow(dpy, tmp_win->right_w[i], winmask, &winwc);
+                     */
 		  else
 		    {
-		      xwc.x = -tmp_win->title_height;
-                      XMoveResizeWindow (dpy, tmp_win->right_w[i], xwc.x, xwc.y, xwc.width, xwc.height);
+		      winwc.x = -tmp_win->title_height;
+		      XMoveResizeWindow (dpy, tmp_win->right_w[i], winwc.x,
+					 winwc.y, winwc.width, winwc.height);
+                      /*
+		      XConfigureWindow(dpy, tmp_win->right_w[i], winmask, &winwc);
+                       */
 		    }
 		}
 	    }
@@ -922,13 +970,13 @@ SetupFrame (XfwmWindow * tmp_win, int x, int y, int w, int h,
 
       if (tmp_win->flags & BORDER)
 	{
-	  tmp_win->corner_width = GetDecor (tmp_win, TitleHeight) + tmp_win->bw +
-	    tmp_win->boundary_width;
+	  tmp_win->corner_width =
+	    GetDecor (tmp_win,
+		      TitleHeight) + tmp_win->bw + tmp_win->boundary_width;
 
 	  if (w < 2 * tmp_win->corner_width)
 	    tmp_win->corner_width = w / 3;
-	  if ((h < 2 * tmp_win->corner_width)
-	    )
+	  if ((h < 2 * tmp_win->corner_width))
 	    tmp_win->corner_width = h / 3;
 	  xwidth = w - 2 * tmp_win->corner_width + tmp_win->bw;
 	  ywidth = h - 2 * tmp_win->corner_width;
@@ -941,66 +989,97 @@ SetupFrame (XfwmWindow * tmp_win, int x, int y, int w, int h,
 	    {
 	      if (i == 0)
 		{
-		  xwc.x = tmp_win->corner_width;
-		  xwc.y = 0;
-		  xwc.height = tmp_win->boundary_width;
-		  xwc.width = xwidth;
+		  winwc.x = tmp_win->corner_width;
+		  winwc.y = 0;
+		  winwc.height = tmp_win->boundary_width;
+		  winwc.width = xwidth;
 		}
 	      else if (i == 1)
 		{
-		  xwc.x = w - tmp_win->boundary_width + tmp_win->bw;
-		  xwc.y = tmp_win->corner_width;
-		  xwc.width = tmp_win->boundary_width;
-		  xwc.height = ywidth;
+		  winwc.x = w - tmp_win->boundary_width + tmp_win->bw;
+		  winwc.y = tmp_win->corner_width;
+		  winwc.width = tmp_win->boundary_width;
+		  winwc.height = ywidth;
 
 		}
 	      else if (i == 2)
 		{
-		  xwc.x = tmp_win->corner_width;
-		  xwc.y = h - tmp_win->boundary_width + tmp_win->bw;
-		  xwc.height = tmp_win->boundary_width + tmp_win->bw;
-		  xwc.width = xwidth;
+		  winwc.x = tmp_win->corner_width;
+		  winwc.y = h - tmp_win->boundary_width + tmp_win->bw;
+		  winwc.height = tmp_win->boundary_width + tmp_win->bw;
+		  winwc.width = xwidth;
 		}
 	      else
 		{
-		  xwc.x = 0;
-		  xwc.y = tmp_win->corner_width;
-		  xwc.width = tmp_win->boundary_width;
-		  xwc.height = ywidth;
+		  winwc.x = 0;
+		  winwc.y = tmp_win->corner_width;
+		  winwc.width = tmp_win->boundary_width;
+		  winwc.height = ywidth;
 		}
-              XMoveResizeWindow (dpy, tmp_win->sides[i], xwc.x, xwc.y, xwc.width, xwc.height);
-              XFlush (dpy);
+	      XMoveResizeWindow (dpy, tmp_win->sides[i], winwc.x, winwc.y,
+				 winwc.width, winwc.height);
+              /*
+	      XConfigureWindow(dpy, tmp_win->sides[i], winmask, &winwc);
+               */
 	    }
 
-	  xwc.width = tmp_win->corner_width;
-	  xwc.height = tmp_win->corner_width;
+	  winwc.width = tmp_win->corner_width;
+	  winwc.height = tmp_win->corner_width;
 	  for (i = 0; i < 4; i++)
 	    {
 	      if (i % 2)
-		xwc.x = w - tmp_win->corner_width + tmp_win->bw;
+		winwc.x = w - tmp_win->corner_width + tmp_win->bw;
 	      else
-		xwc.x = 0;
+		winwc.x = 0;
 
 	      if (i / 2)
-		xwc.y = h - tmp_win->corner_width;
+		winwc.y = h - tmp_win->corner_width;
 	      else
-		xwc.y = 0;
+		winwc.y = 0;
 
-              XMoveResizeWindow (dpy, tmp_win->corners[i], xwc.x, xwc.y, xwc.width, xwc.height);
+              XMoveResizeWindow (dpy, tmp_win->corners[i], winwc.x, winwc.y,
+				 winwc.width, winwc.height);
+	      /*
+	      XConfigureWindow(dpy, tmp_win->corners[i], winmask, &winwc);
+               */
 	    }
 	}
     }
 
+  tmp_win->attr.width = w - 2 * tmp_win->boundary_width;
+  tmp_win->attr.height = horig - tmp_win->title_height
+    - 2 * tmp_win->boundary_width;
+  /* may need to omit the -1 for shaped windows, next two lines */
+  cx = tmp_win->boundary_width - tmp_win->bw;
+  cy = tmp_win->title_height + tmp_win->boundary_width - tmp_win->bw;
+
+  XResizeWindow (dpy, tmp_win->w, tmp_win->attr.width, tmp_win->attr.height);
+  XMoveResizeWindow (dpy, tmp_win->Parent, cx, cy,
+		     tmp_win->attr.width, tmp_win->attr.height);
+  /* 
+   * fix up frame and assign size/location values in tmp_win
+   */
+  winwc.x = tmp_win->frame_x = tmp_win->shade_x = x;
+  winwc.y = tmp_win->frame_y = tmp_win->shade_y = y;
+  winwc.width = tmp_win->frame_width = tmp_win->shade_width = w;
+  tmp_win->shade_height = tmp_win->title_height + 2 * tmp_win->boundary_width;
+  tmp_win->frame_height = horig;
+  winwc.height = h;
+  /* 
+  XConfigureWindow (dpy, tmp_win->frame, winmask, &winwc);
+   */
+  XMoveResizeWindow (dpy, tmp_win->frame, winwc.x, winwc.y,
+		     winwc.width, winwc.height);
+
   if (ShapesSupported)
     {
       if ((Resized) && (tmp_win->wShaped))
-        SetShape (tmp_win, w);
+	SetShape (tmp_win, w);
     }
-  XSync (dpy, 0);
   if (sendEvent)
-    sendclient_event(tmp_win, x, y, w, horig);
+    sendclient_event (tmp_win, x, y, w, horig);
   if (broadcast)
-    BroadcastConfig (M_CONFIGURE_WINDOW, tmp_win);
+    BroadcastConfig (XFCE_M_CONFIGURE_WINDOW, tmp_win);
 }
 
 /****************************************************************************
@@ -1018,8 +1097,7 @@ SetShape (XfwmWindow * tmp_win, int w)
       XShapeCombineShape (dpy, tmp_win->frame, ShapeBounding,
 			  tmp_win->boundary_width,
 			  tmp_win->title_height + tmp_win->boundary_width,
-			  tmp_win->w,
-			  ShapeBounding, ShapeSet);
+			  tmp_win->w, ShapeBounding, ShapeSet);
       if (tmp_win->title_w)
 	{
 	  /* windows w/ titles */
