@@ -30,6 +30,10 @@
 #include "screen.h"
 #include "lightdark.h"
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 char *white = "white";
 char *black = "black";
 
@@ -51,10 +55,10 @@ GetShadow (Pixel background)
 
   bg_color.pixel = background;
   XQueryColor (dpy, attributes.colormap, &bg_color);
- 
-  bg_color.red   = shift16 (bg_color.red,   LO_MULT);
+
+  bg_color.red = shift16 (bg_color.red, LO_MULT);
   bg_color.green = shift16 (bg_color.green, LO_MULT);
-  bg_color.blue  = shift16 (bg_color.blue,  LO_MULT);
+  bg_color.blue = shift16 (bg_color.blue, LO_MULT);
 
   if (!XAllocColor (dpy, attributes.colormap, &bg_color))
     {
@@ -81,10 +85,10 @@ GetHilite (Pixel background)
   bg_color.pixel = background;
   XQueryColor (dpy, attributes.colormap, &bg_color);
 
-  bg_color.red   = shift16 (bg_color.red,   HI_MULT);
+  bg_color.red = shift16 (bg_color.red, HI_MULT);
   bg_color.green = shift16 (bg_color.green, HI_MULT);
-  bg_color.blue  = shift16 (bg_color.blue,  HI_MULT);
-  
+  bg_color.blue = shift16 (bg_color.blue, HI_MULT);
+
   if (!XAllocColor (dpy, attributes.colormap, &bg_color))
     {
       nocolor ("alloc hilight", "");
@@ -93,6 +97,20 @@ GetHilite (Pixel background)
   return bg_color.pixel;
 }
 
+int
+brightness (Pixel p)
+{
+  XColor color;
+  XWindowAttributes attributes;
+
+  XGetWindowAttributes (dpy, Scr.Root, &attributes);
+  color.pixel = p;
+  XQueryColor (dpy, attributes.colormap, &color);
+  return (
+	  (100 * ((color.red >> 8) + (color.green >> 8) + (color.blue >> 8)) /
+	   765));
+}
+
 /***********************************************************************
  *
  *  Procedure:
@@ -107,9 +125,10 @@ CreateGCs (void)
   unsigned long gcm;
 
   /* create scratch GC's */
-  gcm = GCFunction | GCPlaneMask | GCGraphicsExposures | GCLineWidth | GCCapStyle;
+  gcm =
+    GCFunction | GCPlaneMask | GCGraphicsExposures | GCLineWidth | GCCapStyle;
   gcv.line_width = 1;
-  gcv.cap_style=CapProjecting;
+  gcv.cap_style = CapProjecting;
   gcv.function = GXcopy;
   gcv.plane_mask = AllPlanes;
   gcv.graphics_exposures = False;
@@ -118,8 +137,9 @@ CreateGCs (void)
   Scr.ScratchGC3 = XCreateGC (dpy, Scr.Root, gcm, &gcv);
 
   Scr.TransMaskGC = XCreateGC (dpy, Scr.Root, gcm, &gcv);
-  gcm = GCFunction | GCPlaneMask | GCGraphicsExposures | GCLineWidth | GCForeground |
-    GCBackground | GCCapStyle;
+  gcm =
+    GCFunction | GCPlaneMask | GCGraphicsExposures | GCLineWidth |
+    GCForeground | GCBackground | GCCapStyle;
   gcv.fill_style = FillSolid;
   gcv.plane_mask = AllPlanes;
   gcv.function = GXcopy;
@@ -133,7 +153,8 @@ CreateGCs (void)
   gcm = GCFunction | GCLineWidth | GCForeground | GCSubwindowMode;
   gcv.function = GXxor;
   gcv.line_width = 2;
-  gcv.foreground = BlackPixel (dpy, Scr.screen) ^ WhitePixel (dpy, Scr.screen);
+  gcv.foreground =
+    BlackPixel (dpy, Scr.screen) ^ WhitePixel (dpy, Scr.screen);
   gcv.subwindow_mode = IncludeInferiors;
   Scr.HintsGC = XCreateGC (dpy, Scr.Root, gcm, &gcv);
 }
@@ -172,8 +193,7 @@ GetColor (char *name)
  *
  ****************************************************************************/
 Pixel *
-AllocNonlinearGradient (char *s_colors[], int clen[],
-			int nsegs, int npixels)
+AllocNonlinearGradient (char *s_colors[], int clen[], int nsegs, int npixels)
 {
   Pixel *pixels = (Pixel *) safemalloc (sizeof (Pixel) * npixels);
   int i = 0, curpixel = 0, perc = 0;
@@ -225,7 +245,8 @@ AllocLinearGradient (char *s_from, char *s_to, int npixels)
 
   if (npixels < 1)
     return NULL;
-  if (!s_from || !XParseColor (dpy, Scr.XfwmRoot.attr.colormap, s_from, &from))
+  if (!s_from
+      || !XParseColor (dpy, Scr.XfwmRoot.attr.colormap, s_from, &from))
     {
       nocolor ("parse", s_from);
       return NULL;
