@@ -46,24 +46,28 @@
 #include "parse.h"
 #include "menus.h"
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 extern Atom _XA_MwmAtom;
 
 /* Motif WM window hints structure */
 typedef struct
-  {
-    CARD32 flags;		/* window hints */
-    CARD32 functions;		/* requested functions */
-    CARD32 decorations;		/* requested decorations */
-    INT32 inputMode;		/* input mode */
-    CARD32 status;		/* status (ignored) */
-  }
+{
+  CARD32 flags;			/* window hints */
+  CARD32 functions;		/* requested functions */
+  CARD32 decorations;		/* requested decorations */
+  INT32 inputMode;		/* input mode */
+  CARD32 status;		/* status (ignored) */
+}
 PropMotifWmHints;
 
 typedef struct _extended_hints
 {
-    int flags;
-    int desktop;
-} 
+  int flags;
+  int desktop;
+}
 ExtendedHints;
 
 typedef PropMotifWmHints PropMwmHints;
@@ -116,68 +120,74 @@ GetMwmHints (XfwmWindow * t)
   Atom actual_type;
   unsigned long nitems, bytesafter;
 
+  t->mwm_hints = NULL;
   if (XGetWindowProperty (dpy, t->w, _XA_MwmAtom, 0L, 20L, False,
 			  _XA_MwmAtom, &actual_type, &actual_format, &nitems,
-		  &bytesafter, (unsigned char **) &t->mwm_hints) == Success)
+			  &bytesafter,
+			  (unsigned char **) &t->mwm_hints) == Success)
     {
       if (nitems >= PROP_MOTIF_WM_HINTS_ELEMENTS)
-	  return;
-      XFree((char *)t->mwm_hints);
+	return;
+      if (t->mwm_hints)
+        XFree ((char *) t->mwm_hints);
     }
 
   t->mwm_hints = NULL;
 }
 
 void
-GetExtHints(XfwmWindow * t)
+GetExtHints (XfwmWindow * t)
 {
-   Atom 	       a1, a3;
-   unsigned long       lnum, ldummy;
-   int  	       dummy;
-   ExtendedHints       *eh;
+  Atom a1, a3;
+  unsigned long lnum, ldummy;
+  int dummy;
+  ExtendedHints *eh;
 
-   a1 = XInternAtom(dpy, "WM_EXTENDED_HINTS", False);
-   eh = NULL;
-   if (XGetWindowProperty(dpy, t->w, a1, 0, 
-                      sizeof(ExtendedHints)/sizeof(unsigned long), 
-                      False, a1, &a3, &dummy, &lnum,
-		      &ldummy, (unsigned char **)&eh) == Success)
-   {
+  a1 = XInternAtom (dpy, "WM_EXTENDED_HINTS", False);
+  eh = NULL;
+
+  if (XGetWindowProperty (dpy, t->w, a1, 0,
+			  sizeof (ExtendedHints) / sizeof (unsigned long),
+			  False, a1, &a3, &dummy, &lnum,
+			  &ldummy, (unsigned char **) &eh) == Success)
+    {
       if (eh)
 	{
-	   if (eh->flags & EXTENDED_HINT_STICKY)
-	     t->flags |= STICKY;
-	   if (eh->flags & EXTENDED_HINT_ONTOP)
-	     t->flags |= ONTOP;
-	   if (eh->flags & EXTENDED_HINT_ONBOTTOM)
-	     ; /* Not implemented */
-	   if (eh->flags & EXTENDED_HINT_NEVER_USE_AREA)
-	     ; /* Not implemented */
-	   if (eh->flags & EXTENDED_HINT_DESKTOP)
-	     ; /* Not implemented */
-	   XFree(eh);
+	  if (eh->flags & EXTENDED_HINT_STICKY)
+	    t->flags |= STICKY;
+	  if (eh->flags & EXTENDED_HINT_ONTOP)
+	    t->flags |= ONTOP;
+	  if (eh->flags & EXTENDED_HINT_ONBOTTOM)
+	    ;			/* Not implemented */
+	  if (eh->flags & EXTENDED_HINT_NEVER_USE_AREA)
+	    ;			/* Not implemented */
+	  if (eh->flags & EXTENDED_HINT_DESKTOP)
+	    ;			/* Not implemented */
+	  XFree (eh);
 	}
     }
 }
 
 void
-GetKDEHints(XfwmWindow * t)
+GetKDEHints (XfwmWindow * t)
 {
-   Atom                a, dummy_a;
-   unsigned long       lnum, ldummy;
-   int  	       dummy, status;
-   long                *p = 0;
+  Atom a, dummy_a;
+  unsigned long lnum, ldummy;
+  int dummy;
+  long *kh;
 
-   a = XInternAtom(dpy, "KWM_WIN_DECORATION", False);
-   t->kde_hints = -1;
-   status = XGetWindowProperty(dpy, t->w, a, 0L, 1L, False, a, &dummy_a, &dummy,
-                    &lnum, &ldummy, (unsigned char **)&p);
-   if ((status == Success) && (p != 0)) {
-     t->kde_hints = (p[0] & 3);
-     if (lnum == 0)
-       XFree((void*) *p);
-     XFree((char *) p);
-   }
+  kh = NULL;
+  a = XInternAtom (dpy, "KWM_WIN_DECORATION", False);
+  t->kde_hints = -1;
+  if (XGetWindowProperty (dpy, t->w, a, 0L, 1L, False, a, &dummy_a, &dummy,
+			&lnum, &ldummy, (unsigned char **) &kh) == Success);
+    {
+      if (kh) 
+        {
+          t->kde_hints = (kh[0] & 3);
+          XFree ((char *) kh);
+        }
+    }
 }
 
 /****************************************************************************
@@ -223,7 +233,7 @@ SelectDecor (XfwmWindow * t, unsigned long tflags, int border_width)
        * ALL except the other things... */
       t->functions &= ~MWM_FUNC_ALL;
       t->functions = (MWM_FUNC_RESIZE | MWM_FUNC_MOVE | MWM_FUNC_MINIMIZE |
-		    MWM_FUNC_MAXIMIZE | MWM_FUNC_CLOSE) & (~(t->functions));
+		      MWM_FUNC_MAXIMIZE | MWM_FUNC_CLOSE) & (~(t->functions));
     }
   if ((tflags & MWM_FUNCTIONS_FLAG) && (t->flags & TRANSIENT))
     {
@@ -255,28 +265,31 @@ SelectDecor (XfwmWindow * t, unsigned long tflags, int border_width)
   if (tflags & NOBORDER_FLAG)
     decor &= ~MWM_DECOR_RESIZEH;
 
-  if ((tflags & MWM_DECOR_FLAG) && (t->flags & TRANSIENT)) 
+  if ((tflags & MWM_DECOR_FLAG) && (t->flags & TRANSIENT))
     {
       decor &= ~(MWM_DECOR_MAXIMIZE | MWM_DECOR_MINIMIZE);
     }
 
-  if (t->kde_hints == KDE_normalDecoration) {
-    decor        |= MWM_DECOR_ALL;
-    t->functions |= MWM_FUNC_ALL;
-  }
-  else if (t->kde_hints == KDE_noDecoration){
-    decor &= ~(MWM_DECOR_BORDER | MWM_DECOR_RESIZEH | MWM_DECOR_TITLE |
-	       MWM_DECOR_MENU | MWM_DECOR_MINIMIZE | MWM_DECOR_MAXIMIZE);
-    t->functions &= ~MWM_FUNC_ALL;
-    border_width = Scr.NoBoundaryWidth;
-  }
-  else if (t->kde_hints == KDE_tinyDecoration) {
-    decor        &= ~(MWM_DECOR_MAXIMIZE | MWM_DECOR_MINIMIZE |
-                      MWM_DECOR_TITLE | MWM_DECOR_RESIZEH);
-    t->functions &= ~(MWM_DECOR_MENU | MWM_FUNC_MINIMIZE |
-		      MWM_FUNC_MAXIMIZE | MWM_DECOR_TITLE);
-    border_width = 2;
-  }
+  if (t->kde_hints == KDE_normalDecoration)
+    {
+      decor |= MWM_DECOR_ALL;
+      t->functions |= MWM_FUNC_ALL;
+    }
+  else if (t->kde_hints == KDE_noDecoration)
+    {
+      decor &= ~(MWM_DECOR_BORDER | MWM_DECOR_RESIZEH | MWM_DECOR_TITLE |
+		 MWM_DECOR_MENU | MWM_DECOR_MINIMIZE | MWM_DECOR_MAXIMIZE);
+      t->functions &= ~MWM_FUNC_ALL;
+      border_width = Scr.NoBoundaryWidth;
+    }
+  else if (t->kde_hints == KDE_tinyDecoration)
+    {
+      decor &= ~(MWM_DECOR_MAXIMIZE | MWM_DECOR_MINIMIZE |
+		 MWM_DECOR_TITLE | MWM_DECOR_RESIZEH);
+      t->functions &= ~(MWM_DECOR_MENU | MWM_FUNC_MINIMIZE |
+			MWM_FUNC_MAXIMIZE | MWM_DECOR_TITLE);
+      border_width = 2;
+    }
 
   if (ShapesSupported)
     {
@@ -356,7 +369,7 @@ SelectDecor (XfwmWindow * t, unsigned long tflags, int border_width)
 
   t->bw = 0;
   if (t->boundary_width <= 0)
-      t->boundary_width = 0;
+    t->boundary_width = 0;
   if (t->title_height > 0)
     t->title_height += t->bw;
   if (t->boundary_width == 0)
@@ -378,12 +391,13 @@ check_allowed_function (MenuItem * mi)
   /* Complex functions are a little tricky... ignore them for now */
 
   if ((Tmp_win) &&
-    (!(Tmp_win->flags & DoesWmDeleteWindow)) && (mi->func_type == F_DELETE))
+      (!(Tmp_win->flags & DoesWmDeleteWindow)) && (mi->func_type == F_DELETE))
     return 0;
 
   /* Move is a funny hint. Keeps it out of the menu, but you're still allowed
    * to move. */
-  if ((mi->func_type == F_MOVE) && (Tmp_win) && (!(Tmp_win->functions & MWM_FUNC_MOVE)))
+  if ((mi->func_type == F_MOVE) && (Tmp_win)
+      && (!(Tmp_win->functions & MWM_FUNC_MOVE)))
     return 0;
 
   if ((mi->func_type == F_RESIZE) && (Tmp_win) &&
@@ -421,40 +435,49 @@ check_allowed_function (MenuItem * mi)
 	return 0;
 
       if ((Tmp_win) && (!(Tmp_win->functions & MWM_FUNC_RESIZE)) &&
-	  (mystrncasecmp (mi->item, RESIZE_STRING1, strlen (RESIZE_STRING1)) == 0))
+	  (mystrncasecmp (mi->item, RESIZE_STRING1,
+			  strlen (RESIZE_STRING1)) == 0))
 	return 0;
 
       if ((Tmp_win) && (!(Tmp_win->functions & MWM_FUNC_RESIZE)) &&
-	  (mystrncasecmp (mi->item, RESIZE_STRING2, strlen (RESIZE_STRING2)) == 0))
+	  (mystrncasecmp (mi->item, RESIZE_STRING2,
+			  strlen (RESIZE_STRING2)) == 0))
 	return 0;
 
       if ((Tmp_win) && (!(Tmp_win->functions & MWM_FUNC_MINIMIZE)) &&
 	  (!(Tmp_win->flags & ICONIFIED)) &&
-	  (mystrncasecmp (mi->item, MINIMIZE_STRING, strlen (MINIMIZE_STRING)) == 0))
+	  (mystrncasecmp (mi->item, MINIMIZE_STRING, strlen (MINIMIZE_STRING))
+	   == 0))
 	return 0;
 
       if ((Tmp_win) && (!(Tmp_win->functions & MWM_FUNC_MINIMIZE)) &&
-	  (mystrncasecmp (mi->item, MINIMIZE_STRING2, strlen (MINIMIZE_STRING2)) == 0))
+	  (mystrncasecmp (mi->item, MINIMIZE_STRING2,
+			  strlen (MINIMIZE_STRING2)) == 0))
 	return 0;
 
       if ((Tmp_win) && (!(Tmp_win->functions & MWM_FUNC_MAXIMIZE)) &&
-	  (mystrncasecmp (mi->item, MAXIMIZE_STRING, strlen (MAXIMIZE_STRING)) == 0))
+	  (mystrncasecmp (mi->item, MAXIMIZE_STRING,
+			  strlen (MAXIMIZE_STRING)) == 0))
 	return 0;
 
       if ((Tmp_win) && (!(Tmp_win->functions & MWM_FUNC_CLOSE)) &&
-      (mystrncasecmp (mi->item, CLOSE_STRING1, strlen (CLOSE_STRING1)) == 0))
+	  (mystrncasecmp (mi->item, CLOSE_STRING1,
+			  strlen (CLOSE_STRING1)) == 0))
 	return 0;
 
       if ((Tmp_win) && (!(Tmp_win->functions & MWM_FUNC_CLOSE)) &&
-      (mystrncasecmp (mi->item, CLOSE_STRING2, strlen (CLOSE_STRING2)) == 0))
+	  (mystrncasecmp (mi->item, CLOSE_STRING2,
+			  strlen (CLOSE_STRING2)) == 0))
 	return 0;
 
       if ((Tmp_win) && (!(Tmp_win->functions & MWM_FUNC_CLOSE)) &&
-      (mystrncasecmp (mi->item, CLOSE_STRING3, strlen (CLOSE_STRING3)) == 0))
+	  (mystrncasecmp (mi->item, CLOSE_STRING3,
+			  strlen (CLOSE_STRING3)) == 0))
 	return 0;
 
       if ((Tmp_win) && (!(Tmp_win->functions & MWM_FUNC_CLOSE)) &&
-      (mystrncasecmp (mi->item, CLOSE_STRING4, strlen (CLOSE_STRING4)) == 0))
+	  (mystrncasecmp (mi->item, CLOSE_STRING4,
+			  strlen (CLOSE_STRING4)) == 0))
 	return 0;
 
     }
