@@ -66,6 +66,10 @@
 #include "constant.h"
 #include "session.h"
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 unsigned int mods_used = (ShiftMask | ControlMask | Mod1Mask |
 			  Mod2Mask | Mod3Mask | Mod4Mask | Mod5Mask);
 extern int menuFromFrameOrWindowOrTitlebar;
@@ -100,10 +104,11 @@ Window PressedW;
 typedef void (*PFEH) ();
 PFEH EventHandlerJumpTable[LASTEvent];
 
-void enterAlarm(int nonsense)
+void
+enterAlarm (int nonsense)
 {
   alarmed = True;
-  signal(SIGALRM, enterAlarm);
+  signal (SIGALRM, enterAlarm);
 }
 
 /*
@@ -119,26 +124,25 @@ InitEventHandlerJumpTable (void)
     {
       EventHandlerJumpTable[i] = NULL;
     }
-  EventHandlerJumpTable[Expose] 	  = HandleExpose;
-  EventHandlerJumpTable[DestroyNotify] 	  = HandleDestroyNotify;
-  EventHandlerJumpTable[MapRequest] 	  = HandleMapRequest;
-  EventHandlerJumpTable[MapNotify] 	  = HandleMapNotify;
-  EventHandlerJumpTable[UnmapNotify] 	  = HandleUnmapNotify;
-  EventHandlerJumpTable[ButtonPress] 	  = HandleButtonPress;
-  EventHandlerJumpTable[EnterNotify] 	  = HandleEnterNotify;
-  EventHandlerJumpTable[LeaveNotify] 	  = HandleLeaveNotify;
-  EventHandlerJumpTable[FocusIn] 	  = HandleFocusIn;
-  EventHandlerJumpTable[FocusOut] 	  = HandleFocusOut;
+  EventHandlerJumpTable[Expose] = HandleExpose;
+  EventHandlerJumpTable[DestroyNotify] = HandleDestroyNotify;
+  EventHandlerJumpTable[MapRequest] = HandleMapRequest;
+  EventHandlerJumpTable[MapNotify] = HandleMapNotify;
+  EventHandlerJumpTable[UnmapNotify] = HandleUnmapNotify;
+  EventHandlerJumpTable[ButtonPress] = HandleButtonPress;
+  EventHandlerJumpTable[EnterNotify] = HandleEnterNotify;
+  EventHandlerJumpTable[LeaveNotify] = HandleLeaveNotify;
+  EventHandlerJumpTable[FocusIn] = HandleFocusIn;
+  EventHandlerJumpTable[FocusOut] = HandleFocusOut;
   EventHandlerJumpTable[ConfigureRequest] = HandleConfigureRequest;
-  EventHandlerJumpTable[ClientMessage] 	  = HandleClientMessage;
-  EventHandlerJumpTable[PropertyNotify]   = HandlePropertyNotify;
-  EventHandlerJumpTable[KeyPress] 	  = HandleKeyPress;
+  EventHandlerJumpTable[ClientMessage] = HandleClientMessage;
+  EventHandlerJumpTable[PropertyNotify] = HandlePropertyNotify;
+  EventHandlerJumpTable[KeyPress] = HandleKeyPress;
   EventHandlerJumpTable[VisibilityNotify] = HandleVisibilityNotify;
-  EventHandlerJumpTable[ColormapNotify]   = HandleColormapNotify;
-  EventHandlerJumpTable[MotionNotify] 	  = HandleMotionNotify;
+  EventHandlerJumpTable[ColormapNotify] = HandleColormapNotify;
+  EventHandlerJumpTable[MotionNotify] = HandleMotionNotify;
   if (ShapesSupported)
-    EventHandlerJumpTable[ShapeEventBase + ShapeNotify] 
-    					  = HandleShapeNotify;
+    EventHandlerJumpTable[ShapeEventBase + ShapeNotify] = HandleShapeNotify;
 }
 
 /***********************************************************************
@@ -211,7 +215,8 @@ GetContext (XfwmWindow * t, XEvent * e, Window * w)
   if ((e->type == KeyPress) && (e->xkey.subwindow != None))
     *w = e->xkey.subwindow;
 
-  if ((e->type == ButtonPress) && (e->xbutton.subwindow != None) && (e->xbutton.subwindow == t->w))
+  if ((e->type == ButtonPress) && (e->xbutton.subwindow != None) &&
+      ((e->xbutton.subwindow == t->w) || (e->xbutton.subwindow == t->Parent)))
     *w = e->xbutton.subwindow;
 
   if (*w == Scr.Root)
@@ -220,7 +225,7 @@ GetContext (XfwmWindow * t, XEvent * e, Window * w)
     {
       if (*w == t->title_w)
 	Context = C_TITLE;
-      if (*w == t->w)
+      if ((*w == t->w) || (*w == t->Parent))
 	Context = C_WINDOW;
       if (*w == t->icon_w)
 	Context = C_ICON;
@@ -291,10 +296,9 @@ HandleFocusIn ()
       else
 	{
 	  SetBorder (Scr.Hilite, False, True, True, None);
-	  Broadcast (M_FOCUS_CHANGE, 5, 0, 0, 0,
+	  Broadcast (XFCE_M_FOCUS_CHANGE, 5, 0, 0, 0,
 		     Scr.DefaultDecor.HiColors.fore,
-		     Scr.DefaultDecor.HiColors.back,
-		     0, 0);
+		     Scr.DefaultDecor.HiColors.back, 0, 0);
 	  if (Scr.ColormapFocus == COLORMAP_FOLLOWS_FOCUS)
 	    {
 	      if ((Scr.Hilite) && (!(Scr.Hilite->flags & ICONIFIED)))
@@ -312,11 +316,10 @@ HandleFocusIn ()
   else if (Tmp_win != Scr.Hilite)
     {
       SetBorder (Tmp_win, True, True, True, None);
-      Broadcast (M_FOCUS_CHANGE, 5, Tmp_win->w,
+      Broadcast (XFCE_M_FOCUS_CHANGE, 5, Tmp_win->w,
 		 Tmp_win->frame, (unsigned long) Tmp_win,
 		 GetDecor (Tmp_win, HiColors.fore),
-		 GetDecor (Tmp_win, HiColors.back),
-		 0, 0);
+		 GetDecor (Tmp_win, HiColors.back), 0, 0);
       if (Scr.ColormapFocus == COLORMAP_FOLLOWS_FOCUS)
 	{
 	  if ((Scr.Hilite) && (!(Scr.Hilite->flags & ICONIFIED)))
@@ -332,15 +335,15 @@ HandleFocusIn ()
 }
 
 void
-HandleFocusOut()
+HandleFocusOut ()
 {
-    Window focusBug;
-    int rt;
+  Window focusBug;
+  int rt;
 
-    XGetInputFocus(dpy, &focusBug, &rt);
-    if ((Tmp_win == NULL) && (Scr.Focus != NULL) && (focusBug == None))
+  XGetInputFocus (dpy, &focusBug, &rt);
+  if ((Tmp_win == NULL) && (Scr.Focus != NULL) && (focusBug == None))
     {
-        XSetInputFocus(dpy, Scr.Focus->w, RevertToParent, CurrentTime);
+      XSetInputFocus (dpy, Scr.Focus->w, RevertToParent, CurrentTime);
     }
 }
 
@@ -355,27 +358,24 @@ HandleKeyPress ()
 {
   Binding *key;
   unsigned int modifier;
-  modifier = vmod((Event.xkey.state) & KeyMask);
+  modifier = vmod ((Event.xkey.state) & KeyMask);
   ButtonWindow = Tmp_win;
 
   Context = GetContext (Tmp_win, &Event, &PressedW);
   PressedW = None;
 
-  /* Here's a real hack - some systems have two keys with the
-   * same keysym and different keycodes. This converts all
-   * the cases to one keycode. */
   Event.xkey.keycode =
     XKeysymToKeycode (dpy, XKeycodeToKeysym (dpy, Event.xkey.keycode, 0));
 
   for (key = Scr.AllBindings; key != NULL; key = key->NextBinding)
     {
       if ((key->Button_Key == Event.xkey.keycode) &&
-	  ((vmod(key->Modifier) == modifier) ||
-	   (key->Modifier == AnyModifier)) &&
-	  (key->Context & Context) &&
-	  (key->IsMouse == 0))
+	  ((vmod (key->Modifier) == modifier)
+	   || (key->Modifier == AnyModifier)) && (key->Context & Context)
+	  && (key->IsMouse == 0))
 	{
 	  ExecuteFunction (key->Action, Tmp_win, &Event, Context, -1);
+	  MyXUngrabServer (dpy);
 	  return;
 	}
     }
@@ -411,27 +411,31 @@ HandlePropertyNotify ()
   XTextProperty text_prop;
 
   if (Event.xproperty.atom == _XA_WIN_WORKSPACE_COUNT)
-        {
-          Atom atype;
-          int aformat;
-          unsigned long nitems, bytes_remain;
-          unsigned char* prop;
+    {
+      Atom atype;
+      int aformat;
+      unsigned long nitems, bytes_remain;
+      unsigned char *prop;
 
-          if ((XGetWindowProperty (dpy, Scr.Root, _XA_WIN_WORKSPACE_COUNT, 0L, 1L, False,
-			         XA_CARDINAL, &atype, &aformat, &nitems,
-			         &bytes_remain, &prop)) == Success)
-            {
-	      if (prop != NULL)
-	        {
-	          Scr.ndesks = *(unsigned long *) prop;
-	        }
-            }
-            
-          return;
-        }
+      if (
+	  (XGetWindowProperty
+	   (dpy, Scr.Root, _XA_WIN_WORKSPACE_COUNT, 0L, 1L, False,
+	    XA_CARDINAL, &atype, &aformat, &nitems, &bytes_remain,
+	    &prop)) == Success)
+	{
+	  if (prop != NULL)
+	    {
+	      Scr.ndesks = *(unsigned long *) prop;
+	      XFree (prop);
+	    }
+	}
+
+      return;
+    }
 
   if ((!Tmp_win) || (XGetGeometry (dpy, Tmp_win->w, &JunkRoot, &JunkX, &JunkY,
-			&JunkWidth, &JunkHeight, &JunkBW, &JunkDepth) == 0))
+				   &JunkWidth, &JunkHeight, &JunkBW,
+				   &JunkDepth) == 0))
     return;
 
   switch (Event.xproperty.atom)
@@ -439,33 +443,44 @@ HandlePropertyNotify ()
     case XA_WM_NAME:
       if (!XGetWMName (dpy, Tmp_win->w, &text_prop))
 	return;
-
       free_window_names (Tmp_win, True, False);
-      Tmp_win->name = NULL;
       if (text_prop.format == 8)
-        { /* Multi-byte string */
-          char **text_list = NULL;
-          int text_list_num;
-          if (XmbTextPropertyToTextList(dpy, &text_prop,
-                                &text_list, &text_list_num) == Success)
-            {
+	{			/* Multi-byte string */
+	  char **text_list = NULL;
+	  int text_list_num;
+	  if (XmbTextPropertyToTextList (dpy, &text_prop,
+					 &text_list,
+					 &text_list_num) == Success)
+	    {
 	      if (text_list)
-	        {
-                  Tmp_win->name = (char *) malloc(strlen (text_list[0]) + 1);
-                  strcpy (Tmp_win->name, text_list[0]);
-                  XFreeStringList(text_list);
-	        }
-            }
-          else
-            Tmp_win->name = (char *) text_prop.value;
-        }
+		{
+		  Tmp_win->name = (char *) malloc (strlen (text_list[0]) + 1);
+		  strcpy (Tmp_win->name, text_list[0]);
+		  XFreeStringList (text_list);
+		}
+	    }
+	  else
+	    {
+	      Tmp_win->name =
+		(char *) malloc (strlen ((char *) text_prop.value) + 1);
+	      strcpy (Tmp_win->name, (char *) text_prop.value);
+	    }
+	}
       else
-        Tmp_win->name = (char *) text_prop.value;
+	{
+	  Tmp_win->name =
+	    (char *) malloc (strlen ((char *) text_prop.value) + 1);
+	  strcpy (Tmp_win->name, (char *) text_prop.value);
+	}
+      XFree (text_prop.value);
 
-      if (Tmp_win->name == NULL)
-	Tmp_win->name = NoName;
+      if (!(Tmp_win->name))
+      {
+        Tmp_win->name = (char *) malloc (strlen (NoName) + 1);
+        strcpy (Tmp_win->name, NoName);
+      }
       Tmp_win->flags |= WM_NAME_CHANGED;
-      BroadcastName (M_WINDOW_NAME, Tmp_win->w, Tmp_win->frame,
+      BroadcastName (XFCE_M_WINDOW_NAME, Tmp_win->w, Tmp_win->frame,
 		     (unsigned long) Tmp_win, Tmp_win->name);
 
       /* fix the name in the title bar */
@@ -476,10 +491,12 @@ HandlePropertyNotify ()
        * if the icon name is NoName, set the name of the icon to be
        * the same as the window 
        */
-      if (Tmp_win->icon_name == NoName)
+      if (!mystrncasecmp (Tmp_win->icon_name, NoName, strlen (NoName)))
 	{
-	  Tmp_win->icon_name = Tmp_win->name;
-	  BroadcastName (M_ICON_NAME, Tmp_win->w, Tmp_win->frame,
+          free_window_names (Tmp_win, False, True);
+          Tmp_win->icon_name = (char *) malloc (strlen (Tmp_win->name) + 1);
+          strcpy (Tmp_win->icon_name, Tmp_win->name);
+	  BroadcastName (XFCE_M_ICON_NAME, Tmp_win->w, Tmp_win->frame,
 			 (unsigned long) Tmp_win, Tmp_win->icon_name);
 	  RedoIconName (Tmp_win);
 	}
@@ -489,29 +506,43 @@ HandlePropertyNotify ()
       if (!XGetWMIconName (dpy, Tmp_win->w, &text_prop))
 	return;
       free_window_names (Tmp_win, False, True);
-      Tmp_win->icon_name = Tmp_win->icon_name;
       if (text_prop.format == 8)
-        { /* Multi-byte string */
-          char **text_list = NULL;
-          int text_list_num;
-          if (XmbTextPropertyToTextList(dpy, &text_prop,
-                                &text_list, &text_list_num) == Success)
-            {
+	{			/* Multi-byte string */
+	  char **text_list = NULL;
+	  int text_list_num;
+	  if (XmbTextPropertyToTextList (dpy, &text_prop,
+					 &text_list,
+					 &text_list_num) == Success)
+	    {
 	      if (text_list)
-	        {
-                  Tmp_win->icon_name = (char *) malloc(strlen (text_list[0]) + 1);
-                  strcpy (Tmp_win->icon_name, text_list[0]);
-                  XFreeStringList(text_list);
-	        }
-            }
-          else
-            Tmp_win->icon_name = (char *) text_prop.value;
-        }
+		{
+		  Tmp_win->icon_name =
+		    (char *) malloc (strlen (text_list[0]) + 1);
+		  strcpy (Tmp_win->icon_name, text_list[0]);
+		  XFreeStringList (text_list);
+		}
+	    }
+	  else
+	    {
+	      Tmp_win->icon_name =
+		(char *) malloc (strlen ((char *) text_prop.value) + 1);
+	      strcpy (Tmp_win->icon_name, (char *) text_prop.value);
+	    }
+	}
       else
-        Tmp_win->icon_name = (char *) text_prop.value;
-      if (Tmp_win->icon_name == NULL)
-	Tmp_win->icon_name = Tmp_win->name;
-      BroadcastName (M_ICON_NAME, Tmp_win->w, Tmp_win->frame,
+	{
+	  Tmp_win->icon_name =
+	    (char *) malloc (strlen ((char *) text_prop.value) + 1);
+	  strcpy (Tmp_win->icon_name, (char *) text_prop.value);
+	}
+      XFree (text_prop.value);
+      if (!(Tmp_win->icon_name))
+	{
+	  Tmp_win->icon_name = (char *) malloc (strlen (Tmp_win->name) + 1);
+	  strcpy (Tmp_win->icon_name, Tmp_win->name);
+	}
+
+      BroadcastName (XFCE_M_ICON_NAME, Tmp_win->w, Tmp_win->frame,
 		     (unsigned long) Tmp_win, Tmp_win->icon_name);
       RedoIconName (Tmp_win);
       break;
@@ -542,7 +573,8 @@ HandlePropertyNotify ()
 		  if (Tmp_win->icon_pixmap_w != None)
 		    {
 		      XDestroyWindow (dpy, Tmp_win->icon_pixmap_w);
-		      XDeleteContext (dpy, Tmp_win->icon_pixmap_w, XfwmContext);
+		      XDeleteContext (dpy, Tmp_win->icon_pixmap_w,
+				      XfwmContext);
 		    }
 		}
 	      else
@@ -555,22 +587,22 @@ HandlePropertyNotify ()
 	    {
 	      Tmp_win->flags &= ~ICONIFIED;
 	      Tmp_win->flags &= ~ICON_UNMAPPED;
-	      CreateIconWindow (Tmp_win, Tmp_win->icon_x_loc, Tmp_win->icon_y_loc);
-	      Broadcast (M_ICONIFY, 7, Tmp_win->w, Tmp_win->frame,
-			 (unsigned long) Tmp_win,
-			 Tmp_win->icon_x_loc,
-			 Tmp_win->icon_y_loc,
-			 Tmp_win->icon_w_width,
+	      CreateIconWindow (Tmp_win, Tmp_win->icon_x_loc,
+				Tmp_win->icon_y_loc);
+	      Broadcast (XFCE_M_ICONIFY, 7, Tmp_win->w, Tmp_win->frame,
+			 (unsigned long) Tmp_win, Tmp_win->icon_x_loc,
+			 Tmp_win->icon_y_loc, Tmp_win->icon_w_width,
 			 Tmp_win->icon_w_height);
-	      BroadcastConfig (M_CONFIGURE_WINDOW, Tmp_win);
+	      BroadcastConfig (XFCE_M_CONFIGURE_WINDOW, Tmp_win);
 
 	      if (!(Tmp_win->flags & SUPPRESSICON))
 		{
-                  if (!(Tmp_win->flags & STARTICONIC))
-                    LowerWindow (Tmp_win);
+		  if (!(Tmp_win->flags & STARTICONIC))
+		    LowerWindow (Tmp_win);
 
-		  if ((!(Tmp_win->flags & STARTICONIC)) && 
-		      (!(Tmp_win->flags & ICON_MOVED) || !CheckIconPlace (Tmp_win)))
+		  if ((!(Tmp_win->flags & STARTICONIC)) &&
+		      (!(Tmp_win->flags & ICON_MOVED)
+		       || !CheckIconPlace (Tmp_win)))
 		    AutoPlace (Tmp_win, False);
 
 		  if (Tmp_win->Desk == Scr.CurrentDesk)
@@ -583,7 +615,7 @@ HandlePropertyNotify ()
 		}
 	      Tmp_win->flags |= ICONIFIED;
 	      DrawIconWindow (Tmp_win);
-              LowerWindow (Tmp_win);
+	      LowerWindow (Tmp_win);
 	    }
 	}
       break;
@@ -591,7 +623,7 @@ HandlePropertyNotify ()
     case XA_WM_NORMAL_HINTS:
       {
 	GetWindowSizeHints (Tmp_win);
-	BroadcastConfig (M_CONFIGURE_WINDOW, Tmp_win);
+	BroadcastConfig (XFCE_M_CONFIGURE_WINDOW, Tmp_win);
       }
       break;
     default:
@@ -632,8 +664,7 @@ HandleClientMessage ()
     {
       XQueryPointer (dpy, Scr.Root, &JunkRoot, &JunkChild,
 		     &(button.xmotion.x_root),
-		     &(button.xmotion.y_root),
-		     &JunkX, &JunkY, &JunkMask);
+		     &(button.xmotion.y_root), &JunkX, &JunkY, &JunkMask);
       button.type = 0;
       ExecuteFunction ("Iconify", Tmp_win, &button, C_FRAME, -1);
       return;
@@ -660,11 +691,13 @@ HandleExpose ()
 	}
       else if ((Tmp_win->flags) & ICONIFIED)
 	{
-	  SetBorder (Tmp_win, (Scr.Hilite == Tmp_win), True, True, Event.xany.window);
+	  SetBorder (Tmp_win, (Scr.Hilite == Tmp_win), True, True,
+		     Event.xany.window);
 	}
       else
 	{
-	  SetBorder (Tmp_win, (Scr.Hilite == Tmp_win), False, True, Event.xany.window);
+	  SetBorder (Tmp_win, (Scr.Hilite == Tmp_win), False, True,
+		     Event.xany.window);
 	}
     }
   return;
@@ -691,29 +724,23 @@ HandleDestroyNotify ()
  ************************************************************************/
 void
 HandleMapRequest ()
-{
-  HandleMapRequestKeepRaised (None);
-}
-
-void
-HandleMapRequestKeepRaised (Window KeepRaised)
 {
   extern long isIconicState;
-
-  XFlush (dpy);
-  MyXGrabServer (dpy);
-
+  
   Event.xany.window = Event.xmaprequest.window;
 
   if (XFindContext (dpy, Event.xany.window, XfwmContext,
 		    (caddr_t *) & Tmp_win) == XCNOENT)
-    Tmp_win = NULL;
+   {
+      Tmp_win = NULL;
+   }
+
+  XFlush(dpy);
   if (!Tmp_win)
     {
       Tmp_win = AddWindow (Event.xany.window);
       if (Tmp_win == NULL)
         {
-          MyXUngrabServer (dpy);
 	  return;
         }
     }
@@ -733,41 +760,41 @@ HandleMapRequestKeepRaised (Window KeepRaised)
       if (isIconicState != DontCareState)
 	state = isIconicState;
 
+      MyXGrabServer (dpy);
       switch (state)
 	{
 	case IconicState:
 	  if (Tmp_win->wmhints)
-	    Iconify (Tmp_win, Tmp_win->wmhints->icon_x, 
-                              Tmp_win->wmhints->icon_y);
+	    Iconify (Tmp_win, Tmp_win->wmhints->icon_x,
+		     Tmp_win->wmhints->icon_y);
 	  else
 	    Iconify (Tmp_win, 0, 0);
 	  break;
+	case DontCareState:
+	case NormalState:
+	case InactiveState:
 	default:
-	  SetMapStateProp (Tmp_win, NormalState);
-	  Tmp_win->flags |= MAP_PENDING;
+	  XMapWindow (dpy, Tmp_win->w);
 	  if (Tmp_win->Desk == Scr.CurrentDesk)
 	    {
-  	      XMapWindow (dpy, Tmp_win->frame);
-	      SetFocus(Tmp_win->w,Tmp_win,1);
+	      XMapWindow (dpy, Tmp_win->frame);
+	      Tmp_win->flags |= MAP_PENDING;
+	      SetFocus (Tmp_win->w, Tmp_win, 1);
 	    }
-          if (!(Tmp_win->flags & SHADED))
-            {
-  	      XMapWindow (dpy, Tmp_win->w);
-            }
+	  if (Tmp_win->flags & SHADED)
+	    {
+	      XUnmapWindow (dpy, Tmp_win->Parent);
+	    }
+	  SetMapStateProp (Tmp_win, NormalState);
 	  break;
 	}
+      XSync (dpy, 0);
+      MyXUngrabServer (dpy);
     }
   else
     {
       DeIconify (Tmp_win);
-      RaiseWindow(Tmp_win);
-      if (Tmp_win->flags & SHADED)
-        Unshade(Tmp_win);
-      SetFocus(Tmp_win->w,Tmp_win,1);
-      KeepOnTop ();
     }
-  XSync (dpy, 0);
-  MyXUngrabServer (dpy);
 }
 
 
@@ -780,9 +807,7 @@ HandleMapRequestKeepRaised (Window KeepRaised)
 void
 HandleMapNotify ()
 {
-  XWindowAttributes winattrs;
-  unsigned long eventMask;
-
+  MyXGrabServer (dpy);
   if (!Tmp_win)
     {
       if ((Event.xmap.override_redirect == True) &&
@@ -791,13 +816,13 @@ HandleMapNotify ()
 	  XSelectInput (dpy, Event.xmap.window, FocusChangeMask);
 	  Scr.UnknownWinFocused = Event.xmap.window;
 	}
+      MyXUngrabServer (dpy);
       return;
     }
-
+  /*
   if (Event.xmap.event != Event.xmap.window)
     return;
-
-  MyXGrabServer (dpy);
+   */
   if (Tmp_win->icon_w)
     XUnmapWindow (dpy, Tmp_win->icon_w);
   if (Tmp_win->icon_pixmap_w != None)
@@ -807,33 +832,31 @@ HandleMapNotify ()
   if (Tmp_win->Desk == Scr.CurrentDesk)
     XMapWindow (dpy, Tmp_win->frame);
 
-  XSync (dpy, 0);
-
   if (Tmp_win->flags & SHADED)
-    {
-      XGetWindowAttributes (dpy, Tmp_win->w, &winattrs);
-      eventMask = winattrs.your_event_mask;
-
-      XSelectInput (dpy, Tmp_win->w, eventMask & ~StructureNotifyMask);
-      XUnmapWindow (dpy, Tmp_win->w);
-      XSelectInput (dpy, Tmp_win->w, eventMask);
-    }
+    XUnmapWindow (dpy, Tmp_win->Parent);
 
   if (Tmp_win->flags & ICONIFIED)
-      Broadcast (M_DEICONIFY, 3, Tmp_win->w, Tmp_win->frame,
+    Broadcast (XFCE_M_DEICONIFY, 3, Tmp_win->w, Tmp_win->frame,
 	       (unsigned long) Tmp_win, 0, 0, 0, 0);
   else
-      Broadcast (M_MAP, 3, Tmp_win->w, Tmp_win->frame,
-		 (unsigned long) Tmp_win, 0, 0, 0, 0);
+    Broadcast (XFCE_M_MAP, 3, Tmp_win->w, Tmp_win->frame,
+	       (unsigned long) Tmp_win, 0, 0, 0, 0);
   SetFocus (Tmp_win->w, Tmp_win, 1);
-  if ((!(Tmp_win->flags & (BORDER | TITLE))) && (Tmp_win->boundary_width < 2))
-    SetBorder (Tmp_win, False, False, True, Tmp_win->frame);
+  SetBorder (Tmp_win, True, True, True, Tmp_win->frame);
   Tmp_win->flags |= MAPPED;
   Tmp_win->flags &= ~MAP_PENDING;
   Tmp_win->flags &= ~ICONIFIED;
   Tmp_win->flags &= ~ICON_UNMAPPED;
-  MyXUngrabServer (dpy);
   XSync (dpy, 0);
+  /*
+  while (XCheckMaskEvent (dpy, ExposureMask | VisibilityChangeMask, &Event))
+    {
+      StashEventTime (&Event);
+      DispatchEvent ();
+    }
+   */
+  MyXUngrabServer (dpy);
+  KeepOnTop();
 }
 
 
@@ -886,9 +909,9 @@ HandleUnmapNotify ()
   if (Tmp_win == Scr.Focus)
     {
       if (Tmp_win->next)
-	SetFocus(Tmp_win->next->w, Tmp_win->next, 1);
+	SetFocus (Tmp_win->next->w, Tmp_win->next, 1);
       else if (Tmp_win->prev)
-	SetFocus(Tmp_win->prev->w, Tmp_win->prev, 1);
+	SetFocus (Tmp_win->prev->w, Tmp_win->prev, 1);
       else
 	SetFocus (Scr.NoFocusWin, NULL, 1);
     }
@@ -899,12 +922,14 @@ HandleUnmapNotify ()
   if (Tmp_win == colormap_win)
     colormap_win = NULL;
 
-  if (!(Tmp_win->flags & MAPPED) && !(Tmp_win->flags & ICONIFIED) && !(Tmp_win->flags & SHADED))
-      return;
+  if (!(Tmp_win->flags & MAPPED) && !(Tmp_win->flags & ICONIFIED)
+      && !(Tmp_win->flags & SHADED))
+    return;
 
   MyXGrabServer (dpy);
 
-  if (XCheckTypedWindowEvent (dpy, Event.xunmap.window, DestroyNotify, &dummy))
+  if (XCheckTypedWindowEvent
+      (dpy, Event.xunmap.window, DestroyNotify, &dummy))
     {
       Destroy (Tmp_win);
       MyXUngrabServer (dpy);
@@ -932,7 +957,7 @@ HandleUnmapNotify ()
 	  if (Tmp_win->old_bw)
 	    XSetWindowBorderWidth (dpy, Event.xunmap.window, Tmp_win->old_bw);
 	  if ((!(Tmp_win->flags & SUPPRESSICON)) &&
-	   (Tmp_win->wmhints && (Tmp_win->wmhints->flags & IconWindowHint)))
+	      (Tmp_win->wmhints && (Tmp_win->wmhints->flags & IconWindowHint)))
 	    XUnmapWindow (dpy, Tmp_win->wmhints->icon_window);
 	}
       else
@@ -940,9 +965,9 @@ HandleUnmapNotify ()
       XRemoveFromSaveSet (dpy, Event.xunmap.window);
       XSelectInput (dpy, Event.xunmap.window, NoEventMask);
       Destroy (Tmp_win);	/* do not need to mash event before */
-    }				/* else window no longer exists and we'll get a destroy notify */
+    }
   MyXUngrabServer (dpy);
-  XSync (dpy, 0);
+  XFlush (dpy);
 }
 
 
@@ -959,29 +984,33 @@ HandleButtonPress ()
   Binding *MouseEntry;
   Window x;
   int LocalContext;
-
   if (Scr.Options & AutoRaiseWin)
-    SetTimer(0);
+    SetTimer (0);
   if (Tmp_win)
     {
-      if ((Event.xbutton.window == Tmp_win->frame) || 
-          (Tmp_win != Scr.Focus) || 
-          (Tmp_win != Scr.LastWindowRaised))
-        {
+      if (!(Tmp_win->triggered) || (Event.xbutton.window == Tmp_win->frame))
+	{
           if (Tmp_win != Scr.Focus)
-            SetFocus (Tmp_win->w, Tmp_win, 1);
-          if ((GetContext(Tmp_win,&Event, &PressedW) != C_WINDOW) || 
-              (Scr.Options & (AutoRaiseWin | ClickToFocus)) || 
-              (Tmp_win->flags & ICONIFIED) ||
-              (!(Tmp_win->flags & (BORDER | TITLE))))
-            {
-              RaiseWindow (Tmp_win);
-            }
-          XSync(dpy,0);
-          XAllowEvents(dpy,ReplayPointer,CurrentTime);
-          XSync(dpy,0);
-          return;
-        }
+  	    SetFocus (Tmp_win->w, Tmp_win, 1);
+	  if ((Scr.Options & AutoRaiseWin) ||
+	      (Scr.Options & ClickToFocus) ||
+	      (Scr.Options & ClickRaise) ||
+	      (!(Tmp_win->flags & TITLE)) ||
+	      (GetContext (Tmp_win, &Event, &PressedW) != C_WINDOW))
+	    {
+	      RaiseWindow (Tmp_win);
+	    }
+	  Tmp_win->triggered = True;
+	  XSync (dpy, 0);
+	  XAllowEvents (dpy, ReplayPointer, CurrentTime);
+	  XSync (dpy, 0);
+	  return;
+	}
+    }
+
+  if (Tmp_win)
+    {
+      Tmp_win->triggered = False;
     }
 
   XSync (dpy, 0);
@@ -989,6 +1018,7 @@ HandleButtonPress ()
   XSync (dpy, 0);
 
   Context = GetContext (Tmp_win, &Event, &PressedW);
+  modifier = vmod ((Event.xkey.state) & KeyMask);
   LocalContext = Context;
   x = PressedW;
   if (Context == C_TITLE)
@@ -1000,17 +1030,17 @@ HandleButtonPress ()
 
   /* we have to execute a function or pop up a menu */
 
-  modifier = vmod((Event.xkey.state) & KeyMask);
   /* need to search for an appropriate mouse binding */
   for (MouseEntry = Scr.AllBindings; MouseEntry != NULL;
        MouseEntry = MouseEntry->NextBinding)
     {
-      if (((MouseEntry->Button_Key == Event.xbutton.button) ||
-	   (MouseEntry->Button_Key == 0)) &&
-	  (MouseEntry->Context & Context) &&
-	  ((vmod(MouseEntry->Modifier) == modifier) ||
-	   (MouseEntry->Modifier == AnyModifier)) &&
-	  (MouseEntry->IsMouse == 1))
+      if (
+	  ((MouseEntry->Button_Key == Event.xbutton.button)
+	   || (MouseEntry->Button_Key == 0))
+	  && (MouseEntry->Context & Context)
+	  && ((vmod (MouseEntry->Modifier) == modifier)
+	      || (MouseEntry->Modifier == AnyModifier))
+	  && (MouseEntry->IsMouse == 1))
 	{
 	  /* got a match, now process it */
 	  ExecuteFunction (MouseEntry->Action, Tmp_win, &Event, Context, -1);
@@ -1036,29 +1066,32 @@ void
 HandleEnterNotify ()
 {
   XCrossingEvent *e;
-  
-  e = (XCrossingEvent *) &Event;
+
+  e = (XCrossingEvent *) & Event;
   XSync (dpy, False);
 
   /* make sure its for one of our windows */
   if (!Tmp_win)
     return;
 
-  if(!(Scr.Options & ClickToFocus) && (!(e->focus)) &&
-     ((e->x_root != old_x_root) || (e->y_root != old_y_root)) &&
-     (e->mode == NotifyNormal))
-    {
-      old_x_root = e->x_root;
-      old_y_root = e->y_root;
-      SetFocus(Tmp_win->w, Tmp_win, 0);
+  if (!(Scr.Options & ClickToFocus) &&
+      !(e->focus) &&
+      ((e->x_root != old_x_root) || (e->y_root != old_y_root) || (Scr.Options & ForceFocus)) && 
+      (e->mode == NotifyNormal))
 
-      if (((Scr.Options & AutoRaiseWin) && (Scr.AutoRaiseDelay > 0)) 
-         && (!(Tmp_win->flags & ICONIFIED) && !(Tmp_win->flags & RAISEDWIN)))
-	   SetTimer(Scr.AutoRaiseDelay);
+    {
+      SetFocus (Tmp_win->w, Tmp_win, 1);
+
+      if (((Scr.Options & AutoRaiseWin) && (Scr.AutoRaiseDelay > 0))
+	  && (!(Tmp_win->flags & ICONIFIED) && !(Tmp_win->flags & RAISEDWIN)))
+	SetTimer (Scr.AutoRaiseDelay);
     }
+  old_x_root = e->x_root;
+  old_y_root = e->y_root;
   if (Scr.ColormapFocus == COLORMAP_FOLLOWS_MOUSE)
     {
-      if ((!(Tmp_win->flags & ICONIFIED)) && (Event.xany.window == Tmp_win->w))
+      if ((!(Tmp_win->flags & ICONIFIED))
+	  && (Event.xany.window == Tmp_win->w))
 	InstallWindowColormaps (Tmp_win);
       else
 	InstallWindowColormaps (NULL);
@@ -1083,7 +1116,7 @@ HandleLeaveNotify ()
   if (Event.xcrossing.window == Scr.Root)
     {
       if (Scr.Options & AutoRaiseWin)
-        SetTimer(0);
+	SetTimer (0);
       if (Event.xcrossing.mode == NotifyNormal)
 	{
 	  if (Event.xcrossing.detail != NotifyInferior)
@@ -1117,7 +1150,8 @@ HandleConfigureRequest ()
    */
 
   Event.xany.window = cre->window;	/* mash parent field */
-  if (XFindContext (dpy, cre->window, XfwmContext, (caddr_t *) & Tmp_win) == XCNOENT)
+  if (XFindContext (dpy, cre->window, XfwmContext, (caddr_t *) & Tmp_win) ==
+      XCNOENT)
     Tmp_win = NULL;
 
   if (!Tmp_win || (Tmp_win->icon_w == cre->window))
@@ -1133,7 +1167,7 @@ HandleConfigureRequest ()
 	    (Tmp_win->icon_w_width - Tmp_win->icon_p_width) / 2;
 	  Tmp_win->icon_y_loc = cre->y - Tmp_win->icon_p_height;
 	  if (!(Tmp_win->flags & ICON_UNMAPPED))
-	    Broadcast (M_ICON_LOCATION, 7, Tmp_win->w, Tmp_win->frame,
+	    Broadcast (XFCE_M_ICON_LOCATION, 7, Tmp_win->w, Tmp_win->frame,
 		       (unsigned long) Tmp_win,
 		       Tmp_win->icon_x_loc, Tmp_win->icon_y_loc,
 		       Tmp_win->icon_w_width,
@@ -1163,14 +1197,27 @@ HandleConfigureRequest ()
   if (cre->value_mask & CWStackMode)
     {
       XfwmWindow *otherwin;
+      XfwmWindow *t;
+      Bool cnt;
 
-      xwc.sibling = (((cre->value_mask & CWSibling) &&
-		      (XFindContext (dpy, cre->above, XfwmContext,
-				     (caddr_t *) & otherwin) == XCSUCCESS))
-		     ? otherwin->frame : cre->above);
+      cnt =
+	(XFindContext (dpy, cre->above, XfwmContext, (caddr_t *) & otherwin)
+	 == XCSUCCESS);
+      xwc.sibling =
+	(((cre->value_mask & CWSibling) && cnt) ? otherwin->
+	 frame : cre->above);
       xwc.stack_mode = cre->detail;
       XConfigureWindow (dpy, Tmp_win->frame,
 			cre->value_mask & (CWSibling | CWStackMode), &xwc);
+      /* Netscape is braindead : It raises its window on top of its own transient windows ! */
+      MyXGrabServer (dpy);
+      for (t = Scr.XfwmRoot.next; t != NULL; t = t->next)
+	{
+	  if ((t->flags & TRANSIENT) && (t->transientfor == Tmp_win->w))
+	    XRaiseWindow (dpy, t->frame);
+	}
+      KeepOnTop ();
+      MyXUngrabServer (dpy);
       XSync (dpy, False);
     }
 
@@ -1193,16 +1240,18 @@ HandleConfigureRequest ()
 
   /* for restoring */
   if (cre->value_mask & CWBorderWidth)
-      Tmp_win->old_bw = cre->border_width;
+    Tmp_win->old_bw = cre->border_width;
 
   if (cre->value_mask & CWX)
     x = cre->x - Tmp_win->boundary_width - Tmp_win->bw;
   if (cre->value_mask & CWY)
-    y = cre->y - Tmp_win->boundary_width - Tmp_win->title_height - Tmp_win->bw;
+    y =
+      cre->y - Tmp_win->boundary_width - Tmp_win->title_height - Tmp_win->bw;
   if (cre->value_mask & CWWidth)
     width = cre->width + 2 * Tmp_win->boundary_width;
   if (cre->value_mask & CWHeight)
-    height = cre->height + Tmp_win->title_height + 2 * Tmp_win->boundary_width;
+    height =
+      cre->height + Tmp_win->title_height + 2 * Tmp_win->boundary_width;
 
   SetupFrame (Tmp_win, x, y, width, height, FALSE, TRUE);
 }
@@ -1250,7 +1299,8 @@ HandleVisibilityNotify ()
 
       if (((vevent->state == VisibilityPartiallyObscured) ||
 	   (vevent->state == VisibilityFullyObscured)) &&
-	  (Tmp_win->flags & ONTOP) && (Tmp_win->flags & RAISED) && !(Tmp_win->flags & ICONIFIED))
+	  (Tmp_win->flags & ONTOP) && (Tmp_win->flags & RAISED)
+	  && !(Tmp_win->flags & ICONIFIED))
 	{
 	  RaiseWindow (Tmp_win);
 	  Tmp_win->flags &= ~RAISED;
@@ -1264,31 +1314,39 @@ HandleVisibilityNotify ()
  *     HandleRootMotionNotify - Root-MotionNotify event handler
  *
  ************************************************************************/
-int _xfwm_deskwrap (int horz, int vert)
+int
+_xfwm_deskwrap (int horz, int vert)
 {
   int ndesks = Scr.ndesks;
   int desk = Scr.CurrentDesk;
 
-  if (!ndesks) ndesks = 1;
-    
+  if (!ndesks)
+    ndesks = 1;
+
   /*assumes that the desk-layout is alway 2 rows in height -gud */
-  
-  if (horz) 
-  {
-     desk += horz*2;
-     if (desk >= ndesks) { desk -= ndesks; }
-     if (desk < 0) { desk += ndesks; }
-  }
-  if (vert) 
-  {
-     desk ^= 1;
-  }
+
+  if (horz)
+    {
+      desk += horz * 2;
+      if (desk >= ndesks)
+	{
+	  desk -= ndesks;
+	}
+      if (desk < 0)
+	{
+	  desk += ndesks;
+	}
+    }
+  if (vert)
+    {
+      desk ^= 1;
+    }
 
   return desk;
 }
 
 void
-sendclient_event(XfwmWindow *tmp_win, int x, int y, int w, int h)
+sendclient_event (XfwmWindow * tmp_win, int x, int y, int w, int h)
 {
   XEvent client_event;
 
@@ -1313,53 +1371,72 @@ sendclient_event(XfwmWindow *tmp_win, int x, int y, int w, int h)
 void
 HandleRootMotionNotify ()
 {
-  if (Scr.SnapSize < MINRESISTANCE) 
+  if (Scr.SnapSize < MINRESISTANCE)
     {
       return;
     }
   else
-    { /* check if the pointer is pushed onto the screen border,
-         if so, increment the corresponding X or Y counter (until Snapsize),
-         otherwise reset them to null.
-      */
-           if (Event.xmotion.x_root == 0) { Scr.EdgeScrollX--; }
-      else if (Event.xmotion.y_root == 0) { Scr.EdgeScrollY--; }
-      else if (Event.xmotion.x_root >= Scr.MyDisplayWidth-1)  { Scr.EdgeScrollX++; }
-      else if (Event.xmotion.y_root >= Scr.MyDisplayHeight-1) { Scr.EdgeScrollY++; }
-      else { Scr.EdgeScrollY = Scr.EdgeScrollX = 0; }
-      
+    {				/* check if the pointer is pushed onto the screen border,
+				   if so, increment the corresponding X or Y counter (until Snapsize),
+				   otherwise reset them to null.
+				 */
+      if (Event.xmotion.x_root == 0)
+	{
+	  Scr.EdgeScrollX--;
+	}
+      else if (Event.xmotion.y_root == 0)
+	{
+	  Scr.EdgeScrollY--;
+	}
+      else if (Event.xmotion.x_root >= Scr.MyDisplayWidth - 1)
+	{
+	  Scr.EdgeScrollX++;
+	}
+      else if (Event.xmotion.y_root >= Scr.MyDisplayHeight - 1)
+	{
+	  Scr.EdgeScrollY++;
+	}
+      else
+	{
+	  Scr.EdgeScrollY = Scr.EdgeScrollX = 0;
+	}
+
       /* now check if some EdgeCounter has reached Snapsize, so that
          we shall emit signals to switch to the next desk (computed in 
          the deskwrap-helper)
-      */
-      if (Scr.EdgeScrollX <= (-EDGEFACTOR * Scr.SnapSize)) 
-        { /* move desktop left */
-          changeDesks (0, _xfwm_deskwrap(-1,0), 1, 1);
-          Scr.EdgeScrollX = Scr.EdgeScrollY = 0;
-          XWarpPointer (dpy, None, None, 0,0,0,0, +(Scr.MyDisplayWidth-Scr.SnapSize),(0));
+       */
+      if (Scr.EdgeScrollX <= (-EDGEFACTOR * Scr.SnapSize))
+	{			/* move desktop left */
+	  changeDesks (0, _xfwm_deskwrap (-1, 0), 1, 1, 1);
+	  Scr.EdgeScrollX = Scr.EdgeScrollY = 0;
+	  XWarpPointer (dpy, None, None, 0, 0, 0, 0,
+			+(Scr.MyDisplayWidth - Scr.SnapSize), (0));
 	  return;
-        }
-      if (Scr.EdgeScrollX >= (EDGEFACTOR * Scr.SnapSize)) 
-        { /* move desktop right */
-          changeDesks (0, _xfwm_deskwrap(+1,0), 1, 1);
-          Scr.EdgeScrollX = Scr.EdgeScrollY = 0;
-          XWarpPointer (dpy, None, None, 0,0,0,0, -(Scr.MyDisplayWidth-Scr.SnapSize),(0));
+	}
+      if (Scr.EdgeScrollX >= (EDGEFACTOR * Scr.SnapSize))
+	{			/* move desktop right */
+	  changeDesks (0, _xfwm_deskwrap (+1, 0), 1, 1, 1);
+	  Scr.EdgeScrollX = Scr.EdgeScrollY = 0;
+	  XWarpPointer (dpy, None, None, 0, 0, 0, 0,
+			-(Scr.MyDisplayWidth - Scr.SnapSize), (0));
 	  return;
-        }
-      if (Scr.EdgeScrollY <= (-EDGEFACTOR * Scr.SnapSize)) 
-        { /* move desktop upper */
-          changeDesks (0, _xfwm_deskwrap(0,-1), 1, 1);
-          Scr.EdgeScrollX = Scr.EdgeScrollY = 0;
-          XWarpPointer (dpy, None, None, 0,0,0,0, (0),+(Scr.MyDisplayHeight-Scr.SnapSize));
+	}
+      if (Scr.EdgeScrollY <= (-EDGEFACTOR * Scr.SnapSize))
+	{			/* move desktop upper */
+	  changeDesks (0, _xfwm_deskwrap (0, -1), 1, 1, 1);
+	  Scr.EdgeScrollX = Scr.EdgeScrollY = 0;
+	  XWarpPointer (dpy, None, None, 0, 0, 0, 0, (0),
+			+(Scr.MyDisplayHeight - Scr.SnapSize));
 	  return;
-        }
-      if (Scr.EdgeScrollY >= (EDGEFACTOR * Scr.SnapSize)) 
-        { /* move desktop lower */
-          changeDesks (0, _xfwm_deskwrap(0,+1), 1, 1);
-          Scr.EdgeScrollX = Scr.EdgeScrollY = 0;
-          XWarpPointer (dpy, None, None, 0,0,0,0, (0),-(Scr.MyDisplayHeight-Scr.SnapSize));
+	}
+      if (Scr.EdgeScrollY >= (EDGEFACTOR * Scr.SnapSize))
+	{			/* move desktop lower */
+	  changeDesks (0, _xfwm_deskwrap (0, +1), 1, 1, 1);
+	  Scr.EdgeScrollX = Scr.EdgeScrollY = 0;
+	  XWarpPointer (dpy, None, None, 0, 0, 0, 0, (0),
+			-(Scr.MyDisplayHeight - Scr.SnapSize));
 	  return;
-        }
+	}
     }
 }
 
@@ -1373,8 +1450,8 @@ void
 HandleMotionNotify ()
 {
   XMotionEvent *e;
-  
-  e = (XMotionEvent *) &Event;
+
+  e = (XMotionEvent *) & Event;
 
   if ((e->x_root != old_x_root) || (e->y_root != old_y_root))
     {
@@ -1408,7 +1485,8 @@ My_XNextEvent (Display * dpy, XEvent * event)
   FD_SET (x_fd, &in_fdset);
   FD_ZERO (&out_fdset);
 #ifdef HAVE_SESSION
-  if (sm_fd >= 0) FD_SET(sm_fd, &in_fdset);
+  if (sm_fd >= 0)
+    FD_SET (sm_fd, &in_fdset);
 #endif
   for (i = 0; i < npipes; i++)
     {
@@ -1418,12 +1496,12 @@ My_XNextEvent (Display * dpy, XEvent * event)
 	FD_SET (writePipes[i], &out_fdset);
     }
 
-  if(alarmed)
+  if (alarmed)
     {
-      SetTimer(0);
+      SetTimer (0);
       alarmed = False;
       if (Scr.Focus != NULL)
-        RaiseWindow(Scr.Focus);
+	RaiseWindow (Scr.Focus);
       return 0;
     }
 
@@ -1438,7 +1516,8 @@ My_XNextEvent (Display * dpy, XEvent * event)
     }
 
 #ifdef __hpux
-  retval = select (fd_width, (fd_set *) &in_fdset, (fd_set *) &out_fdset, 0, NULL);
+  retval =
+    select (fd_width, (fd_set *) & in_fdset, (fd_set *) & out_fdset, 0, NULL);
 #else
   retval = select (fd_width, &in_fdset, &out_fdset, 0, NULL);
 #endif
@@ -1468,20 +1547,12 @@ My_XNextEvent (Display * dpy, XEvent * event)
 	      FlushQueue (i);
 	    }
 	}
-      }
+    }
 #ifdef HAVE_SESSION
   /* Weird : If alarm is set, ProcessICEMsgs () stucks */
-  if ((!alarmed) && (sm_fd >= 0) && (FD_ISSET(sm_fd, &in_fdset))) ProcessICEMsgs();
+  if ((!alarmed) && (sm_fd >= 0) && (FD_ISSET (sm_fd, &in_fdset)))
+    ProcessICEMsgs ();
 #endif
- 
-  /* Process any new X events, to save a recall if any new event have come arround */
-  XFlush (dpy);
-  if (XPending (dpy))
-    {
-      XNextEvent (dpy, event);
-      StashEventTime (event);
-      return 1;
-    }
 
   return 0;
 }
