@@ -29,6 +29,10 @@
 #include "screen.h"
 #include "module.h"
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 extern XEvent Event;
 extern XfwmWindow *Tmp_win;
 extern int menuFromFrameOrWindowOrTitlebar;
@@ -37,8 +41,7 @@ Bool desperate;
 /*
  * ** be sure to keep this list properly ordered for bsearch routine!
  */
-static struct functions func_config[] =
-{
+static struct functions func_config[] = {
   {"+", add_another_item, F_ADDMENU2, FUNC_NO_WINDOW},
   {"ActiveColor", SetHiColor, F_HICOLOR, FUNC_NO_WINDOW},
   {"AddModuleConfig", AddModConfig, F_ADD_MOD, FUNC_NO_WINDOW},
@@ -50,6 +53,7 @@ static struct functions func_config[] =
   {"AutoRaiseDelay", SetAutoRaiseDelay, F_AUTORAISEDELAY, FUNC_NO_WINDOW},
   {"Beep", Bell, F_BEEP, FUNC_NO_WINDOW},
   {"BitmapButtons", use_bitmap_buttons, F_BITMAPBUTTONS, FUNC_NO_WINDOW},
+  {"ClickRaise", SetClickRaise, F_SETCLICKRAISE, FUNC_NO_WINDOW},
   {"ClickTime", SetClick, F_CLICK, FUNC_NO_WINDOW},
   {"Close", close_function, F_CLOSE, FUNC_NEEDS_WINDOW},
   {"ColormapFocus", SetColormapFocus, F_COLORMAP_FOCUS, FUNC_NO_WINDOW},
@@ -68,6 +72,7 @@ static struct functions func_config[] =
   {"FlipFocus", flip_focus_func, F_FLIP_FOCUS, FUNC_NEEDS_WINDOW},
   {"Focus", focus_func, F_FOCUS, FUNC_NEEDS_WINDOW},
   {"FocusMode", SetFocusMode, F_SETFOCUSMODE, FUNC_NO_WINDOW},
+  {"ForceFocus", SetForceFocus, F_SETFORCEFOCUS, FUNC_NO_WINDOW},
   {"Function", ComplexFunction, F_FUNCTION, FUNC_NO_WINDOW},
   {"IconFont", LoadIconFont, F_ICONFONT, FUNC_NO_WINDOW},
   {"IconGrid", SetIconGrid, F_ICONGRID, FUNC_NO_WINDOW},
@@ -178,7 +183,8 @@ ExecuteFunction (char *Action, XfwmWindow * tmp_win, XEvent * eventp,
 	{
 	  matched = TRUE;
 	  /* found key word */
-	  func_config[j].action (eventp, w, tmp_win, context, action, &Module);
+	  func_config[j].action (eventp, w, tmp_win, context, action,
+				 &Module);
 	}
       else
 	j++;
