@@ -42,6 +42,10 @@
 
 #include <X11/extensions/shape.h>
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 void GrabIconButtons (XfwmWindow *, Window);
 void GrabIconKeys (XfwmWindow *, Window);
 
@@ -71,13 +75,13 @@ CreateIconWindow (XfwmWindow * tmp_win, int def_x, int def_y)
   tmp_win->icon_p_width = 0;
 
   /* First, check for a monochrome bitmap */
-  if(tmp_win->icon_bitmap_file != NULL)
-    GetBitmapFile(tmp_win);
+  if (tmp_win->icon_bitmap_file != NULL)
+    GetBitmapFile (tmp_win);
 
   /* Next, check for a color pixmap */
-  if((tmp_win->icon_bitmap_file != NULL)&&
-     (tmp_win->icon_p_height == 0)&&(tmp_win->icon_p_width == 0))
-    GetXPMFile(tmp_win);
+  if ((tmp_win->icon_bitmap_file != NULL) &&
+      (tmp_win->icon_p_height == 0) && (tmp_win->icon_p_width == 0))
+    GetXPMFile (tmp_win);
 
   /* See if the app supplies its own icon window */
   if ((tmp_win->icon_p_height == 0) && (tmp_win->icon_p_width == 0) &&
@@ -97,15 +101,16 @@ CreateIconWindow (XfwmWindow * tmp_win, int def_x, int def_y)
     {
       XFontSet fontset = Scr.IconFont.fontset;
       if (fontset)
-        {
-          XRectangle rect1, rect2;
-          XmbTextExtents (fontset, tmp_win->icon_name, strlen (tmp_win->icon_name), &rect1, &rect2);
-          tmp_win->icon_t_width = rect2.width;
-        }
+	{
+	  XRectangle rect1, rect2;
+	  XmbTextExtents (fontset, tmp_win->icon_name,
+			  strlen (tmp_win->icon_name), &rect1, &rect2);
+	  tmp_win->icon_t_width = rect2.width;
+	}
       else
-        tmp_win->icon_t_width = XTextWidth (Scr.IconFont.font,
-				      tmp_win->icon_name,
-				      strlen (tmp_win->icon_name));
+	tmp_win->icon_t_width = XTextWidth (Scr.IconFont.font,
+					    tmp_win->icon_name,
+					    strlen (tmp_win->icon_name));
       tmp_win->icon_w_height = ICON_HEIGHT;
     }
   else
@@ -161,7 +166,8 @@ CreateIconWindow (XfwmWindow * tmp_win, int def_x, int def_y)
       tmp_win->icon_pixmap_w =
 	XCreateWindow (dpy, Scr.Root, final_x, final_y, tmp_win->icon_p_width,
 		       tmp_win->icon_p_height, 0, CopyFromParent,
-		    CopyFromParent, CopyFromParent, valuemask, &attributes);
+		       CopyFromParent, CopyFromParent, valuemask,
+		       &attributes);
     }
   else
     {
@@ -191,7 +197,8 @@ CreateIconWindow (XfwmWindow * tmp_win, int def_x, int def_y)
     }
   if (tmp_win->icon_pixmap_w != None)
     {
-      XSaveContext (dpy, tmp_win->icon_pixmap_w, XfwmContext, (caddr_t) tmp_win);
+      XSaveContext (dpy, tmp_win->icon_pixmap_w, XfwmContext,
+		    (caddr_t) tmp_win);
       XDefineCursor (dpy, tmp_win->icon_pixmap_w, Scr.XfwmCursors[DEFAULT]);
       GrabIconButtons (tmp_win, tmp_win->icon_pixmap_w);
       GrabIconKeys (tmp_win, tmp_win->icon_pixmap_w);
@@ -224,7 +231,9 @@ DrawIconWindow (XfwmWindow * Tmp_win)
       TextColor = GetDecor (Tmp_win, HiColors.fore);
       BackColor = GetDecor (Tmp_win, HiColors.back);
       if (Tmp_win->icon_w != None)
-        XSetWindowBackground(dpy,Tmp_win->icon_w, GetDecor (Tmp_win, titlebar.state[Active].u.back));
+	XSetWindowBackground (dpy, Tmp_win->icon_w,
+			      GetDecor (Tmp_win,
+					titlebar.state[Active].u.back));
       /* resize the icon name window */
       if (Tmp_win->icon_w != None)
 	{
@@ -236,7 +245,7 @@ DrawIconWindow (XfwmWindow * Tmp_win)
 	  /* start keep label on screen. dje 8/7/97 */
 	  if (Tmp_win->icon_xl_loc < 0)
 	    {			/* if new loc neg (off left edge) */
-	      Tmp_win->icon_xl_loc = 0;		/* move to edge */
+	      Tmp_win->icon_xl_loc = 0;	/* move to edge */
 	    }
 	  else
 	    {			/* if not on left edge */
@@ -245,7 +254,8 @@ DrawIconWindow (XfwmWindow * Tmp_win)
 		  Scr.MyDisplayWidth)
 		{		/* off right */
 		  /* position up against right edge */
-		  Tmp_win->icon_xl_loc = Scr.MyDisplayWidth - Tmp_win->icon_w_width;
+		  Tmp_win->icon_xl_loc =
+		    Scr.MyDisplayWidth - Tmp_win->icon_w_width;
 		}
 	      /* end keep label on screen. dje 8/7/97 */
 	    }
@@ -258,7 +268,9 @@ DrawIconWindow (XfwmWindow * Tmp_win)
       TextColor = GetDecor (Tmp_win, LoColors.fore);
       BackColor = GetDecor (Tmp_win, LoColors.back);
       if (Tmp_win->icon_w != None)
-        XSetWindowBackground(dpy,Tmp_win->icon_w, GetDecor (Tmp_win, titlebar.state[Inactive].u.back));
+	XSetWindowBackground (dpy, Tmp_win->icon_w,
+			      GetDecor (Tmp_win,
+					titlebar.state[Inactive].u.back));
       /* resize the icon name window */
       if (Tmp_win->icon_w != None)
 	{
@@ -267,8 +279,7 @@ DrawIconWindow (XfwmWindow * Tmp_win)
 	}
     }
   if ((Tmp_win->flags & ICON_OURS) && (Tmp_win->icon_pixmap_w != None))
-    XSetWindowBackground (dpy, Tmp_win->icon_pixmap_w,
-			  BackColor);
+    XSetWindowBackground (dpy, Tmp_win->icon_pixmap_w, BackColor);
   /* write the icon label */
   if (Scr.IconFont.font)
     {
@@ -302,12 +313,14 @@ DrawIconWindow (XfwmWindow * Tmp_win)
     {
       if (Tmp_win->iconDepth == Scr.d_depth)
 	{
-	  XCopyArea (dpy, Tmp_win->iconPixmap, Tmp_win->icon_pixmap_w, Scr.ScratchGC3,
-	  0, 0, Tmp_win->icon_p_width - 4, Tmp_win->icon_p_height - 4, 2, 2);
+	  XCopyArea (dpy, Tmp_win->iconPixmap, Tmp_win->icon_pixmap_w,
+		     Scr.ScratchGC3, 0, 0, Tmp_win->icon_p_width - 4,
+		     Tmp_win->icon_p_height - 4, 2, 2);
 	}
       else
-	XCopyPlane (dpy, Tmp_win->iconPixmap, Tmp_win->icon_pixmap_w, Scr.ScratchGC3, 0,
-	 0, Tmp_win->icon_p_width - 4, Tmp_win->icon_p_height - 4, 2, 2, 1);
+	XCopyPlane (dpy, Tmp_win->iconPixmap, Tmp_win->icon_pixmap_w,
+		    Scr.ScratchGC3, 0, 0, Tmp_win->icon_p_width - 4,
+		    Tmp_win->icon_p_height - 4, 2, 2, 1);
     }
 
   if (Tmp_win->icon_w != None)
@@ -319,20 +332,20 @@ DrawIconWindow (XfwmWindow * Tmp_win)
 	x = 3;
 
       if (fontset)
-        XmbDrawString (dpy, Tmp_win->icon_w, fontset, Scr.ScratchGC3, x,
-                       Tmp_win->icon_w_height - Scr.IconFont.height +
+	XmbDrawString (dpy, Tmp_win->icon_w, fontset, Scr.ScratchGC3, x,
+		       Tmp_win->icon_w_height - Scr.IconFont.height +
 		       Scr.IconFont.y - 3,
 		       Tmp_win->icon_name, strlen (Tmp_win->icon_name));
       else
-        XDrawString (dpy, Tmp_win->icon_w, Scr.ScratchGC3, x,
+	XDrawString (dpy, Tmp_win->icon_w, Scr.ScratchGC3, x,
 		     Tmp_win->icon_w_height - Scr.IconFont.height +
 		     Scr.IconFont.y - 3,
 		     Tmp_win->icon_name, strlen (Tmp_win->icon_name));
       RelieveRectangle (Tmp_win->icon_w, 0, 0, Tmp_win->icon_w_width,
-		       ICON_HEIGHT, Shadow, Relief);
-        if (!(Scr.Hilite == Tmp_win))
-	  RelieveRectangle (Tmp_win->icon_w, 1, 1, Tmp_win->icon_w_width - 2,
-		     ICON_HEIGHT - 2, Relief, Shadow);
+			ICON_HEIGHT, Shadow, Relief);
+      if (!(Scr.Hilite == Tmp_win))
+	RelieveRectangle (Tmp_win->icon_w, 1, 1, Tmp_win->icon_w_width - 2,
+			  ICON_HEIGHT - 2, Relief, Shadow);
     }
 }
 
@@ -356,12 +369,13 @@ RedoIconName (XfwmWindow * Tmp_win)
   if (fontset)
     {
       XRectangle rect1, rect2;
-      XmbTextExtents (fontset, Tmp_win->icon_name, strlen (Tmp_win->icon_name), &rect1, &rect2);
+      XmbTextExtents (fontset, Tmp_win->icon_name,
+		      strlen (Tmp_win->icon_name), &rect1, &rect2);
       Tmp_win->icon_t_width = rect2.width;
     }
   else
     Tmp_win->icon_t_width = XTextWidth (Scr.IconFont.font, Tmp_win->icon_name,
-				        strlen (Tmp_win->icon_name));
+					strlen (Tmp_win->icon_name));
   /* clear the icon window, and trigger a re-draw via an expose event */
   if (Tmp_win->flags & ICONIFIED)
     XClearArea (dpy, Tmp_win->icon_w, 0, 0, 0, 0, True);
@@ -399,9 +413,9 @@ RedoIconName (XfwmWindow * Tmp_win)
     ((x4 >= x1) && (x4 <= x2) && (y4 >= y1) && (y4 <= y2)) || \
     ((x3 >= x1) && (x3 <= x2) && (y4 >= y1) && (y4 <= y2)) || \
     ((x4 >= x1) && (x4 <= x2) && (y3 >= y1) && (y3 <= y2)))
-     
 
-Bool 
+
+Bool
 CheckIconPlace (XfwmWindow * t)
 {
   XfwmWindow *tw;
@@ -414,17 +428,16 @@ CheckIconPlace (XfwmWindow * t)
       if (tw->Desk == t->Desk)
 	{
 	  if ((tw->flags & ICONIFIED) &&
-	      (tw->icon_w || tw->icon_pixmap_w) &&
-	      (tw != t))
+	      (tw->icon_w || tw->icon_pixmap_w) && (tw != t))
 	    {
-	      if (OVERLAP(t->icon_x_loc - Scr.iconspacing, 
-	                  t->icon_y_loc - Scr.iconspacing,
-                          t->icon_x_loc + t->icon_p_width + Scr.iconspacing, 
-			  t->icon_y_loc + t->icon_w_height + t->icon_p_height + Scr.iconspacing,
-                          tw->icon_x_loc, 
-			  tw->icon_y_loc,
-                          tw->icon_x_loc + tw->icon_p_width, 
-			  tw->icon_y_loc + tw->icon_w_height + tw->icon_p_height))
+	      if (OVERLAP (t->icon_x_loc - Scr.iconspacing,
+			   t->icon_y_loc - Scr.iconspacing,
+			   t->icon_x_loc + t->icon_p_width + Scr.iconspacing,
+			   t->icon_y_loc + t->icon_w_height +
+			   t->icon_p_height + Scr.iconspacing, tw->icon_x_loc,
+			   tw->icon_y_loc, tw->icon_x_loc + tw->icon_p_width,
+			   tw->icon_y_loc + tw->icon_w_height +
+			   tw->icon_p_height))
 		{
 		  loc_ok = False;
 		}
@@ -460,12 +473,14 @@ AutoPlace (XfwmWindow * t, Bool rearrange)
       break;
     case 2:
       base_x = 0;
-      base_y = ((int) (Scr.MyDisplayHeight - height) /  Scr.icongrid) * Scr.icongrid;
+      base_y =
+	((int) (Scr.MyDisplayHeight - height) / Scr.icongrid) * Scr.icongrid;
       step_x = Scr.icongrid;
       step_y = -Scr.icongrid;
       break;
     case 3:
-      base_x = ((int) (Scr.MyDisplayWidth - width) /  Scr.icongrid) * Scr.icongrid;
+      base_x =
+	((int) (Scr.MyDisplayWidth - width) / Scr.icongrid) * Scr.icongrid;
       base_y = 0;
       step_x = -Scr.icongrid;
       step_y = Scr.icongrid;
@@ -523,19 +538,22 @@ AutoPlace (XfwmWindow * t, Bool rearrange)
 		      (test_window != t))
 		    {
 		      tw = test_window->icon_p_width;
-		      th = test_window->icon_p_height + test_window->icon_w_height;
+		      th =
+			test_window->icon_p_height +
+			test_window->icon_w_height;
 		      tx = test_window->icon_x_loc;
 		      ty = test_window->icon_y_loc;
 
-		      if (OVERLAP(tx - Scr.iconspacing, 
-		                  ty - Scr.iconspacing, 
-				  tx + tw + Scr.iconspacing, 
-				  ty + th + Scr.iconspacing,
-				  real_x,
-				  real_y, 
-				  real_x + width,
-			          real_y + height) &&
-			  !(rearrange && !(test_window->icon_arranged) && !(test_window->flags & ICON_MOVED)))
+		      if (OVERLAP (tx - Scr.iconspacing,
+				   ty - Scr.iconspacing,
+				   tx + tw + Scr.iconspacing,
+				   ty + th + Scr.iconspacing,
+				   real_x,
+				   real_y,
+				   real_x + width,
+				   real_y + height) &&
+			  !(rearrange && !(test_window->icon_arranged)
+			    && !(test_window->flags & ICON_MOVED)))
 			{
 			  loc_ok = False;
 			}
@@ -569,7 +587,7 @@ AutoPlace (XfwmWindow * t, Bool rearrange)
 		       t->icon_y_loc + t->icon_p_height,
 		       t->icon_w_width, ICON_HEIGHT);
   MyXUngrabServer (dpy);
-  Broadcast (M_ICON_LOCATION, 7, t->w, t->frame,
+  Broadcast (XFCE_M_ICON_LOCATION, 7, t->w, t->frame,
 	     (unsigned long) t,
 	     t->icon_x_loc, t->icon_y_loc,
 	     t->icon_w_width, t->icon_w_height + t->icon_p_height);
@@ -587,12 +605,10 @@ AutoPlace (XfwmWindow * t, Bool rearrange)
 void
 GrabIconButtons (XfwmWindow * tmp_win, Window w)
 {
-  XGrabButton (dpy, AnyButton, 0, w, True,
-               ButtonPressMask, GrabModeSync, GrabModeAsync, None,
-               None);
-  XGrabButton (dpy, AnyButton, AnyModifier, w, True,
-               ButtonPressMask, GrabModeSync, GrabModeAsync, None,
-               None);
+  MyXGrabButton (dpy, AnyButton, 0, w, True,
+		 ButtonPressMask, GrabModeSync, GrabModeAsync, None, None);
+  MyXGrabButton (dpy, AnyButton, AnyModifier, w, True,
+		 ButtonPressMask, GrabModeSync, GrabModeAsync, None, None);
   return;
 }
 
@@ -612,8 +628,8 @@ GrabIconKeys (XfwmWindow * tmp_win, Window w)
   for (tmp = Scr.AllBindings; tmp != NULL; tmp = tmp->NextBinding)
     {
       if ((tmp->Context & C_ICON) && (tmp->IsMouse == 0))
-	XGrabKey (dpy, tmp->Button_Key, tmp->Modifier, w, True,
-		  GrabModeAsync, GrabModeAsync);
+	MyXGrabKey (dpy, tmp->Button_Key, tmp->Modifier, w, True,
+		    GrabModeAsync, GrabModeAsync);
     }
   return;
 }
@@ -623,18 +639,19 @@ GrabIconKeys (XfwmWindow * tmp_win, Window w)
  * Looks for a monochrome icon bitmap file
  *
  ****************************************************************************/
-void GetBitmapFile(XfwmWindow * tmp_win)
+void
+GetBitmapFile (XfwmWindow * tmp_win)
 {
-  int HotX,HotY;
+  int HotX, HotY;
   int res;
-  
+
   res = 0;
   if (check_existfile (tmp_win->icon_bitmap_file))
-     res = (XReadBitmapFile (dpy, Scr.Root,tmp_win->icon_bitmap_file,
-		      (unsigned int *)&tmp_win->icon_p_width, 
-		      (unsigned int *)&tmp_win->icon_p_height, 
-		      &tmp_win->iconPixmap,
-		      &HotX, &HotY) != BitmapSuccess);
+    res = (XReadBitmapFile (dpy, Scr.Root, tmp_win->icon_bitmap_file,
+			    (unsigned int *) &tmp_win->icon_p_width,
+			    (unsigned int *) &tmp_win->icon_p_height,
+			    &tmp_win->iconPixmap,
+			    &HotX, &HotY) != BitmapSuccess);
 
   if (!res)
     {
@@ -651,59 +668,58 @@ void GetBitmapFile(XfwmWindow * tmp_win)
 void
 GetXPMFile (XfwmWindow * tmp_win)
 {
-  int res;  
+  int res;
 #ifdef HAVE_IMLIB
-  ImlibImage         *im;
+  ImlibImage *im;
 
   res = 0;
-  im=Imlib_load_image(imlib_id, tmp_win->icon_bitmap_file);
+  im = Imlib_load_image (imlib_id, tmp_win->icon_bitmap_file);
   if (!im)
     {
-      im = Imlib_create_image_from_xpm_data(imlib_id, default_icon);
+      im = Imlib_create_image_from_xpm_data (imlib_id, default_icon);
     }
   if (im)
     {
-      
+
       if ((im->rgb_width > 48) || (im->rgb_height > 48))
-        {
-          res = Imlib_render(imlib_id, im, 48, 48);
-          tmp_win->icon_p_width = tmp_win->icon_p_height = 48;
+	{
+	  res = Imlib_render (imlib_id, im, 48, 48);
+	  tmp_win->icon_p_width = tmp_win->icon_p_height = 48;
 	}
       else
-        {
-          res = Imlib_render(imlib_id, im,im->rgb_width,im->rgb_height);
-          tmp_win->icon_p_width = im->rgb_width;
-          tmp_win->icon_p_height = im->rgb_height;
+	{
+	  res = Imlib_render (imlib_id, im, im->rgb_width, im->rgb_height);
+	  tmp_win->icon_p_width = im->rgb_width;
+	  tmp_win->icon_p_height = im->rgb_height;
 	}
 
-      tmp_win->iconPixmap      = Imlib_move_image(imlib_id, im);
-      tmp_win->icon_maskPixmap = Imlib_move_mask(imlib_id, im);
-      Imlib_kill_image(imlib_id, im);
+      tmp_win->iconPixmap = Imlib_move_image (imlib_id, im);
+      tmp_win->icon_maskPixmap = Imlib_move_mask (imlib_id, im);
+      Imlib_kill_image (imlib_id, im);
     }
 #else
   XWindowAttributes root_attr;
   XpmAttributes xpm_attributes;
-  static XpmColorSymbol none_color =
-  {NULL, "None", (Pixel) 0};
+  static XpmColorSymbol none_color = { NULL, "None", (Pixel) 0 };
 
   XGetWindowAttributes (dpy, Scr.Root, &root_attr);
   xpm_attributes.colormap = root_attr.colormap;
   xpm_attributes.closeness = 40000;	/* Allow for "similar" colors */
-  xpm_attributes.valuemask = XpmSize | XpmReturnPixels | XpmColormap | XpmCloseness;
+  xpm_attributes.valuemask = XpmSize | XpmColormap | XpmCloseness;
   xpm_attributes.colorsymbols = &none_color;
   xpm_attributes.numsymbols = 1;
 
   res = 0;
   if (check_existfile (tmp_win->icon_bitmap_file))
     res = (XpmReadFileToPixmap (dpy, Scr.Root, tmp_win->icon_bitmap_file,
-			       &tmp_win->iconPixmap,
-			       &tmp_win->icon_maskPixmap,
-			       &xpm_attributes) == XpmSuccess);
-  if (!res) 
+				&tmp_win->iconPixmap,
+				&tmp_win->icon_maskPixmap,
+				&xpm_attributes) == XpmSuccess);
+  if (!res)
     res = (XpmCreatePixmapFromData (dpy, Scr.Root, default_icon,
-			       &tmp_win->iconPixmap,
-			       &tmp_win->icon_maskPixmap,
-			       &xpm_attributes) == XpmSuccess);
+				    &tmp_win->iconPixmap,
+				    &tmp_win->icon_maskPixmap,
+				    &xpm_attributes) == XpmSuccess);
 
   if (res)
     {
@@ -773,7 +789,8 @@ GetIconBitmap (XfwmWindow * tmp_win)
    * routine */
   XGetGeometry (dpy, tmp_win->wmhints->icon_pixmap, &JunkRoot, &JunkX, &JunkY,
 		(unsigned int *) &tmp_win->icon_p_width,
-	     (unsigned int *) &tmp_win->icon_p_height, &JunkBW, &JunkDepth);
+		(unsigned int *) &tmp_win->icon_p_height, &JunkBW,
+		&JunkDepth);
   tmp_win->iconPixmap = tmp_win->wmhints->icon_pixmap;
   tmp_win->iconDepth = JunkDepth;
   if (ShapesSupported)
@@ -823,14 +840,15 @@ DeIconify (XfwmWindow * tmp_win)
 	    SetBorder (t, False, True, True, None);
 
 	  if (!(t->flags & SHADED))
-	    XMapWindow (dpy, t->w);
+	    {
+	      XMapWindow (dpy, t->w);
+	      XMapWindow (dpy, t->Parent);
+	    }
 	  if (t->Desk == Scr.CurrentDesk)
 	    {
 	      XMapWindow (dpy, t->frame);
 	      t->flags |= MAP_PENDING;
 	    }
-	  if (!(t->flags & SHADED))
-            XMapWindow (dpy, t->w);
 	  SetMapStateProp (t, NormalState);
 	  t->flags &= ~ICONIFIED;
 	  t->flags &= ~ICON_UNMAPPED;
@@ -841,7 +859,8 @@ DeIconify (XfwmWindow * tmp_win)
 	    XUnmapWindow (dpy, t->icon_w);
 	  if (t->icon_pixmap_w)
 	    XUnmapWindow (dpy, t->icon_pixmap_w);
-	  Broadcast (M_DEICONIFY, 3, t->w, t->frame, (unsigned long) t, 0, 0, 0, 0);
+	  Broadcast (XFCE_M_DEICONIFY, 3, t->w, t->frame, (unsigned long) t,
+		     0, 0, 0, 0);
 	}
     }
 
@@ -872,7 +891,8 @@ Iconify (XfwmWindow * tmp_win, int def_x, int def_y)
 
   XGetWindowAttributes (dpy, tmp_win->w, &winattrs);
   eventMask = winattrs.your_event_mask;
-  if ((tmp_win->Desk == Scr.CurrentDesk) && (tmp_win) && (tmp_win == Scr.Hilite))
+  if ((tmp_win->Desk == Scr.CurrentDesk) && (tmp_win)
+      && (tmp_win == Scr.Hilite))
     {
       if (tmp_win->next)
 	SetFocus (tmp_win->next->w, tmp_win->next, 1);
@@ -908,12 +928,12 @@ Iconify (XfwmWindow * tmp_win, int def_x, int def_y)
 	    {
 	      t->flags |= ICONIFIED | ICON_UNMAPPED;
 
-	      Broadcast (M_ICONIFY, 7, t->w, t->frame,
+	      Broadcast (XFCE_M_ICONIFY, 7, t->w, t->frame,
 			 (unsigned long) t,
 			 -10000, -10000,
 			 t->icon_w_width,
 			 t->icon_w_height + t->icon_p_height);
-	      BroadcastConfig (M_CONFIGURE_WINDOW, t);
+	      BroadcastConfig (XFCE_M_CONFIGURE_WINDOW, t);
 	    }
 	}
     }
@@ -921,9 +941,9 @@ Iconify (XfwmWindow * tmp_win, int def_x, int def_y)
   if (tmp_win->icon_w == None)
     {
       if (tmp_win->flags & ICON_MOVED)
-        CreateIconWindow (tmp_win, tmp_win->icon_x_loc, tmp_win->icon_y_loc);
+	CreateIconWindow (tmp_win, tmp_win->icon_x_loc, tmp_win->icon_y_loc);
       else
-        CreateIconWindow (tmp_win, def_x, def_y);
+	CreateIconWindow (tmp_win, def_x, def_y);
     }
   tmp_win->icon_arranged = False;
   /* if no pixmap we want icon width to change to text width every iconify */
@@ -931,65 +951,65 @@ Iconify (XfwmWindow * tmp_win, int def_x, int def_y)
     {
       XFontSet fontset = Scr.IconFont.fontset;
       if (fontset)
-        {
-          XRectangle rect1, rect2;
-          XmbTextExtents (fontset, tmp_win->icon_name, strlen (tmp_win->icon_name), &rect1, &rect2);
-          tmp_win->icon_t_width = rect2.width;
-        }
+	{
+	  XRectangle rect1, rect2;
+	  XmbTextExtents (fontset, tmp_win->icon_name,
+			  strlen (tmp_win->icon_name), &rect1, &rect2);
+	  tmp_win->icon_t_width = rect2.width;
+	}
       else
-        tmp_win->icon_t_width =
+	tmp_win->icon_t_width =
 	  XTextWidth (Scr.IconFont.font, tmp_win->icon_name,
-		    strlen (tmp_win->icon_name));
+		      strlen (tmp_win->icon_name));
       tmp_win->icon_p_width = tmp_win->icon_t_width + 6;
       tmp_win->icon_w_width = tmp_win->icon_p_width;
     }
 
-  if ((!(tmp_win->flags & STARTICONIC)) && 
+  if ((!(tmp_win->flags & STARTICONIC)) &&
       (!(tmp_win->flags & ICON_MOVED) || !CheckIconPlace (tmp_win)))
     AutoPlace (tmp_win, False);
   tmp_win->flags |= ICONIFIED;
   tmp_win->flags &= ~ICON_UNMAPPED;
-  Broadcast (M_ICONIFY, 7, tmp_win->w, tmp_win->frame,
+  Broadcast (XFCE_M_ICONIFY, 7, tmp_win->w, tmp_win->frame,
 	     (unsigned long) tmp_win,
 	     tmp_win->icon_x_loc, tmp_win->icon_y_loc,
 	     tmp_win->icon_w_width,
 	     tmp_win->icon_w_height + tmp_win->icon_p_height);
-  BroadcastConfig (M_CONFIGURE_WINDOW, tmp_win);
+  BroadcastConfig (XFCE_M_CONFIGURE_WINDOW, tmp_win);
 
 
   if (tmp_win->Desk == Scr.CurrentDesk)
     {
       LowerWindow (tmp_win);
       if (!(tmp_win->flags & STARTICONIC))
-        Animate (tmp_win->frame_x,
-	     tmp_win->frame_y,
-	     tmp_win->frame_width,
-	     tmp_win->flags & SHADED ?
-	     tmp_win->title_height + 2 * tmp_win->boundary_width :
-	     tmp_win->frame_height,
-	     tmp_win->icon_x_loc,
-	     tmp_win->icon_y_loc,
-	     tmp_win->icon_w_width,
-	     tmp_win->icon_w_height);
+	Animate (tmp_win->frame_x,
+		 tmp_win->frame_y,
+		 tmp_win->frame_width,
+		 tmp_win->flags & SHADED ?
+		 tmp_win->title_height + 2 * tmp_win->boundary_width :
+		 tmp_win->frame_height,
+		 tmp_win->icon_x_loc,
+		 tmp_win->icon_y_loc,
+		 tmp_win->icon_w_width, tmp_win->icon_w_height);
 
       if (tmp_win->icon_w != None)
 	XMapWindow (dpy, tmp_win->icon_w);
 
       if (tmp_win->icon_pixmap_w != None);
-	XMapWindow (dpy, tmp_win->icon_pixmap_w);
+      XMapWindow (dpy, tmp_win->icon_pixmap_w);
       KeepOnTop ();
 
       if ((tmp_win->Desk == Scr.CurrentDesk) && (tmp_win == Scr.Focus))
-        {
-          if (Scr.PreviousFocus == Scr.Focus)
+	{
+	  if (Scr.PreviousFocus == Scr.Focus)
 	    Scr.PreviousFocus = NULL;
-          if (tmp_win->next)
+	  if (tmp_win->next)
 	    SetFocus (tmp_win->next->w, tmp_win->next, 1);
-          else if (tmp_win->prev)
+	  else if (tmp_win->prev)
 	    SetFocus (tmp_win->prev->w, tmp_win->prev, 1);
-          else
+	  else
 	    SetFocus (Scr.NoFocusWin, NULL, 1);
-        }
+	}
     }
 
   return;
