@@ -31,6 +31,10 @@
 #include "parse.h"
 #include "screen.h"
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 int menu_on = 0;
 
 MenuRoot *ActiveMenu = NULL;	/* the active menu */
@@ -89,12 +93,13 @@ do_menu (MenuRoot * menu, int style)
       PrevActiveMenu = ActiveMenu;
       PrevActiveItem = ActiveItem;
       if (ActiveMenu)
-      {
-        if ((Stashed_X + (ActiveMenu->width >> 1) + menu->width) < Scr.MyDisplayWidth)
-           x = Stashed_X + (ActiveMenu->width >> 1) + (menu->width >> 1);
-        else
-           x = Stashed_X - (ActiveMenu->width >> 1) - (menu->width >> 1);
-      }
+	{
+	  if ((Stashed_X + (ActiveMenu->width >> 1) + menu->width) <
+	      Scr.MyDisplayWidth)
+	    x = Stashed_X + (ActiveMenu->width >> 1) + (menu->width >> 1);
+	  else
+	    x = Stashed_X - (ActiveMenu->width >> 1) - (menu->width >> 1);
+	}
       if (ActiveItem)
 	y = ActiveItem->y_offset + MenuY + (Scr.EntryHeight >> 1);
     }
@@ -105,13 +110,14 @@ do_menu (MenuRoot * menu, int style)
       if (!GrabEm (MENU))
 	{
 	  XBell (dpy, Scr.screen);
+          xfwm_msg (WARN, "do_menu", "Can't grab mouse/kbd\n");
 	  return MENU_DONE;
 	}
-        if ((x + menu->width + 5) < Scr.MyDisplayWidth)
-	   x += ((menu->width >> 1) + 5);
-        else
-           x -= ((menu->width >> 1) + 5);
-     }
+      if ((x + menu->width + 5) < Scr.MyDisplayWidth)
+	x += ((menu->width >> 1) + 5);
+      else
+	x -= ((menu->width >> 1) + 5);
+    }
   if (PopUpMenu (menu, x, y))
     {
       retval = UpdateMenu (style);
@@ -145,7 +151,8 @@ do_menu (MenuRoot * menu, int style)
  *
  ***********************************************************************/
 void
-RelieveRectangle (Window win, int x, int y, int w, int h, GC Hilite, GC Shadow)
+RelieveRectangle (Window win, int x, int y, int w, int h, GC Hilite,
+		  GC Shadow)
 {
   XDrawLine (dpy, win, Hilite, x, y, w + x - 1, y);
   XDrawLine (dpy, win, Hilite, x, y, x, h + y - 1);
@@ -164,12 +171,14 @@ RelieveRectangle (Window win, int x, int y, int w, int h, GC Hilite, GC Shadow)
 
 void
 RelieveHalfRectangle (Window win, int x, int y, int w, int h,
-		         GC Hilite, GC Shadow, int Top)
+		      GC Hilite, GC Shadow, int Top)
 {
-  XDrawLine (dpy, win, Hilite, x, y, x, h + y);
+  XDrawLine (dpy, win, Scr.BlackGC, x, y, x, h + y);
+  XDrawLine (dpy, win, Hilite, x + 1, y, x + 1, h + y);
 
+  XDrawLine (dpy, win, Shadow, w + x - 2, y + (Top ? 1 : 0), w + x - 2,
+	     h + y);
   XDrawLine (dpy, win, Scr.BlackGC, w + x - 1, y - 1, w + x - 1, h + y);
-  XDrawLine (dpy, win, Shadow, w + x - 2, y + (Top ? 1 : 0), w + x - 2, h + y);
 }
 
 /***********************************************************************
@@ -219,15 +228,17 @@ PaintEntry (MenuRoot * mr, MenuItem * mi)
 		      ShadowGC, ReliefGC);
 
   RelieveHalfRectangle (mr->w, 0, y_offset - 1, mr->width,
-    			y_height + 2, ReliefGC, ShadowGC, (mi == mr->first));
+			y_height + 2, ReliefGC, ShadowGC, (mi == mr->first));
+
 
   text_y += HEIGHT_EXTRA >> 1;
   if (mi->func_type == F_TITLE)
     {
       if (mi->next != NULL)
 	{
-	  DrawSeparator (mr->w, ShadowGC, ReliefGC, 5, y_offset + y_height - 3,
-			 mr->width - 6, y_offset + y_height - 3, 1);
+	  DrawSeparator (mr->w, ShadowGC, ReliefGC, 5,
+			 y_offset + y_height - 3, mr->width - 6,
+			 y_offset + y_height - 3, 1);
 	}
       if (mi != mr->first)
 	{
@@ -236,13 +247,18 @@ PaintEntry (MenuRoot * mr, MenuItem * mi)
 			 mr->width - 6, y_offset + 1, 1);
 	}
     }
+
   if (mi->func_type == F_NOP && *mi->item == 0)
     {
-      DrawSeparator (mr->w, ShadowGC, ReliefGC, 2, y_offset - 1 + HEIGHT_SEPARATOR / 2,
-		     mr->width - 3, y_offset - 1 + HEIGHT_SEPARATOR / 2, 0);
+      DrawSeparator (mr->w, ShadowGC, ReliefGC, 2,
+		     y_offset - 1 + HEIGHT_SEPARATOR / 2, mr->width - 3,
+		     y_offset - 1 + HEIGHT_SEPARATOR / 2, 0);
     }
   if (mi == mr->first)
-      XDrawLine (dpy, mr->w, ReliefGC, 0, 0, mr->width - 2, 0);
+    {
+      XDrawLine (dpy, mr->w, Scr.BlackGC, 0, 0, mr->width - 2, 0);
+      XDrawLine (dpy, mr->w, ReliefGC, 1, 1, mr->width - 3, 1);
+    }
 
   if (mi->next == NULL)
     DrawSeparator (mr->w, ShadowGC, Scr.BlackGC, 2, mr->height - 2,
@@ -251,26 +267,32 @@ PaintEntry (MenuRoot * mr, MenuItem * mi)
   if (fontset)
     {
       if (*mi->item)
-        XmbDrawString (dpy, mr->w, fontset, currentGC, mi->x, text_y, mi->item, mi->strlen);
+	XmbDrawString (dpy, mr->w, fontset, currentGC, mi->x, text_y,
+		       mi->item, mi->strlen);
       if (mi->strlen2 > 0)
-        XmbDrawString (dpy, mr->w, fontset, currentGC, mi->x2, text_y, mi->item2, mi->strlen2);
+	XmbDrawString (dpy, mr->w, fontset, currentGC, mi->x2, text_y,
+		       mi->item2, mi->strlen2);
     }
   else
     {
       if (*mi->item)
-        XDrawString (dpy, mr->w, currentGC, mi->x, text_y, mi->item, mi->strlen);
+	XDrawString (dpy, mr->w, currentGC, mi->x, text_y, mi->item,
+		     mi->strlen);
       if (mi->strlen2 > 0)
-        XDrawString (dpy, mr->w, currentGC, mi->x2, text_y, mi->item2, mi->strlen2);
+	XDrawString (dpy, mr->w, currentGC, mi->x2, text_y, mi->item2,
+		     mi->strlen2);
     }
   if (mi->hotkey > 0)
     DrawUnderline (mr->w, currentGC, mi->x, text_y, mi->item, mi->hotkey - 1);
   if (mi->hotkey < 0)
-    DrawUnderline (mr->w, currentGC, mi->x2, text_y, mi->item2, -1 - mi->hotkey);
+    DrawUnderline (mr->w, currentGC, mi->x2, text_y, mi->item2,
+		   -1 - mi->hotkey);
 
   d = (Scr.EntryHeight - 7) / 2;
   if (mi->func_type == F_POPUP)
     DrawTrianglePattern (mr->w, currentGC, mr->width - d - 8,
-		     y_offset + d - 1, mr->width - d - 1, y_offset + d + 7);
+			 y_offset + d - 1, mr->width - d - 1,
+			 y_offset + d + 7);
   return;
 }
 
@@ -307,17 +329,19 @@ DrawUnderline (Window w, GC gc, int x, int y, char *txt, int posn)
 
   XDrawLine (dpy, w, gc, x + off1, y + 2, x + off2, y + 2);
 }
+
 /****************************************************************************
  *
  *  Draws two horizontal lines to form a separator
  *
  ****************************************************************************/
 void
-DrawSeparator (Window w, GC TopGC, GC BottomGC, int x1, int y1, int x2, int y2,
-	       int extra_off)
+DrawSeparator (Window w, GC TopGC, GC BottomGC, int x1, int y1, int x2,
+	       int y2, int extra_off)
 {
   XDrawLine (dpy, w, TopGC, x1, y1, x2, y2);
-  XDrawLine (dpy, w, BottomGC, x1 - extra_off, y1 + 1, x2 + extra_off, y2 + 1);
+  XDrawLine (dpy, w, BottomGC, x1 - extra_off, y1 + 1, x2 + extra_off,
+	     y2 + 1);
 }
 
 /****************************************************************************
@@ -325,7 +349,7 @@ DrawSeparator (Window w, GC TopGC, GC BottomGC, int x1, int y1, int x2, int y2,
  *  Draws a little Triangle pattern within a window
  *
  ****************************************************************************/
-void 
+void
 DrawTrianglePattern (Window w, GC gc, int l, int t, int r, int b)
 {
   int m;
@@ -440,7 +464,8 @@ FindEntry (void)
 	}
     }
   /* end a sub-menu */
-  if (XFindContext (dpy, Child, MenuContext, (caddr_t *) & actual_mr) == XCNOENT)
+  if (XFindContext (dpy, Child, MenuContext, (caddr_t *) & actual_mr) ==
+      XCNOENT)
     {
       return retval;
     }
@@ -455,9 +480,10 @@ FindEntry (void)
 	      return SUBMENU_DONE;
 	    }
 	}
-      else {
-	return SUBMENU_DONE;
-      }
+      else
+	{
+	  return SUBMENU_DONE;
+	}
     }
   return retval;
 }
@@ -480,7 +506,7 @@ menuShortcuts (XEvent * ev)
   KeySym keysym = XLookupKeysym (&ev->xkey, 0);
 
   /* Try to match hot keys */
-  if (((keysym >= XK_a) && (keysym <= XK_z)) ||		/* Only consider alphabetic */
+  if (((keysym >= XK_a) && (keysym <= XK_z)) ||	/* Only consider alphabetic */
       ((keysym >= XK_0) && (keysym <= XK_9)))	/* ...or numeric keys   */
     {
       /* Search menu for matching hotkey */
@@ -499,7 +525,7 @@ menuShortcuts (XEvent * ev)
 	  if (keysym == key)
 	    {			/* Are they equal?              */
 	      ActiveItem = mi;	/* Yes: Make this the active item */
-	      ev->type = ButtonRelease;		/* Force a menu exit            */
+	      ev->type = ButtonRelease;	/* Force a menu exit            */
 	      return;
 	    }
 	}
@@ -557,14 +583,15 @@ UpdateMenu (int sticks)
     {
       /* block until there is an event */
       XMaskEvent (dpy, ButtonPressMask | ButtonReleaseMask | ExposureMask |
-	    KeyPressMask | VisibilityChangeMask | ButtonMotionMask, &Event);
+		  KeyPressMask | VisibilityChangeMask | ButtonMotionMask,
+		  &Event);
       StashEventTime (&Event);
       done = 0;
       if (Event.type == MotionNotify)
 	{
 	  /* discard any extra motion events before a release */
 	  while ((XCheckMaskEvent (dpy, ButtonMotionMask | ButtonReleaseMask,
-				 &Event)) && (Event.type != ButtonRelease));
+				   &Event)) && (Event.type != ButtonRelease));
 	}
       /* Handle a limited number of key press events to allow mouseless
        * operation */
@@ -586,11 +613,11 @@ UpdateMenu (int sticks)
 	      XQueryPointer (dpy, Scr.Root, &JunkRoot, &JunkChild,
 			     &JunkX, &JunkY, &x, &y, &JunkMask);
 	      if ((XFindContext (dpy, JunkChild, MenuContext,
-				 (caddr_t *) & actual_mr) != XCNOENT) && 
-		  (actual_mr != ActiveMenu)) 
+				 (caddr_t *) & actual_mr) != XCNOENT) &&
+		  (actual_mr != ActiveMenu))
 		{
-		   done = 1;
-		   break; 
+		  done = 1;
+		  break;
 		}
 	    }
 	  PopDownMenu ();
@@ -691,15 +718,21 @@ PopUpMenu (MenuRoot * menu, int x, int y)
 
   if ((Tmp_win) && (menu_on == 1) && (Context & C_LALL))
     {
-      y = Tmp_win->frame_y + Tmp_win->boundary_width + Tmp_win->title_height + 1;
+      y =
+	Tmp_win->frame_y + Tmp_win->boundary_width + Tmp_win->title_height +
+	1;
     }
   if ((Tmp_win) && (menu_on == 1) && (Context & C_RALL))
     {
-      y = Tmp_win->frame_y + Tmp_win->boundary_width + Tmp_win->title_height + 1;
+      y =
+	Tmp_win->frame_y + Tmp_win->boundary_width + Tmp_win->title_height +
+	1;
     }
   if ((Tmp_win) && (menu_on == 1) && (Context & C_TITLE))
     {
-      y = Tmp_win->frame_y + Tmp_win->boundary_width + Tmp_win->title_height + 1;
+      y =
+	Tmp_win->frame_y + Tmp_win->boundary_width + Tmp_win->title_height +
+	1;
     }
 
   /* clip to screen */
@@ -780,13 +813,14 @@ WaitForButtonsUp ()
 		     &JunkX, &JunkY, &JunkX, &JunkY, &mask);
 
       if ((mask &
-	   (Button1Mask | Button2Mask | Button3Mask | Button4Mask | Button5Mask)) == 0)
+	   (Button1Mask | Button2Mask | Button3Mask | Button4Mask |
+	    Button5Mask)) == 0)
 	AllUp = True;
     }
   XSync (dpy, 0);
   while (XCheckMaskEvent (dpy,
-		     ButtonPressMask | ButtonReleaseMask | ButtonMotionMask,
-			  &JunkEvent))
+			  ButtonPressMask | ButtonReleaseMask |
+			  ButtonMotionMask, &JunkEvent))
     {
       StashEventTime (&JunkEvent);
       XAllowEvents (dpy, ReplayPointer, CurrentTime);
@@ -820,7 +854,8 @@ DestroyMenu (MenuRoot * mr)
 
   XDestroyWindow (dpy, mr->w);
   XDeleteContext (dpy, mr->w, MenuContext);
-  if (mr->name) free (mr->name);
+  if (mr->name)
+    free (mr->name);
 
   /* need to free the window list ? */
   mi = mr->first;
@@ -880,13 +915,13 @@ MakeMenu (MenuRoot * mr)
     {
       XFontSet fontset = Scr.StdFont.fontset;
       if (fontset)
-        {
-          XRectangle rect1, rect2;
-          XmbTextExtents (fontset, cur->item, cur->strlen, &rect1, &rect2);
-          width = rect2.width;
-        }
+	{
+	  XRectangle rect1, rect2;
+	  XmbTextExtents (fontset, cur->item, cur->strlen, &rect1, &rect2);
+	  width = rect2.width;
+	}
       else
-        width = XTextWidth (Scr.StdFont.font, cur->item, cur->strlen);
+	width = XTextWidth (Scr.StdFont.font, cur->item, cur->strlen);
       if (cur->func_type == F_POPUP)
 	width += 15;
       if (width <= 0)
@@ -895,13 +930,13 @@ MakeMenu (MenuRoot * mr)
 	mr->width = width;
 
       if (fontset)
-        {
-          XRectangle rect1, rect2;
-          XmbTextExtents (fontset, cur->item2, cur->strlen2, &rect1, &rect2);
-          width = rect2.width;
-        }
+	{
+	  XRectangle rect1, rect2;
+	  XmbTextExtents (fontset, cur->item2, cur->strlen2, &rect1, &rect2);
+	  width = rect2.width;
+	}
       else
-        width = XTextWidth (Scr.StdFont.font, cur->item2, cur->strlen2);
+	width = XTextWidth (Scr.StdFont.font, cur->item2, cur->strlen2);
       if (width < 0)
 	width = 0;
       if (width > mr->width2)
@@ -924,19 +959,20 @@ MakeMenu (MenuRoot * mr)
 	{
 	  /* Title */
 	  if (cur->strlen2 == 0)
-            {
-              XFontSet fontset = Scr.StdFont.fontset;
-              int width;
-              if (fontset)
-                {
-                  XRectangle rect1, rect2;
-                  XmbTextExtents (fontset, cur->item, cur->strlen, &rect1, &rect2);
-                  width = rect2.width;
-                }
-              else
-                width = XTextWidth (Scr.StdFont.font, cur->item, cur->strlen);
+	    {
+	      XFontSet fontset = Scr.StdFont.fontset;
+	      int width;
+	      if (fontset)
+		{
+		  XRectangle rect1, rect2;
+		  XmbTextExtents (fontset, cur->item, cur->strlen, &rect1,
+				  &rect2);
+		  width = rect2.width;
+		}
+	      else
+		width = XTextWidth (Scr.StdFont.font, cur->item, cur->strlen);
 	      cur->x = (mr->width + mr->width2 - width) >> 1;
-            }
+	    }
 	  if ((cur->strlen > 0) || (cur->strlen2 > 0))
 	    cur->y_height = Scr.EntryHeight + HEIGHT_EXTRA_TITLE;
 	  else
@@ -974,8 +1010,7 @@ MakeMenu (MenuRoot * mr)
   mr->w = XCreateWindow (dpy, Scr.Root, 0, 0, (unsigned int) (mr->width),
 			 (unsigned int) mr->height, (unsigned int) 0,
 			 CopyFromParent, (unsigned int) InputOutput,
-			 (Visual *) CopyFromParent,
-			 valuemask, &attributes);
+			 (Visual *) CopyFromParent, valuemask, &attributes);
   XSaveContext (dpy, mr->w, MenuContext, (caddr_t) mr);
 
   return;
