@@ -42,17 +42,21 @@
 #include <Imlib.h>
 #endif
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 char NoName[] = "Untitled";	/* name if no name in XA_WM_NAME */
 char NoClass[] = "NoClass";	/* Class if no res_class in class hints */
 char NoResource[] = "NoResource";	/* Class if no res_name in class hints */
 
-int 
-check_existfile(char *filename)
+int
+check_existfile (char *filename)
 {
   struct stat s;
   int status;
 
-  if ((!filename) || (!strlen(filename)))
+  if ((!filename) || (!strlen (filename)))
     return (0);
 
   status = stat (filename, &s);
@@ -69,42 +73,40 @@ check_existfile(char *filename)
 void
 free_window_names (XfwmWindow * tmp, Bool nukename, Bool nukeicon)
 {
+
   if (!tmp)
-    return;
+    {
+      xfwm_msg (WARN, "free_window_names", "Cannot unallocate");
+      return;
+    }
 
   if (nukename && nukeicon)
     {
-      if (tmp->name == tmp->icon_name)
+      if ((tmp->name != NoName) && (tmp->name != NULL))
 	{
-	  if (tmp->name != NoName && tmp->name != NULL)
-	    XFree (tmp->name);
-	  tmp->name = NULL;
-	  tmp->icon_name = NULL;
+	  free (tmp->name);
 	}
-      else
+      tmp->name = NULL;
+      if ((tmp->icon_name != NoName) && (tmp->icon_name != NULL))
 	{
-	  if (tmp->name != NoName && tmp->name != NULL)
-	    XFree (tmp->name);
-	  tmp->name = NULL;
-	  if (tmp->icon_name != NoName && tmp->icon_name != NULL)
-	    XFree (tmp->icon_name);
-	  tmp->icon_name = NULL;
+	  free (tmp->icon_name);
 	}
+      tmp->icon_name = NULL;
     }
   else if (nukename)
     {
-      if (tmp->name != tmp->icon_name
-	  && tmp->name != NoName
-	  && tmp->name != NULL)
-	XFree (tmp->name);
+      if ((tmp->name != NoName) && (tmp->name != NULL))
+	{
+	  free (tmp->name);
+	}
       tmp->name = NULL;
     }
   else
     {				/* if (nukeicon) */
-      if (tmp->icon_name != tmp->name
-	  && tmp->icon_name != NoName
-	  && tmp->icon_name != NULL)
-	XFree (tmp->icon_name);
+      if ((tmp->icon_name != NoName) && (tmp->icon_name != NULL))
+	{
+	  free (tmp->icon_name);
+	}
       tmp->icon_name = NULL;
     }
 
@@ -138,7 +140,7 @@ Destroy (XfwmWindow * Tmp_win)
   if (Tmp_win == Scr.Hilite)
     Scr.Hilite = NULL;
 
-  Broadcast (M_DESTROY_WINDOW, 3, Tmp_win->w, Tmp_win->frame,
+  Broadcast (XFCE_M_DESTROY_WINDOW, 3, Tmp_win->w, Tmp_win->frame,
 	     (unsigned long) Tmp_win, 0, 0, 0, 0);
 
   if (Scr.PreviousFocus == Tmp_win)
@@ -150,9 +152,9 @@ Destroy (XfwmWindow * Tmp_win)
   if (Tmp_win == Scr.Focus)
     {
       if (Tmp_win->next)
-	SetFocus(Tmp_win->next->w,Tmp_win->next, 1);
+	SetFocus (Tmp_win->next->w, Tmp_win->next, 1);
       else if (Tmp_win->prev)
-        SetFocus (Tmp_win->prev->w, Tmp_win->prev, 1);
+	SetFocus (Tmp_win->prev->w, Tmp_win->prev, 1);
       else
 	SetFocus (Scr.NoFocusWin, NULL, 1);
     }
@@ -165,12 +167,13 @@ Destroy (XfwmWindow * Tmp_win)
 
   XDestroyWindow (dpy, Tmp_win->frame);
   XDeleteContext (dpy, Tmp_win->frame, XfwmContext);
-
+  XDestroyWindow (dpy, Tmp_win->Parent);
+  XDeleteContext (dpy, Tmp_win->Parent, XfwmContext);
   XDeleteContext (dpy, Tmp_win->w, XfwmContext);
 
   if ((Tmp_win->icon_w) && (Tmp_win->flags & PIXMAP_OURS))
 #ifdef HAVE_IMLIB
-    Imlib_free_pixmap(imlib_id, Tmp_win->iconPixmap);
+    Imlib_free_pixmap (imlib_id, Tmp_win->iconPixmap);
 #else
     XFreePixmap (dpy, Tmp_win->iconPixmap);
 #endif
@@ -335,7 +338,7 @@ RestoreWithdrawnLocation (XfwmWindow * tmp, Bool restart)
  * Start/Stops the auto-raise timer
  *
  ****************************************************************************/
-void 
+void
 SetTimer (int delay)
 {
   struct itimerval value;
@@ -394,7 +397,8 @@ StashEventTime (XEvent * ev)
   /* Only update is the new timestamp is later than the old one, or
    * if the new one is from a time at least 30 seconds earlier than the
    * old one (in which case the system clock may have changed) */
-  if ((NewTimestamp > lastTimestamp) || ((lastTimestamp - NewTimestamp) > 30000))
+  if ((NewTimestamp > lastTimestamp)
+      || ((lastTimestamp - NewTimestamp) > 30000))
     lastTimestamp = NewTimestamp;
 
   return True;
@@ -402,7 +406,8 @@ StashEventTime (XEvent * ev)
 
 
 int
-GetTwoArguments (char *action, int *val1, int *val2, int *val1_unit, int *val2_unit)
+GetTwoArguments (char *action, int *val1, int *val2, int *val1_unit,
+		 int *val2_unit)
 {
   char c1, c2;
   int n;
@@ -458,6 +463,138 @@ GetOneArgument (char *action, long *val1, int *val1_unit)
   return 1;
 }
 
+/*
+ * A handy function to grab a button along with its modifier, ignoring other "fake"
+ * modifiers
+ */
+void
+MyXGrabButton (Display * dpi, unsigned int button, unsigned int modifiers,
+	       Window grab_window, Bool owner_events, unsigned int event_mask,
+	       int pointer_mode, int keyboard_mode, Window confine_to,
+	       Cursor cursor)
+{
+  if ((modifiers == AnyModifier) || (modifiers == 0))
+    {
+      XGrabButton (dpi, button, modifiers,
+		   grab_window, owner_events, event_mask,
+		   pointer_mode, keyboard_mode, confine_to, cursor);
+    }
+  else
+    {
+      XGrabButton (dpi, button, modifiers,
+		   grab_window, owner_events, event_mask,
+		   pointer_mode, keyboard_mode, confine_to, cursor);
+      XGrabButton (dpi, button, modifiers | ScrollLockMask,
+		   grab_window, owner_events, event_mask,
+		   pointer_mode, keyboard_mode, confine_to, cursor);
+      XGrabButton (dpi, button, modifiers | NumLockMask,
+		   grab_window, owner_events, event_mask,
+		   pointer_mode, keyboard_mode, confine_to, cursor);
+      XGrabButton (dpi, button, modifiers | CapsLockMask,
+		   grab_window, owner_events, event_mask,
+		   pointer_mode, keyboard_mode, confine_to, cursor);
+      XGrabButton (dpi, button, modifiers | ScrollLockMask | NumLockMask,
+		   grab_window, owner_events, event_mask,
+		   pointer_mode, keyboard_mode, confine_to, cursor);
+      XGrabButton (dpi, button, modifiers | ScrollLockMask | CapsLockMask,
+		   grab_window, owner_events, event_mask,
+		   pointer_mode, keyboard_mode, confine_to, cursor);
+      XGrabButton (dpi, button, modifiers | CapsLockMask | NumLockMask,
+		   grab_window, owner_events, event_mask,
+		   pointer_mode, keyboard_mode, confine_to, cursor);
+      XGrabButton (dpi, button,
+		   modifiers | ScrollLockMask | CapsLockMask | NumLockMask,
+		   grab_window, owner_events, event_mask, pointer_mode,
+		   keyboard_mode, confine_to, cursor);
+    }
+}
+
+void
+MyXUngrabButton (Display * dpi, unsigned int button,
+		 unsigned int modifiers, Window grab_window)
+{
+  if ((modifiers == AnyModifier) || (modifiers == 0))
+    {
+      XUngrabButton (dpi, button, modifiers, grab_window);
+    }
+  else
+    {
+      XUngrabButton (dpi, button, modifiers, grab_window);
+      XUngrabButton (dpi, button, modifiers | ScrollLockMask, grab_window);
+      XUngrabButton (dpi, button, modifiers | NumLockMask, grab_window);
+      XUngrabButton (dpi, button, modifiers | CapsLockMask, grab_window);
+      XUngrabButton (dpi, button, modifiers | ScrollLockMask | NumLockMask,
+		     grab_window);
+      XUngrabButton (dpi, button, modifiers | ScrollLockMask | CapsLockMask,
+		     grab_window);
+      XUngrabButton (dpi, button, modifiers | CapsLockMask | NumLockMask,
+		     grab_window);
+      XUngrabButton (dpi, button,
+		     modifiers | ScrollLockMask | CapsLockMask | NumLockMask,
+		     grab_window);
+    }
+}
+
+/*
+ * Idem for keys
+ */
+void
+MyXGrabKey (Display * dpi, int keycode, unsigned int modifiers,
+	    Window grab_window, Bool owner_events,
+	    int pointer_mode, int keyboard_mode)
+{
+  if ((modifiers == AnyModifier) || (modifiers == 0))
+    {
+      XGrabKey (dpi, keycode, modifiers,
+		grab_window, owner_events, pointer_mode, keyboard_mode);
+    }
+  else
+    {
+      XGrabKey (dpi, keycode, modifiers,
+		grab_window, owner_events, pointer_mode, keyboard_mode);
+      XGrabKey (dpi, keycode, modifiers | ScrollLockMask,
+		grab_window, owner_events, pointer_mode, keyboard_mode);
+      XGrabKey (dpi, keycode, modifiers | NumLockMask,
+		grab_window, owner_events, pointer_mode, keyboard_mode);
+      XGrabKey (dpi, keycode, modifiers | CapsLockMask,
+		grab_window, owner_events, pointer_mode, keyboard_mode);
+      XGrabKey (dpi, keycode, modifiers | ScrollLockMask | NumLockMask,
+		grab_window, owner_events, pointer_mode, keyboard_mode);
+      XGrabKey (dpi, keycode, modifiers | ScrollLockMask | CapsLockMask,
+		grab_window, owner_events, pointer_mode, keyboard_mode);
+      XGrabKey (dpi, keycode, modifiers | CapsLockMask | NumLockMask,
+		grab_window, owner_events, pointer_mode, keyboard_mode);
+      XGrabKey (dpi, keycode,
+		modifiers | ScrollLockMask | CapsLockMask | NumLockMask,
+		grab_window, owner_events, pointer_mode, keyboard_mode);
+    }
+}
+
+void
+MyXUngrabKey (Display * dpi, int keycode,
+	      unsigned int modifiers, Window grab_window)
+{
+  if ((modifiers == AnyModifier) || (modifiers == 0))
+    {
+      XUngrabKey (dpi, keycode, modifiers, grab_window);
+    }
+  else
+    {
+      XUngrabKey (dpi, keycode, modifiers, grab_window);
+      XUngrabKey (dpi, keycode, modifiers | ScrollLockMask, grab_window);
+      XUngrabKey (dpi, keycode, modifiers | NumLockMask, grab_window);
+      XUngrabKey (dpi, keycode, modifiers | CapsLockMask, grab_window);
+      XUngrabKey (dpi, keycode, modifiers | ScrollLockMask | NumLockMask,
+		  grab_window);
+      XUngrabKey (dpi, keycode, modifiers | ScrollLockMask | CapsLockMask,
+		  grab_window);
+      XUngrabKey (dpi, keycode, modifiers | CapsLockMask | NumLockMask,
+		  grab_window);
+      XUngrabKey (dpi, keycode,
+		  modifiers | ScrollLockMask | CapsLockMask | NumLockMask,
+		  grab_window);
+    }
+}
 
 /*****************************************************************************
  *
@@ -479,11 +616,14 @@ GrabEm (int cursor)
   if (Scr.PreviousFocus == NULL)
     Scr.PreviousFocus = Scr.Focus;
   SetFocus (Scr.NoFocusWin, NULL, 0);
-  mask = ButtonPressMask | ButtonReleaseMask | ButtonMotionMask | PointerMotionMask
+  mask =
+    ButtonPressMask | ButtonReleaseMask | ButtonMotionMask | PointerMotionMask
     | EnterWindowMask | LeaveWindowMask;
-  while ((i < 1000) && (val = XGrabPointer (dpy, Scr.Root, True, mask,
-				     GrabModeAsync, GrabModeAsync, Scr.Root,
-				     vs, CurrentTime) != GrabSuccess))
+  while ((i < 1000)
+	 && (val =
+	     XGrabPointer (dpy, Scr.Root, True, mask, GrabModeAsync,
+			   GrabModeAsync, Scr.Root, vs,
+			   CurrentTime) != GrabSuccess))
     {
       i++;
       /* If you go too fast, other windows may not get a change to release
@@ -547,7 +687,8 @@ KeepOnTop ()
   /* flag that on-top windows should be re-raised */
   for (t = Scr.XfwmRoot.next; t != NULL; t = t->next)
     {
-      if ((t->flags & ONTOP) && !(t->flags & VISIBLE) && !(t->flags & ICONIFIED))
+      if ((t->flags & ONTOP) && !(t->flags & VISIBLE)
+	  && !(t->flags & ICONIFIED))
 	{
 	  RaiseWindow (t);
 	  t->flags &= ~RAISED;
@@ -604,12 +745,12 @@ MapIt (XfwmWindow * t)
       if (t->icon_w != None)
 	XMapWindow (dpy, t->icon_w);
     }
-  else if (t->flags & (MAPPED | MAP_PENDING))
+  else if (t->flags & MAPPED)
     {
-      if (!(t->flags & SHADED))
-	XMapWindow (dpy, t->w);
       XMapWindow (dpy, t->frame);
       t->flags |= MAP_PENDING;
+      if (!(t->flags & SHADED))
+	XMapWindow (dpy, t->Parent);
     }
 }
 
@@ -620,22 +761,22 @@ RaiseWindow (XfwmWindow * t)
   int count, i;
   Window *wins;
 
-  MyXGrabServer (dpy);
   /* raise the target, at least */
   count = 1;
-  Broadcast (M_RAISE_WINDOW, 3, t->w, t->frame, (unsigned long) t, 0, 0, 0, 0);
+  Broadcast (XFCE_M_RAISE_WINDOW, 3, t->w, t->frame, (unsigned long) t, 0, 0,
+	     0, 0);
 
+  MyXGrabServer (dpy);
   for (t2 = Scr.XfwmRoot.next; t2 != NULL; t2 = t2->next)
     {
       t2->flags &= ~RAISEDWIN;
       if ((t2->flags & ONTOP) && !(t2->flags & ICONIFIED))
 	count++;
-      if ((t2->flags & TRANSIENT) && (t2->transientfor == t->w) &&
-	  (t2 != t))
+      if ((t2->flags & TRANSIENT) && (t2->transientfor == t->w) && (t2 != t))
 	{
 	  count++;
-	  Broadcast (M_RAISE_WINDOW, 3, t2->w, t2->frame, (unsigned long) t2,
-		     0, 0, 0, 0);
+	  Broadcast (XFCE_M_RAISE_WINDOW, 3, t2->w, t2->frame,
+		     (unsigned long) t2, 0, 0, 0, 0);
 
 	  if ((t2->flags & ICONIFIED) && (!(t2->flags & SUPPRESSICON)))
 	    {
@@ -657,8 +798,8 @@ RaiseWindow (XfwmWindow * t)
     {
       if ((t2->flags & ONTOP) && !(t2->flags & ICONIFIED))
 	{
-	  Broadcast (M_RAISE_WINDOW, 3, t2->w, t2->frame, (unsigned long) t2,
-		     0, 0, 0, 0);
+	  Broadcast (XFCE_M_RAISE_WINDOW, 3, t2->w, t2->frame,
+		     (unsigned long) t2, 0, 0, 0, 0);
 	  wins[i++] = t2->frame;
 	}
     }
@@ -667,9 +808,7 @@ RaiseWindow (XfwmWindow * t)
   for (t2 = Scr.XfwmRoot.next; t2 != NULL; t2 = t2->next)
     {
       if ((t2->flags & TRANSIENT) &&
-	  (t2->transientfor == t->w) &&
-	  (t2 != t) &&
-	  (!(t2->flags & ONTOP)))
+	  (t2->transientfor == t->w) && (t2 != t) && (!(t2->flags & ONTOP)))
 	{
 	  wins[i++] = t2->frame;
 	  if ((t2->flags & ICONIFIED) && (!(t2->flags & SUPPRESSICON)))
@@ -692,6 +831,7 @@ RaiseWindow (XfwmWindow * t)
   if (!(t->flags & ONTOP))
     {
       wins[i++] = t->frame;
+      Scr.LastWindowRaised = t;
     }
 
   if (i > 0)
@@ -701,8 +841,9 @@ RaiseWindow (XfwmWindow * t)
   free (wins);
 
   t->flags |= RAISEDWIN;
-  Scr.LastWindowRaised = t;
+  XSync (dpy, 0);
   MyXUngrabServer (dpy);
+
 }
 
 
@@ -711,7 +852,8 @@ LowerWindow (XfwmWindow * t)
 {
   XLowerWindow (dpy, t->frame);
 
-  Broadcast (M_LOWER_WINDOW, 3, t->w, t->frame, (unsigned long) t, 0, 0, 0, 0);
+  Broadcast (XFCE_M_LOWER_WINDOW, 3, t->w, t->frame, (unsigned long) t, 0, 0,
+	     0, 0);
 
   if ((t->flags & ICONIFIED) && (!(t->flags & SUPPRESSICON)))
     {
@@ -728,7 +870,7 @@ LowerWindow (XfwmWindow * t)
  * ** id -> name of function, or other identifier
  */
 void
-xfwm_msg (int type, char *id, char *msg,...)
+xfwm_msg (int type, char *id, char *msg, ...)
 {
   char *typestr;
   va_list args;
@@ -763,7 +905,7 @@ xfwm_msg (int type, char *id, char *msg,...)
       vsprintf (tmp + strlen (tmp), msg, args);
       tmp[strlen (tmp) + 1] = '\0';
       tmp[strlen (tmp)] = '\n';
-      BroadcastName (M_ERROR, 0, 0, 0, tmp);
+      BroadcastName (XFCE_M_ERROR, 0, 0, 0, tmp);
     }
 
   va_end (args);
