@@ -22,48 +22,49 @@
 #define my_abs(a)   ((a > 0) ? a : -a)
 
 typedef struct name_list_struct
-  {
-    struct name_list_struct *next;	/* pointer to the next name */
-    char *name;			/* the name of the window */
-    char *value;		/* icon name */
-    int Desk;			/* Desktop number */
-    unsigned long on_flags;
-    unsigned long off_flags;
-    int border_width;
-    int resize_width;
-    char *ForeColor;
-    char *BackColor;
-    unsigned long on_buttons;
-    unsigned long off_buttons;
+{
+  struct name_list_struct *next;	/* pointer to the next name */
+  char *name;			/* the name of the window */
+  char *value;			/* icon name */
+  int Desk;			/* Desktop number */
+  unsigned long on_flags;
+  unsigned long off_flags;
+  int border_width;
+  int resize_width;
+  char *ForeColor;
+  char *BackColor;
+  unsigned long on_buttons;
+  unsigned long off_buttons;
 
-  }
+}
 name_list;
 
 /* used for parsing configuration */
 struct config
-  {
-    char *keyword;
+{
+  char *keyword;
 #ifdef __STDC__
-    void (*action) (char *, FILE *, char **, int *);
+  void (*action) (char *, FILE *, char **, int *);
 #else
-    void (*action) ();
+  void (*action) ();
 #endif
-    char **arg;
-    int *arg2;
-  };
+  char **arg;
+  int *arg2;
+};
 
 /* used for parsing commands */
 struct functions
-  {
-    char *keyword;
+{
+  char *keyword;
 #ifdef __STDC__
-    void (*action) (XEvent *, Window, XfwmWindow *, unsigned long, char *, int *);
+  void (*action) (XEvent *, Window, XfwmWindow *, unsigned long, char *,
+		  int *);
 #else
-    void (*action) ();
+  void (*action) ();
 #endif
-    int code;
-    int type;
-  };
+  int code;
+  int type;
+};
 
 /* values for name_list flags */
 /* The first 13 items are mapped directly into the XfwmWindow structures
@@ -89,14 +90,11 @@ struct functions
 #define BW_FLAG              (1<<17)
 #define FORE_COLOR_FLAG      (1<<18)
 #define BACK_COLOR_FLAG      (1<<19)
-#define RANDOM_PLACE_FLAG    (1<<20)
-#define SMART_PLACE_FLAG     (1<<21)
-#define MWM_BUTTON_FLAG      (1<<22)
-#define MWM_DECOR_FLAG       (1<<23)
-#define MWM_FUNCTIONS_FLAG   (1<<24)
-#define MWM_OVERRIDE_FLAG    (1<<25)
-#define NO_PPOSITION_FLAG    (1<<26)
-#define OL_DECOR_FLAG        (1<<27)
+#define MWM_BUTTON_FLAG      (1<<20)
+#define MWM_DECOR_FLAG       (1<<21)
+#define MWM_FUNCTIONS_FLAG   (1<<22)
+#define MWM_OVERRIDE_FLAG    (1<<23)
+#define NO_PPOSITION_FLAG    (1<<24)
 
 /* some fancy font handling stuff */
 #define NewFontAndColor(newfont,color,backcolor) {\
@@ -124,7 +122,7 @@ extern unsigned long LookInList (name_list *, char *, XClassHint *,
 				 char **forecolor, char **backcolor,
 				 unsigned long *buttons);
 extern void MoveOutline (XfwmWindow *, int, int, int, int);
-extern void DisplayPosition(XfwmWindow *, int, int, int, int);
+extern void DisplayPosition (XfwmWindow *, int, int, int, int);
 extern void DoResize (int, int, XfwmWindow *);
 extern void SetupFrame (XfwmWindow *, int, int, int, int, Bool, Bool);
 extern void CreateGCs (void);
@@ -143,7 +141,6 @@ extern void HandleFocusIn (void);
 extern void HandleFocusOut (void);
 extern void HandleDestroyNotify (void);
 extern void HandleMapRequest (void);
-extern void HandleMapRequestKeepRaised (Window keepraised);
 extern void HandleMapNotify (void);
 extern void HandleUnmapNotify (void);
 extern void HandleMotionNotify (void);
@@ -167,14 +164,15 @@ extern int MappedNotOverride (Window w);
 extern void GrabButtons (XfwmWindow *);
 extern void GrabKeys (XfwmWindow *);
 extern void GetWindowSizeHints (XfwmWindow *);
-extern Bool moveLoop (XfwmWindow *, int, int, int, int, int *, int *, Bool, Bool);
+extern Bool moveLoop (XfwmWindow *, int, int, int, int, int *, int *, Bool,
+		      Bool);
 
 extern void Keyboard_shortcuts (XEvent *, int);
 extern void RedoIconName (XfwmWindow *);
 extern void DrawIconWindow (XfwmWindow *);
 extern void CreateIconWindow (XfwmWindow * tmp_win, int def_x, int def_y);
 extern void RelieveWindow (XfwmWindow *, Window,
-				  int, int, int, int, GC, GC, int);
+			   int, int, int, int, GC, GC, int);
 void RelieveParts (XfwmWindow * t, int i, GC hor, GC vert);
 #define NO_HILITE     0x0000
 #define TOP_HILITE    0x0001
@@ -186,13 +184,19 @@ void RelieveParts (XfwmWindow * t, int i, GC hor, GC vert);
 
 extern void sleep_a_little (int);
 extern void Maximize (XEvent * eventp, Window w, XfwmWindow * tmp_win,
-	       unsigned long context, char *action, int *Module);
-extern void Shade(XfwmWindow * tmp_win);
-extern void Unshade(XfwmWindow * tmp_win);
+		      unsigned long context, char *action, int *Module);
+extern void Shade (XfwmWindow * tmp_win);
+extern void Unshade (XfwmWindow * tmp_win);
 extern void shade_function (XEvent * eventp, Window w, XfwmWindow * tmp_win,
-	    unsigned long context, char *action, int *Module);
+			    unsigned long context, char *action, int *Module);
 extern void RaiseWindow (XfwmWindow * t);
 extern void LowerWindow (XfwmWindow * t);
+extern void MyXGrabButton (Display *, unsigned int, unsigned int,
+			   Window, Bool, unsigned int, int, int, Window,
+			   Cursor);
+extern void MyXUngrabButton (Display *, unsigned int, unsigned int, Window);
+extern void MyXGrabKey (Display *, int, unsigned int, Window, Bool, int, int);
+extern void MyXUngrabKey (Display *, int, unsigned int, Window);
 extern Bool GrabEm (int);
 extern void UngrabEm (void);
 extern MenuRoot *NewMenuRoot (char *name, int function_or_popup);
@@ -234,11 +238,11 @@ void Broadcast (unsigned long event_type, unsigned long num_datum,
 		unsigned long data5, unsigned long data6,
 		unsigned long data7);
 void BroadcastConfig (unsigned long event_type, XfwmWindow * t);
-void SendPacket (int channel, unsigned long event_type, unsigned long num_datum,
-		 unsigned long data1, unsigned long data2,
-		 unsigned long data3, unsigned long data4,
-		 unsigned long data5, unsigned long data6,
-		 unsigned long data7);
+void SendPacket (int channel, unsigned long event_type,
+		 unsigned long num_datum, unsigned long data1,
+		 unsigned long data2, unsigned long data3,
+		 unsigned long data4, unsigned long data5,
+		 unsigned long data6, unsigned long data7);
 void SendConfig (int Module, unsigned long event_type, XfwmWindow * t);
 void BroadcastName (unsigned long event_type, unsigned long data1,
 		    unsigned long data2, unsigned long data3, char *name);
@@ -254,7 +258,8 @@ void SelectDecor (XfwmWindow *, unsigned long, int);
 extern Bool PopUpMenu (MenuRoot *, int, int);
 void ComplexFunction (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 		      unsigned long context, char *action, int *Module);
-extern int DeferExecution (XEvent *, Window *, XfwmWindow **, unsigned long *, int, int);
+extern int DeferExecution (XEvent *, Window *, XfwmWindow **, unsigned long *,
+			   int, int);
 void my_sleep (int);
 void Animate (int, int, int, int, int, int, int, int);
 void SetBorder (XfwmWindow *, Bool, Bool, Bool, Window);
@@ -278,11 +283,13 @@ Bool PlaceWindow (XfwmWindow * tmp_win, unsigned long flags, int Desk);
 void free_window_names (XfwmWindow * tmp, Bool nukename, Bool nukeicon);
 
 int do_menu (MenuRoot * menu, int style);
-void RelieveRectangle (Window win, int x, int y, int w, int h, GC Hilite, GC Shadow);
-void RelieveHalfRectangle (Window win, int x, int y, int w, int h,GC Hilite, GC Shadow, int Top);
+void RelieveRectangle (Window win, int x, int y, int w, int h, GC Hilite,
+		       GC Shadow);
+void RelieveHalfRectangle (Window win, int x, int y, int w, int h, GC Hilite,
+			   GC Shadow, int Top);
 int check_allowed_function (MenuItem * mi);
 void ReInstallActiveColormap (void);
-unsigned int vmod(int m);
+unsigned int vmod (int m);
 void ParsePopupEntry (char *, FILE *, char **, int *);
 void ParseMouseEntry (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 		      unsigned long context, char *tline, int *Module);
@@ -310,6 +317,7 @@ void SetColormapFocus (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 void DrawPattern (Window, GC, GC, int, int, int);
 Pixel GetShadow (Pixel);
 Pixel GetHilite (Pixel);
+int brightness (Pixel);
 
 
 #define UP 1
@@ -318,7 +326,7 @@ void MapIt (XfwmWindow * t);
 void UnmapIt (XfwmWindow * t);
 void do_save (void);
 Bool StashEventTime (XEvent * ev);
-void sendclient_event(XfwmWindow *, int, int, int, int);
+void sendclient_event (XfwmWindow *, int, int, int, int);
 int My_XNextEvent (Display * dpy, XEvent * event);
 void FlushQueue (int Module);
 void QuickRestart (void);
@@ -326,8 +334,8 @@ void AddFuncKey (char *, int, int, int, char *, int, int, MenuRoot *,
 		 char, char);
 char *GetNextPtr (char *ptr);
 
-Bool InteractiveMove (Window * w, XfwmWindow * tmp_win, int *FinalX, int *FinalY,
-		      XEvent * eventp);
+Bool InteractiveMove (Window * w, XfwmWindow * tmp_win, int *FinalX,
+		      int *FinalY, XEvent * eventp);
 
 MenuRoot *FindPopup (char *action);
 
@@ -362,11 +370,12 @@ void stick_function (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 
 void changeDesks_func (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 		       unsigned long context, char *action, int *Module);
-void changeDesks (int, int, Bool, Bool);
+void changeDesks (int, int, Bool, Bool, Bool);
 void changeWindowsDesk (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 			unsigned long context, char *action, int *Module);
 
-int GetTwoArguments (char *action, int *val1, int *val2, int *val1_unit, int *val2_unit);
+int GetTwoArguments (char *action, int *val1, int *val2, int *val1_unit,
+		     int *val2_unit);
 int GetOneArgument (char *action, long *val1, int *val1_unit);
 void wait_func (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 		unsigned long context, char *action, int *Module);
@@ -392,8 +401,8 @@ void echo_func (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 		unsigned long context, char *action, int *Module);
 void raiselower_func (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 		      unsigned long context, char *action, int *Module);
-void Nop_func (XEvent * eventp, Window w, XfwmWindow * tmp_win, unsigned long context,
-	       char *action, int *Module);
+void Nop_func (XEvent * eventp, Window w, XfwmWindow * tmp_win,
+	       unsigned long context, char *action, int *Module);
 void set_mask_function (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 			unsigned long context, char *action, int *Module);
 void SetFocusMode (XEvent * eventp, Window w, XfwmWindow * tmp_win,
@@ -403,7 +412,7 @@ void SetAnimate (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 void SetOpaqueMove (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 		    unsigned long context, char *action, int *Module);
 void SetOpaqueResize (XEvent * eventp, Window w, XfwmWindow * tmp_win,
-		    unsigned long context, char *action, int *Module);
+		      unsigned long context, char *action, int *Module);
 void SetAutoRaise (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 		   unsigned long context, char *action, int *Module);
 void SetAutoRaiseDelay (XEvent * eventp, Window w, XfwmWindow * tmp_win,
@@ -413,13 +422,13 @@ void SetIconPos (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 void Arrange_Icons (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 		    unsigned long context, char *action, int *Module);
 void SetIconGrid (XEvent * eventp, Window w, XfwmWindow * tmp_win,
-		 unsigned long context, char *action, int *Module);
+		  unsigned long context, char *action, int *Module);
 void SetIconSpacing (XEvent * eventp, Window w, XfwmWindow * tmp_win,
-		 unsigned long context, char *action, int *Module);
+		     unsigned long context, char *action, int *Module);
 void use_bitmap_buttons (XEvent * eventp, Window w, XfwmWindow * tmp_win,
-		 unsigned long context, char *action, int *Module);
+			 unsigned long context, char *action, int *Module);
 void show_buttons (XEvent * eventp, Window w, XfwmWindow * tmp_win,
-      	         unsigned long context, char *action, int *Module);
+		   unsigned long context, char *action, int *Module);
 void DestroyMenu (MenuRoot * mr);
 void GetColors (void);
 XColor GetXColor (char *);
@@ -433,21 +442,17 @@ void MakeMenus (void);
 void GetMenuXPMFile (char *name, MenuItem * it);
 void GetMenuBitmapFile (char *name, MenuItem * it);
 void add_item_to_menu (XEvent * eventp, Window w, XfwmWindow * tmp_win,
-		       unsigned long context,
-		       char *action, int *Module);
+		       unsigned long context, char *action, int *Module);
 void destroy_menu (XEvent * eventp, Window w, XfwmWindow * tmp_win,
-		   unsigned long context,
-		   char *action, int *Module);
+		   unsigned long context, char *action, int *Module);
 void add_another_item (XEvent * eventp, Window w, XfwmWindow * tmp_win,
-		       unsigned long context,
-		       char *action, int *Module);
+		       unsigned long context, char *action, int *Module);
 void add_item_to_func (XEvent * eventp, Window w, XfwmWindow * tmp_win,
-		       unsigned long context,
-		       char *action, int *Module);
+		       unsigned long context, char *action, int *Module);
 void setModulePath (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 		    unsigned long context, char *action, int *Module);
-void ProcessNewStyle (XEvent * eventp, Window w, XfwmWindow * tmp_win, unsigned long context,
-		      char *action, int *Module);
+void ProcessNewStyle (XEvent * eventp, Window w, XfwmWindow * tmp_win,
+		      unsigned long context, char *action, int *Module);
 void SetHiColor (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 		 unsigned long context, char *action, int *Module);
 void SetLoColor (XEvent * eventp, Window w, XfwmWindow * tmp_win,
@@ -494,13 +499,17 @@ void SnapXYWH (int *x, int *y, int w, int h, XfwmWindow * skip);
 void SnapMove (int *FinalX, int *FinalY, int Width, int Height,
 	       XfwmWindow * skip);
 void SetSnapSize (XEvent * eventp, Window w, XfwmWindow * tmp_win,
-	       unsigned long context, char *action, int *Module);
+		  unsigned long context, char *action, int *Module);
 void wait_session (XEvent * eventp, Window w, XfwmWindow * tmp_win,
-	       unsigned long context, char *action, int *Module);
+		   unsigned long context, char *action, int *Module);
 void SetSessionMgt (XEvent * eventp, Window w, XfwmWindow * tmp_win,
-	       unsigned long context, char *action, int *Module);
+		    unsigned long context, char *action, int *Module);
+void SetClickRaise (XEvent * eventp, Window w, XfwmWindow * tmp_win,
+		    unsigned long context, char *action, int *Module);
+void SetForceFocus (XEvent * eventp, Window w, XfwmWindow * tmp_win,
+		    unsigned long context, char *action, int *Module);
 
-int check_existfile(char *filename);
+int check_existfile (char *filename);
 /*
  * ** message levels for xfwm_msg:
  */
@@ -508,7 +517,7 @@ int check_existfile(char *filename);
 #define INFO 0
 #define WARN 1
 #define ERR  2
-void xfwm_msg (int type, char *id, char *msg,...);
+void xfwm_msg (int type, char *id, char *msg, ...);
 
 #ifdef BROKEN_SUN_HEADERS
 #include "sun_headers.h"
