@@ -34,6 +34,10 @@
 #include "screen.h"
 #include "module.h"
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 int npipes;
 int *readPipes;
 int *writePipes;
@@ -95,12 +99,14 @@ ClosePipes (void)
 	  DeleteQueueBuff (i);
 	}
     }
+  /*
   free (pipeQueue);
   free (pipeName);
   free (PipeMask);
   free (pipeOn);
   free (readPipes);
   free (writePipes);
+   */
 }
 
 
@@ -144,7 +150,8 @@ executeModule (XEvent * eventp, Window w, XfwmWindow * tmp_win,
       if (cptr != NULL)
 	{
 	  xfwm_msg (ERR, "executeModule",
-		"No such module '%s' in ModulePath '%s'", cptr, ModulePath);
+		    "No such module '%s' in ModulePath '%s'", cptr,
+		    ModulePath);
 	  free (cptr);
 	}
       return;
@@ -159,6 +166,8 @@ executeModule (XEvent * eventp, Window w, XfwmWindow * tmp_win,
       xfwm_msg (ERR, "executeModule", "Too many Accessories!");
       if (cptr != NULL)
 	free (cptr);
+      if (arg1 != NULL)
+	free (arg1);
       return;
     }
 
@@ -168,6 +177,10 @@ executeModule (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   if (pipe (xfwm_to_app) != 0)
     {
       xfwm_msg (ERR, "executeModule", "Failed to open pipe");
+      if (cptr != NULL)
+	free (cptr);
+      if (arg1 != NULL)
+	free (arg1);
       return;
     }
   if (pipe (app_to_xfwm) != 0)
@@ -175,6 +188,8 @@ executeModule (XEvent * eventp, Window w, XfwmWindow * tmp_win,
       xfwm_msg (ERR, "executeModule", "Failed to open pipe2");
       if (cptr != NULL)
 	free (cptr);
+      if (arg1 != NULL)
+	free (arg1);
       close (xfwm_to_app[0]);
       close (xfwm_to_app[1]);
       return;
@@ -203,13 +218,12 @@ executeModule (XEvent * eventp, Window w, XfwmWindow * tmp_win,
       nargs++;
     }
   if (strlen (args[nargs - 1]) <= 0)
+    {
+      free (args[nargs - 1]);
       nargs--;
+    }
 
   args[nargs] = 0;
-
-  /* Try vfork instead of fork. The man page says that vfork is better! */
-  /* Also, had to change exit to _exit() */
-  /* Not everyone has vfork! */
   val = fork ();
   if (val > 0)
     {
@@ -238,6 +252,10 @@ executeModule (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 
       if (cptr != NULL)
 	free (cptr);
+      if (arg1 != NULL)
+	free (arg1);
+      for (i = 7; i < nargs; i++)
+	free (args[i]);
     }
   else if (val == 0)
     {
@@ -255,6 +273,8 @@ executeModule (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   else
     {
       xfwm_msg (ERR, "executeModule", "Fork failed");
+      for (i = 7; i < nargs; i++)
+	free (args[i]);
       free (arg1);
     }
   return;
@@ -329,7 +349,8 @@ HandleModuleInput (Window w, int channel)
 	Event.xany.type = ButtonRelease;
       Event.xany.window = w;
 
-      if (XFindContext (dpy, w, XfwmContext, (caddr_t *) & tmp_win) == XCNOENT)
+      if (XFindContext (dpy, w, XfwmContext, (caddr_t *) & tmp_win) ==
+	  XCNOENT)
 	{
 	  tmp_win = NULL;
 	  w = None;
@@ -474,10 +495,14 @@ SendConfig (int module, unsigned long event_type, XfwmWindow * t)
   body[HEADER_SIZE + 8] = t->flags;
   body[HEADER_SIZE + 9] = t->title_height;
   body[HEADER_SIZE + 10] = t->boundary_width;
-  body[HEADER_SIZE + 11] = (t->hints.flags & PBaseSize) ? t->hints.base_width : 0;
-  body[HEADER_SIZE + 12] = (t->hints.flags & PBaseSize) ? t->hints.base_height : 0;
-  body[HEADER_SIZE + 13] = (t->hints.flags & PResizeInc) ? t->hints.width_inc : 1;
-  body[HEADER_SIZE + 14] = (t->hints.flags & PResizeInc) ? t->hints.height_inc : 1;
+  body[HEADER_SIZE + 11] =
+    (t->hints.flags & PBaseSize) ? t->hints.base_width : 0;
+  body[HEADER_SIZE + 12] =
+    (t->hints.flags & PBaseSize) ? t->hints.base_height : 0;
+  body[HEADER_SIZE + 13] =
+    (t->hints.flags & PResizeInc) ? t->hints.width_inc : 1;
+  body[HEADER_SIZE + 14] =
+    (t->hints.flags & PResizeInc) ? t->hints.height_inc : 1;
   body[HEADER_SIZE + 15] = t->hints.min_width;
   body[HEADER_SIZE + 16] = t->hints.min_height;
   body[HEADER_SIZE + 17] = t->hints.max_width;
@@ -563,7 +588,7 @@ SendStrToModule (XEvent * eventp, Window junk, XfwmWindow * tmp_win,
     {
       if ((pipeName[i] != NULL) && (matchWildcards (module, pipeName[i])))
 	{
-	  SendName (i, M_STRING, 0, 0, 0, str);
+	  SendName (i, XFCE_M_STRING, 0, 0, 0, str);
 	}
     }
 
@@ -590,7 +615,9 @@ AddToQueue (int module, unsigned long *ptr, int size, int done)
   struct queue_buff_struct *c, *e;
   unsigned long *d;
 
-  c = (struct queue_buff_struct *) safemalloc (sizeof (struct queue_buff_struct));
+  c =
+    (struct queue_buff_struct *)
+    safemalloc (sizeof (struct queue_buff_struct));
   c->next = NULL;
   c->size = size;
   c->done = done;
@@ -648,7 +675,8 @@ FlushQueue (int module)
 	   * returns EAGAIN under these conditions. Hopefully other OSes
 	   * return one of these values too. Solaris 2 doesn't seem to have
 	   * a man page for write(2) (!) */
-	  else if ((errno == EWOULDBLOCK) || (errno == EAGAIN) || (errno == EINTR))
+	  else if ((errno == EWOULDBLOCK) || (errno == EAGAIN)
+		   || (errno == EINTR))
 	    {
 	      return;
 	    }
@@ -665,65 +693,64 @@ FlushQueue (int module)
 
 void
 send_list_func (XEvent * eventp, Window w, XfwmWindow * tmp_win,
-		unsigned long context, char *action,
-		int *Module)
+		unsigned long context, char *action, int *Module)
 {
   XfwmWindow *t;
 
   if (*Module >= 0)
     {
-      SendPacket (*Module, M_NEW_DESK, 1, Scr.CurrentDesk, 0, 0, 0, 0, 0, 0);
+      SendPacket (*Module, XFCE_M_NEW_DESK, 1, Scr.CurrentDesk, 0, 0, 0, 0, 0,
+		  0);
       if (Scr.Hilite != NULL)
-	SendPacket (*Module, M_FOCUS_CHANGE, 5, Scr.Hilite->w, Scr.Hilite->frame,
-		    (unsigned long) Scr.Hilite,
+	SendPacket (*Module, XFCE_M_FOCUS_CHANGE, 5, Scr.Hilite->w,
+		    Scr.Hilite->frame, (unsigned long) Scr.Hilite,
 		    Scr.DefaultDecor.HiColors.fore,
-		    Scr.DefaultDecor.HiColors.back,
-		    0, 0);
+		    Scr.DefaultDecor.HiColors.back, 0, 0);
       else
-	SendPacket (*Module, M_FOCUS_CHANGE, 5, 0, 0, 0, Scr.DefaultDecor.HiColors.fore,
+	SendPacket (*Module, XFCE_M_FOCUS_CHANGE, 5, 0, 0, 0,
+		    Scr.DefaultDecor.HiColors.fore,
 		    Scr.DefaultDecor.HiColors.back, 0, 0);
       if (Scr.DefaultIcon != NULL)
-	SendName (*Module, M_DEFAULTICON, 0, 0, 0, Scr.DefaultIcon);
+	SendName (*Module, XFCE_M_DEFAULTICON, 0, 0, 0, Scr.DefaultIcon);
       for (t = Scr.XfwmRoot.next; t != NULL; t = t->next)
 	{
-	  SendConfig (*Module, M_CONFIGURE_WINDOW, t);
-	  SendName (*Module, M_WINDOW_NAME, t->w, t->frame,
+	  SendConfig (*Module, XFCE_M_CONFIGURE_WINDOW, t);
+	  SendName (*Module, XFCE_M_WINDOW_NAME, t->w, t->frame,
 		    (unsigned long) t, t->name);
-	  SendName (*Module, M_ICON_NAME, t->w, t->frame,
+	  SendName (*Module, XFCE_M_ICON_NAME, t->w, t->frame,
 		    (unsigned long) t, t->icon_name);
 	  if (t->icon_bitmap_file != NULL &&
 	      t->icon_bitmap_file != Scr.DefaultIcon)
-	    SendName (*Module, M_ICON_FILE, t->w, t->frame,
+	    SendName (*Module, XFCE_M_ICON_FILE, t->w, t->frame,
 		      (unsigned long) t, t->icon_bitmap_file);
-	  SendName (*Module, M_RES_CLASS, t->w, t->frame,
+	  SendName (*Module, XFCE_M_RES_CLASS, t->w, t->frame,
 		    (unsigned long) t, t->class.res_class);
-	  SendName (*Module, M_RES_NAME, t->w, t->frame,
+	  SendName (*Module, XFCE_M_RES_NAME, t->w, t->frame,
 		    (unsigned long) t, t->class.res_name);
 
 	  if ((t->flags & ICONIFIED) && (!(t->flags & ICON_UNMAPPED)))
-	    SendPacket (*Module, M_ICONIFY, 7, t->w, t->frame,
+	    SendPacket (*Module, XFCE_M_ICONIFY, 7, t->w, t->frame,
 			(unsigned long) t,
 			t->icon_x_loc, t->icon_y_loc,
-			t->icon_w_width,
-			t->icon_w_height + t->icon_p_height);
+			t->icon_w_width, t->icon_w_height + t->icon_p_height);
 	  if ((t->flags & ICONIFIED) && (t->flags & ICON_UNMAPPED))
-	    SendPacket (*Module, M_ICONIFY, 7, t->w, t->frame,
+	    SendPacket (*Module, XFCE_M_ICONIFY, 7, t->w, t->frame,
 			(unsigned long) t, 0, 0, 0, 0);
 	}
       if (Scr.Hilite == NULL)
 	{
-	  Broadcast (M_FOCUS_CHANGE, 5, 0, 0, 0, Scr.DefaultDecor.HiColors.fore,
+	  Broadcast (XFCE_M_FOCUS_CHANGE, 5, 0, 0, 0,
+		     Scr.DefaultDecor.HiColors.fore,
 		     Scr.DefaultDecor.HiColors.back, 0, 0);
 	}
       else
 	{
-	  Broadcast (M_FOCUS_CHANGE, 5, Scr.Hilite->w,
+	  Broadcast (XFCE_M_FOCUS_CHANGE, 5, Scr.Hilite->w,
 		     Scr.Hilite->frame, (unsigned long) Scr.Hilite,
 		     Scr.DefaultDecor.HiColors.fore,
-		     Scr.DefaultDecor.HiColors.back,
-		     0, 0);
+		     Scr.DefaultDecor.HiColors.back, 0, 0);
 	}
-      SendPacket (*Module, M_END_WINDOWLIST, 0, 0, 0, 0, 0, 0, 0, 0);
+      SendPacket (*Module, XFCE_M_END_WINDOWLIST, 0, 0, 0, 0, 0, 0, 0, 0);
     }
 }
 void
