@@ -18,6 +18,7 @@
 #include <signal.h>
 #include <string.h>
 #include <X11/keysym.h>
+
 #include "xfwm.h"
 #include "menus.h"
 #include "misc.h"
@@ -26,14 +27,18 @@
 #include "module.h"
 #include "constant.h"
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 extern XEvent Event;
 extern int menuFromFrameOrWindowOrTitlebar;
-extern XfwmWindow *Tmp_win;		/* the current xfwm window */
+extern XfwmWindow *Tmp_win;	/* the current xfwm window */
 extern int _xfwm_deskwrap (int x_off, int y_off);
 
-/*forward*/ 
-int XFwmMoveWindow (XfwmWindow* tmp_win, int xl, int yt, int Width,
-                     int Height, int desk, Bool opaque_move);
+/*forward*/
+int XFwmMoveWindow (XfwmWindow * tmp_win, int xl, int yt, int Width,
+		    int Height, int desk, Bool opaque_move);
 
 /****************************************************************************
  *
@@ -48,7 +53,7 @@ move_window (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   int val1, val2, val1_unit, val2_unit, n;
   int startDesk;
   Bool window_deleted = FALSE;
-  
+
   n = GetTwoArguments (action, &val1, &val2, &val1_unit, &val2_unit);
 
   if (DeferExecution (eventp, &w, &tmp_win, &context, MOVE, ButtonPress))
@@ -67,7 +72,6 @@ move_window (XEvent * eventp, Window w, XfwmWindow * tmp_win,
       else
 	w = tmp_win->icon_w;
     }
-  XFlush (dpy);
   if (n == 2)
     {
       FinalX = val1 * val1_unit / 100;
@@ -77,18 +81,20 @@ move_window (XEvent * eventp, Window w, XfwmWindow * tmp_win,
     window_deleted = InteractiveMove (&w, tmp_win, &FinalX, &FinalY, eventp);
 
   if (startDesk != Scr.CurrentDesk)
-    Broadcast (M_NEW_DESK, 1, Scr.CurrentDesk, 0, 0, 0, 0, 0, 0);
+    Broadcast (XFCE_M_NEW_DESK, 1, Scr.CurrentDesk, 0, 0, 0, 0, 0, 0);
 
   if (window_deleted)
+    {
       return;
+    }
 
   if (w == tmp_win->frame)
     {
       SetupFrame (tmp_win, FinalX, FinalY,
 		  tmp_win->frame_width, tmp_win->frame_height, TRUE, TRUE);
       if (startDesk != Scr.CurrentDesk)
-        {
-          MapIt (tmp_win);
+	{
+	  MapIt (tmp_win);
 	  SetFocus (tmp_win->w, tmp_win, 0);
 	}
     }
@@ -100,7 +106,7 @@ move_window (XEvent * eventp, Window w, XfwmWindow * tmp_win,
       tmp_win->icon_xl_loc = FinalX -
 	(tmp_win->icon_w_width - tmp_win->icon_p_width) / 2;
       tmp_win->icon_y_loc = FinalY;
-      Broadcast (M_ICON_LOCATION, 7, tmp_win->w, tmp_win->frame,
+      Broadcast (XFCE_M_ICON_LOCATION, 7, tmp_win->w, tmp_win->frame,
 		 (unsigned long) tmp_win,
 		 tmp_win->icon_x_loc, tmp_win->icon_y_loc,
 		 tmp_win->icon_w_width, tmp_win->icon_w_height
@@ -110,19 +116,19 @@ move_window (XEvent * eventp, Window w, XfwmWindow * tmp_win,
       if (tmp_win->icon_pixmap_w != None)
 	{
 	  XMapWindow (dpy, tmp_win->icon_w);
-	  XMoveWindow (dpy, tmp_win->icon_pixmap_w, tmp_win->icon_x_loc, FinalY);
+	  XMoveWindow (dpy, tmp_win->icon_pixmap_w, tmp_win->icon_x_loc,
+		       FinalY);
 	  XMapWindow (dpy, w);
 	}
     }
 
-  XFlush (dpy);
   return;
 }
 
 /*
  * moveLoop : Returns True if window has been deleted during operation
  */
- 
+
 Bool
 moveLoop (XfwmWindow * tmp_win, int XOffset, int YOffset, int Width,
 	  int Height, int *FinalX, int *FinalY, Bool opaque_move,
@@ -151,16 +157,17 @@ moveLoop (XfwmWindow * tmp_win, int XOffset, int YOffset, int Width,
 
   while (!finished)
     {
-      XNextEvent(dpy, &Event);
+      XNextEvent (dpy, &Event);
       StashEventTime (&Event);
 
       if (Event.type == MotionNotify)
-        while (XCheckMaskEvent (dpy, PointerMotionMask | ButtonMotionMask |
-        		        ButtonPressMask | ButtonRelease, &Event))
-          {
-            StashEventTime (&Event);
-            if (Event.type == ButtonRelease) break;
-          }
+	while (XCheckMaskEvent (dpy, PointerMotionMask | ButtonMotionMask |
+				ButtonPressMask | ButtonRelease, &Event))
+	  {
+	    StashEventTime (&Event);
+	    if (Event.type == ButtonRelease)
+	      break;
+	  }
 
       done = FALSE;
       /* Handle a limited number of key press events to allow mouseless
@@ -180,23 +187,23 @@ moveLoop (XfwmWindow * tmp_win, int XOffset, int YOffset, int Width,
 	  if (XLookupKeysym (&(Event.xkey), 0) == XK_Escape)
 	    {
 	      if (!(tmp_win->flags & ICONIFIED))
-                {
-	          *FinalX = tmp_win->frame_x;
-	          *FinalY = tmp_win->frame_y;
-	          SnapMove (FinalX, FinalY, Width, Height, tmp_win);
-                }
-              else
-                {
-                  *FinalX = tmp_win->icon_x_loc;
-                  *FinalY = tmp_win->icon_y_loc;
-                }
+		{
+		  *FinalX = tmp_win->frame_x;
+		  *FinalY = tmp_win->frame_y;
+		  SnapMove (FinalX, FinalY, Width, Height, tmp_win);
+		}
+	      else
+		{
+		  *FinalX = tmp_win->icon_x_loc;
+		  *FinalY = tmp_win->icon_y_loc;
+		}
 	      finished = TRUE;
 	    }
 	  done = TRUE;
 	  break;
 	case ButtonPress:
 	  XAllowEvents (dpy, ReplayPointer, CurrentTime);
-          done = 1;
+	  done = 1;
 	  break;
 	case ButtonRelease:
 	  xl = Event.xmotion.x_root + XOffset;
@@ -224,49 +231,54 @@ moveLoop (XfwmWindow * tmp_win, int XOffset, int YOffset, int Width,
 	  yt += YOffset;
 
 	  if (!(tmp_win->flags & ICONIFIED))
-            {
-              SnapMove (&xl, &yt, Width, Height, tmp_win);
-  	      newdesk = XFwmMoveWindow (tmp_win, xl, yt, Width, Height, newdesk, opaque_move);
-            }
+	    {
+	      SnapMove (&xl, &yt, Width, Height, tmp_win);
+	      newdesk =
+		XFwmMoveWindow (tmp_win, xl, yt, Width, Height, newdesk,
+				opaque_move);
+	    }
 	  else
 	    {
 	      xl = ((int) (xl / Scr.icongrid)) * Scr.icongrid;
 	      yt = ((int) (yt / Scr.icongrid)) * Scr.icongrid;
 	      tmp_win->icon_x_loc = xl;
 	      tmp_win->icon_xl_loc = xl -
-	    	(tmp_win->icon_w_width - tmp_win->icon_p_width) / 2;
+		(tmp_win->icon_w_width - tmp_win->icon_p_width) / 2;
 	      tmp_win->icon_y_loc = yt;
 	      if (tmp_win->icon_pixmap_w != None)
-	    	XMoveWindow (dpy, tmp_win->icon_pixmap_w,
-	    		     tmp_win->icon_x_loc, yt);
+		XMoveWindow (dpy, tmp_win->icon_pixmap_w,
+			     tmp_win->icon_x_loc, yt);
 	      else if (tmp_win->icon_w != None)
-	    	XMoveWindow (dpy, tmp_win->icon_w, tmp_win->icon_xl_loc,
-	    		     yt + tmp_win->icon_p_height);
+		XMoveWindow (dpy, tmp_win->icon_w, tmp_win->icon_xl_loc,
+			     yt + tmp_win->icon_p_height);
 
 	    }
 	  done = TRUE;
 	  break;
 	case DestroyNotify:
-          if (Event.xdestroywindow.window == tmp_win->frame)
-            {
+	  if (Event.xdestroywindow.window == tmp_win->frame)
+	    {
 	      finished = TRUE;
 	      done = TRUE;
-              window_deleted = True;
-            }
-          DispatchEvent ();
+	      window_deleted = True;
+	    }
+	  DispatchEvent ();
 	  break;
 	case ConfigureRequest:
-          /* Here we shall override the value_mask to avoid programs such as
-             xmovie to generate a change in their geometry during resize 
-             operation, otherwise xfwm enters an infinite loop */
-          if (Event.xconfigurerequest.window == tmp_win->w)
-            Event.xconfigurerequest.value_mask &= ~(CWX | CWY | CWWidth | CWHeight | CWBorderWidth);
-          DispatchEvent ();
-          break;
+	  /* Here we shall override the value_mask to avoid programs such as
+	     xmovie to generate a change in their geometry during resize 
+	     operation, otherwise xfwm enters an infinite loop */
+	  if (Event.xconfigurerequest.window == tmp_win->w)
+	    Event.xconfigurerequest.value_mask &=
+	      ~(CWX | CWY | CWWidth | CWHeight | CWBorderWidth);
+	  DispatchEvent ();
+	  break;
 	default:
-	  if (!opaque_move) MoveOutline (tmp_win, 0,0,0,0);
-          DispatchEvent ();
-	  if (!opaque_move) MoveOutline (tmp_win, xl, yt, Width, Height);
+	  if (!opaque_move)
+	    MoveOutline (tmp_win, 0, 0, 0, 0);
+	  DispatchEvent ();
+	  if (!opaque_move)
+	    MoveOutline (tmp_win, xl, yt, Width, Height);
 	  break;
 	}
     }
@@ -362,7 +374,8 @@ Keyboard_shortcuts (XEvent * Event, int ReturnEvent)
  */
 
 Bool
-InteractiveMove (Window * win, XfwmWindow * tmp_win, int *FinalX, int *FinalY, XEvent * eventp)
+InteractiveMove (Window * win, XfwmWindow * tmp_win, int *FinalX, int *FinalY,
+		 XEvent * eventp)
 {
   extern int Stashed_X, Stashed_Y;
   int origDragX, origDragY, DragX, DragY, DragWidth, DragHeight;
@@ -398,130 +411,155 @@ InteractiveMove (Window * win, XfwmWindow * tmp_win, int *FinalX, int *FinalY, X
   YOffset = origDragY - DragY;
   iconified = tmp_win->flags & ICONIFIED;
 
-  XSync (dpy, 0);
-
   if (!(Scr.Options & MoveOpaqueWin) && !(iconified))
     MyXGrabServer (dpy);
-  window_deleted = moveLoop (tmp_win, XOffset, YOffset, DragWidth, DragHeight, FinalX, FinalY,
-      (Scr.Options & MoveOpaqueWin) || (iconified), False);
+  window_deleted =
+    moveLoop (tmp_win, XOffset, YOffset, DragWidth, DragHeight, FinalX,
+	      FinalY, (Scr.Options & MoveOpaqueWin) || (iconified), False);
   if (!(Scr.Options & MoveOpaqueWin) && !(iconified))
     MyXUngrabServer (dpy);
   UninstallRootColormap ();
 
   UngrabEm ();
-  XSync (dpy, 0);
-  
+
   /* Flush the event queue and discard all ConfigureRequest relative to resized window */
-  while ((!window_deleted) && My_XNextEvent (dpy, &Event))
+  XFlush (dpy);
+  while ((!window_deleted) && XPending (dpy))
     {
-      if ((Event.type == ConfigureRequest) &&(Event.xconfigurerequest.window == tmp_win->w))
-        Event.xconfigurerequest.value_mask &= ~(CWX | CWY | CWWidth | CWHeight | CWBorderWidth);
-      else if ((Event.type == DestroyNotify) &&(Event.xdestroywindow.window == tmp_win->frame))
-        window_deleted = True;
+      XNextEvent (dpy, &Event);
+      if ((Event.type == ConfigureRequest)
+	  && (Event.xconfigurerequest.window == tmp_win->w))
+	Event.xconfigurerequest.value_mask &=
+	  ~(CWX | CWY | CWWidth | CWHeight | CWBorderWidth);
+      else if ((Event.type == DestroyNotify)
+	       && (Event.xdestroywindow.window == tmp_win->frame))
+	window_deleted = True;
+      StashEventTime (&Event);
       DispatchEvent ();
     }
   return (window_deleted);
 }
 
 void
-domove(XfwmWindow* tmp_win, int xl, int yt, int Width, 
-       int Height, Bool opaque_move)
+domove (XfwmWindow * tmp_win, int xl, int yt, int Width,
+	int Height, Bool opaque_move)
 {
   if (!opaque_move)
     MoveOutline (tmp_win, xl, yt, Width, Height);
   else
-   {
-     tmp_win->frame_x = tmp_win->shade_x = xl;
-     tmp_win->frame_y = tmp_win->shade_y = yt;
-     XMoveWindow (dpy, tmp_win->frame, xl, yt);
-   }
+    {
+      tmp_win->frame_x = tmp_win->shade_x = xl;
+      tmp_win->frame_y = tmp_win->shade_y = yt;
+      XMoveWindow (dpy, tmp_win->frame, xl, yt);
+    }
 }
 
 int
-XFwmMoveWindow (XfwmWindow* tmp_win, int xl, int yt, int Width,
-                int Height, int desk, Bool opaque_move)
+XFwmMoveWindow (XfwmWindow * tmp_win, int xl, int yt, int Width,
+		int Height, int desk, Bool opaque_move)
 {
   int newdesk = desk;
   if (Scr.SnapSize < MINRESISTANCE)
-    { /* do the standard stuff */
-      domove(tmp_win, xl, yt, Width, Height, opaque_move);
+    {				/* do the standard stuff */
+      domove (tmp_win, xl, yt, Width, Height, opaque_move);
       return (tmp_win->Desk);
     }
   else
-    { /* check if the pointer is pushed onto the screen border,
-         if so, increment the corresponding X or Y counter (until Snapsize),
-         otherwise reset them to null.
-      */
-           if (Event.xmotion.x_root == 0) { Scr.EdgeScrollX--; }
-      else if (Event.xmotion.y_root == 0) { Scr.EdgeScrollY--; }
-      else if (Event.xmotion.x_root >= Scr.MyDisplayWidth-1) { Scr.EdgeScrollX++; }
-      else if (Event.xmotion.y_root >= Scr.MyDisplayHeight-1) { Scr.EdgeScrollY++; }
-      else { Scr.EdgeScrollY = Scr.EdgeScrollX = 0; }
-      
+    {				/* check if the pointer is pushed onto the screen border,
+				   if so, increment the corresponding X or Y counter (until Snapsize),
+				   otherwise reset them to null.
+				 */
+      if (Event.xmotion.x_root == 0)
+	{
+	  Scr.EdgeScrollX--;
+	}
+      else if (Event.xmotion.y_root == 0)
+	{
+	  Scr.EdgeScrollY--;
+	}
+      else if (Event.xmotion.x_root >= Scr.MyDisplayWidth - 1)
+	{
+	  Scr.EdgeScrollX++;
+	}
+      else if (Event.xmotion.y_root >= Scr.MyDisplayHeight - 1)
+	{
+	  Scr.EdgeScrollY++;
+	}
+      else
+	{
+	  Scr.EdgeScrollY = Scr.EdgeScrollX = 0;
+	}
+
       /* now check if some EdgeCounter has reached Snapsize, so that
          we shall emit signals to switch to the next desk (computed in 
          the deskwrap-helper)
-      */
-      if (Scr.EdgeScrollX <= -Scr.SnapSize) 
-        { /* move desktop left */
-          Scr.EdgeScrollX = Scr.EdgeScrollY = 0;
-          XWarpPointer (dpy, None, None, 0,0,0,0, +(Scr.MyDisplayWidth-Scr.SnapSize),(0));
+       */
+      if (Scr.EdgeScrollX <= -Scr.SnapSize)
+	{			/* move desktop left */
+	  Scr.EdgeScrollX = Scr.EdgeScrollY = 0;
+	  XWarpPointer (dpy, None, None, 0, 0, 0, 0,
+			+(Scr.MyDisplayWidth - Scr.SnapSize), (0));
 	  if (!opaque_move)
 	    MoveOutline (tmp_win, 0, 0, 0, 0);
-          newdesk = _xfwm_deskwrap(-1,0);
+	  newdesk = _xfwm_deskwrap (-1, 0);
 	  if (opaque_move)
-            tmp_win->Desk = newdesk;
-          changeDesks (0, newdesk, 0, 0);
-          DispatchEvent ();
-	  domove(tmp_win, xl+(Scr.MyDisplayWidth-Scr.SnapSize), yt,Width, Height, opaque_move);
+	    tmp_win->Desk = newdesk;
+	  changeDesks (0, newdesk, 0, 0, !opaque_move);
+	  DispatchEvent ();
+	  domove (tmp_win, xl + (Scr.MyDisplayWidth - Scr.SnapSize), yt,
+		  Width, Height, opaque_move);
 	  return (newdesk);
-        }
-      if (Scr.EdgeScrollX >= +Scr.SnapSize) 
-        { /* move desktop right */
-          Scr.EdgeScrollX = Scr.EdgeScrollY = 0;
-          XWarpPointer (dpy, None, None, 0,0,0,0, -(Scr.MyDisplayWidth-Scr.SnapSize),(0));
+	}
+      if (Scr.EdgeScrollX >= +Scr.SnapSize)
+	{			/* move desktop right */
+	  Scr.EdgeScrollX = Scr.EdgeScrollY = 0;
+	  XWarpPointer (dpy, None, None, 0, 0, 0, 0,
+			-(Scr.MyDisplayWidth - Scr.SnapSize), (0));
 	  if (!opaque_move)
 	    MoveOutline (tmp_win, 0, 0, 0, 0);
-          newdesk = _xfwm_deskwrap(+1,0);
+	  newdesk = _xfwm_deskwrap (+1, 0);
 	  if (opaque_move)
-            tmp_win->Desk = newdesk;
-          changeDesks (0, newdesk, 0, 0);
-          DispatchEvent ();
-          domove(tmp_win, xl-(Scr.MyDisplayWidth-Scr.SnapSize), yt,Width, Height, opaque_move);
+	    tmp_win->Desk = newdesk;
+	  changeDesks (0, newdesk, 0, 0, !opaque_move);
+	  DispatchEvent ();
+	  domove (tmp_win, xl - (Scr.MyDisplayWidth - Scr.SnapSize), yt,
+		  Width, Height, opaque_move);
 	  return (newdesk);
-        }
-      if (Scr.EdgeScrollY <= -Scr.SnapSize) 
-        { /* move desktop upper */
-          Scr.EdgeScrollX = Scr.EdgeScrollY = 0;
-          XWarpPointer (dpy, None, None, 0,0,0,0, (0),+(Scr.MyDisplayHeight-Scr.SnapSize));
+	}
+      if (Scr.EdgeScrollY <= -Scr.SnapSize)
+	{			/* move desktop upper */
+	  Scr.EdgeScrollX = Scr.EdgeScrollY = 0;
+	  XWarpPointer (dpy, None, None, 0, 0, 0, 0, (0),
+			+(Scr.MyDisplayHeight - Scr.SnapSize));
 	  if (!opaque_move)
 	    MoveOutline (tmp_win, 0, 0, 0, 0);
-          newdesk = _xfwm_deskwrap(0,-1);
+	  newdesk = _xfwm_deskwrap (0, -1);
 	  if (opaque_move)
-            tmp_win->Desk = newdesk;
-          changeDesks (0, newdesk, 0, 0);
-          DispatchEvent ();
-	  domove(tmp_win, xl, yt+(Scr.MyDisplayHeight-Scr.SnapSize),Width, Height, opaque_move);
+	    tmp_win->Desk = newdesk;
+	  changeDesks (0, newdesk, 0, 0, !opaque_move);
+	  DispatchEvent ();
+	  domove (tmp_win, xl, yt + (Scr.MyDisplayHeight - Scr.SnapSize),
+		  Width, Height, opaque_move);
 	  return (newdesk);
-        }
-      if (Scr.EdgeScrollY >= +Scr.SnapSize) 
-        { /* move desktop lower */
-          Scr.EdgeScrollX = Scr.EdgeScrollY = 0;
-          XWarpPointer (dpy, None, None, 0,0,0,0, (0),-(Scr.MyDisplayHeight-Scr.SnapSize));
+	}
+      if (Scr.EdgeScrollY >= +Scr.SnapSize)
+	{			/* move desktop lower */
+	  Scr.EdgeScrollX = Scr.EdgeScrollY = 0;
+	  XWarpPointer (dpy, None, None, 0, 0, 0, 0, (0),
+			-(Scr.MyDisplayHeight - Scr.SnapSize));
 	  if (!opaque_move)
 	    MoveOutline (tmp_win, 0, 0, 0, 0);
-          newdesk = _xfwm_deskwrap(0,+1);
+	  newdesk = _xfwm_deskwrap (0, +1);
 	  if (opaque_move)
-            tmp_win->Desk = newdesk;
-          changeDesks (0, newdesk, 0, 0);
-          DispatchEvent ();
-	  domove(tmp_win, xl, yt-(Scr.MyDisplayHeight-Scr.SnapSize),Width, Height, opaque_move);
+	    tmp_win->Desk = newdesk;
+	  changeDesks (0, newdesk, 0, 0, !opaque_move);
+	  DispatchEvent ();
+	  domove (tmp_win, xl, yt - (Scr.MyDisplayHeight - Scr.SnapSize),
+		  Width, Height, opaque_move);
 	  return (newdesk);
-        }
-      domove(tmp_win, xl, yt, Width, Height, opaque_move);
+	}
+      domove (tmp_win, xl, yt, Width, Height, opaque_move);
       return (newdesk);
     }
   return (newdesk);
 }
-
-
