@@ -28,8 +28,8 @@
 #define F_TITLE			5
 #define F_CIRCULATE_UP          6
 #define F_CIRCULATE_DOWN        7
-#define F_WINDOWLIST            8 
-#define F_MOVECURSOR            9 
+#define F_WINDOWLIST            8
+#define F_MOVECURSOR            9
 #define F_FUNCTION              10
 #define F_MODULE                11
 #define F_DESK                  12
@@ -89,6 +89,8 @@
 #define F_ICONSPACING           66
 #define F_BITMAPBUTTONS         67
 #define F_SHOWBUTTONS	        68
+#define F_SETCLICKRAISE	        69
+#define F_SETFORCEFOCUS	        70
 /* Functions which require a target window */
 #define F_RESIZE		100
 #define F_RAISE			101
