@@ -22,6 +22,10 @@
 #include "screen.h"
 #include "parse.h"
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 static int dragx;		/* all these variables are used */
 static int dragy;		/* in resize operations */
 static int dragWidth;
@@ -36,7 +40,7 @@ static int initHeight;
 static int ymotion = 0, xmotion = 0;
 static int last_width, last_height;
 extern int menuFromFrameOrWindowOrTitlebar;
-extern XfwmWindow *Tmp_win;		/* the current xfwm window */
+extern XfwmWindow *Tmp_win;	/* the current xfwm window */
 
 extern Window PressedW;
 
@@ -53,7 +57,7 @@ resize_window (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   int x, y, mouse_x, mouse_y;
   int delta_x;
   int delta_y;
-  Window ResizeWindow;  
+  Window ResizeWindow;
   extern int Stashed_X, Stashed_Y;
   int val1, val2, val1_unit, val2_unit, n;
   XGCValues gcv;
@@ -73,7 +77,7 @@ resize_window (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 
   if (!(Scr.Options & ResizeOpaqueWin))
     {
-      gcv.line_width = 3;
+      gcv.line_width = 2;
       XChangeGC (dpy, Scr.DrawGC, GCLineWidth, &gcv);
     }
 
@@ -97,8 +101,8 @@ resize_window (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   if (menuFromFrameOrWindowOrTitlebar)
     {
       XWarpPointer (dpy, None, Scr.Root, 0, 0, 0, 0, Stashed_X, Stashed_Y);
+      XFlush (dpy);
     }
-  XFlush (dpy);
 
   if (!GrabEm (MOVE))
     {
@@ -120,8 +124,8 @@ resize_window (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   else
     {
       XGetGeometry (dpy, (Drawable) ResizeWindow, &JunkRoot,
-		  &dragx, &dragy, (unsigned int *) &dragWidth,
-		  (unsigned int *) &dragHeight, &JunkBW, &JunkDepth);
+		    &dragx, &dragy, (unsigned int *) &dragWidth,
+		    (unsigned int *) &dragHeight, &JunkBW, &JunkDepth);
       initHeight = dragHeight;
     }
   origx = dragx;
@@ -201,24 +205,24 @@ resize_window (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   if (!(Scr.Options & ResizeOpaqueWin))
     {
       MoveOutline (tmp_win, dragx - tmp_win->bw, dragy - tmp_win->bw,
-	       dragWidth + 2 * tmp_win->bw,
-	       dragHeight + 2 * tmp_win->bw);
+		   dragWidth + 2 * tmp_win->bw, dragHeight + 2 * tmp_win->bw);
     }
   /* loop to resize */
   while (!finished)
     {
-      XNextEvent(dpy, &Event);
+      XNextEvent (dpy, &Event);
       StashEventTime (&Event);
 
       if (Event.type == MotionNotify)
-        while (XCheckMaskEvent (dpy, PointerMotionMask | ButtonMotionMask |
-        		        ButtonPressMask | ButtonRelease, &Event))
-         {
-           StashEventTime(&Event);      
-           if (Event.type == ButtonRelease) break;
-         }
+	while (XCheckMaskEvent (dpy, PointerMotionMask | ButtonMotionMask |
+				ButtonPressMask | ButtonRelease, &Event))
+	  {
+	    StashEventTime (&Event);
+	    if (Event.type == ButtonRelease)
+	      break;
+	  }
 
-       done = FALSE;
+      done = FALSE;
       /* Handle a limited number of key press events to allow mouseless
        * operation */
       if (Event.type == KeyPress)
@@ -253,30 +257,31 @@ resize_window (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 	  done = TRUE;
 	  break;
 	case DestroyNotify:
-          if (Event.xdestroywindow.window == tmp_win->frame)
-            {
+	  if (Event.xdestroywindow.window == tmp_win->frame)
+	    {
 	      finished = TRUE;
 	      done = TRUE;
-              window_deleted = True;
-            }
-          DispatchEvent ();
+	      window_deleted = True;
+	    }
+	  DispatchEvent ();
+	  break;
+	case ConfigureRequest:
+	  /* Here we shall override the value_mask to avoid programs such as
+	     xmovie to generate a change in their geometry during resize 
+	     operation, otherwise xfwm enters an infinite loop */
+	  if (Event.xconfigurerequest.window == tmp_win->w)
+	    Event.xconfigurerequest.value_mask &=
+	      ~(CWX | CWY | CWWidth | CWHeight | CWBorderWidth);
+	  DispatchEvent ();
 	  break;
-        case ConfigureRequest:
-          /* Here we shall override the value_mask to avoid programs such as
-             xmovie to generate a change in their geometry during resize 
-             operation, otherwise xfwm enters an infinite loop */
-          if (Event.xconfigurerequest.window == tmp_win->w)
-            Event.xconfigurerequest.value_mask &= ~(CWX | CWY | CWWidth | CWHeight | CWBorderWidth);
-          DispatchEvent ();
-          break;
 	default:
-	  if (!(Scr.Options & ResizeOpaqueWin)) 
-	    MoveOutline (tmp_win, 0,0,0,0);
-          DispatchEvent ();
-	  if (!(Scr.Options & ResizeOpaqueWin)) 
-	     MoveOutline (tmp_win, dragx - tmp_win->bw, dragy - tmp_win->bw,
-	       dragWidth + 2 * tmp_win->bw,
-	       dragHeight + 2 * tmp_win->bw);
+	  if (!(Scr.Options & ResizeOpaqueWin))
+	    MoveOutline (tmp_win, 0, 0, 0, 0);
+	  DispatchEvent ();
+	  if (!(Scr.Options & ResizeOpaqueWin))
+	    MoveOutline (tmp_win, dragx - tmp_win->bw, dragy - tmp_win->bw,
+			 dragWidth + 2 * tmp_win->bw,
+			 dragHeight + 2 * tmp_win->bw);
 	  break;
 	}
     }
@@ -288,31 +293,39 @@ resize_window (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   if (!window_deleted)
     {
       if (!abort)
-        {
-          ConstrainSize (tmp_win, &dragWidth, &dragHeight);
-          SetupFrame (tmp_win, dragx - tmp_win->bw,
-		      dragy - tmp_win->bw, dragWidth, ((tmp_win->flags & SHADED) ? initHeight : dragHeight), FALSE, TRUE);
-        }
+	{
+	  ConstrainSize (tmp_win, &dragWidth, &dragHeight);
+	  SetupFrame (tmp_win, dragx - tmp_win->bw,
+		      dragy - tmp_win->bw, dragWidth,
+		      ((tmp_win->flags & SHADED) ? initHeight : dragHeight),
+		      FALSE, TRUE);
+	}
       else
-          SetupFrame (tmp_win, origx, origy, origWidth, ((tmp_win->flags & SHADED) ? initHeight : origHeight), FALSE, TRUE);
+	SetupFrame (tmp_win, origx, origy, origWidth,
+		    ((tmp_win->flags & SHADED) ? initHeight : origHeight),
+		    FALSE, TRUE);
     }
   UninstallRootColormap ();
   ResizeWindow = None;
   if (!(Scr.Options & ResizeOpaqueWin))
     MyXUngrabServer (dpy);
-  UngrabEm (); 
-  XSync (dpy, 0);
+  UngrabEm ();
   /* Flush the event queue and discard all ConfigureRequest relative to resized window */
-  while ((!window_deleted) && My_XNextEvent (dpy, &Event))
+  XFlush (dpy);
+  while ((!window_deleted) && XPending (dpy))
     {
-      if ((Event.type == ConfigureRequest) &&(Event.xconfigurerequest.window == tmp_win->w))
-        Event.xconfigurerequest.value_mask &= ~(CWX | CWY | CWWidth | CWHeight | CWBorderWidth);
-      else if ((Event.type == DestroyNotify) &&(Event.xdestroywindow.window == tmp_win->frame))
-        window_deleted = True;
+      XNextEvent (dpy, &Event);
+      if ((Event.type == ConfigureRequest)
+	  && (Event.xconfigurerequest.window == tmp_win->w))
+	Event.xconfigurerequest.value_mask &=
+	  ~(CWX | CWY | CWWidth | CWHeight | CWBorderWidth);
+      else if ((Event.type == DestroyNotify)
+	       && (Event.xdestroywindow.window == tmp_win->frame))
+	window_deleted = True;
+      StashEventTime (&Event);
       DispatchEvent ();
     }
 
-  XFlush (dpy);
   xmotion = 0;
   ymotion = 0;
   return;
@@ -335,12 +348,13 @@ DoResize (int x_root, int y_root, XfwmWindow * tmp_win)
 {
   int action = 0;
 
-  if ((y_root <= origy) || ((ymotion == 1) && (y_root < origy + origHeight - 1)))
+  if ((y_root <= origy)
+      || ((ymotion == 1) && (y_root < origy + origHeight - 1)))
     {
       SnapXY (&x_root, &y_root, tmp_win);
       dragy = y_root;
       if (!(tmp_win->flags & SHADED))
-        dragHeight = origy + origHeight - y_root;
+	dragHeight = origy + origHeight - y_root;
       action = 1;
       ymotion = 1;
     }
@@ -351,7 +365,7 @@ DoResize (int x_root, int y_root, XfwmWindow * tmp_win)
       SnapXY (&x_root, &y_root, tmp_win);
       dragy = origy;
       if (!(tmp_win->flags & SHADED))
-        dragHeight = y_root - dragy;
+	dragHeight = y_root - dragy;
       action = 1;
       ymotion = -1;
     }
@@ -366,7 +380,7 @@ DoResize (int x_root, int y_root, XfwmWindow * tmp_win)
       xmotion = 1;
     }
   else if ((x_root >= origx + origWidth - 1) ||
-      ((xmotion == -1) && (x_root > origx)))
+	   ((xmotion == -1) && (x_root > origx)))
     {
       x_root++;
       SnapXY (&x_root, &y_root, tmp_win);
@@ -384,12 +398,15 @@ DoResize (int x_root, int y_root, XfwmWindow * tmp_win)
       if (ymotion == 1)
 	dragy = origy + origHeight - dragHeight;
 
-          if (!(Scr.Options & ResizeOpaqueWin))
-            MoveOutline (tmp_win, dragx - tmp_win->bw, dragy - tmp_win->bw,
-		 dragWidth + 2 * tmp_win->bw, dragHeight + 2 * tmp_win->bw);
-          else
-	    SetupFrame (tmp_win, dragx - tmp_win->bw, 
-		      dragy - tmp_win->bw, dragWidth, ((tmp_win->flags & SHADED) ? initHeight : dragHeight), FALSE, FALSE);  
+      if (!(Scr.Options & ResizeOpaqueWin))
+	MoveOutline (tmp_win, dragx - tmp_win->bw, dragy - tmp_win->bw,
+		     dragWidth + 2 * tmp_win->bw,
+		     dragHeight + 2 * tmp_win->bw);
+      else
+	SetupFrame (tmp_win, dragx - tmp_win->bw, dragy - tmp_win->bw,
+		    dragWidth,
+		    ((tmp_win->flags & SHADED) ? initHeight : dragHeight),
+		    FALSE, FALSE);
     }
 }
 
@@ -476,15 +493,13 @@ ConstrainSize (XfwmWindow * tmp_win, int *widthp, int *heightp)
       if ((minAspectX * dheight > minAspectY * dwidth) && (xmotion == 0))
 	{
 	  /* Change width to match */
-	  delta = makemult (minAspectX * dheight / minAspectY - dwidth,
-			    xinc);
+	  delta = makemult (minAspectX * dheight / minAspectY - dwidth, xinc);
 	  if (dwidth + delta <= maxWidth)
 	    dwidth += delta;
 	}
       if (minAspectX * dheight > minAspectY * dwidth)
 	{
-	  delta = makemult (dheight - dwidth * minAspectY / minAspectX,
-			    yinc);
+	  delta = makemult (dheight - dwidth * minAspectY / minAspectX, yinc);
 	  if (dheight - delta >= minHeight)
 	    dheight -= delta;
 	  else
@@ -498,15 +513,13 @@ ConstrainSize (XfwmWindow * tmp_win, int *widthp, int *heightp)
 
       if ((maxAspectX * dheight < maxAspectY * dwidth) && (ymotion == 0))
 	{
-	  delta = makemult (dwidth * maxAspectY / maxAspectX - dheight,
-			    yinc);
+	  delta = makemult (dwidth * maxAspectY / maxAspectX - dheight, yinc);
 	  if (dheight + delta <= maxHeight)
 	    dheight += delta;
 	}
       if ((maxAspectX * dheight < maxAspectY * dwidth))
 	{
-	  delta = makemult (dwidth - maxAspectX * dheight / maxAspectY,
-			    xinc);
+	  delta = makemult (dwidth - maxAspectX * dheight / maxAspectY, xinc);
 	  if (dwidth - delta >= minWidth)
 	    dwidth -= delta;
 	  else
@@ -544,7 +557,7 @@ ConstrainSize (XfwmWindow * tmp_win, int *widthp, int *heightp)
  *
  ***********************************************************************/
 void
-MoveOutline (XfwmWindow *tmp_win, int x, int y, int width, int height)
+MoveOutline (XfwmWindow * tmp_win, int x, int y, int width, int height)
 {
   static int lastx = 0;
   static int lasty = 0;
@@ -557,8 +570,10 @@ MoveOutline (XfwmWindow *tmp_win, int x, int y, int width, int height)
   /* undraw the old one, if any */
   if (lastWidth || lastHeight)
     {
-      XDrawRectangle (dpy, Scr.Root, Scr.DrawGC, lastx, lasty, lastWidth, lastHeight);
-      if (tmp_win) DisplayPosition(tmp_win, lastx, lasty, lastWidth, lastHeight);
+      XDrawRectangle (dpy, Scr.Root, Scr.DrawGC, lastx, lasty, lastWidth,
+		      lastHeight);
+      if (tmp_win)
+	DisplayPosition (tmp_win, lastx, lasty, lastWidth, lastHeight);
     }
 
   lastx = x;
@@ -569,23 +584,26 @@ MoveOutline (XfwmWindow *tmp_win, int x, int y, int width, int height)
   /* draw the new one, if any */
   if (lastWidth || lastHeight)
     {
-      if (tmp_win) DisplayPosition(tmp_win, lastx, lasty, lastWidth, lastHeight);
-      XDrawRectangle (dpy, Scr.Root, Scr.DrawGC, lastx, lasty, lastWidth, lastHeight);
+      if (tmp_win)
+	DisplayPosition (tmp_win, lastx, lasty, lastWidth, lastHeight);
+      XDrawRectangle (dpy, Scr.Root, Scr.DrawGC, lastx, lasty, lastWidth,
+		      lastHeight);
     }
 }
 
-void DisplayPosition(XfwmWindow *tmp_win, int x, int y, int w, int h)
+void
+DisplayPosition (XfwmWindow * tmp_win, int x, int y, int w, int h)
 {
-  char strxy[20],strw[10],strh[10],strd[10];
-  int dwidth,dheight;
+  char strxy[20], strw[10], strh[10], strd[10];
+  int dwidth, dheight;
   int offsetx, offsetw, offsetd;
   XPoint points[3];
 
   if (!tmp_win)
     return;
-    
-  dheight = h - tmp_win->title_height - 2*tmp_win->boundary_width;
-  dwidth = w - 2*tmp_win->boundary_width;
+
+  dheight = h - tmp_win->title_height - 2 * tmp_win->boundary_width;
+  dwidth = w - 2 * tmp_win->boundary_width;
 
   dwidth -= tmp_win->hints.base_width;
   dheight -= tmp_win->hints.base_height;
@@ -595,56 +613,64 @@ void DisplayPosition(XfwmWindow *tmp_win, int x, int y, int w, int h)
     dheight /= tmp_win->hints.height_inc;
 
   sprintf (strxy, "(X=%d, Y=%d)", x, y);
-  sprintf (strw, "(W=%d)",  dwidth);
-  sprintf (strh, "(H=%d)",  dheight);
-  sprintf (strd, "[Desk %d]",  Scr.CurrentDesk + 1);
-  offsetx=XTextWidth(Scr.StdFont.font,strxy,strlen(strxy));
-  offsetw=XTextWidth(Scr.StdFont.font,strw,strlen(strw));
-  offsetd=XTextWidth(Scr.StdFont.font,strd,strlen(strd));
-  
+  sprintf (strw, "(W=%d)", dwidth);
+  sprintf (strh, "(H=%d)", dheight);
+  sprintf (strd, "[Desk %d]", Scr.CurrentDesk + 1);
+  offsetx = XTextWidth (Scr.StdFont.font, strxy, strlen (strxy));
+  offsetw = XTextWidth (Scr.StdFont.font, strw, strlen (strw));
+  offsetd = XTextWidth (Scr.StdFont.font, strd, strlen (strd));
+
   XDrawString (dpy, Scr.Root, Scr.HintsGC,
-	       x + (w - offsetx) / 2 , y + 5 + Scr.StdFont.height,
-	       strxy, strlen(strxy));
+	       x + (w - offsetx) / 2, y + 5 + Scr.StdFont.height,
+	       strxy, strlen (strxy));
   XDrawString (dpy, Scr.Root, Scr.HintsGC,
-	       x + (w - offsetw) / 2 , y + h + 5 + Scr.StdFont.height,
-	       strw, strlen(strw));
+	       x + (w - offsetw) / 2, y + h + 5 + Scr.StdFont.height,
+	       strw, strlen (strw));
   XDrawString (dpy, Scr.Root, Scr.HintsGC,
 	       x + w + 5, y + (h + Scr.StdFont.height) / 2,
-	       strh, strlen(strh));
+	       strh, strlen (strh));
   if (h > 3 * Scr.StdFont.height)
     XDrawString (dpy, Scr.Root, Scr.HintsGC,
-	         x + (w - offsetd) / 2, y + (h + Scr.StdFont.height) / 2,
-	         strd, strlen(strd));
+		 x + (w - offsetd) / 2, y + (h + Scr.StdFont.height) / 2,
+		 strd, strlen (strd));
   points[0].x = x + 15;
   points[0].y = y + h + 5;
   points[1].x = x;
   points[1].y = y + h + 10;
   points[2].x = x + 15;
   points[2].y = y + h + 15;
-  XFillPolygon (dpy, Scr.Root, Scr.HintsGC, points, 3, Convex, CoordModeOrigin);
+  XFillPolygon (dpy, Scr.Root, Scr.HintsGC, points, 3, Convex,
+		CoordModeOrigin);
   points[0].x = x + w - 15;
   points[0].y = y + h + 5;
   points[1].x = x + w;
   points[1].y = y + h + 10;
   points[2].x = x + w - 15;
   points[2].y = y + h + 15;
-  XFillPolygon (dpy, Scr.Root, Scr.HintsGC, points, 3, Convex, CoordModeOrigin);
+  XFillPolygon (dpy, Scr.Root, Scr.HintsGC, points, 3, Convex,
+		CoordModeOrigin);
   points[0].x = x + w + 5;
   points[0].y = y + 15;
   points[1].x = x + w + 10;
   points[1].y = y;
   points[2].x = x + w + 15;
   points[2].y = y + 15;
-  XFillPolygon (dpy, Scr.Root, Scr.HintsGC, points, 3, Convex, CoordModeOrigin);
+  XFillPolygon (dpy, Scr.Root, Scr.HintsGC, points, 3, Convex,
+		CoordModeOrigin);
   points[0].x = x + w + 5;
   points[0].y = y + h - 15;
   points[1].x = x + w + 10;
   points[1].y = y + h;
   points[2].x = x + w + 15;
   points[2].y = y + h - 15;
-  XFillPolygon (dpy, Scr.Root, Scr.HintsGC, points, 3, Convex, CoordModeOrigin);
-  XDrawLine(dpy, Scr.Root, Scr.HintsGC, x + 15, y + h + 10, x + (w - offsetw) / 2 - 5, y + h + 10);
-  XDrawLine(dpy, Scr.Root, Scr.HintsGC, x + (w + offsetw) / 2 + 5, y + h + 10, x + w - 15, y + h + 10);
-  XDrawLine(dpy, Scr.Root, Scr.HintsGC, x + w + 10, y + 15, x + w + 10, y + (h - Scr.StdFont.height) / 2 - 5);
-  XDrawLine(dpy, Scr.Root, Scr.HintsGC, x + w + 10, y + (h + Scr.StdFont.height) / 2 + 5, x + w + 10, y + h - 15);
+  XFillPolygon (dpy, Scr.Root, Scr.HintsGC, points, 3, Convex,
+		CoordModeOrigin);
+  XDrawLine (dpy, Scr.Root, Scr.HintsGC, x + 15, y + h + 10,
+	     x + (w - offsetw) / 2 - 5, y + h + 10);
+  XDrawLine (dpy, Scr.Root, Scr.HintsGC, x + (w + offsetw) / 2 + 5,
+	     y + h + 10, x + w - 15, y + h + 10);
+  XDrawLine (dpy, Scr.Root, Scr.HintsGC, x + w + 10, y + 15, x + w + 10,
+	     y + (h - Scr.StdFont.height) / 2 - 5);
+  XDrawLine (dpy, Scr.Root, Scr.HintsGC, x + w + 10,
+	     y + (h + Scr.StdFont.height) / 2 + 5, x + w + 10, y + h - 15);
 }
