@@ -27,13 +27,15 @@
 #include "parse.h"
 #include "screen.h"
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 void
 ProcessNewStyle (XEvent * eventp,
 		 Window w,
 		 XfwmWindow * tmp_win,
-		 unsigned long context,
-		 char *text,
-		 int *Module)
+		 unsigned long context, char *text, int *Module)
 {
   char *name, *line, *restofline, *tmp;
   char *icon_name = NULL;
@@ -67,11 +69,6 @@ ProcessNewStyle (XEvent * eventp,
       switch (tolower (restofline[0]))
 	{
 	case 'a':
-	  if (mystrncasecmp (restofline, "activeplacement", 15) == 0)
-	    {
-	      restofline += 15;
-	      on_flags |= RANDOM_PLACE_FLAG;
-	    }
 	  break;
 	case 'b':
 	  if (mystrncasecmp (restofline, "borderwidth", 11) == 0)
@@ -79,8 +76,9 @@ ProcessNewStyle (XEvent * eventp,
 	      restofline += 11;
 	      off_flags |= BW_FLAG;
 	      sscanf (restofline, "%d", &bw);
-              /* Avoid border width = 1, use 0 or >= 2 */
-              if (bw == 1) bw = 2;
+	      /* Avoid border width = 1, use 0 or >= 2 */
+	      if (bw == 1)
+		bw = 2;
 	      while (isspace (*restofline))
 		restofline++;
 	      while ((!isspace (*restofline)) && (*restofline != 0) &&
@@ -93,11 +91,6 @@ ProcessNewStyle (XEvent * eventp,
 	case 'c':
 	  break;
 	case 'd':
-	  if (mystrncasecmp (restofline, "dumbplacement", 13) == 0)
-	    {
-	      restofline += 13;
-	      on_flags |= SMART_PLACE_FLAG;
-	    }
 	  break;
 	case 'e':
 	  break;
@@ -108,37 +101,41 @@ ProcessNewStyle (XEvent * eventp,
 	case 'h':
 	  break;
 	case 'i':
-          if(mystrncasecmp(restofline,"icon",4)==0)
-          {
-            restofline +=4;
-            while(isspace(*restofline))restofline++;
-            len = 0;
-	    tmp = restofline;
-	    is_quoted = 0;
-            if (*restofline == '"') {
-              is_quoted = 1;
-              ++restofline;
-            }
-            while((tmp != NULL) && (*tmp != 0)
-		   && (((*tmp != ',') && (*tmp != '\n'))
-		       || ((is_quoted && (*tmp != '\n') && (*tmp != '"')))))
-            {
-              if (!(is_quoted && (*tmp == '"'))) len++;
-	      tmp++;
-            }
-            if(len > 0)
-            {
-              icon_name = safemalloc(len+1);
-              strncpy(icon_name,restofline,len);
-              icon_name[len] = 0;
-              off_flags |= ICON_FLAG;
-              on_flags |= SUPPRESSICON_FLAG;
-              if (is_quoted) tmp++;
-            }
-            else
-              on_flags |= SUPPRESSICON_FLAG;	    
-            restofline = tmp;
-          }
+	  if (mystrncasecmp (restofline, "icon", 4) == 0)
+	    {
+	      restofline += 4;
+	      while (isspace (*restofline))
+		restofline++;
+	      len = 0;
+	      tmp = restofline;
+	      is_quoted = 0;
+	      if (*restofline == '"')
+		{
+		  is_quoted = 1;
+		  ++restofline;
+		}
+	      while ((tmp != NULL) && (*tmp != 0)
+		     && (((*tmp != ',') && (*tmp != '\n'))
+			 || ((is_quoted && (*tmp != '\n') && (*tmp != '"')))))
+		{
+		  if (!(is_quoted && (*tmp == '"')))
+		    len++;
+		  tmp++;
+		}
+	      if (len > 0)
+		{
+		  icon_name = safemalloc (len + 1);
+		  strncpy (icon_name, restofline, len);
+		  icon_name[len] = 0;
+		  off_flags |= ICON_FLAG;
+		  on_flags |= SUPPRESSICON_FLAG;
+		  if (is_quoted)
+		    tmp++;
+		}
+	      else
+		on_flags |= SUPPRESSICON_FLAG;
+	      restofline = tmp;
+	    }
 	  break;
 	case 'j':
 	  break;
@@ -162,19 +159,9 @@ ProcessNewStyle (XEvent * eventp,
 	case 'q':
 	  break;
 	case 'r':
-	  if (mystrncasecmp (restofline, "randomplacement", 15) == 0)
-	    {
-	      restofline += 15;
-	      off_flags |= RANDOM_PLACE_FLAG;
-	    }
 	  break;
 	case 's':
-	  if (mystrncasecmp (restofline, "smartplacement", 14) == 0)
-	    {
-	      restofline += 14;
-	      off_flags |= SMART_PLACE_FLAG;
-	    }
-	  else if (mystrncasecmp (restofline, "stickyicon", 10) == 0)
+	  if (mystrncasecmp (restofline, "stickyicon", 10) == 0)
 	    {
 	      restofline += 10;
 	      off_flags |= STICKY_ICON_FLAG;
@@ -263,7 +250,7 @@ ProcessNewStyle (XEvent * eventp,
     }
 
   AddToList (name, icon_name, off_flags, on_flags, desknumber, bw,
-     forecolor, backcolor, off_buttons, on_buttons);
+	     forecolor, backcolor, off_buttons, on_buttons);
 }
 
 
@@ -276,8 +263,7 @@ AddToList (char *name,
 	   int bw,
 	   char *forecolor,
 	   char *backcolor,
-	   unsigned long off_buttons,
-	   unsigned long on_buttons)
+	   unsigned long off_buttons, unsigned long on_buttons)
 {
   name_list *nptr, *lastptr = NULL;
 
