@@ -14,6 +14,10 @@
 #include "screen.h"
 #include "module.h"
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 /**************************************************************************
  * 
  * Move to a new desktop
@@ -26,11 +30,11 @@ changeDesks_func (XEvent * eventp, Window w, XfwmWindow * tmp_win,
   int n, val1, val1_unit, val2, val2_unit;
 
   n = GetTwoArguments (action, &val1, &val2, &val1_unit, &val2_unit);
-  changeDesks (val1, val2, 1, 1);
+  changeDesks (val1, val2, 1, 1, 1);
 }
 
 void
-changeDesks (int val1, int val2, Bool handle_focus, Bool broadcast)
+changeDesks (int val1, int val2, Bool handle_focus, Bool broadcast, Bool grab)
 {
 
   int oldDesk;
@@ -39,13 +43,14 @@ changeDesks (int val1, int val2, Bool handle_focus, Bool broadcast)
 
   oldDesk = Scr.CurrentDesk;
 
+
   if (val1 != 0)
     {
-      Scr.CurrentDesk = Scr.CurrentDesk + val1; 
+      Scr.CurrentDesk = Scr.CurrentDesk + val1;
       if (Scr.CurrentDesk < 0)
-        Scr.CurrentDesk = Scr.ndesks - 1;
+	Scr.CurrentDesk = Scr.ndesks - 1;
       else if (Scr.CurrentDesk > Scr.ndesks - 1)
-        Scr.CurrentDesk = 0;
+	Scr.CurrentDesk = 0;
     }
   else
     {
@@ -54,11 +59,13 @@ changeDesks (int val1, int val2, Bool handle_focus, Bool broadcast)
 	return;
     }
 
+  if (grab)
+    MyXGrabServer (dpy);
+
   if (broadcast)
-    Broadcast (M_NEW_DESK, 1, Scr.CurrentDesk, 0, 0, 0, 0, 0, 0);
+    Broadcast (XFCE_M_NEW_DESK, 1, Scr.CurrentDesk, 0, 0, 0, 0, 0, 0);
   /* Scan the window list, mapping windows on the new Desk,
    * unmapping windows on the old Desk */
-  MyXGrabServer (dpy);
   for (t = Scr.XfwmRoot.next; t != NULL; t = t->next)
     {
       /* Only change mapping for non-sticky windows */
@@ -100,21 +107,24 @@ changeDesks (int val1, int val2, Bool handle_focus, Bool broadcast)
        * icon */
 
       if (((t->flags & STICKY) || (t->flags & StickyIcon)) &&
-          (t->flags & ICONIFIED) && (!(t->flags & ICON_MOVED)) &&
-          (!(t->flags & ICON_UNMAPPED)) && (!(t->flags & STARTICONIC)))
-        AutoPlace (t, False);
+	  (t->flags & ICONIFIED) && (!(t->flags & ICON_MOVED)) &&
+	  (!(t->flags & ICON_UNMAPPED)) && (!(t->flags & STARTICONIC)))
+	AutoPlace (t, False);
     }
-  MyXUngrabServer (dpy);
 
   if (handle_focus)
     {
-      if (FocusWin)
+      if (!(Scr.Options & ClickToFocus) && (Scr.Options & ForceFocus))
+       	SetFocus (Scr.NoFocusWin, NULL, 1);
+      else if (FocusWin)
 	SetFocus (FocusWin->w, FocusWin, 0);
       else if (StickyWin && (StickyWin->flags && STICKY))
 	SetFocus (StickyWin->w, StickyWin, 1);
       else
 	SetFocus (Scr.NoFocusWin, NULL, 1);
     }
+  if (grab)
+    MyXUngrabServer (dpy);
   XSync (dpy, 0);
 }
 
@@ -163,8 +173,8 @@ changeWindowsDesk (XEvent * eventp, Window w, XfwmWindow * t,
       if (t->Desk == Scr.CurrentDesk)
 	{
 	  t->Desk = val1;
-          if (t->flags & ICONIFIED)
-            LowerWindow(t);
+	  if (t->flags & ICONIFIED)
+	    LowerWindow (t);
 	  UnmapIt (t);
 	}
       else if (val1 == Scr.CurrentDesk)
@@ -172,15 +182,15 @@ changeWindowsDesk (XEvent * eventp, Window w, XfwmWindow * t,
 	  t->Desk = val1;
 	  /* If its an icon, auto-place it */
 	  if (t->flags & ICONIFIED)
-            {
-              if ((!(t->flags & STARTICONIC)) && (!(t->flags & ICON_MOVED)))
-	        AutoPlace (t, False);
-              LowerWindow(t);
-            }
+	    {
+	      if ((!(t->flags & STARTICONIC)) && (!(t->flags & ICON_MOVED)))
+		AutoPlace (t, False);
+	      LowerWindow (t);
+	    }
 	  MapIt (t);
 	}
       else
 	t->Desk = val1;
     }
-  BroadcastConfig (M_CONFIGURE_WINDOW, t);
+  BroadcastConfig (XFCE_M_CONFIGURE_WINDOW, t);
 }
