@@ -27,13 +27,9 @@
 #include "parse.h"
 #include "screen.h"
 
-#if 0
-/* I tried to include "limits.h" to get these values, but it
- * didn't work for some reason */
-/* Minimum and maximum values a `signed int' can hold.  */
-#define MY_INT_MIN (- MY_INT_MAX - 1)
-#define MY_INT_MAX 2147483647
-#endif /* 0 */
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
 
 #define SHOW_GEOMETRY (1<<0)
 #define SHOW_ALLDESKS (1<<1)
@@ -198,8 +194,7 @@ do_windowList (XEvent * eventp, Window w, XfwmWindow * tmp_win,
       for (ii = 0; ii < numWindows; ii++)
 	{
 	  t = windowList[ii];
-	  if ((t->Desk == next_desk) &&
-	      (!(t->flags & WINDOWLISTSKIP)))
+	  if ((t->Desk == next_desk) && (!(t->flags & WINDOWLISTSKIP)))
 	    {
 	      if (!(flags & SHOW_ICONIC) && (t->flags & ICONIFIED))
 		continue;	/* don't want icons - skip */
@@ -209,8 +204,7 @@ do_windowList (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 		continue;	/* don't want ontop ones - skip */
 	      if (!(flags & SHOW_NORMAL) &&
 		  !((t->flags & ICONIFIED) ||
-		    (t->flags & STICKY) ||
-		    (t->flags & ONTOP)))
+		    (t->flags & STICKY) || (t->flags & ONTOP)))
 		continue;	/* don't want "normal" ones - skip */
 
 	      if (++scut == ('9' + 1))
@@ -231,7 +225,8 @@ do_windowList (XEvent * eventp, Window w, XfwmWindow * tmp_win,
 
 		  if (t->flags & ICONIFIED)
 		    strcat (tname, "(");
-		  dheight = t->frame_height - t->title_height - 2 * t->boundary_width;
+		  dheight =
+		    t->frame_height - t->title_height - 2 * t->boundary_width;
 		  dwidth = t->frame_width - 2 * t->boundary_width;
 
 		  dwidth -= t->hints.base_width;
