@@ -22,7 +22,6 @@
 #include <string.h>
 #include <unistd.h>
 #include <stdarg.h>
-#include <locale.h>
 #include <pwd.h>
 #include <sys/types.h>
 
@@ -47,11 +46,19 @@
 #include <sys/systeminfo.h>
 #endif
 
+#ifdef  ENABLE_NLS
+#include "locale.h"
+#endif
+
 #ifdef HAVE_IMLIB
 #include <Imlib.h>
 #include <fcntl.h>
 #endif
 
+#ifdef DMALLOC
+#  include "dmalloc.h"
+#endif
+
 #include "close.xbm"
 #include "iconify.xbm"
 #include "maximize.xbm"
@@ -96,7 +103,7 @@ static void SaveDesktopState (void);
 static void SetMWM_INFO (Window window);
 static void SetRCDefaults (void);
 void StartupStuff (void);
-void initModifiers(void);
+void initModifiers (void);
 
 XContext XfwmContext;		/* context for xfwm windows */
 XContext MenuContext;		/* context for xfwm menus */
@@ -114,6 +121,7 @@ unsigned int AltMask;
 unsigned int MetaMask;
 unsigned int NumLockMask;
 unsigned int ScrollLockMask;
+unsigned int CapsLockMask;
 unsigned int SuperMask;
 unsigned int HyperMask;
 
@@ -163,7 +171,7 @@ int fd_width, x_fd;
 char *display_name = NULL;
 char *client_id = NULL;
 
-char restore_filename [MAXSTRLEN];
+char restore_filename[MAXSTRLEN];
 
 /***********************************************************************
  *
@@ -179,7 +187,7 @@ int
 main (int argc, char **argv)
 {
   XSetWindowAttributes attributes;	/* attributes for create windows */
-  void enterAlarm(int);
+  void enterAlarm (int);
   int i;
   extern int x_fd;
   int len;
@@ -191,8 +199,10 @@ main (int argc, char **argv)
   Bool launch_xfce = True;
   char *temp_path = NULL;
   struct passwd *pwd;
-    
+
+#ifdef  ENABLE_NLS
   setlocale (LC_ALL, "");
+#endif
   bindtextdomain (PACKAGE, XFCE_LOCALE_DIR);
   textdomain (PACKAGE);
 
@@ -220,20 +230,20 @@ main (int argc, char **argv)
 	  launch_xfce = False;
 	}
 #ifdef HAVE_SESSION
-      else if (strncasecmp(argv[i], "-clientId", 9) == 0)
-        {
+      else if (strncasecmp (argv[i], "-clientId", 9) == 0)
+	{
 	  if (++i >= argc)
 	    usage ();
 	  client_id = argv[i];
-        }
+	}
 #endif
-      else if (strncasecmp(argv[i], "-restore", 8) == 0)
-        {
+      else if (strncasecmp (argv[i], "-restore", 8) == 0)
+	{
 	  if (++i >= argc)
-	    usage();
+	    usage ();
 	  strcpy (restore_filename, argv[i]);
-          custom_filename = True;          
-        }
+	  custom_filename = True;
+	}
       else if (mystrncasecmp (argv[i], "-d", 2) == 0)
 	{
 	  if (++i >= argc)
@@ -254,7 +264,8 @@ main (int argc, char **argv)
 	    }
 	  else
 	    {
-	      xfwm_msg (ERR, "main", "only %d -f and -cmd parms allowed!", MAX_CFG_CMDS);
+	      xfwm_msg (ERR, "main", "only %d -f and -cmd parms allowed!",
+			MAX_CFG_CMDS);
 	    }
 	}
       else if (mystrncasecmp (argv[i], "-cmd", 4) == 0)
@@ -268,7 +279,8 @@ main (int argc, char **argv)
 	    }
 	  else
 	    {
-	      xfwm_msg (ERR, "main", "only %d -f and -cmd parms allowed!", MAX_CFG_CMDS);
+	      xfwm_msg (ERR, "main", "only %d -f and -cmd parms allowed!",
+			MAX_CFG_CMDS);
 	    }
 	}
       else if (mystrncasecmp (argv[i], "-outfile", 8) == 0)
@@ -289,7 +301,7 @@ main (int argc, char **argv)
       else if (mystrncasecmp (argv[i], "-version", 8) == 0)
 	{
 	  fprintf (stderr, "Xfwm Version %s compiled on %s at %s\n",
-		    VERSION, __DATE__, __TIME__);
+		   VERSION, __DATE__, __TIME__);
 	  exit (0);
 	}
       else
@@ -314,19 +326,20 @@ main (int argc, char **argv)
   signal (SIGFPE, on_signal);
   signal (SIGUSR1, Restart);
   signal (SIGPIPE, DeadPipe);
-  signal(SIGALRM,enterAlarm);
+  signal (SIGALRM, enterAlarm);
 
   ReapChildren ();
 
   if (!(dpy = XOpenDisplay (display_name)))
     {
-      xfwm_msg (ERR, "main", "can't open display %s", XDisplayName (display_name));
+      xfwm_msg (ERR, "main", "can't open display %s",
+		XDisplayName (display_name));
       exit (1);
     }
   Scr.screen = DefaultScreen (dpy);
   Scr.NumberOfScreens = ScreenCount (dpy);
 
-  initModifiers();
+  initModifiers ();
   master_pid = getpid ();
 
   if (!single)
@@ -357,13 +370,13 @@ main (int argc, char **argv)
 	      dpy = XOpenDisplay (message);
 	      Scr.screen = myscreen;
 	      Scr.NumberOfScreens = ScreenCount (dpy);
-              if ((!custom_filename) && (myscreen != 0))
-                {
-                  char temp[4];
-                  
-                  sprintf (temp, "-%i", (int) Scr.screen);
-                  strcat (restore_filename, temp);
-                }
+	      if ((!custom_filename) && (myscreen != 0))
+		{
+		  char temp[4];
+
+		  sprintf (temp, "-%i", (int) Scr.screen);
+		  strcat (restore_filename, temp);
+		}
 
 	      break;
 	    }
@@ -396,7 +409,8 @@ main (int argc, char **argv)
       char client[MAXHOSTNAME], *rdisplay_string;
       mygethostname (client, MAXHOSTNAME);
       rdisplay_string = safemalloc (len + 14 + strlen (client));
-      sprintf (rdisplay_string, "HOSTDISPLAY=%s:%s", client, &display_string[9]);
+      sprintf (rdisplay_string, "HOSTDISPLAY=%s:%s", client,
+	       &display_string[9]);
       putenv (rdisplay_string);
     }
   else if (strncmp (display_string, "DISPLAY=unix:", 13) == 0)
@@ -419,15 +433,17 @@ main (int argc, char **argv)
   Scr.Root = RootWindow (dpy, Scr.screen);
   if (Scr.Root == None)
     {
-      xfwm_msg (ERR, "main", "Screen %d is not a valid screen", (char *) Scr.screen);
+      xfwm_msg (ERR, "main", "Screen %d is not a valid screen",
+		(char *) Scr.screen);
       exit (1);
     }
 
 #ifdef HAVE_IMLIB
-  imlib_id=Imlib_init(dpy);
+  imlib_id = Imlib_init (dpy);
 #endif
-   
-  ShapesSupported = XShapeQueryExtension (dpy, &ShapeEventBase, &ShapeErrorBase);
+
+  ShapesSupported =
+    XShapeQueryExtension (dpy, &ShapeEventBase, &ShapeErrorBase);
 
   InternUsefulAtoms ();
 
@@ -440,14 +456,29 @@ main (int argc, char **argv)
   XSelectInput (dpy, Scr.Root,
 		LeaveWindowMask | EnterWindowMask | PropertyChangeMask |
 		SubstructureRedirectMask | KeyPressMask |
-		SubstructureNotifyMask |
-                PointerMotionMask |                /* AutoDeskSwitch */
+		SubstructureNotifyMask | PointerMotionMask |	/* AutoDeskSwitch */
 		ButtonPressMask | ButtonReleaseMask);
   XSync (dpy, 0);
 
   XSetErrorHandler ((XErrorHandler) XfwmErrorHandler);
   BlackoutScreen ();		/* if they want to hide the capture/startup */
 
+  /* create a window which will accept the keyboard focus when no other 
+   * windows have it */
+  attributes.event_mask = KeyPressMask | FocusChangeMask;
+  attributes.override_redirect = True;
+  Scr.NoFocusWin = XCreateWindow (dpy, Scr.Root, -10, -10, 10, 10, 0, 0,
+				  InputOnly, CopyFromParent,
+				  CWEventMask | CWOverrideRedirect,
+				  &attributes);
+  XMapWindow (dpy, Scr.NoFocusWin);
+
+  SetMWM_INFO (Scr.NoFocusWin);
+
+  XSetInputFocus (dpy, Scr.NoFocusWin, RevertToParent, CurrentTime);
+
+  XSync (dpy, 0);
+
   CreateCursors ();
   InitVariables ();
   InitEventHandlerJumpTable ();
@@ -470,29 +501,14 @@ main (int argc, char **argv)
     {
       ExecuteFunction (default_config_command, NULL, &Event, C_ROOT, -1);
     }
-  
+
   if (launch_xfce)
     ExecuteFunction ("Module xfce", NULL, &Event, C_ROOT, -1);
 
-  /* create a window which will accept the keyboard focus when no other 
-   * windows have it */
-  attributes.event_mask = KeyPressMask | FocusChangeMask;
-  attributes.override_redirect = True;
-  Scr.NoFocusWin = XCreateWindow (dpy, Scr.Root, -10, -10, 10, 10, 0, 0,
-				  InputOnly, CopyFromParent,
-				  CWEventMask | CWOverrideRedirect,
-				  &attributes);
-  XMapWindow (dpy, Scr.NoFocusWin);
-
-  SetMWM_INFO (Scr.NoFocusWin);
-
-  XSetInputFocus (dpy, Scr.NoFocusWin, RevertToParent, CurrentTime);
-
-  XSync (dpy, 0);
   UnBlackoutScreen ();		/* if we need to remove blackout window */
   if (Scr.Options & SessionMgt)
-    LoadWindowStates(restore_filename);
-  SessionInit(client_id);
+    LoadWindowStates (restore_filename);
+  SessionInit (client_id);
   HandleEvents ();
   return (0);
 }
@@ -515,7 +531,8 @@ StartupStuff (void)
     {
       mr = FindPopup ("RestartFunction");
       if (mr != NULL)
-	ExecuteFunction ("Function RestartFunction", NULL, &Event, C_ROOT, -1);
+	ExecuteFunction ("Function RestartFunction", NULL, &Event, C_ROOT,
+			 -1);
     }
   else
     {
@@ -548,11 +565,8 @@ CaptureAllWindows (void)
   int aformat;
   unsigned long nitems, bytes_remain;
 
-  MyXGrabServer (dpy);
-
   if (!XQueryTree (dpy, Scr.Root, &root, &parent, &children, &nchildren))
     {
-      MyXUngrabServer (dpy);
       return;
     }
 
@@ -594,7 +608,7 @@ CaptureAllWindows (void)
 	    {
 	      XUnmapWindow (dpy, children[i]);
 	      Event.xmaprequest.window = children[i];
-	      HandleMapRequestKeepRaised (BlackoutWin);
+	      HandleMapRequest ();
 	    }
 	}
       Scr.flags |= WindowsCaptured;
@@ -610,10 +624,10 @@ CaptureAllWindows (void)
 			    (caddr_t *) & tmp) != XCNOENT)
 	    {
 	      isIconicState = DontCareState;
-	      if (XGetWindowProperty (dpy, tmp->w, _XA_WM_STATE, 0L, 3L, False,
-				      _XA_WM_STATE,
-			 &atype, &aformat, &nitems, &bytes_remain, &prop) ==
-		  Success)
+	      if (XGetWindowProperty
+		  (dpy, tmp->w, _XA_WM_STATE, 0L, 3L, False, _XA_WM_STATE,
+		   &atype, &aformat, &nitems, &bytes_remain,
+		   &prop) == Success)
 		{
 		  if (prop != NULL)
 		    {
@@ -623,18 +637,23 @@ CaptureAllWindows (void)
 		}
 	      next = tmp->next;
 	      data[0] = (unsigned long) tmp->Desk;
-	      XChangeProperty (dpy, tmp->w, _XA_WM_DESKTOP, _XA_WM_DESKTOP, 32,
-			       PropModeReplace, (unsigned char *) data, 1);
+	      XChangeProperty (dpy, tmp->w, _XA_WM_DESKTOP, _XA_WM_DESKTOP,
+			       32, PropModeReplace, (unsigned char *) data,
+			       1);
 
-              data[0] = (unsigned long) (tmp->flags & (STICKY | ICON_MOVED | SHADED));
-              XChangeProperty (dpy, tmp->w, _XA_XFWM_FLAGS, _XA_XFWM_FLAGS, 32,
-		               PropModeReplace, (unsigned char *) data, 1);
-              data[0] = (unsigned long) tmp->icon_x_loc;
-              XChangeProperty (dpy, tmp->w, _XA_XFWM_ICONPOS_X, _XA_XFWM_ICONPOS_X, 32,
-		               PropModeReplace, (unsigned char *) data, 1);
-              data[0] = (unsigned long) tmp->icon_y_loc;
-              XChangeProperty (dpy, tmp->w, _XA_XFWM_ICONPOS_Y, _XA_XFWM_ICONPOS_Y, 32,
-		               PropModeReplace, (unsigned char *) data, 1);
+	      data[0] =
+		(unsigned long) (tmp->flags & (STICKY | ICON_MOVED | SHADED));
+	      XChangeProperty (dpy, tmp->w, _XA_XFWM_FLAGS, _XA_XFWM_FLAGS,
+			       32, PropModeReplace, (unsigned char *) data,
+			       1);
+	      data[0] = (unsigned long) tmp->icon_x_loc;
+	      XChangeProperty (dpy, tmp->w, _XA_XFWM_ICONPOS_X,
+			       _XA_XFWM_ICONPOS_X, 32, PropModeReplace,
+			       (unsigned char *) data, 1);
+	      data[0] = (unsigned long) tmp->icon_y_loc;
+	      XChangeProperty (dpy, tmp->w, _XA_XFWM_ICONPOS_Y,
+			       _XA_XFWM_ICONPOS_Y, 32, PropModeReplace,
+			       (unsigned char *) data, 1);
 	      XSelectInput (dpy, tmp->w, 0);
 	      w = tmp->w;
 	      XUnmapWindow (dpy, tmp->frame);
@@ -642,7 +661,7 @@ CaptureAllWindows (void)
 	      RestoreWithdrawnLocation (tmp, True);
 	      Destroy (tmp);
 	      Event.xmaprequest.window = w;
-	      HandleMapRequestKeepRaised (BlackoutWin);
+	      HandleMapRequest ();
 	      tmp = next;
 	    }
 	}
@@ -656,9 +675,6 @@ CaptureAllWindows (void)
   /* after the windows already on the screen are in place,
    * don't use PPosition */
   PPosOverride = False;
-  KeepOnTop ();
-  MyXUngrabServer (dpy);
-  XSync (dpy, 0);		/* should we do this on initial capture? */
 }
 
 /*
@@ -670,8 +686,7 @@ static void
 SetRCDefaults ()
 {
   /* set up default colors, fonts, etc */
-  char *defaults[] =
-  {
+  char *defaults[] = {
     "XORValue 0",
     "ModulePath $PATH",
     "ActiveColor white #C0C0C0",
@@ -695,13 +710,12 @@ SetRCDefaults ()
     "WindowFont fixed",
     "MenuFont fixed",
     "Style \"*\" Title, BorderWidth 6",
-    "Style \"*\" RandomPlacement, SmartPlacement",
     "Style \"XFce*\" Sticky",
     "Style \"XFbd*\" Sticky",
     "Style \"Popup*\" Sticky",
     "AddToMenu \"__builtin_exit_menu__\"",
     "+ \"" N_("&Restart") "\" Restart xfwm",
-    "+ \"" N_("&Quit")"\" Quit",
+    "+ \"" N_("&Quit") "\" Quit",
     "+ \"\" Nop",
     "+ \"" N_("&Cancel") "\" Nop",
     "AddToMenu \"__builtin_sendtodesk_menu__\"",
@@ -741,6 +755,10 @@ SetRCDefaults ()
     "+ \"" N_("&Sound...") "\" Exec xfsound",
     "+ \"\" Nop",
     "+ \"" N_("&Quit XFwm") "\" Popup \"__builtin_exit_menu__\"",
+    "AddToMenu \"__Maximize_menu__\"",
+    "+ \"" N_("&Full Screen") "\" Maximize 100 100",
+    "+ \"" N_("&Vertical") "\" Maximize 0   100",
+    "+ \"" N_("&Horizontal") "\" Maximize 100   0",
     "AddToFunc WindowListFunc \"I\" WindowId $0 Iconify -1",
     "+ \"I\" WindowId $0 Focus",
     "+ \"I\" WindowId $0 Raise",
@@ -766,14 +784,16 @@ SetRCDefaults ()
     "AddToFunc \"__builtin_focus_raise__\"",
     "+ \"I\" Focus",
     "+ \"I\" Raise",
-    "AddToFunc \"__builtin_iconify_and_focus__"
-    "+ \"I\" Iconify",
+    "AddToFunc \"__builtin_iconify_and_focus__" "+ \"I\" Iconify",
     "+ \"I\" Current [Iconic] __builtin_Focus_Prev__",
+    "AddToFunc \"__builtin_maximize_function__\"",
+    "+ \"C\" Maximize 100 100",
+    "+ \"M\" PopUp \"__Maximize_menu__\"",
     "Mouse 1 T A Function __Move__",
     "Mouse 2 T A Function __Move__",
     "Mouse 3 T A Shade",
     "Mouse 0 1 A __builtin_windowops_or_die__",
-    "Mouse 0 4 A Maximize",
+    "Mouse 0 4 A __builtin_maximize_function__",
     "Mouse 0 3 A Stick",
     "Mouse 0 6 A Iconify",
     "Mouse 0 5 A Shade",
@@ -781,6 +801,7 @@ SetRCDefaults ()
     "Mouse 0 2 S Destroy",
     "Mouse 0 FS A Function __Resize__",
     "Mouse 1 FS S Move",
+    "Mouse 1 FS M Move",
     "Mouse 2 FS A Move",
     "Mouse 3 FS S Move",
     "Mouse 0 I A Function __Iconfunc__",
@@ -788,6 +809,7 @@ SetRCDefaults ()
     "Mouse 2 R A Menu __builtin_window_menu__ Nop",
     "Mouse 3 I A Menu __builtin_window_menu__ Nop",
     "Mouse 3 R A WindowList",
+    "Mouse 1 W M Move",
     "Key Tab A M Prev [CurrentDesk] __builtin_focus_raise__",
     "Key Tab A SM Next [CurrentDesk] __builtin_focus_raise__",
     "Key Escape A S __builtin_iconify_and_focus__",
@@ -869,7 +891,8 @@ MappedNotOverride (Window w)
     return False;
 
   if (XGetWindowProperty (dpy, w, _XA_WM_STATE, 0L, 3L, False, _XA_WM_STATE,
-		&atype, &aformat, &nitems, &bytes_remain, &prop) == Success)
+			  &atype, &aformat, &nitems, &bytes_remain,
+			  &prop) == Success)
     {
       if (prop != NULL)
 	{
@@ -885,98 +908,103 @@ MappedNotOverride (Window w)
 	  (wa.override_redirect != True));
 }
 
-static KeyCode sym2code(KeySym k) {
-    return XKeysymToKeycode(dpy, k);
+static KeyCode
+sym2code (KeySym k)
+{
+  return XKeysymToKeycode (dpy, k);
 }
 
-void initModifiers() 
+void
+initModifiers ()
 {
-    XModifierKeymap *xmk = XGetModifierMapping(dpy);
-    int m, k;
-    
-    AltMask = MetaMask = NumLockMask = ScrollLockMask = SuperMask = HyperMask = 0;
-    if (xmk) 
-      {
-        KeyCode *c = xmk->modifiermap;
-        KeyCode numLockKeyCode;
-        KeyCode scrollLockKeyCode;
-        KeyCode altKeyCode;
-        KeyCode metaKeyCode;
-        KeyCode superKeyCode;
-        KeyCode hyperKeyCode;
+  XModifierKeymap *xmk = XGetModifierMapping (dpy);
+  int m, k;
 
-        numLockKeyCode = sym2code(XK_Num_Lock);
-        scrollLockKeyCode = sym2code(XK_Scroll_Lock);
-        altKeyCode = sym2code(XK_Alt_L);
-        metaKeyCode = sym2code(XK_Meta_L);
-        superKeyCode = sym2code(XK_Super_L);
-        hyperKeyCode = sym2code(XK_Hyper_L);
+  AltMask = MetaMask = NumLockMask = ScrollLockMask = CapsLockMask =
+    SuperMask = HyperMask = 0;
+  if (xmk)
+    {
+      KeyCode *c = xmk->modifiermap;
+      KeyCode numLockKeyCode;
+      KeyCode scrollLockKeyCode;
+      KeyCode capsLockKeyCode;
+      KeyCode altKeyCode;
+      KeyCode metaKeyCode;
+      KeyCode superKeyCode;
+      KeyCode hyperKeyCode;
 
-        if (!altKeyCode)
-            altKeyCode = sym2code(XK_Alt_R);
-        if (!metaKeyCode)
-            metaKeyCode = sym2code(XK_Meta_R);
-        if (!superKeyCode)
-            superKeyCode = sym2code(XK_Super_R);
-        if (!hyperKeyCode)
-            hyperKeyCode = sym2code(XK_Hyper_R);
+      numLockKeyCode = sym2code (XK_Num_Lock);
+      scrollLockKeyCode = sym2code (XK_Scroll_Lock);
+      capsLockKeyCode = sym2code (XK_Caps_Lock);
+      altKeyCode = sym2code (XK_Alt_L);
+      metaKeyCode = sym2code (XK_Meta_L);
+      superKeyCode = sym2code (XK_Super_L);
+      hyperKeyCode = sym2code (XK_Hyper_L);
+
+      if (!altKeyCode)
+	altKeyCode = sym2code (XK_Alt_R);
+      if (!metaKeyCode)
+	metaKeyCode = sym2code (XK_Meta_R);
+      if (!superKeyCode)
+	superKeyCode = sym2code (XK_Super_R);
+      if (!hyperKeyCode)
+	hyperKeyCode = sym2code (XK_Hyper_R);
 
 
-        for (m = 0; m < 8; m++)
-            for (k = 0; k < xmk->max_keypermod; k++, c++) {
-                if (*c == NoSymbol)
-                    continue;
-                if (*c == numLockKeyCode)
-                    NumLockMask = (1 << m);
-                if (*c == scrollLockKeyCode)
-                    ScrollLockMask = (1 << m);
-                if (*c == altKeyCode)
-                    AltMask = (1 << m);
-                if (*c == metaKeyCode)
-                    MetaMask = (1 << m);
-                if (*c == superKeyCode)
-                    SuperMask = (1 << m);
-                if (*c == hyperKeyCode)
-                    HyperMask = (1 << m);
-            }
+      for (m = 0; m < 8; m++)
+	for (k = 0; k < xmk->max_keypermod; k++, c++)
+	  {
+	    if (*c == NoSymbol)
+	      continue;
+	    if (*c == numLockKeyCode)
+	      NumLockMask = (1 << m);
+	    if (*c == scrollLockKeyCode)
+	      ScrollLockMask = (1 << m);
+	    if (*c == capsLockKeyCode)
+	      CapsLockMask = (1 << m);
+	    if (*c == altKeyCode)
+	      AltMask = (1 << m);
+	    if (*c == metaKeyCode)
+	      MetaMask = (1 << m);
+	    if (*c == superKeyCode)
+	      SuperMask = (1 << m);
+	    if (*c == hyperKeyCode)
+	      HyperMask = (1 << m);
+	  }
+      XFreeModifiermap (xmk);
     }
-    if (MetaMask == AltMask)
-        MetaMask = 0;
+  if (MetaMask == AltMask)
+    MetaMask = 0;
 
-    if ((AltMask != 0) && (MetaMask == Mod1Mask)) {
-        MetaMask = AltMask;
-        AltMask = Mod1Mask;
+  if ((AltMask != 0) && (MetaMask == Mod1Mask))
+    {
+      MetaMask = AltMask;
+      AltMask = Mod1Mask;
     }
 
-    if ((AltMask == 0) && (MetaMask != 0)) {
-        if (MetaMask != Mod1Mask) {
-            AltMask = Mod1Mask;
-        }
-        else {
-            AltMask = MetaMask;
-            MetaMask = 0;
-        }
+  if ((AltMask == 0) && (MetaMask != 0))
+    {
+      if (MetaMask != Mod1Mask)
+	{
+	  AltMask = Mod1Mask;
+	}
+      else
+	{
+	  AltMask = MetaMask;
+	  MetaMask = 0;
+	}
     }
 
-    if (AltMask == 0)
-        AltMask = Mod1Mask;
+  if (AltMask == 0)
+    AltMask = Mod1Mask;
 
-    KeyMask =
-        ControlMask |
-        ShiftMask |
-        AltMask |
-        MetaMask |
-        SuperMask |
-        HyperMask;
+  KeyMask =
+    ControlMask | ShiftMask | AltMask | MetaMask | SuperMask | HyperMask;
 
-    ButtonMask =
-        Button1Mask |
-        Button2Mask |
-        Button3Mask |
-        Button4Mask |
-        Button5Mask;
+  ButtonMask =
+    Button1Mask | Button2Mask | Button3Mask | Button4Mask | Button5Mask;
 
-    ButtonKeyMask = KeyMask | ButtonMask;
+  ButtonKeyMask = KeyMask | ButtonMask;
 }
 
 static void
@@ -1015,9 +1043,9 @@ InternUsefulAtoms (void)
   _XA_WIN_WORKSPACE_COUNT = XInternAtom (dpy, "_WIN_WORKSPACE_COUNT", False);
   _XA_WIN_WORKSPACE = XInternAtom (dpy, "_WIN_WORKSPACE", False);
 
-  _XA_WM_WINDOW_ROLE=XInternAtom(dpy, "WM_WINDOW_ROLE",False);
-  _XA_WM_CLIENT_LEADER=XInternAtom(dpy, "WM_CLIENT_LEADER",False);
-  _XA_SM_CLIENT_ID=XInternAtom(dpy, "SM_CLIENT_ID",False);
+  _XA_WM_WINDOW_ROLE = XInternAtom (dpy, "WM_WINDOW_ROLE", False);
+  _XA_WM_CLIENT_LEADER = XInternAtom (dpy, "WM_CLIENT_LEADER", False);
+  _XA_SM_CLIENT_ID = XInternAtom (dpy, "SM_CLIENT_ID", False);
 
   return;
 }
@@ -1108,8 +1136,10 @@ CreateCursors (void)
   Scr.XfwmCursors[BOTTOM] = XCreateFontCursor (dpy, XC_bottom_side);
   Scr.XfwmCursors[TOP_LEFT] = XCreateFontCursor (dpy, XC_top_left_corner);
   Scr.XfwmCursors[TOP_RIGHT] = XCreateFontCursor (dpy, XC_top_right_corner);
-  Scr.XfwmCursors[BOTTOM_LEFT] = XCreateFontCursor (dpy, XC_bottom_left_corner);
-  Scr.XfwmCursors[BOTTOM_RIGHT] = XCreateFontCursor (dpy, XC_bottom_right_corner);
+  Scr.XfwmCursors[BOTTOM_LEFT] =
+    XCreateFontCursor (dpy, XC_bottom_left_corner);
+  Scr.XfwmCursors[BOTTOM_RIGHT] =
+    XCreateFontCursor (dpy, XC_bottom_right_corner);
 }
 
 /***********************************************************************
@@ -1141,7 +1171,9 @@ LoadDefaultLeftButton (ButtonFace * bf, int i)
       bf->vector.y[4] = 42;
       bf->vector.line_style[4] = 1;
       bf->vector.num = 5;
-      bf->bitmap = XCreateBitmapFromData(dpy, Scr.Root, menu_bits, menu_width, menu_height);
+      bf->bitmap =
+	XCreateBitmapFromData (dpy, Scr.Root, menu_bits, menu_width,
+			       menu_height);
       bf->bitmap_pressed = None;
       break;
     case 1:
@@ -1173,8 +1205,12 @@ LoadDefaultLeftButton (ButtonFace * bf, int i)
       bf->vector.y[8] = 20;
       bf->vector.line_style[8] = 1;
       bf->vector.num = 9;
-      bf->bitmap = XCreateBitmapFromData(dpy, Scr.Root, stick_bits, stick_width, stick_height);
-      bf->bitmap_pressed = XCreateBitmapFromData(dpy, Scr.Root, stick_pressed_bits, stick_pressed_width, stick_pressed_height);
+      bf->bitmap =
+	XCreateBitmapFromData (dpy, Scr.Root, stick_bits, stick_width,
+			       stick_height);
+      bf->bitmap_pressed =
+	XCreateBitmapFromData (dpy, Scr.Root, stick_pressed_bits,
+			       stick_pressed_width, stick_pressed_height);
       break;
     case 2:
       bf->vector.x[0] = 20;
@@ -1217,8 +1253,12 @@ LoadDefaultLeftButton (ButtonFace * bf, int i)
       bf->vector.y[12] = 36;
       bf->vector.line_style[12] = 0;
       bf->vector.num = 13;
-      bf->bitmap = XCreateBitmapFromData(dpy, Scr.Root, shade_bits, shade_width, shade_height);
-      bf->bitmap_pressed = XCreateBitmapFromData(dpy, Scr.Root, shade_pressed_bits, shade_pressed_width, shade_pressed_height);
+      bf->bitmap =
+	XCreateBitmapFromData (dpy, Scr.Root, shade_bits, shade_width,
+			       shade_height);
+      bf->bitmap_pressed =
+	XCreateBitmapFromData (dpy, Scr.Root, shade_pressed_bits,
+			       shade_pressed_width, shade_pressed_height);
       break;
     default:
       break;
@@ -1278,7 +1318,9 @@ LoadDefaultRightButton (ButtonFace * bf, int i)
       bf->vector.y[12] = 20;
       bf->vector.line_style[12] = 1;
       bf->vector.num = 13;
-      bf->bitmap = XCreateBitmapFromData(dpy, Scr.Root, close_bits, close_width, close_height);
+      bf->bitmap =
+	XCreateBitmapFromData (dpy, Scr.Root, close_bits, close_width,
+			       close_height);
       bf->bitmap_pressed = None;
       break;
     case 1:
@@ -1298,8 +1340,13 @@ LoadDefaultRightButton (ButtonFace * bf, int i)
       bf->vector.y[4] = 20;
       bf->vector.line_style[4] = 1;
       bf->vector.num = 5;
-      bf->bitmap = XCreateBitmapFromData(dpy, Scr.Root, maximize_bits, maximize_width, maximize_height);
-      bf->bitmap_pressed = XCreateBitmapFromData(dpy, Scr.Root, maximize_pressed_bits, maximize_pressed_width, maximize_pressed_height);
+      bf->bitmap =
+	XCreateBitmapFromData (dpy, Scr.Root, maximize_bits, maximize_width,
+			       maximize_height);
+      bf->bitmap_pressed =
+	XCreateBitmapFromData (dpy, Scr.Root, maximize_pressed_bits,
+			       maximize_pressed_width,
+			       maximize_pressed_height);
       break;
     case 2:
       bf->vector.x[0] = 42;
@@ -1318,7 +1365,9 @@ LoadDefaultRightButton (ButtonFace * bf, int i)
       bf->vector.y[4] = 42;
       bf->vector.line_style[4] = 1;
       bf->vector.num = 5;
-      bf->bitmap = XCreateBitmapFromData(dpy, Scr.Root, iconify_bits, iconify_width, iconify_height);
+      bf->bitmap =
+	XCreateBitmapFromData (dpy, Scr.Root, iconify_bits, iconify_width,
+			       iconify_height);
       bf->bitmap_pressed = None;
       break;
     default:
@@ -1338,9 +1387,9 @@ LoadDefaultButton (ButtonFace * bf, int i)
   bf->bitmap = None;
   bf->bitmap_pressed = None;
   if (i & 1)
-    LoadDefaultRightButton(bf, i / 2);
+    LoadDefaultRightButton (bf, i / 2);
   else
-    LoadDefaultLeftButton(bf, i / 2);
+    LoadDefaultLeftButton (bf, i / 2);
 }
 
 extern void FreeButtonFace (Display * dpy, ButtonFace * bf);
@@ -1377,8 +1426,8 @@ ResetAllButtons (XfwmDecor * fl)
   fl->left_buttons[0].flags |= MWMDecorMenu;
   fl->left_buttons[1].flags |= DecorSticky;
   fl->left_buttons[2].flags |= DecorShaded;
-  /* Treat "close" button similar to menu button for Motif hints*/
-  fl->right_buttons[0].flags |= MWMDecorMenu; 
+  /* Treat "close" button similar to menu button for Motif hints */
+  fl->right_buttons[0].flags |= MWMDecorMenu;
   fl->right_buttons[1].flags |= MWMDecorMaximize;
   fl->right_buttons[2].flags |= MWMDecorMinimize;
 }
@@ -1444,6 +1493,8 @@ InitXfwmDecor (XfwmDecor * fl)
   int i;
   ButtonFace tmpbf;
 
+  fl->WindowFont.font = NULL;
+  fl->WindowFont.fontset = NULL;
   fl->HiReliefGC = NULL;
   fl->HiShadowGC = NULL;
   fl->LoReliefGC = NULL;
@@ -1511,7 +1562,7 @@ InitVariables (void)
 
   Scr.DefaultIcon = NULL;
   Scr.TransMaskGC = (GC) NULL;
-  Scr.DrawGC = (GC) NULL;  
+  Scr.DrawGC = (GC) NULL;
   Scr.MenuGC = (GC) NULL;
   Scr.MenuSelGC = (GC) NULL;
   Scr.MenuReliefGC = (GC) NULL;
@@ -1520,7 +1571,7 @@ InitVariables (void)
   Scr.ScratchGC3 = (GC) NULL;
   Scr.BlackGC = (GC) NULL;
   Scr.HintsGC = (GC) NULL;
- 
+
   /* create graphics contexts */
   CreateGCs ();
 
@@ -1541,7 +1592,7 @@ InitVariables (void)
   Scr.CornerWidth = CORNER_WIDTH;
   Scr.Hilite = NULL;
   Scr.Focus = NULL;
-  Scr.Options = (ClickToFocus | AnimateWin | BitmapButtons);
+  Scr.Options = (ClickToFocus | AnimateWin | BitmapButtons | ForceFocus);
   Scr.AutoRaiseDelay = 200;
   Scr.iconbox = 0;
   Scr.StdFont.font = NULL;
@@ -1568,6 +1619,7 @@ InitVariables (void)
 	  {
 	    Restarting = True;
 	    Scr.CurrentDesk = *(unsigned long *) prop;
+	    XFree (prop);
 	  }
       }
     /* The gnome-compatible properties shall override others -gud */
@@ -1579,18 +1631,23 @@ InitVariables (void)
 	  {
 	    Restarting = True;
 	    Scr.CurrentDesk = *(unsigned long *) prop;
-                        	if (Scr.CurrentDesk > 10) Scr.CurrentDesk = 1;
+	    if (Scr.CurrentDesk > NBSCREENS)
+	      Scr.CurrentDesk = 1;
+	    XFree (prop);
 	  }
       }
-    if ((XGetWindowProperty (dpy, Scr.Root, _XA_WIN_WORKSPACE_COUNT, 0L, 1L, False,
-			     XA_CARDINAL, &atype, &aformat, &nitems,
-			     &bytes_remain, &prop)) == Success)
+    if (
+	(XGetWindowProperty
+	 (dpy, Scr.Root, _XA_WIN_WORKSPACE_COUNT, 0L, 1L, False, XA_CARDINAL,
+	  &atype, &aformat, &nitems, &bytes_remain, &prop)) == Success)
       {
 	if (prop != NULL)
 	  {
 	    Restarting = True;
 	    Scr.ndesks = *(unsigned long *) prop;
-            if (Scr.ndesks > 10) Scr.ndesks = 10;
+	    if (Scr.ndesks > NBSCREENS)
+	      Scr.ndesks = NBSCREENS;
+	    XFree (prop);
 	  }
       }
   }
@@ -1608,7 +1665,7 @@ InitVariables (void)
 
   Scr.SnapSize = 10;
   Scr.sessionwait = 10;
-  
+
   /* Not the right place for this, should only be called once somewhere .. */
   InitPictureCMap (dpy, Scr.Root);
 
@@ -1657,6 +1714,18 @@ SigDone (int nonsense)
   SIGNAL_RETURN;
 }
 
+void
+FreeWindowName (void)
+{
+  XfwmWindow *t;
+
+  for (t = Scr.XfwmRoot.next; t != NULL; t = t->next)
+    {
+      free_window_names (t, True, True);
+    }
+}
+
+
 void
 Done (int restart, char *command)
 {
@@ -1669,7 +1738,7 @@ Done (int restart, char *command)
   if (!restart)
     {
       /* LogoutICEConn(); */
-      CloseICEConn();
+      CloseICEConn ();
     }
 
   /* Close all my pipes */
@@ -1679,32 +1748,49 @@ Done (int restart, char *command)
 
   /* Cleanup stuff (avoid memory leak) */
 
-  if (ModulePath) free(ModulePath);
+  if (ModulePath)
+    free (ModulePath);
 
-  if (Scr.TransMaskGC) 		XFreeGC(dpy, Scr.TransMaskGC);
-  if (Scr.DrawGC) 		XFreeGC(dpy, Scr.DrawGC);  
-  if (Scr.MenuGC) 		XFreeGC(dpy, Scr.MenuGC);
-  if (Scr.MenuSelGC) 		XFreeGC(dpy, Scr.MenuSelGC);
-  if (Scr.MenuReliefGC) 	XFreeGC(dpy, Scr.MenuReliefGC);
-  if (Scr.MenuShadowGC) 	XFreeGC(dpy, Scr.MenuShadowGC);
-  if (Scr.ScratchGC1) 		XFreeGC(dpy, Scr.ScratchGC1);
-  if (Scr.ScratchGC3) 		XFreeGC(dpy, Scr.ScratchGC3);
-  if (Scr.BlackGC)   		XFreeGC(dpy, Scr.BlackGC);
-  if (Scr.HintsGC)   		XFreeGC(dpy, Scr.HintsGC);
-  
-  mr=Scr.AllMenus;
+  if (Scr.TransMaskGC)
+    XFreeGC (dpy, Scr.TransMaskGC);
+  if (Scr.DrawGC)
+    XFreeGC (dpy, Scr.DrawGC);
+  if (Scr.MenuGC)
+    XFreeGC (dpy, Scr.MenuGC);
+  if (Scr.MenuSelGC)
+    XFreeGC (dpy, Scr.MenuSelGC);
+  if (Scr.MenuReliefGC)
+    XFreeGC (dpy, Scr.MenuReliefGC);
+  if (Scr.MenuShadowGC)
+    XFreeGC (dpy, Scr.MenuShadowGC);
+  if (Scr.ScratchGC1)
+    XFreeGC (dpy, Scr.ScratchGC1);
+  if (Scr.ScratchGC3)
+    XFreeGC (dpy, Scr.ScratchGC3);
+  if (Scr.BlackGC)
+    XFreeGC (dpy, Scr.BlackGC);
+  if (Scr.HintsGC)
+    XFreeGC (dpy, Scr.HintsGC);
+
+  mr = Scr.AllMenus;
   while (mr)
     {
-      DestroyMenu( mr );
+      DestroyMenu (mr);
       mr = mr->next;
     }
 
-  if (Scr.StdFont.font) XFreeFont(dpy, Scr.StdFont.font);
-  if (Scr.StdFont.fontset) XFreeFontSet(dpy, Scr.StdFont.fontset);
-  if (Scr.IconFont.font) XFreeFont(dpy, Scr.IconFont.font);
-  if (Scr.IconFont.fontset) XFreeFontSet(dpy, Scr.IconFont.fontset);
-  if (Scr.WindowFont.font) XFreeFont(dpy, Scr.WindowFont.font);
-  if (Scr.WindowFont.fontset) XFreeFontSet(dpy, Scr.WindowFont.fontset);
+  if (Scr.StdFont.font)
+    XFreeFont (dpy, Scr.StdFont.font);
+  if (Scr.StdFont.fontset)
+    XFreeFontSet (dpy, Scr.StdFont.fontset);
+  if (Scr.IconFont.font)
+    XFreeFont (dpy, Scr.IconFont.font);
+  if (Scr.IconFont.fontset)
+    XFreeFontSet (dpy, Scr.IconFont.fontset);
+  if (Scr.WindowFont.font)
+    XFreeFont (dpy, Scr.WindowFont.font);
+  if (Scr.WindowFont.fontset)
+    XFreeFontSet (dpy, Scr.WindowFont.fontset);
 
   /* Take time to save the current session (if ICE is not available) */
 
@@ -1712,9 +1798,10 @@ Done (int restart, char *command)
     builtin_save_session ();
 
   /* Free up structure allocated by session management */
-  FreeWindowStates();
+  FreeWindowStates ();
 
   DestroyXfwmDecor (&Scr.DefaultDecor);
+  FreeWindowName ();
 
   if (restart)
     {
@@ -1754,8 +1841,8 @@ Done (int restart, char *command)
 	ReapChildren ();
 	execvp (command, my_argv);
       }
-      xfwm_msg (ERR, "Done", "Call of '%s' failed!!!! (restarting '%s' instead)",
-		command,
+      xfwm_msg (ERR, "Done",
+		"Call of '%s' failed!!!! (restarting '%s' instead)", command,
 		g_argv[0]);
       execvp (g_argv[0], g_argv);	/* that _should_ work */
       xfwm_msg (ERR, "Done", "Call of '%s' failed!!!!", g_argv[0]);
@@ -1804,11 +1891,13 @@ XfwmErrorHandler (Display * dpy, XErrorEvent * event)
 
   /* some errors are acceptable, mostly they're caused by 
    * trying to update a lost  window */
-  if ((event->error_code == BadWindow) || (event->request_code == X_GetGeometry) ||
-      (event->error_code == BadDrawable) || (event->request_code == X_SetInputFocus) ||
-      (event->request_code == X_GrabButton) ||
-      (event->request_code == X_ChangeWindowAttributes) ||
-      (event->request_code == X_InstallColormap))
+  if ((event->error_code == BadWindow)
+      || (event->request_code == X_GetGeometry)
+      || (event->error_code == BadDrawable)
+      || (event->request_code == X_SetInputFocus)
+      || (event->request_code == X_GrabButton)
+      || (event->request_code == X_ChangeWindowAttributes)
+      || (event->request_code == X_InstallColormap))
     return 0;
 
 
@@ -1816,9 +1905,7 @@ XfwmErrorHandler (Display * dpy, XErrorEvent * event)
   xfwm_msg (ERR, "XfwmErrorHandler", "*** internal error ***");
   xfwm_msg (ERR, "XfwmErrorHandler", "%s", buf);
   xfwm_msg (ERR, "XfwmErrorHandler", "Request %d, Error %d, EventType: %d",
-	    event->request_code,
-	    event->error_code,
-	    last_event_type);
+	    event->request_code, event->error_code, last_event_type);
   return 0;
 }
 
@@ -1826,8 +1913,10 @@ void
 usage (void)
 {
   fprintf (stderr, "\nXfwm Version %s Usage:\n\n", VERSION);
-  fprintf (stderr, "  %s [-d dpy] [-f config_cmd] [-s] [-blackout] [-version] [-h]\n"
-                   "  [ -noxfce ] [ -sync ] [ -clientId n] [ -restore ]\n\n", g_argv[0]);
+  fprintf (stderr,
+	   "  %s [-d dpy] [-f config_cmd] [-s] [-blackout] [-version] [-h]\n"
+	   "  [ -noxfce ] [ -sync ] [ -clientId n] [ -restore ]\n\n",
+	   g_argv[0]);
   fprintf (stderr, "  -blackout Blackout screen at startup\n");
   fprintf (stderr, "  -cmd      Specify the command to run as startup\n");
   fprintf (stderr, "  -d        Specify the display to connect\n");
@@ -1856,7 +1945,10 @@ SaveDesktopState ()
       data[0] = (unsigned long) t->Desk;
       XChangeProperty (dpy, t->w, _XA_WM_DESKTOP, _XA_WM_DESKTOP, 32,
 		       PropModeReplace, (unsigned char *) data, 1);
-      data[0] = (unsigned long) (t->flags & (STICKY | ICONIFIED| ICON_MOVED | SHADED | WM_NAME_CHANGED));
+      data[0] =
+	(unsigned long) (t->flags &
+			 (STICKY | ICONIFIED | ICON_MOVED | SHADED |
+			  WM_NAME_CHANGED));
       XChangeProperty (dpy, t->w, _XA_XFWM_FLAGS, _XA_XFWM_FLAGS, 32,
 		       PropModeReplace, (unsigned char *) data, 1);
       data[0] = (unsigned long) t->icon_x_loc;
@@ -1882,13 +1974,14 @@ SetMWM_INFO (Window window)
   {
     long flags;
     Window win;
-  }  motif_wm_info;
+  }
+  motif_wm_info;
 
-  motif_wm_info.flags     = 2;
+  motif_wm_info.flags = 2;
   motif_wm_info.win = window;
 
-  XChangeProperty(dpy,Scr.Root,_XA_MOTIF_WM,_XA_MOTIF_WM,32,
-		  PropModeReplace,(unsigned char *)&motif_wm_info,2);
+  XChangeProperty (dpy, Scr.Root, _XA_MOTIF_WM, _XA_MOTIF_WM, 32,
+		   PropModeReplace, (unsigned char *) &motif_wm_info, 2);
 }
 
 void
@@ -1905,9 +1998,7 @@ BlackoutScreen ()
       attributes.bit_gravity = NorthWestGravity;
       attributes.override_redirect = True;	/* is override redirect needed? */
       valuemask = CWBorderPixel |
-	CWBackPixel |
-	CWBitGravity |
-	CWOverrideRedirect;
+	CWBackPixel | CWBitGravity | CWOverrideRedirect;
       BlackoutWin = XCreateWindow (dpy, Scr.Root, 0, 0,
 				   DisplayWidth (dpy, Scr.screen),
 				   DisplayHeight (dpy, Scr.screen), 0,
