@@ -110,104 +110,106 @@
 #define C_ALL   (C_WINDOW|C_TITLE|C_ICON|C_ROOT|C_FRAME|C_SIDEBAR|\
                  C_L1|C_L2|C_L3|C_L4|C_L5|C_R1|C_R2|C_R3|C_R4|C_R5)
 
-#define XFWM_HALT    0  /* Quit */
-#define XFWM_RESTART 1  /* Restart */
-#define XFWM_END     2  /* Session mgt terminating */
+#define XFWM_HALT    0		/* Quit */
+#define XFWM_RESTART 1		/* Restart */
+#define XFWM_END     2		/* Session mgt terminating */
 
 typedef struct MyFont
-  {
-    XFontStruct *font;		/* font structure */
-    XFontSet fontset;           /* fontset for multi-language */
-    int height;			/* height of the font */
-    int y;			/* Y coordinate to draw characters */
-  }
+{
+  XFontStruct *font;		/* font structure */
+  XFontSet fontset;		/* fontset for multi-language */
+  int height;			/* height of the font */
+  int y;			/* Y coordinate to draw characters */
+}
 MyFont;
 
 typedef struct ColorPair
-  {
-    Pixel fore;
-    Pixel back;
-  }
+{
+  Pixel fore;
+  Pixel back;
+}
 ColorPair;
 
 /* for each window that is on the display, one of these structures
  * is allocated and linked into a list 
  */
 typedef struct XfwmWindow
-  {
-    struct XfwmWindow *next;	/* next xfwm window */
-    struct XfwmWindow *prev;	/* prev xfwm window */
-    Window w;			/* the child window */
-    int old_bw;			/* border width before reparenting */
-    Window frame;		/* the frame window */
-    Window title_w;		/* the title bar window */
-    Window sides[4];
-    Window corners[4];		/* Corner pieces */
-    int nr_left_buttons;
-    int nr_right_buttons;
-    Window left_w[3];
-    Window right_w[3];
-    Window icon_w;		/* the icon window */
-    Window icon_pixmap_w;	/* the icon window */
-    int wShaped;		/* is this a shaped window */
-    int frame_x;		/* x position of frame */
-    int frame_y;		/* y position of frame */
-    int frame_width;		/* width of frame */
-    int frame_height;		/* height of frame */
-    int boundary_width;
-    int corner_width;
-    int bw;
-    int title_x;
-    int title_y;
-    int title_height;		/* height of the title bar */
-    int title_width;		/* width of the title bar */
-    int icon_x_loc;		/* icon window x coordinate */
-    int icon_xl_loc;		/* icon label window x coordinate */
-    int icon_y_loc;		/* icon window y coordiante */
-    int icon_w_width;		/* width of the icon window */
-    int icon_w_height;		/* height of the icon window */
-    int icon_t_width;		/* width of the icon title window */
-    int icon_p_width;		/* width of the icon pixmap window */
-    int icon_p_height;		/* height of the icon pixmap window */
-    int shade_x;		/* shaded window x coordinate */
-    int shade_y;		/* shaded window y coordiante */
-    int shade_width;		/* width of the shaded window */
-    int shade_height;		/* height of the shaded window */
-    Bool icon_arranged;		/* internal flag */
-    Pixmap iconPixmap;		/* pixmap for the icon */
-    int iconDepth;		/* Drawable depth for the icon */
-    Pixmap icon_maskPixmap;	/* pixmap for the icon mask */
-    char *name;			/* name of the window */
-    char *icon_name;		/* name of the icon */
-    XWindowAttributes attr;	/* the child window attributes */
-    XSizeHints hints;		/* normal hints */
-    XWMHints *wmhints;		/* WM hints */
-    XClassHint class;
-    int Desk;			/* Tells which desktop this window is on */
-    int FocusDesk;		/* Where (if at all) was it focussed */
-    int DeIconifyDesk;		/* Desk to deiconify to, for StubbornIcons */
-    Window transientfor;
+{
+  struct XfwmWindow *next;	/* next xfwm window */
+  struct XfwmWindow *prev;	/* prev xfwm window */
+  Window w;			/* the child window */
+  int old_bw;			/* border width before reparenting */
+  Window frame;			/* the frame window */
+  Window Parent;		/* Parent window. Mandatory as MWM is designed like this */
+  Window title_w;		/* the title bar window */
+  Window sides[4];
+  Window corners[4];		/* Corner pieces */
+  int nr_left_buttons;
+  int nr_right_buttons;
+  Window left_w[3];
+  Window right_w[3];
+  Window icon_w;		/* the icon window */
+  Window icon_pixmap_w;		/* the icon window */
+  int wShaped;			/* is this a shaped window */
+  int frame_x;			/* x position of frame */
+  int frame_y;			/* y position of frame */
+  int frame_width;		/* width of frame */
+  int frame_height;		/* height of frame */
+  int boundary_width;
+  int corner_width;
+  int bw;
+  int title_x;
+  int title_y;
+  int title_height;		/* height of the title bar */
+  int title_width;		/* width of the title bar */
+  int icon_x_loc;		/* icon window x coordinate */
+  int icon_xl_loc;		/* icon label window x coordinate */
+  int icon_y_loc;		/* icon window y coordiante */
+  int icon_w_width;		/* width of the icon window */
+  int icon_w_height;		/* height of the icon window */
+  int icon_t_width;		/* width of the icon title window */
+  int icon_p_width;		/* width of the icon pixmap window */
+  int icon_p_height;		/* height of the icon pixmap window */
+  int shade_x;			/* shaded window x coordinate */
+  int shade_y;			/* shaded window y coordiante */
+  int shade_width;		/* width of the shaded window */
+  int shade_height;		/* height of the shaded window */
+  Bool icon_arranged;		/* internal flag */
+  Bool triggered;		/* internal flag */
+  Pixmap iconPixmap;		/* pixmap for the icon */
+  int iconDepth;		/* Drawable depth for the icon */
+  Pixmap icon_maskPixmap;	/* pixmap for the icon mask */
+  char *name;			/* name of the window */
+  char *icon_name;		/* name of the icon */
+  XWindowAttributes attr;	/* the child window attributes */
+  XSizeHints hints;		/* normal hints */
+  XWMHints *wmhints;		/* WM hints */
+  XClassHint class;
+  int Desk;			/* Tells which desktop this window is on */
+  int FocusDesk;		/* Where (if at all) was it focussed */
+  int DeIconifyDesk;		/* Desk to deiconify to, for StubbornIcons */
+  Window transientfor;
 
-    unsigned long flags;
-    
-    char *icon_bitmap_file;
+  unsigned long flags;
 
-    int orig_x;			/* unmaximized x coordinate */
-    int orig_y;			/* unmaximized y coordinate */
-    int orig_wd;		/* unmaximized window width */
-    int orig_ht;		/* unmaximized window height */
+  char *icon_bitmap_file;
 
-    int xdiff, ydiff;		/* used to restore window position on exit */
-    int *mwm_hints;
-    int ol_hints;
-    int kde_hints;
-    int functions;
-    Window *cmap_windows;	/* Colormap windows property */
-    int number_cmap_windows;	/* Should generally be 0 */
-    Pixel TextPixel;
-    Pixel BackPixel;
-    unsigned long buttons;
-  }
+  int orig_x;			/* unmaximized x coordinate */
+  int orig_y;			/* unmaximized y coordinate */
+  int orig_wd;			/* unmaximized window width */
+  int orig_ht;			/* unmaximized window height */
+
+  int xdiff, ydiff;		/* used to restore window position on exit */
+  int *mwm_hints;
+  int ol_hints;
+  int kde_hints;
+  int functions;
+  Window *cmap_windows;		/* Colormap windows property */
+  int number_cmap_windows;	/* Should generally be 0 */
+  Pixel TextPixel;
+  Pixel BackPixel;
+  unsigned long buttons;
+}
 XfwmWindow;
 
 /***************************************************************************
@@ -242,7 +244,7 @@ XfwmWindow;
 #define ICON_MOVED              (1<<24)
 #define ICON_UNMAPPED           (1<<25)
 #define MAP_PENDING             (1<<26)
-#define RAISEDWIN               (1<<27) /* Used for autoraise facility */
+#define RAISEDWIN               (1<<27)	/* Used for autoraise facility */
 #define SHADED                  (1<<28)
 #define WM_NAME_CHANGED         (1<<29)
 
@@ -255,6 +257,8 @@ XfwmWindow;
 #define ResizeOpaqueWin         (1<<4)
 #define SessionMgt              (1<<5)
 #define BitmapButtons           (1<<6)
+#define ForceFocus           	(1<<7)
+#define ClickRaise	        (1<<8)
 
 
 #define ALL_COMMON_FLAGS (STARTICONIC|ONTOP|STICKY|WINDOWLISTSKIP| \
@@ -333,8 +337,9 @@ extern unsigned int ButtonKeyMask;
 extern unsigned int AltMask;
 extern unsigned int MetaMask;
 extern unsigned int NumLockMask;
+extern unsigned int CapsLockMask;
 extern unsigned int ScrollLockMask;
 extern unsigned int SuperMask;
 extern unsigned int HyperMask;
-    
+
 #endif /* _XFWM_ */
